searchData={"items":[{"type":"module","title":"Fledex","doc":"This module should provide some simple macros that allow to define the\nled strip and to update it. The code you would write (in livebook) would\nlook something like the following:\n``` elixir\n  use Fledex\n  led_strip :strip_name, Kino do\n    animation :john do\n      config = [\n        num_leds: 50,\n        reversed: true\n      ]\n\n      leds(50)\n        |> rainbow(config)\n    end\n  end\n```","ref":"Fledex.html"},{"type":"macro","title":"Fledex.__using__/1","doc":"By `use`-ing this module, the `Fledex` macros are made available.\n\nThis macro does also import `Crontab.CronExpression`, `Fledex.Leds`, `Fledex.Color.Names`,\nand `Fledex.Utils.PubSub`. Therefore the functions from those modules are directly\navailable without namespace.\n\nTake a look at the various [livebook examples](readme-2.html) on how to use the Fledex macros","ref":"Fledex.html#__using__/1"},{"type":"macro","title":"Fledex.animation/3","doc":"This introduces a new `animation` (animation) that will be played over\n  and over again until it is changed.\n\n  Therefore we give it a name to know whether it changes. The `do ... end` block\n  needs to define a function. This function receives a trigger as argument, but\n  you have two possbilities to implement it.\n\n  * Either you pattern match on the triggers, e.g. something like the following:\n  ```elixir\n  led_strip :strip, Kino do\n    animation :name do\n      %{strip: counter} ->\n        do_something_with_the_counter(counter)\n      triggers ->\n        # During init it can happen that the strip trigger is not available yet\n        do_something_during init_phase(triggers)\n    end\n  end\n  ```\n  * Or, if you don't require the trigger, you can specify it without a trigger, e.g.\n  ```elixir\n  led_strip :strip, Kino do\n    animation :name do\n      do_something_without_a_trigger()\n    end\n  end\n  ```","ref":"Fledex.html#animation/3"},{"type":"function","title":"Fledex.component/3","doc":"A component is a pre-defined animation that reacts to some input.\nWe might have a thermometer component that defines the display of\na thermometer:\n\n* input: single value\n* display is a range (positive, 0, negative)\n* ...\n\nA component does not have a `do ... end` block, since it defines it's\nown animation(s), and it's only controlled through some parameters that\ncan be passed as options like:\n\n* the value,\n* the display colors,\n* the range of our scale\n\nThus, our component would look like the following:\n```elixir\n  alias Fledex.Component.Thermometer\n  component :thermo, Thermometer,\n    range: -20..40,\n    trigger: :temperature,\n    negative: :blue,\n    null: :may_green,\n    positive: :red\n```\nIt is up to each component to define their own set of mandatory and optional\nparameters.","ref":"Fledex.html#component/3"},{"type":"macro","title":"Fledex.coordinator/3","doc":"","ref":"Fledex.html#coordinator/3"},{"type":"macro","title":"Fledex.effect/3","doc":"Add an effect to an animation\n\nThis macro allows to add an effect to an animation (or even a component\n(TODO: figure out whether an effect on a static component makes any sense,\nit would mean that the static component suddenly would need to be animated)\n\nYou simply warp the animation inside a effect block. It's possible to have\nsevereal nested effects. In that case they will all be executed in sequence.\n\nExample:\n```elixir\nuse Fledex\nalias Fledex.Effect.Wanish\nled_strip :john, Kino do\n  effect Wanish, trigger_name: :john do\n    animation :test do\n      _triggers ->\n        leds(1) |> light(:red) |> repeat(50)\n    end\n  end\nend\n```","ref":"Fledex.html#effect/3"},{"type":"macro","title":"Fledex.job/4","doc":"A job is a [cron job](https://en.wikipedia.org/wiki/Cron) that will trigger in regular\nintervals (depending on the pattern specified). You can run any function and the most\nlikely event you will trigger is to publish an event to the triggers (see the [weather\nexample livebook](5_fledex_weather_example.livemd)):\n\n```elixir\n  broadcast_trigger(%{temperature: -15.2})\n```\n\nEach job consists of:\n\n* `name`- a unique name\n* `pattern`- a cron pattern (as specified in\n   [this cheatsheet](https://hexdocs.pm/crontab/cron_notation.html#expressions)).\n   Note: `Crontab.CronExpression` gets imported and therefore the sigil can directly\n   be used, i.e. `~e[* * * * * * * *]e`\n* `options`- a keyword list with some options. The following options exist:\n  * `:run_once`- a boolean that indicates whether the job should be run once\n    at creation time. This can be important, because you might otherwise have\n    to wait for an extended time before the function will be executed.\n  * `:timezone`- The timezone the cron pattern applies to. If nothing is specified\n    `:utc` is assumed\n  * `:overlap`- This indicates whether jobs should overlap or not. An overlap can\n    happen when running the job takes more time than the interval between job runs.\n    For safety reason the default is `false`.\n* `:do` - a block of code that should be executed. You can specify directly\n  your code here. It will be wrapped into an anonymous function.\n\nExample:\n```elixir\nuse Fledex\nled_strip :nested_components2, Kino do\n  job :clock, ~e[@secondly]e do\n    date_time = DateTime.utc_now()\n\n    broadcast_trigger(%{\n      clock_hour: date_time.hour,\n      clock_minute: date_time.minute,\n      clock_second: date_time.second\n    })\n  end\nend\n```","ref":"Fledex.html#job/4"},{"type":"macro","title":"Fledex.led_strip/4","doc":"This introduces a new led_strip.\n\n  The `drivers` can be spcified in 3 different ways:\n\n  * just a driver module (like `Spi`). In this case the default settings will be used\n  * a driver module with it's configuration (like `{Spi, [dev: \"spidev0.1\"]}`)\n  * or a set of drivers (always with their configuration), like: `[{Spi, []}, {Spi, [dev: \"spidev0.1\"}]`\n\n  A set of default drivers exist for conenience that can be used like `Spi`, `Null`, ...\n  (see `Fledex.LedStrip` for details).\n\n  A special driver `:config` exists that will simply return the converted dsl to the\n  corresponding configuration. This can be very convenient for\n\n  * running tests\n  * implementing components consisting of several animations. Take a look at the\n  `Fledex.Component.Clock` as an example.\n\n  The `strip_options` configures any non-driver specific settings of the strip (like how\n  often the strip should be repainted, how different animations should be merged, ...).","ref":"Fledex.html#led_strip/4"},{"type":"macro","title":"Fledex.static/3","doc":"The static macro is equal to the animation macro, but it will not receive any triggers.\n\nTherefore, there will not be any repainting and the `def_func` will not receive any\nparameter. It will only be painted once at definition time.","ref":"Fledex.html#static/3"},{"type":"function","title":"Fledex.version/0","doc":"Returns the version of the `Fledex` library.\nIt can be important to know the version in order to adjust some code depending\non the version","ref":"Fledex.html#version/0"},{"type":"module","title":"Fledex.Application","doc":"","ref":"Fledex.Application.html"},{"type":"function","title":"Fledex.Application.start/2","doc":"","ref":"Fledex.Application.html#start/2"},{"type":"module","title":"Fledex.LedStrip","doc":"This module defines a GenServer that manages the LED strip (be it a real one with the\n`Fledex.Driver.Impl.Spi` or a virtual one with e.g. the `Fledex.Driver.Impl.Kino`).\n\nYou would start an `LedStrip` for every led strip you have.\n\nThe `Fledex.LedStrip` will take several `Fledex.Leds` definitions and merge them\ntogether to be displayed on a single LED strip.\n\nThe role the LedStrip plays is similar to the one a window server  plays on a normal\ncomputer, except that a window server would manage several screens, whereas here each\nLED strip would get its own.","ref":"Fledex.LedStrip.html"},{"type":"function","title":"Fledex.LedStrip.change_config/2","doc":"Change some aspect of a configuration for a specific strip. The configuration\nwill be updated and the old values will be returned.","ref":"Fledex.LedStrip.html#change_config/2"},{"type":"function","title":"Fledex.LedStrip.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Fledex.LedStrip.html#child_spec/1"},{"type":"function","title":"Fledex.LedStrip.define_namespace/2","doc":"Define a new namespace","ref":"Fledex.LedStrip.html#define_namespace/2"},{"type":"function","title":"Fledex.LedStrip.drop_namespace/2","doc":"Drop a previously defined namespace.","ref":"Fledex.LedStrip.html#drop_namespace/2"},{"type":"function","title":"Fledex.LedStrip.exist_namespace/2","doc":"Checks whether the specified namespace already exists","ref":"Fledex.LedStrip.html#exist_namespace/2"},{"type":"function","title":"Fledex.LedStrip.init_config/1","doc":"","ref":"Fledex.LedStrip.html#init_config/1"},{"type":"function","title":"Fledex.LedStrip.reinit/3","doc":"In some circumstances it might be necessary to reinitialize the led_strip\n(including the drivers). Most of the time you don't need to call this.\nIf you do, you will surely know about it :)","ref":"Fledex.LedStrip.html#reinit/3"},{"type":"function","title":"Fledex.LedStrip.set_leds/3","doc":"Sets the leds in a specific strip and namespace.\n\nNote: repeated calls of this function will result in previously set leds\nwill be overwritten. We are passing a list of leds which means every led\nwill be rewritten, except if we define a 'shorter\" led sequence. In that\ncase some leds might retain their previously set value.","ref":"Fledex.LedStrip.html#set_leds/3"},{"type":"function","title":"Fledex.LedStrip.start_link/3","doc":"This starts the server controlling a specfic led strip. It is possible\nto install several drivers at the same time, so different hardware gets the same data\nat the same time (similar to mirroring a screen). If you want to send different\ndata to different strips, you should start several instances of this server\n\nBecause we can have several drivers (even though that is rather the exception)\nthe confirgation is split up into several parts (not all of them need to be present):\n* The name of the strip (mandatory)\n* The global configuration of the strip (optional, defaults will be used if not specified)\n* A driver module (that also provides a default set of configs)\n* A list of detailed configs that are overlayed over the defaults. This allows\n  for example to reuse the `Fledex.Driver.Impl.Spi` defaults, but change for example\n  to a different spi device by setting `:dev` to `spidev0.1`\n\nHere some examples (with aliased module names) how you can start the server:\n* Without real driver: `start_link(:name)`\n* With real driver: `start_link(:name, Spi)`\n* With some global config overlay and real driver: `start_link(:name, Spi, timer_only_dirty_update: true)`\n* With real driver and some driver overlay: `start_link(:name, {Spi, dev: \"spidev0.1\"})`\n* With several drivers: `start_link(:name, [{Spu, []}, {Spi, dev: \"spidev0.1\"}])`\n* With several drivers and global config: `start_link(:name, [{Spi, []}, {Spi, dev: \"spidev0.1\"}], timer_only_dirty_update: true)`","ref":"Fledex.LedStrip.html#start_link/3"},{"type":"type","title":"Fledex.LedStrip.start_link_response/0","doc":"","ref":"Fledex.LedStrip.html#t:start_link_response/0"},{"type":"function","title":"Fledex.LedStrip.stop/1","doc":"","ref":"Fledex.LedStrip.html#stop/1"},{"type":"module","title":"Fledex.Leds","doc":"This module allows to define a sequence of Leds. You first create the new sequence of leds\nby calling one of the `leds` functions.\n\n**Note:** usually the `leds` function would rather be called `new` but when importing the `Leds`\nmodule, it becomes more natural to say\n\n```elixir\n  leds(10) |> light(:red)`\n```\n\nTo keep the classical semantics some delegates are defined, so you can use `new` as well.","ref":"Fledex.Leds.html"},{"type":"function","title":"Fledex.Leds.convert_to_leds_structure/2","doc":"Helper function to convert a list of colors to the correct map structure","ref":"Fledex.Leds.html#convert_to_leds_structure/2"},{"type":"function","title":"Fledex.Leds.count/1","doc":"This function checks how many leds are defined in the led sequence.\n\nNote: The color of an led outside that range can be defined, but it won't be\nsend to the `Fledex.LedStrip` when the `send/2` function is called. See also\n`set_count/2` for information.","ref":"Fledex.Leds.html#count/1"},{"type":"function","title":"Fledex.Leds.get_light/2","doc":"Retrieve the color of an led at a specific position","ref":"Fledex.Leds.html#get_light/2"},{"type":"function","title":"Fledex.Leds.gradient/4","doc":"Defines the leds through a gradient function.\n\nThe gradient function will create a smoot transition from a `start_color` to an\n`end_color`. The options that can be specified are the following:\n\n* `\"num_leds`: Over how many leds the transition should happen. (default: all)\n* `:offset`: The offset where to start the gardient at (default: 0)","ref":"Fledex.Leds.html#gradient/4"},{"type":"function","title":"Fledex.Leds.leds/0","doc":"Create a new led sequence of length 0.\n\nThis is rarely useful. Use the `leds/1` function instead (or change the count by using `set_count/2`)","ref":"Fledex.Leds.html#leds/0"},{"type":"function","title":"Fledex.Leds.leds/1","doc":"Creates a new led sequence with a set number of leds","ref":"Fledex.Leds.html#leds/1"},{"type":"function","title":"Fledex.Leds.leds/2","doc":"Create a new led sequence with a set number of leds and some options.\n\nCurrently two options are available:\n\n* `:server_name` and\n* `:namespace`.\n\nThose are important when you want to send your led sequence to an\n`Fledex.LedStrip`.\nYou should prefer to use the `set_led_strip_info/3` function instead.","ref":"Fledex.Leds.html#leds/2"},{"type":"function","title":"Fledex.Leds.leds/3","doc":"Create a new led sequence with a set number of leds, some set leds and options.\n\nThis function is similar to `leds/2`, but you  an specify some leds (between the `count`\nand the `opts`) through a map or a list.\n\nIf a map is used the key of the map (an integer) is the index (one-indexed) of the\nled and the value is the color.\nIf a list is used each entry in the list defines a color. Internally it will be converted\nto a map.\n\nLeds that are outside the `count` can be specified, but will be ignored when sent to\nan `Fledex.LedStrip` through the `send/2` function.","ref":"Fledex.Leds.html#leds/3"},{"type":"function","title":"Fledex.Leds.leds/4","doc":"Creates a led sequence with a set number of leds, some set leds, some options and some\nmeta information.\n\nThis function is similar to the `leds/3` function, but some additional meta information\ncan be specified. Currently the only  meta information is to keep track of an index\nthat specfies which led will be set when using the `light/2` function, i.e. without\nan offset. This way it's possible to have a sequence of updates like the following\nto specify the colors:\n\n```elixir\nleds(10) |> light(:red) |> light(:blue)\n```","ref":"Fledex.Leds.html#leds/4"},{"type":"function","title":"Fledex.Leds.light/2","doc":"Defines the color(s) of the next led\n\nIf there are no more leds, this function will virtually continue and define leds\noutside the scope, see also the note on `set_count/2`.\n\nNote: it is possible to use a sub sequence of leds and they all will be added to\nthe sequence.","ref":"Fledex.Leds.html#light/2"},{"type":"function","title":"Fledex.Leds.light/3","doc":"Defines the color of an led with some options specified.\n\nThe options can be the following:\n\n* `:offset`: by how many leds sdo we want to offset. needs to be\n`> 0` if it's bigger than the count then the led will be stored,\nbut ignored (but see the description of `set_count/2`). The same\nnote as for `light/2` applies.\n* `:repeat`: How often the light should be repeated. It needs to be\nmore than 1, otherwise it wouldn't make sense. In addition the same\nnote as for `light/2` applies.\n\nif you don't specify a list, but only a  number as option, then\nit's the same as specifying the offset.","ref":"Fledex.Leds.html#light/3"},{"type":"function","title":"Fledex.Leds.new/0","doc":"","ref":"Fledex.Leds.html#new/0"},{"type":"function","title":"Fledex.Leds.new/1","doc":"","ref":"Fledex.Leds.html#new/1"},{"type":"function","title":"Fledex.Leds.new/2","doc":"","ref":"Fledex.Leds.html#new/2"},{"type":"function","title":"Fledex.Leds.new/3","doc":"","ref":"Fledex.Leds.html#new/3"},{"type":"function","title":"Fledex.Leds.new/4","doc":"","ref":"Fledex.Leds.html#new/4"},{"type":"function","title":"Fledex.Leds.rainbow/2","doc":"Defines a rainbow over the leds. The options that can be specified are:\n\n* `:num_leds`: how many leds should be part of the rainbow (by default all leds)\n* `:offset`: as from which led we want to start the  rainbow (default: 0, no offset)\n* `:reversed`: The rainbow can go from red (start color) to blue (end color) or the other\n    way around.\n* `:initial_hue`: The starting color in degree (`0..360`). (default: 0)\n\nNote: any led that has been defined before calling this function will be overwritten\nwith the rainbow value.","ref":"Fledex.Leds.html#rainbow/2"},{"type":"function","title":"Fledex.Leds.repeat/2","doc":"repeat the existing sequence `amount` times\n\nThis way you can easily create a repetitive pattern\n\n**Note:** this will change the led sequence count  (`amount` times the initial `count`)","ref":"Fledex.Leds.html#repeat/2"},{"type":"function","title":"Fledex.Leds.send/2","doc":"Convenience function to send the led sequence to an `Fledex.LedStrip`.\n\nIn order for the function to succeed either `set_led_strip_info/3` needs to be\ncalled or the information needs to be passed as part of the opts. The opts can\nbe the following:\n\n* `:offset`: Move the led sequence to the side (see Note below)\n* `:rotate_left`: whether the offset should be appiled toward the right or the left\n* `:server_name`: The name of the server_name to which the led sequence should be send to\n    (default: `Fledex.LedStrip`)\n* `:namespace`: The name of the namespace within the LedStrip (default: `:default`)\n\nNote: the led sequence will always be applied in it's entirety, and will wrap around.\nThrough the `:offset` it is possible to create simple animations by simply counting up\nthe counter.","ref":"Fledex.Leds.html#send/2"},{"type":"function","title":"Fledex.Leds.set_count/2","doc":"This function sets the count of leds of the led sequence.\n\nNote: Be careful if you redefine the count when some leds have\nbeen defined outside of the previous range; they might suddenly become\nvisible.","ref":"Fledex.Leds.html#set_count/2"},{"type":"function","title":"Fledex.Leds.set_led_strip_info/3","doc":"Define the server_name and the namespace\n\nThis is used when the led sequence is sent to the `Fledex.LedStrip` when the\n`send/2` function is called.","ref":"Fledex.Leds.html#set_led_strip_info/3"},{"type":"type","title":"Fledex.Leds.t/0","doc":"","ref":"Fledex.Leds.html#t:t/0"},{"type":"function","title":"Fledex.Leds.to_binary/1","doc":"Convert the sequence of leds to a binary sequence of `Fledex.Color.Types.colorint` colors.\n\nNote: Only the leds that are inside the `count` will be emitted into the binary sequence.","ref":"Fledex.Leds.html#to_binary/1"},{"type":"function","title":"Fledex.Leds.to_list/1","doc":"Convert the sequence of leds into an list of `Fledex.Color.Types.colorint` colors.\n\nNote: Only the leds that are inside the `count` will be added to the list.","ref":"Fledex.Leds.html#to_list/1"},{"type":"function","title":"Fledex.Leds.to_markdown/2","doc":"Convert the sequence of leds to a markdown representation.\n\nThe █ will be used to represent the leds and they will be colored in\nthe appropriate color. It then looks something like this:\n █ \n █ \n █ \nThe opts are currently not used, but are planned to\nbe used for potential color correction (similar to `Fledex.Driver.Impl.Kino`)","ref":"Fledex.Leds.html#to_markdown/2"},{"type":"module","title":"Fledex.Animation.Animator","doc":"The client often wants to run some animations. This can of course be done by\nrepeatedly updating the `Leds` definitions and calling\n`Leds.send()` to send it to the driver.\nThis often results in constructs like the following:application\n```\n  Enum.each(1..10, fn index ->\n  Leds\n    |> led_definition function(index)\n    |> Leds.send(config)\n    Process.sleep(600)\n  end)\n ```\n This creates a loop over some led definition, sends it to the LED strip and then\n waits for a while to do the next step.\n The index can be used for either influencing the led definition function,\n or the offset of the strip and thereby influencing the animation.\n\nThis approach is not really good, because of the following drawbacks:\n* it is difficult to update the animation while it's running,\n   because it would require to interrupt the loop\n* the sending to the LED strip can not be optimized, except by knowing\n   at which update frequency the driver is updating the strip. Of course it would be\n   possible for a client to figure this out, but who would do that?\n\n The idea of this module is to take care of those concerns by implementing a GenServer that\n runs the loop, but can be updated in-between.\n\n From the above example it can be seen that two things can be updated:\n * The led_definition_function and\n * The send config (even though we will have to implement that as a\n  function too due to the handling of the index)\n\n Note: the time is not something that can be specified, since the animator will\n be triggered by `Fledex.LedStrip` in it's update frequency. Thus to implement\n some wait pattern, the trigger counter (or some other timer logic) should be used\n\n Both of them can be set by defining an appropriate function and setting and resetting a reference at will\n\n This module does not define any functions on its own, because the interface is defined\n by `Fledex.Animation.AnimatorBase`.","ref":"Fledex.Animation.Animator.html"},{"type":"function","title":"Fledex.Animation.Animator.apply_effects/4","doc":"","ref":"Fledex.Animation.Animator.html#apply_effects/4"},{"type":"function","title":"Fledex.Animation.Animator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Fledex.Animation.Animator.html#child_spec/1"},{"type":"type","title":"Fledex.Animation.Animator.config_t/0","doc":"","ref":"Fledex.Animation.Animator.html#t:config_t/0"},{"type":"type","title":"Fledex.Animation.Animator.state_t/0","doc":"","ref":"Fledex.Animation.Animator.html#t:state_t/0"},{"type":"function","title":"Fledex.Animation.Animator.update_options/2","doc":"","ref":"Fledex.Animation.Animator.html#update_options/2"},{"type":"module","title":"Fledex.Animation.AnimatorBase","doc":"","ref":"Fledex.Animation.AnimatorBase.html"},{"type":"behaviour","title":"Fledex.Animation.AnimatorInterface","doc":"The behaviour for an Animator.\n\nThis behaviour is the interface expected by the `Fledex.Animation.Manager`\nand should be implemented as a GenServer.\nIf  you implement an animation you will have to implement those functions\nbut you can use `Fledex.Animation.AnimatorBase` to assist you.","ref":"Fledex.Animation.AnimatorInterface.html"},{"type":"function","title":"Fledex.Animation.AnimatorInterface.build_name/3","doc":"This utility function will create an atomic name for the combination of strip name and\nanimation name. This is used to name the animator. It is important that we do\nhave a naming convention, because we would otherwise have a hard time to shutdown\nanimators that have been removed. We do not keep a reference, but only a config\nTherefore the animator needs to adhere to this naming convention to properly be shut down.\nIt is the responsibility of the Animator to set the servername correctly. The\n`Fledex.Animation.AnimatorBase` is doing this by default.","ref":"Fledex.Animation.AnimatorInterface.html#build_name/3"},{"type":"callback","title":"Fledex.Animation.AnimatorInterface.config/3","doc":"(Re-)Configure this animation. You will have to implement this function on server side.\nThis will look something like the following:\n```elixir\n  @spec handle_cast({:config, config_t}, state_t) :: {:noreply, state_t}\n  def handle_cast({:config, config}, state) do\n    # do something here\n    {:noreply, state}\n  end\n```","ref":"Fledex.Animation.AnimatorInterface.html#c:config/3"},{"type":"callback","title":"Fledex.Animation.AnimatorInterface.shutdown/2","doc":"When the animation is no long required, this function should be called. This will\ncall (by default) GenServer.stop. The animation can implement the `terminate/2`\nfunction if necessary.","ref":"Fledex.Animation.AnimatorInterface.html#c:shutdown/2"},{"type":"callback","title":"Fledex.Animation.AnimatorInterface.start_link/3","doc":"Create a new animation (with a given name and configuration) for the led strip\nwith the specified name.","ref":"Fledex.Animation.AnimatorInterface.html#c:start_link/3"},{"type":"callback","title":"Fledex.Animation.AnimatorInterface.update_effect/4","doc":"Update the configuration of an effect at runtime\n\nSometimes you want to change the configuration of an effect not only at definition time,\nbut aiso at runtime.\nIt is possible to apply the configuration change to ALL effects of the animator, which\ncan be convenient especially if you want to enable/disable all effects at once.","ref":"Fledex.Animation.AnimatorInterface.html#c:update_effect/4"},{"type":"behaviour","title":"Fledex.Animation.Coordinator","doc":"","ref":"Fledex.Animation.Coordinator.html"},{"type":"function","title":"Fledex.Animation.Coordinator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Fledex.Animation.Coordinator.html#child_spec/1"},{"type":"function","title":"Fledex.Animation.Coordinator.config/3","doc":"","ref":"Fledex.Animation.Coordinator.html#config/3"},{"type":"callback","title":"Fledex.Animation.Coordinator.config/3","doc":"","ref":"Fledex.Animation.Coordinator.html#c:config/3"},{"type":"type","title":"Fledex.Animation.Coordinator.config_t/0","doc":"","ref":"Fledex.Animation.Coordinator.html#t:config_t/0"},{"type":"function","title":"Fledex.Animation.Coordinator.default_func/3","doc":"","ref":"Fledex.Animation.Coordinator.html#default_func/3"},{"type":"function","title":"Fledex.Animation.Coordinator.shutdown/2","doc":"","ref":"Fledex.Animation.Coordinator.html#shutdown/2"},{"type":"callback","title":"Fledex.Animation.Coordinator.shutdown/2","doc":"","ref":"Fledex.Animation.Coordinator.html#c:shutdown/2"},{"type":"function","title":"Fledex.Animation.Coordinator.start_link/3","doc":"","ref":"Fledex.Animation.Coordinator.html#start_link/3"},{"type":"callback","title":"Fledex.Animation.Coordinator.start_link/3","doc":"","ref":"Fledex.Animation.Coordinator.html#c:start_link/3"},{"type":"behaviour","title":"Fledex.Animation.JobScheduler","doc":"Defines a quantum Scheduler.\n\nWhen used, the quantum scheduler expects the `:otp_app` as option.\nThe `:otp_app` should point to an OTP application that has\nthe quantum runner configuration. For example, the quantum scheduler:\n\n    defmodule Fledex.Animation.JobScheduler do\n      use Quantum, otp_app: :Elixir.Fledex.Animation.JobScheduler\n    end\n\nCould be configured with:\n\n    config :Elixir.Fledex.Animation.JobScheduler, Fledex.Animation.JobScheduler,\n      jobs: [\n        {\"@daily\", {Backup, :backup, []}},\n      ]","ref":"Fledex.Animation.JobScheduler.html"},{"type":"behaviour","title":"Configuration: - Fledex.Animation.JobScheduler","doc":"* `:clock_broadcaster_name` - GenServer name of clock broadcaster \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:execution_broadcaster_name` - GenServer name of execution broadcaster \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:executor_supervisor_name` - GenServer name of execution supervisor \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:debug_logging` - Turn on debug logging\n\n  * `:jobs` - list of cron jobs to execute\n\n  * `:job_broadcaster_name` - GenServer name of job broadcaster \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:name` - GenServer name of scheduler \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:node_selector_broadcaster_name` - GenServer name of node selector broadcaster \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:overlap` - Default overlap of new Job\n\n  * `:otp_app` - Application where scheduler runs\n\n  * `:run_strategy` - Default Run Strategy of new Job\n\n  * `:schedule` - Default schedule of new Job\n\n  * `:storage` - Storage to use for persistence\n\n  * `:storage_name` - GenServer name of storage \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:supervisor_module` - Module to supervise scheduler \\\n    Can be overwritten to supervise processes differently (for example for clustering) \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:task_registry_name` - GenServer name of task registry \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:task_supervisor_name` - GenServer name of task supervisor \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:timeout` - Sometimes, you may come across GenServer timeout errors\n    esp. when you have too many jobs or high load. The default `GenServer.call/3`\n    timeout is `5_000`.\n\n  * `:timezone` - Default timezone of new Job","ref":"Fledex.Animation.JobScheduler.html#module-configuration"},{"type":"behaviour","title":"Telemetry - Fledex.Animation.JobScheduler","doc":"* `[:quantum, :job, :add]`\n  * Description: dispatched when a job is added\n  * Measurements: `%{}`\n  * Metadata: `%{job: Quantum.Job.t(), scheduler: atom()}`\n\n* `[:quantum, :job, :update]`\n  * Description: dispatched when a job is updated\n  * Measurements: `%{}`\n  * Metadata: `%{job: Quantum.Job.t(), scheduler: atom()}`\n\n* `[:quantum, :job, :delete]`\n  * Description: dispatched when a job is deleted\n  * Measurements: `%{}`\n  * Metadata: `%{job: Quantum.Job.t(), scheduler: atom()}`\n\n* `[:quantum, :job, :start]`\n  * Description: dispatched on job execution start\n  * Measurements: `%{system_time: integer()}`\n  * Metadata: `%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom()}`\n\n* `[:quantum, :job, :stop]`\n  * Description: dispatched on job execution end\n  * Measurements: `%{duration: integer()}`\n  * Metadata: `%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom(), result: term()}`\n\n* `[:quantum, :job, :exception]`\n  * Description: dispatched on job execution fail\n  * Measurements: `%{duration: integer()}`\n  * Metadata: `%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom(), kind: :throw | :error | :exit, reason: term(), stacktrace: list()}`","ref":"Fledex.Animation.JobScheduler.html#module-telemetry"},{"type":"behaviour","title":"Examples - Fledex.Animation.JobScheduler","doc":"iex(1)> :telemetry_registry.discover_all(:quantum)\n    :ok\n    iex(2)> :telemetry_registry.spannable_events()\n    [{[:quantum, :job], [:start, :stop, :exception]}]\n    iex(3)> :telemetry_registry.list_events\n    [\n      {[:quantum, :job, :add], Quantum,\n       %{\n         description: \"dispatched when a job is added\",\n         measurements: \"%{}\",\n         metadata: \"%{job: Quantum.Job.t(), scheduler: atom()}\"\n       }},\n      {[:quantum, :job, :delete], Quantum,\n       %{\n         description: \"dispatched when a job is deleted\",\n         measurements: \"%{}\",\n         metadata: \"%{job: Quantum.Job.t(), scheduler: atom()}\"\n       }},\n      {[:quantum, :job, :exception], Quantum,\n       %{\n         description: \"dispatched on job execution fail\",\n         measurements: \"%{duration: integer()}\",\n         metadata: \"%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom(), kind: :throw | :error | :exit, reason: term(), stacktrace: list()}\"\n       }},\n      {[:quantum, :job, :start], Quantum,\n       %{\n         description: \"dispatched on job execution start\",\n         measurements: \"%{system_time: integer()}\",\n         metadata: \"%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom()}\"\n       }},\n      {[:quantum, :job, :stop], Quantum,\n       %{\n         description: \"dispatched on job execution end\",\n         measurements: \"%{duration: integer()}\",\n         metadata: \"%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom(), result: term()}\"\n       }},\n      {[:quantum, :job, :update], Quantum,\n       %{\n         description: \"dispatched when a job is updated\",\n         measurements: \"%{}\",\n         metadata: \"%{job: Quantum.Job.t(), scheduler: atom()}\"\n       }}\n    ]","ref":"Fledex.Animation.JobScheduler.html#module-examples"},{"type":"callback","title":"Fledex.Animation.JobScheduler.add_job/1","doc":"","ref":"Fledex.Animation.JobScheduler.html#c:add_job/1"},{"type":"function","title":"Fledex.Animation.JobScheduler.child_spec/1","doc":"","ref":"Fledex.Animation.JobScheduler.html#child_spec/1"},{"type":"type","title":"Fledex.Animation.JobScheduler.config_t/0","doc":"","ref":"Fledex.Animation.JobScheduler.html#t:config_t/0"},{"type":"function","title":"Fledex.Animation.JobScheduler.create_job/3","doc":"","ref":"Fledex.Animation.JobScheduler.html#create_job/3"},{"type":"callback","title":"Fledex.Animation.JobScheduler.create_job/3","doc":"","ref":"Fledex.Animation.JobScheduler.html#c:create_job/3"},{"type":"callback","title":"Fledex.Animation.JobScheduler.delete_job/1","doc":"","ref":"Fledex.Animation.JobScheduler.html#c:delete_job/1"},{"type":"opaque","title":"Fledex.Animation.JobScheduler.job/0","doc":"","ref":"Fledex.Animation.JobScheduler.html#t:job/0"},{"type":"callback","title":"Fledex.Animation.JobScheduler.run_job/1","doc":"","ref":"Fledex.Animation.JobScheduler.html#c:run_job/1"},{"type":"callback","title":"Fledex.Animation.JobScheduler.start_link/0","doc":"","ref":"Fledex.Animation.JobScheduler.html#c:start_link/0"},{"type":"callback","title":"Fledex.Animation.JobScheduler.stop/0","doc":"","ref":"Fledex.Animation.JobScheduler.html#c:stop/0"},{"type":"module","title":"Fledex.Animation.Manager","doc":"The animation manager manages several animations (and potentially\nserveral led strips at the same time.\nUsually you don't start the service yoursel, but it gets automatically\nstarted when calling `use Fledex` and gets used by the `Fledex` macros.\nThus, you rarely have to interact with it directly.\n\nThe 3 main functions are:\n\n* `register_strip/2`: to add a new led strip. This will also create\nthe necessary `Fledex.LedStrip` and configures it.\n* `unregister_strip/1`: this will remove an led strip again\n* `register_config/2`: this registers (or reregisters) a set of\n  animations. Any animation that is not part of a reregistration will\n  be dropped.","ref":"Fledex.Animation.Manager.html"},{"type":"function","title":"Fledex.Animation.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Fledex.Animation.Manager.html#child_spec/1"},{"type":"type","title":"Fledex.Animation.Manager.configs_t/0","doc":"","ref":"Fledex.Animation.Manager.html#t:configs_t/0"},{"type":"function","title":"Fledex.Animation.Manager.register_config/2","doc":"Register a set of configurations (animations, jobs, ...) for a specific led strip.\nThis function can be called as many times as desired to reconfigure the strip.\nIt should be noted that any animation, job, ... that was defined before calling\nthis function again, will be stopped if they are not part of the configuration anymore.\nNewly defined animations will be started.\n\nNote: the animation functions might get called quite frequently and\ntherefore any work within them should be kept to a minimum.","ref":"Fledex.Animation.Manager.html#register_config/2"},{"type":"function","title":"Fledex.Animation.Manager.register_strip/3","doc":"Register a new LED strip with the specific `strip_name`. The LED strip\nneeds to be configured, either through a simple module (for predefined\nconfigurations, or a touple with module and keyword list to adjust the\nconfiguration.(see [`LedStrip`](Fledex.LedStrip.html) for details).","ref":"Fledex.Animation.Manager.html#register_strip/3"},{"type":"function","title":"Fledex.Animation.Manager.start_link/1","doc":"This starts a new `Fledex.Animation.Manager`. Only a single animation manager will be started\neven if called serveral times (thus it's save to call it repeatedly).\nIn general you want to start the function without options, since they are only for\ndebugging purposes.","ref":"Fledex.Animation.Manager.html#start_link/1"},{"type":"function","title":"Fledex.Animation.Manager.unregister_strip/1","doc":"Unregisters a previously registered led strip. All resources related\nto the led strip will be freed.","ref":"Fledex.Animation.Manager.html#unregister_strip/1"},{"type":"module","title":"Fledex.Effect.Dimming","doc":"","ref":"Fledex.Effect.Dimming.html"},{"type":"function","title":"Fledex.Effect.Dimming.do_apply/5","doc":"","ref":"Fledex.Effect.Dimming.html#do_apply/5"},{"type":"behaviour","title":"Fledex.Effect.Interface","doc":"This module defines the interface for an LED effect. Effects can be used in Animations.\nExamples are:\n\n* Rotation\n* Dimming\n* Randomize\n* Wanishing\n* Blinking\n* etc.","ref":"Fledex.Effect.Interface.html"},{"type":"callback","title":"Fledex.Effect.Interface.apply/5","doc":"Applies an effect to the list of LEDs.\n\nEvery LED in the list can be modified at will, however, the amount should NOT (but can be\nas can be seen in the offset effect) be changed.\nThe function takes the following parameters:\n\n* The `leds` is a list of colorints representing the different colors\n* The `count` is the amount of LEDs in the list (to avoid that we have to traverse it unnecessarily)\n* The `config` are some settings that can be used to configure the effect\n* The `triggers` map contains all the triggers can that can be used by the effect. It\n  does contain also the extra parameters passed in in previous calls (see below)\n* The `context` is a map containing information of `strip_name`, `animation_name` and effect `index`.\n\nThe function returns\n\n* a list of LEDs (color integers),\n* the new count of the list,\n* and a (potentially modified) `triggers` map. This allows to retain some state between applying\nthe filter in consecutive calls.\n\nThe most simplest filter is the one that simply returns the passed in parameters:\n\n```elixir\ndef apply(leds, count, _config, trigggers, _context) do\n  {leds, count, triggers}\nend\n```","ref":"Fledex.Effect.Interface.html#c:apply/5"},{"type":"type","title":"Fledex.Effect.Interface.effect_state_t/0","doc":"Typical states of an effect that should be published\n\nNote: This is not used yet and still very much in flux\n\nAn effect can be in different states\n* `:static`: effect is a static effect (and hence can not be used in a sequencer)\n* `:start`: effect will start with the next iteration (and will move into the :progress state).\n    An effect can skip this state and go directly into the :progress state\n* `:progress`: effect is in progress (and will either go into the :stop_start or :stop state)\n* `:stop_start`:  effect is done with one round and will start the next round. THe next state\n    can either be :start or :progress\n* `:stop`: effect is done with it's effect and will stop\n* `:disabled`: effect is currently disabled (by enabling it goes into the :start state)\n\nThis information can be used by some effect sequencer that plays one effect after the next.","ref":"Fledex.Effect.Interface.html#t:effect_state_t/0"},{"type":"callback","title":"Fledex.Effect.Interface.enabled?/1","doc":"","ref":"Fledex.Effect.Interface.html#c:enabled?/1"},{"type":"module","title":"Fledex.Effect.Offset","doc":"","ref":"Fledex.Effect.Offset.html"},{"type":"function","title":"Fledex.Effect.Offset.do_apply/5","doc":"","ref":"Fledex.Effect.Offset.html#do_apply/5"},{"type":"module","title":"Fledex.Effect.Rotation","doc":"","ref":"Fledex.Effect.Rotation.html"},{"type":"function","title":"Fledex.Effect.Rotation.do_apply/5","doc":"","ref":"Fledex.Effect.Rotation.html#do_apply/5"},{"type":"function","title":"Fledex.Effect.Rotation.rotate/4","doc":"Helper function mainy intended for internal use to rotate the sequence of values by an `offset`.\n\nThe rotation can happen with the offset to the left or to the right.","ref":"Fledex.Effect.Rotation.html#rotate/4"},{"type":"function","title":"Fledex.Effect.Rotation.stretch/2","doc":"","ref":"Fledex.Effect.Rotation.html#stretch/2"},{"type":"module","title":"Fledex.Effect.Wanish","doc":"","ref":"Fledex.Effect.Wanish.html"},{"type":"function","title":"Fledex.Effect.Wanish.do_apply/5","doc":"","ref":"Fledex.Effect.Wanish.html#do_apply/5"},{"type":"module","title":"Fledex.Component.Clock","doc":"","ref":"Fledex.Component.Clock.html"},{"type":"module","title":"Fledex.Component.Dot","doc":"","ref":"Fledex.Component.Dot.html"},{"type":"behaviour","title":"Fledex.Component.Interface","doc":"This interface needs to be implemente by a compoenent. It should be noted\nthat a component is always an animation.","ref":"Fledex.Component.Interface.html"},{"type":"callback","title":"Fledex.Component.Interface.configure/2","doc":"This function will be called during initialization of a component. The various\nsettings are passed in as options.\nThis function can return any valid `t:Fledex.Animation.Animator.config_t` structure which will\nbe passed to the `Fledex.Animation.Manager`.","ref":"Fledex.Component.Interface.html#c:configure/2"},{"type":"module","title":"Fledex.Component.PubSubPainter","doc":"","ref":"Fledex.Component.PubSubPainter.html"},{"type":"module","title":"Fledex.Component.Thermometer","doc":"This is only an example component to demonstrate how a component could look like.\nThe component is not properly tested no major effort will be spend on getting this\nto a better state.\n\nThis component is used in one of the  example livebooks though and therefore this\nshould not be removed.","ref":"Fledex.Component.Thermometer.html"},{"type":"module","title":"Fledex.Driver.Impl.Kino","doc":"","ref":"Fledex.Driver.Impl.Kino.html"},{"type":"module","title":"Fledex.Driver.Impl.Logger","doc":"This is a dummy implementation of the Driver that dumps\n  the binaries to IO. This can be useful if you want to run\n  some tests without real hardware.\n  The real implementatin probably opens a channel (if not already open)\n  to the bus (like SPI) sends the data to the bus.\n\n  Note: this module is allowed to store information in the state\n  (like the channel it has oppened), so that we don't have open/close it\n  all the time. Cleanup should happen in the terminate function","ref":"Fledex.Driver.Impl.Logger.html"},{"type":"module","title":"Fledex.Driver.Impl.Null","doc":"This is a dummy implementation of the Driver that doesn't do\n  anything (similar to a /dev/null device). This can be useful if you\n  want to run some tests without getting any output or sending it to hardware.","ref":"Fledex.Driver.Impl.Null.html"},{"type":"module","title":"Fledex.Driver.Impl.PubSub","doc":"","ref":"Fledex.Driver.Impl.PubSub.html"},{"type":"module","title":"Fledex.Driver.Impl.Spi","doc":"","ref":"Fledex.Driver.Impl.Spi.html"},{"type":"function","title":"Fledex.Driver.Impl.Spi.clear_leds/3","doc":"","ref":"Fledex.Driver.Impl.Spi.html#clear_leds/3"},{"type":"function","title":"Fledex.Driver.Impl.Spi.open_spi/1","doc":"","ref":"Fledex.Driver.Impl.Spi.html#open_spi/1"},{"type":"behaviour","title":"Fledex.Driver.Interface","doc":"A driver dispatches the \"real\" hardware. Differen types of\n  drivers exist. Currently the following drivers exist:\n\n  * [`Null`](Fledex.Driver.Impl.Null.html): a driver that doesn't do\n      anything. This is the default driver. It's also very practical for tests.\n  * [`Logger`](Fledex.Driver.Impl.Logger.html): a driver that logs the\n      led data to the terminal or to the logs\n  * [`Kino`](Fledex.Driver.Impl.Kino.html): a driver that can display\n      the LEDs in a [livebook](https://livebook.dev)\n  * [`Spi`](Fledex.Driver.Impl.Spi.html): a driver that can connect\n      to a real LED strip with a WS2801 chip.\n  * [`PubSub`](Fledex.Driver.Impl.PubSub.html): a driver that can transfer\n      the LED data via pubsub. This should also allow the data to be transferred to\n      a LED strip connected on another computer.\n\n  More Drivers can be created by implementing this simple behaviour","ref":"Fledex.Driver.Interface.html"},{"type":"callback","title":"Fledex.Driver.Interface.configure/1","doc":"This callback will be called to retrieve the default set of parameters for\nthis driver. It will be used as default and then ovelayed with the additional arguments\npassed in (which can be passed in to the function)","ref":"Fledex.Driver.Interface.html#c:configure/1"},{"type":"callback","title":"Fledex.Driver.Interface.init/1","doc":"The init function will be called after the `Fledex.LedStrip` is initialized as part\nof the initialization process. A map of initalization arguments are passed to\nthe driver. The driver can decide what to do with them. The returned map is a\nconfiguration that gets passed to any of the other driver functions.","ref":"Fledex.Driver.Interface.html#c:init/1"},{"type":"callback","title":"Fledex.Driver.Interface.reinit/2","doc":"In some cases it is necessary to reinitialize the driver when a new LED strip\nis defined (see the `Fledex.Driver.Impl.Kino` as an example). The\ndriver should know whether it needs to do anything or not. If it does not need\nto do anything, then simply return the passed in keyword list, i.e.:\n\n```elixir\ndef reinit(_old_module_config, new_module_config), do: new_module_config\n```","ref":"Fledex.Driver.Interface.html#c:reinit/2"},{"type":"callback","title":"Fledex.Driver.Interface.terminate/2","doc":"THe terminate functions gets called when we dispose of the led strip. This the place\nwhere the driver can perform some cleanup (e.g.: close some channels)","ref":"Fledex.Driver.Interface.html#c:terminate/2"},{"type":"callback","title":"Fledex.Driver.Interface.transfer/3","doc":"This is the main function where we transfer the LED information to the \"hardware\"\nThe `leds` is a list of integers, (color codes of the form `0xrrggbb` if written in\nhexadecimal format).\nThe `counter` is a counter that gets incremented in each update loop and thereby allows\nto transfer the data with a lower frequency by not transferring it in every loop.\nThe `module_config` is the config that got returned by the `init/1` or `reinit/1`\nfunctions","ref":"Fledex.Driver.Interface.html#c:transfer/3"},{"type":"module","title":"Fledex.Driver.Manager","doc":"","ref":"Fledex.Driver.Manager.html"},{"type":"type","title":"Fledex.Driver.Manager.driver_t/0","doc":"The structure to hold the driver related data.\n\nIt consists of a list (to allow loading of several modules) of tuples with:\n\n* `driver`: Which modules should get loaded. Each module usually should have\n    a default configuration, which can then be overwritten with specific\n    settings\n* `config`: a keyword list to modify the default settings. Each module has\n    their own set of settings. You need to check the driver module documentation\n    for allowed settings\n\nNote: You can specify a driver module several times and give them different settings.\n      This allows for example to send the same data to two different SPI ports.\n\nExample:\n```elixir\n[{Fledex.Driver.Impl.Kino, update_freq: 10 }]\n```","ref":"Fledex.Driver.Manager.html#t:driver_t/0"},{"type":"function","title":"Fledex.Driver.Manager.remove_invalid_drivers/1","doc":"","ref":"Fledex.Driver.Manager.html#remove_invalid_drivers/1"},{"type":"function","title":"Fledex.Driver.Manager.validate_driver/1","doc":"","ref":"Fledex.Driver.Manager.html#validate_driver/1"},{"type":"module","title":"Fledex.Utils.Cluster","doc":"","ref":"Fledex.Utils.Cluster.html"},{"type":"module","title":"Fledex.Utils.Dsl","doc":"","ref":"Fledex.Utils.Dsl.html"},{"type":"function","title":"Fledex.Utils.Dsl.apply_effect/3","doc":"","ref":"Fledex.Utils.Dsl.html#apply_effect/3"},{"type":"function","title":"Fledex.Utils.Dsl.ast_add_argument_to_func/1","doc":"This function takes an ast function block and adds an argument\nto the function. This is different from `ast_add_argument_to_func_if_missing/1`\nthat it does not expect there to be an arugment and therefore will raise an\n`ArgumentError` if it does find one.","ref":"Fledex.Utils.Dsl.html#ast_add_argument_to_func/1"},{"type":"function","title":"Fledex.Utils.Dsl.ast_add_argument_to_func_if_missing/1","doc":"This function takes an AST block of a function, checks whether\nthe required parameter (`trigger`) is present, and if not will\nadd one.\nThis function is to decide on whether `ast_create_anonymous_func/1`\nor `ast_create_anonymous_func/2` should be called\n\nNOTE: this function makes the assumption that a single argument is\n      required.","ref":"Fledex.Utils.Dsl.html#ast_add_argument_to_func_if_missing/1"},{"type":"function","title":"Fledex.Utils.Dsl.ast_create_anonymous_func/1","doc":"This function takes an AST of a function body and wraps it into\n  an anonymous function.\n  It does expect that the arguments are handled as part of the function\n  body, e.g. the function body should look something like this:\n\n  ```elixir\n  arg1 -> :ok\n  arg1, arg2 -> :ok\n  ```","ref":"Fledex.Utils.Dsl.html#ast_create_anonymous_func/1"},{"type":"function","title":"Fledex.Utils.Dsl.ast_create_anonymous_func/2","doc":"This function is similar to `ast_create_anonymous_func/1`, except that no\n argument was specified in the block (because the user does not want to use it),\n even though the function should have one.\n The function will make sure to add the argument to the block before wrapping\n it into an anonymous function.","ref":"Fledex.Utils.Dsl.html#ast_create_anonymous_func/2"},{"type":"function","title":"Fledex.Utils.Dsl.ast_extract_configs/1","doc":"","ref":"Fledex.Utils.Dsl.html#ast_extract_configs/1"},{"type":"function","title":"Fledex.Utils.Dsl.configure_strip/4","doc":"","ref":"Fledex.Utils.Dsl.html#configure_strip/4"},{"type":"function","title":"Fledex.Utils.Dsl.create_config/3","doc":"","ref":"Fledex.Utils.Dsl.html#create_config/3"},{"type":"function","title":"Fledex.Utils.Dsl.create_config/4","doc":"","ref":"Fledex.Utils.Dsl.html#create_config/4"},{"type":"function","title":"Fledex.Utils.Dsl.create_coordinator/3","doc":"","ref":"Fledex.Utils.Dsl.html#create_coordinator/3"},{"type":"function","title":"Fledex.Utils.Dsl.create_job/4","doc":"","ref":"Fledex.Utils.Dsl.html#create_job/4"},{"type":"function","title":"Fledex.Utils.Dsl.init/1","doc":"","ref":"Fledex.Utils.Dsl.html#init/1"},{"type":"module","title":"Fledex.Utils.Guards","doc":"This module collects all useful guards. If you want to use one of them\n  you need to `import` this module.","ref":"Fledex.Utils.Guards.html"},{"type":"macro","title":"Fledex.Utils.Guards.is_in_range/4","doc":"This guard checks whether the value is within the given range.\n  Notes:\n\n    * The lower bound is excluded (except if `inverse_bounds` is true)\n    * The upper bound is included (except if `inverse_bounds` is true)\n    * This guard is not fully tested, so be careful when using that it works for you.","ref":"Fledex.Utils.Guards.html#is_in_range/4"},{"type":"module","title":"Fledex.Utils.PubSub","doc":"","ref":"Fledex.Utils.PubSub.html"},{"type":"function","title":"Fledex.Utils.PubSub.app/0","doc":"","ref":"Fledex.Utils.PubSub.html#app/0"},{"type":"function","title":"Fledex.Utils.PubSub.broadcast/3","doc":"","ref":"Fledex.Utils.PubSub.html#broadcast/3"},{"type":"function","title":"Fledex.Utils.PubSub.broadcast_state/2","doc":"","ref":"Fledex.Utils.PubSub.html#broadcast_state/2"},{"type":"function","title":"Fledex.Utils.PubSub.broadcast_trigger/1","doc":"","ref":"Fledex.Utils.PubSub.html#broadcast_trigger/1"},{"type":"function","title":"Fledex.Utils.PubSub.channel_state/0","doc":"","ref":"Fledex.Utils.PubSub.html#channel_state/0"},{"type":"function","title":"Fledex.Utils.PubSub.channel_trigger/0","doc":"","ref":"Fledex.Utils.PubSub.html#channel_trigger/0"},{"type":"function","title":"Fledex.Utils.PubSub.direct_broadcast!/4","doc":"","ref":"Fledex.Utils.PubSub.html#direct_broadcast!/4"},{"type":"function","title":"Fledex.Utils.PubSub.subscribe/2","doc":"","ref":"Fledex.Utils.PubSub.html#subscribe/2"},{"type":"function","title":"Fledex.Utils.PubSub.unsubscribe/2","doc":"","ref":"Fledex.Utils.PubSub.html#unsubscribe/2"},{"type":"protocol","title":"Fledex.Color","doc":"","ref":"Fledex.Color.html"},{"type":"type","title":"Fledex.Color.t/0","doc":"All the types that implement this protocol.","ref":"Fledex.Color.html#t:t/0"},{"type":"function","title":"Fledex.Color.to_colorint/1","doc":"convert an abstract colour to a concrete colorint","ref":"Fledex.Color.html#to_colorint/1"},{"type":"function","title":"Fledex.Color.to_rgb/1","doc":"","ref":"Fledex.Color.html#to_rgb/1"},{"type":"module","title":"Fledex.Color.Conversion.Approximate","doc":"","ref":"Fledex.Color.Conversion.Approximate.html"},{"type":"function","title":"Fledex.Color.Conversion.Approximate.rgb2hsv/1","doc":"","ref":"Fledex.Color.Conversion.Approximate.html#rgb2hsv/1"},{"type":"module","title":"Fledex.Color.Conversion.CalcUtils","doc":"Most functions are reimplementations from FastLED. Here is a detailed\nexplanation of those functions:\nhttps://github.com/FastLED/FastLED/wiki/High-performance-math","ref":"Fledex.Color.Conversion.CalcUtils.html"},{"type":"function","title":"Fledex.Color.Conversion.CalcUtils.add_subpixels/1","doc":"This function adds the given subpixels `[{r1, g1, b1}, {r2, g2, b2}, ...]` together.\nThe result {r1+r2+..., g1+g2+..., b1+b2+...} is probably outside of the standard\n8bit range and will have to be rescaled","ref":"Fledex.Color.Conversion.CalcUtils.html#add_subpixels/1"},{"type":"function","title":"Fledex.Color.Conversion.CalcUtils.avg/1","doc":"This function calculates the average of the given \"rgb\" values","ref":"Fledex.Color.Conversion.CalcUtils.html#avg/1"},{"type":"function","title":"Fledex.Color.Conversion.CalcUtils.cap/2","doc":"This function combines (adds) the given rgb values and caps them to the given range\n(by default 0..255)","ref":"Fledex.Color.Conversion.CalcUtils.html#cap/2"},{"type":"function","title":"Fledex.Color.Conversion.CalcUtils.frac8/2","doc":"calculate a fraction mapped to a 8bit range","ref":"Fledex.Color.Conversion.CalcUtils.html#frac8/2"},{"type":"function","title":"Fledex.Color.Conversion.CalcUtils.nscale8/3","doc":"same as #scale8, except that it does it for all 3 rgb value\nat the same time.","ref":"Fledex.Color.Conversion.CalcUtils.html#nscale8/3"},{"type":"function","title":"Fledex.Color.Conversion.CalcUtils.scale8/3","doc":"This function scales a value into a specific range. the video parameter\nindicates whether the returned value should be correct to not return 0","ref":"Fledex.Color.Conversion.CalcUtils.html#scale8/3"},{"type":"function","title":"Fledex.Color.Conversion.CalcUtils.split_into_subpixels/1","doc":"Splits the rgb-integer value into it's subpixels and returns an\n`{r, g, b}` tupel","ref":"Fledex.Color.Conversion.CalcUtils.html#split_into_subpixels/1"},{"type":"module","title":"Fledex.Color.Conversion.Rainbow","doc":"","ref":"Fledex.Color.Conversion.Rainbow.html"},{"type":"function","title":"Fledex.Color.Conversion.Rainbow.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Rainbow.html#hsv2rgb/2"},{"type":"module","title":"Fledex.Color.Conversion.Raw","doc":"","ref":"Fledex.Color.Conversion.Raw.html"},{"type":"function","title":"Fledex.Color.Conversion.Raw.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Raw.html#hsv2rgb/2"},{"type":"function","title":"Fledex.Color.Conversion.Raw.set_colors/4","doc":"","ref":"Fledex.Color.Conversion.Raw.html#set_colors/4"},{"type":"module","title":"Fledex.Color.Conversion.Spectrum","doc":"","ref":"Fledex.Color.Conversion.Spectrum.html"},{"type":"function","title":"Fledex.Color.Conversion.Spectrum.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Spectrum.html#hsv2rgb/2"},{"type":"module","title":"Fledex.Color.Correction","doc":"","ref":"Fledex.Color.Correction.html"},{"type":"function","title":"Fledex.Color.Correction.apply_rgb_correction/2","doc":"","ref":"Fledex.Color.Correction.html#apply_rgb_correction/2"},{"type":"function","title":"Fledex.Color.Correction.calculate_color_correction/3","doc":"","ref":"Fledex.Color.Correction.html#calculate_color_correction/3"},{"type":"function","title":"Fledex.Color.Correction.color_correction_g2/1","doc":"","ref":"Fledex.Color.Correction.html#color_correction_g2/1"},{"type":"function","title":"Fledex.Color.Correction.color_correction_none/1","doc":"","ref":"Fledex.Color.Correction.html#color_correction_none/1"},{"type":"function","title":"Fledex.Color.Correction.define_correction/3","doc":"","ref":"Fledex.Color.Correction.html#define_correction/3"},{"type":"function","title":"Fledex.Color.Correction.no_color_correction/0","doc":"","ref":"Fledex.Color.Correction.html#no_color_correction/0"},{"type":"module","title":"Fledex.Color.Correction.Color","doc":"","ref":"Fledex.Color.Correction.Color.html"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_8mm_pixel/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_8mm_pixel/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_led_strip/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_led_strip/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_pixel/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_pixel/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_smd5050/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_smd5050/0"},{"type":"function","title":"Fledex.Color.Correction.Color.uncorrected_color/0","doc":"","ref":"Fledex.Color.Correction.Color.html#uncorrected_color/0"},{"type":"module","title":"Fledex.Color.Correction.Temperature","doc":"","ref":"Fledex.Color.Correction.Temperature.html"},{"type":"function","title":"Fledex.Color.Correction.Temperature.black_light_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#black_light_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.candle/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#candle/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.carbon_arc/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#carbon_arc/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.clear_blue_sky/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#clear_blue_sky/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.cool_white_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#cool_white_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.direct_sunlight/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#direct_sunlight/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.full_spectrum_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#full_spectrum_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.grow_light_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#grow_light_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.halogen/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#halogen/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.high_noon_sun/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#high_noon_sun/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.high_pressure_sodium/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#high_pressure_sodium/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.mercury_vapor/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#mercury_vapor/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.metal_halide/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#metal_halide/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.overcast_sky/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#overcast_sky/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.sodium_vapor/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#sodium_vapor/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.standard_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#standard_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.tungsten_40w/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#tungsten_40w/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.tungsten_100w/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#tungsten_100w/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.uncorrected_temperature/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#uncorrected_temperature/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.warm_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#warm_fluorescent/0"},{"type":"module","title":"Fledex.Color.Functions","doc":"","ref":"Fledex.Color.Functions.html"},{"type":"function","title":"Fledex.Color.Functions.create_gradient_rgb/3","doc":"","ref":"Fledex.Color.Functions.html#create_gradient_rgb/3"},{"type":"function","title":"Fledex.Color.Functions.create_rainbow_circular_hsv/3","doc":"","ref":"Fledex.Color.Functions.html#create_rainbow_circular_hsv/3"},{"type":"function","title":"Fledex.Color.Functions.create_rainbow_circular_rgb/3","doc":"","ref":"Fledex.Color.Functions.html#create_rainbow_circular_rgb/3"},{"type":"function","title":"Fledex.Color.Functions.hsv2rgb/3","doc":"","ref":"Fledex.Color.Functions.html#hsv2rgb/3"},{"type":"module","title":"Fledex.Color.KinoRender","doc":"","ref":"Fledex.Color.KinoRender.html"},{"type":"macro","title":"Fledex.Color.KinoRender.is_byte/1","doc":"Guard to check that the value is within the provided bounds of a byte [0, 255]","ref":"Fledex.Color.KinoRender.html#is_byte/1"},{"type":"function","title":"Fledex.Color.KinoRender.new/1","doc":"","ref":"Fledex.Color.KinoRender.html#new/1"},{"type":"type","title":"Fledex.Color.KinoRender.t/0","doc":"","ref":"Fledex.Color.KinoRender.html#t:t/0"},{"type":"function","title":"Fledex.Color.KinoRender.to_leds/1","doc":"","ref":"Fledex.Color.KinoRender.html#to_leds/1"},{"type":"function","title":"Fledex.Color.KinoRender.to_markdown/1","doc":"","ref":"Fledex.Color.KinoRender.html#to_markdown/1"},{"type":"module","title":"Fledex.Color.Names","doc":"Fledex has an extensive set of predefined colors from:\n\n* [Wikipedia - List of colors A-F](https://en.wikipedia.org/wiki/List_of_colors:_A%E2%80%93F),\n  [Wikipedia - List of colors G-M](https://en.wikipedia.org/wiki/List_of_colors:_N%E2%80%93Z),\n  [Wikipedia - List of colors N-Z](https://en.wikipedia.org/wiki/List_of_colors:_G%E2%80%93M)\n* [W3C - CSS colors](https://drafts.csswg.org/css-color/#named-colors)\n* [W3C - SVG colors](https://www.w3.org/TR/SVG11/types.html#ColorKeywords)\n* [Wikipedia - List of RAL colors](https://en.wikipedia.org/wiki/List_of_RAL_colours)\n\nYou can retrieve the information through their respective modules (Fledex.Color.Names.Wiki.Wiki,\nFledex.Color.Names.CSS, Fledex.Color.Names.SVG, and Fledex.Color.Names.RAL)\nThis module binds (most of) them together into a single module (in case of conflict the\nfirst mentioned module definition will win).\n\nEach color is reachable through a function with the name of the color. For example, you can\nretrieve the information for the color `:almond` by calling the function with the same name, i.e.\n`almond/1`. It should be noted, that the color functions are defined in other modules and we only\ndelegate to those. Still the documentation is directly available in this module.\n\nThe additional parameter determines which additional information should be provided. The options are:\n\n  * `:all`: This retrieves the full data set\n  * `:descriptive_name`: a string with name (from this the Atom is derived)\n  * `:hex` (default): This is the same as `almond/0`\n  * `:hsl`: This retrieves an HSL struct, i.e. `{h, s, l}`\n  * `:hsv`: This retrieves an HSV struct, i.e. `{h, s, v}`\n  * `:index`: The index of this color in the list of all colors\n  * `:rgb`: This retrieves an RGB struct, i.e. `{r, g, b}`\n  * `:source`: Information where the color comes from, see Wikipedia for more details\n  * `:module`: to get more information where the color is actually implemented. The function might return `:unknown`\n\nAnd finally every color exists also in a version that allows you to add it to a `Fledex.Leds`\nsequence. Either as next led (`almond/1`) or with a specified offset (`almond/2`). The latter\nhas no extra documentation, because it wouldn't add any real value, but would clutter the doc.\nHere an example spec:\n\n```elixir\n@spec almond(leds :: Fledex.Leds.t, offset :: non_neg_integer) :: Fledex.Leds.t\n```\n\nSome additional functions exist for retrieving all `colors`, all color `names`, and `info` about an\n`atom` color. Thus, you can get the same information for `almond()` by calling\n`info(:almond, :hex)`\n\n**Note:**\nRAL colours do have name and a code (the official \"name\"), but neither of those are\ncommonly used and therefore those colors are NOT exposed through this interface. The\nlist is already more extensive than is really needed. But maybe for some special\napplication they might be useful. Thus, you will have to use those colors from the\n`Fledex.Color.Names.RAL` module directly. All color names modules have the same\ninterface.","ref":"Fledex.Color.Names.html"},{"type":"function","title":"Fledex.Color.Names.absolute_zero/0","doc":"Defines the color rgb(0, 71, 186).","ref":"Fledex.Color.Names.html#absolute_zero/0"},{"type":"function","title":"Fledex.Color.Names.acid_green/0","doc":"Defines the color rgb(175, 191, 25).","ref":"Fledex.Color.Names.html#acid_green/0"},{"type":"function","title":"Fledex.Color.Names.aero/0","doc":"Defines the color rgb(124, 186, 232).","ref":"Fledex.Color.Names.html#aero/0"},{"type":"function","title":"Fledex.Color.Names.african_violet/0","doc":"Defines the color rgb(178, 132, 191).","ref":"Fledex.Color.Names.html#african_violet/0"},{"type":"function","title":"Fledex.Color.Names.air_superiority_blue/0","doc":"Defines the color rgb(114, 160, 193).","ref":"Fledex.Color.Names.html#air_superiority_blue/0"},{"type":"function","title":"Fledex.Color.Names.alice_blue/0","doc":"Defines the color rgb(239, 247, 255).","ref":"Fledex.Color.Names.html#alice_blue/0"},{"type":"function","title":"Fledex.Color.Names.aliceblue/0","doc":"","ref":"Fledex.Color.Names.html#aliceblue/0"},{"type":"function","title":"Fledex.Color.Names.alizarin/0","doc":"Defines the color rgb(219, 45, 66).","ref":"Fledex.Color.Names.html#alizarin/0"},{"type":"function","title":"Fledex.Color.Names.alloy_orange/0","doc":"Defines the color rgb(196, 96, 15).","ref":"Fledex.Color.Names.html#alloy_orange/0"},{"type":"function","title":"Fledex.Color.Names.almond/0","doc":"Defines the color rgb(239, 221, 204).","ref":"Fledex.Color.Names.html#almond/0"},{"type":"function","title":"Fledex.Color.Names.amaranth_deep_purple/0","doc":"Defines the color rgb(158, 43, 104).","ref":"Fledex.Color.Names.html#amaranth_deep_purple/0"},{"type":"function","title":"Fledex.Color.Names.amaranth_pink/0","doc":"Defines the color rgb(242, 155, 186).","ref":"Fledex.Color.Names.html#amaranth_pink/0"},{"type":"function","title":"Fledex.Color.Names.amaranth_purple/0","doc":"Defines the color rgb(170, 38, 79).","ref":"Fledex.Color.Names.html#amaranth_purple/0"},{"type":"function","title":"Fledex.Color.Names.amazon/0","doc":"Defines the color rgb(58, 122, 86).","ref":"Fledex.Color.Names.html#amazon/0"},{"type":"function","title":"Fledex.Color.Names.amber/0","doc":"Defines the color rgb(255, 191, 0).","ref":"Fledex.Color.Names.html#amber/0"},{"type":"function","title":"Fledex.Color.Names.amethyst/0","doc":"Defines the color rgb(153, 102, 204).","ref":"Fledex.Color.Names.html#amethyst/0"},{"type":"function","title":"Fledex.Color.Names.android_green/0","doc":"Defines the color rgb(61, 219, 135).","ref":"Fledex.Color.Names.html#android_green/0"},{"type":"function","title":"Fledex.Color.Names.antique_brass/0","doc":"Defines the color rgb(204, 147, 117).","ref":"Fledex.Color.Names.html#antique_brass/0"},{"type":"function","title":"Fledex.Color.Names.antique_bronze/0","doc":"Defines the color rgb(102, 91, 30).","ref":"Fledex.Color.Names.html#antique_bronze/0"},{"type":"function","title":"Fledex.Color.Names.antique_fuchsia/0","doc":"Defines the color rgb(145, 91, 130).","ref":"Fledex.Color.Names.html#antique_fuchsia/0"},{"type":"function","title":"Fledex.Color.Names.antique_ruby/0","doc":"Defines the color rgb(132, 28, 45).","ref":"Fledex.Color.Names.html#antique_ruby/0"},{"type":"function","title":"Fledex.Color.Names.antique_white/0","doc":"Defines the color rgb(249, 234, 214).","ref":"Fledex.Color.Names.html#antique_white/0"},{"type":"function","title":"Fledex.Color.Names.antiquewhite/0","doc":"","ref":"Fledex.Color.Names.html#antiquewhite/0"},{"type":"function","title":"Fledex.Color.Names.apricot/0","doc":"Defines the color rgb(249, 206, 175).","ref":"Fledex.Color.Names.html#apricot/0"},{"type":"function","title":"Fledex.Color.Names.aqua/0","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.html#aqua/0"},{"type":"function","title":"Fledex.Color.Names.aquamarine/0","doc":"Defines the color rgb(127, 255, 211).","ref":"Fledex.Color.Names.html#aquamarine/0"},{"type":"function","title":"Fledex.Color.Names.arctic_lime/0","doc":"Defines the color rgb(209, 255, 20).","ref":"Fledex.Color.Names.html#arctic_lime/0"},{"type":"function","title":"Fledex.Color.Names.artichoke_green/0","doc":"Defines the color rgb(73, 112, 68).","ref":"Fledex.Color.Names.html#artichoke_green/0"},{"type":"function","title":"Fledex.Color.Names.arylide_yellow/0","doc":"Defines the color rgb(232, 214, 107).","ref":"Fledex.Color.Names.html#arylide_yellow/0"},{"type":"function","title":"Fledex.Color.Names.ash_gray/0","doc":"Defines the color rgb(178, 191, 181).","ref":"Fledex.Color.Names.html#ash_gray/0"},{"type":"function","title":"Fledex.Color.Names.atomic_tangerine/0","doc":"Defines the color rgb(255, 153, 102).","ref":"Fledex.Color.Names.html#atomic_tangerine/0"},{"type":"function","title":"Fledex.Color.Names.aureolin/0","doc":"Defines the color rgb(252, 237, 0).","ref":"Fledex.Color.Names.html#aureolin/0"},{"type":"function","title":"Fledex.Color.Names.azure/0","doc":"Defines the color rgb(0, 127, 255).","ref":"Fledex.Color.Names.html#azure/0"},{"type":"function","title":"Fledex.Color.Names.azure_x11_web_color/0","doc":"Defines the color rgb(239, 255, 255).","ref":"Fledex.Color.Names.html#azure_x11_web_color/0"},{"type":"function","title":"Fledex.Color.Names.b_dazzled_blue/0","doc":"Defines the color rgb(45, 89, 147).","ref":"Fledex.Color.Names.html#b_dazzled_blue/0"},{"type":"function","title":"Fledex.Color.Names.baby_blue/0","doc":"Defines the color rgb(137, 206, 239).","ref":"Fledex.Color.Names.html#baby_blue/0"},{"type":"function","title":"Fledex.Color.Names.baby_blue_eyes/0","doc":"Defines the color rgb(160, 201, 242).","ref":"Fledex.Color.Names.html#baby_blue_eyes/0"},{"type":"function","title":"Fledex.Color.Names.baby_pink/0","doc":"Defines the color rgb(244, 193, 193).","ref":"Fledex.Color.Names.html#baby_pink/0"},{"type":"function","title":"Fledex.Color.Names.baby_powder/0","doc":"Defines the color rgb(255, 255, 249).","ref":"Fledex.Color.Names.html#baby_powder/0"},{"type":"function","title":"Fledex.Color.Names.baker_miller_pink/0","doc":"Defines the color rgb(255, 145, 175).","ref":"Fledex.Color.Names.html#baker_miller_pink/0"},{"type":"function","title":"Fledex.Color.Names.banana_mania/0","doc":"Defines the color rgb(249, 232, 181).","ref":"Fledex.Color.Names.html#banana_mania/0"},{"type":"function","title":"Fledex.Color.Names.barn_red/0","doc":"Defines the color rgb(124, 10, 2).","ref":"Fledex.Color.Names.html#barn_red/0"},{"type":"function","title":"Fledex.Color.Names.battleship_grey/0","doc":"Defines the color rgb(132, 132, 130).","ref":"Fledex.Color.Names.html#battleship_grey/0"},{"type":"function","title":"Fledex.Color.Names.beau_blue/0","doc":"Defines the color rgb(188, 211, 229).","ref":"Fledex.Color.Names.html#beau_blue/0"},{"type":"function","title":"Fledex.Color.Names.beaver/0","doc":"Defines the color rgb(158, 130, 112).","ref":"Fledex.Color.Names.html#beaver/0"},{"type":"function","title":"Fledex.Color.Names.beige/0","doc":"Defines the color rgb(244, 244, 219).","ref":"Fledex.Color.Names.html#beige/0"},{"type":"function","title":"Fledex.Color.Names.big_dip_o_ruby/0","doc":"Defines the color rgb(155, 38, 66).","ref":"Fledex.Color.Names.html#big_dip_o_ruby/0"},{"type":"function","title":"Fledex.Color.Names.bisque/0","doc":"Defines the color rgb(255, 226, 196).","ref":"Fledex.Color.Names.html#bisque/0"},{"type":"function","title":"Fledex.Color.Names.bistre/0","doc":"Defines the color rgb(61, 43, 30).","ref":"Fledex.Color.Names.html#bistre/0"},{"type":"function","title":"Fledex.Color.Names.bistre_brown/0","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.html#bistre_brown/0"},{"type":"function","title":"Fledex.Color.Names.bitter_lemon/0","doc":"Defines the color rgb(201, 224, 12).","ref":"Fledex.Color.Names.html#bitter_lemon/0"},{"type":"function","title":"Fledex.Color.Names.black/0","doc":"Defines the color rgb(0, 0, 0).","ref":"Fledex.Color.Names.html#black/0"},{"type":"function","title":"Fledex.Color.Names.black_bean/0","doc":"Defines the color rgb(61, 12, 2).","ref":"Fledex.Color.Names.html#black_bean/0"},{"type":"function","title":"Fledex.Color.Names.black_coral/0","doc":"Defines the color rgb(84, 96, 112).","ref":"Fledex.Color.Names.html#black_coral/0"},{"type":"function","title":"Fledex.Color.Names.black_olive/0","doc":"Defines the color rgb(58, 61, 53).","ref":"Fledex.Color.Names.html#black_olive/0"},{"type":"function","title":"Fledex.Color.Names.black_shadows/0","doc":"Defines the color rgb(191, 175, 178).","ref":"Fledex.Color.Names.html#black_shadows/0"},{"type":"function","title":"Fledex.Color.Names.blanched_almond/0","doc":"Defines the color rgb(255, 234, 204).","ref":"Fledex.Color.Names.html#blanched_almond/0"},{"type":"function","title":"Fledex.Color.Names.blanchedalmond/0","doc":"","ref":"Fledex.Color.Names.html#blanchedalmond/0"},{"type":"function","title":"Fledex.Color.Names.blast_off_bronze/0","doc":"Defines the color rgb(165, 112, 99).","ref":"Fledex.Color.Names.html#blast_off_bronze/0"},{"type":"function","title":"Fledex.Color.Names.bleu_de_france/0","doc":"Defines the color rgb(48, 140, 232).","ref":"Fledex.Color.Names.html#bleu_de_france/0"},{"type":"function","title":"Fledex.Color.Names.blizzard_blue/0","doc":"Defines the color rgb(170, 229, 237).","ref":"Fledex.Color.Names.html#blizzard_blue/0"},{"type":"function","title":"Fledex.Color.Names.blood_red/0","doc":"Defines the color rgb(102, 0, 0).","ref":"Fledex.Color.Names.html#blood_red/0"},{"type":"function","title":"Fledex.Color.Names.blue/0","doc":"Defines the color rgb(0, 0, 255).","ref":"Fledex.Color.Names.html#blue/0"},{"type":"function","title":"Fledex.Color.Names.blue_bell/0","doc":"Defines the color rgb(163, 163, 209).","ref":"Fledex.Color.Names.html#blue_bell/0"},{"type":"function","title":"Fledex.Color.Names.blue_crayola/0","doc":"Defines the color rgb(30, 117, 255).","ref":"Fledex.Color.Names.html#blue_crayola/0"},{"type":"function","title":"Fledex.Color.Names.blue_gray_crayola/0","doc":"Defines the color rgb(102, 153, 204).","ref":"Fledex.Color.Names.html#blue_gray_crayola/0"},{"type":"function","title":"Fledex.Color.Names.blue_jeans/0","doc":"Defines the color rgb(91, 173, 237).","ref":"Fledex.Color.Names.html#blue_jeans/0"},{"type":"function","title":"Fledex.Color.Names.blue_munsell/0","doc":"Defines the color rgb(0, 147, 175).","ref":"Fledex.Color.Names.html#blue_munsell/0"},{"type":"function","title":"Fledex.Color.Names.blue_ncs/0","doc":"Defines the color rgb(0, 135, 188).","ref":"Fledex.Color.Names.html#blue_ncs/0"},{"type":"function","title":"Fledex.Color.Names.blue_pantone/0","doc":"Defines the color rgb(0, 22, 168).","ref":"Fledex.Color.Names.html#blue_pantone/0"},{"type":"function","title":"Fledex.Color.Names.blue_pigment/0","doc":"Defines the color rgb(51, 51, 153).","ref":"Fledex.Color.Names.html#blue_pigment/0"},{"type":"function","title":"Fledex.Color.Names.blue_sapphire/0","doc":"Defines the color rgb(17, 96, 127).","ref":"Fledex.Color.Names.html#blue_sapphire/0"},{"type":"function","title":"Fledex.Color.Names.blue_violet/0","doc":"Defines the color rgb(137, 43, 226).","ref":"Fledex.Color.Names.html#blue_violet/0"},{"type":"function","title":"Fledex.Color.Names.blue_yonder/0","doc":"Defines the color rgb(79, 114, 165).","ref":"Fledex.Color.Names.html#blue_yonder/0"},{"type":"function","title":"Fledex.Color.Names.bluetiful/0","doc":"Defines the color rgb(61, 104, 232).","ref":"Fledex.Color.Names.html#bluetiful/0"},{"type":"function","title":"Fledex.Color.Names.blueviolet/0","doc":"","ref":"Fledex.Color.Names.html#blueviolet/0"},{"type":"function","title":"Fledex.Color.Names.blush/0","doc":"Defines the color rgb(221, 91, 130).","ref":"Fledex.Color.Names.html#blush/0"},{"type":"function","title":"Fledex.Color.Names.bole/0","doc":"Defines the color rgb(119, 68, 58).","ref":"Fledex.Color.Names.html#bole/0"},{"type":"function","title":"Fledex.Color.Names.bone/0","doc":"Defines the color rgb(226, 216, 201).","ref":"Fledex.Color.Names.html#bone/0"},{"type":"function","title":"Fledex.Color.Names.brick_red/0","doc":"Defines the color rgb(204, 63, 84).","ref":"Fledex.Color.Names.html#brick_red/0"},{"type":"function","title":"Fledex.Color.Names.bright_lilac/0","doc":"Defines the color rgb(216, 145, 239).","ref":"Fledex.Color.Names.html#bright_lilac/0"},{"type":"function","title":"Fledex.Color.Names.bright_yellow_crayola/0","doc":"Defines the color rgb(255, 170, 28).","ref":"Fledex.Color.Names.html#bright_yellow_crayola/0"},{"type":"function","title":"Fledex.Color.Names.bronze/0","doc":"Defines the color rgb(204, 127, 51).","ref":"Fledex.Color.Names.html#bronze/0"},{"type":"function","title":"Fledex.Color.Names.brown/0","doc":"","ref":"Fledex.Color.Names.html#brown/0"},{"type":"function","title":"Fledex.Color.Names.brown_sugar/0","doc":"Defines the color rgb(175, 109, 76).","ref":"Fledex.Color.Names.html#brown_sugar/0"},{"type":"function","title":"Fledex.Color.Names.bud_green/0","doc":"Defines the color rgb(122, 181, 96).","ref":"Fledex.Color.Names.html#bud_green/0"},{"type":"function","title":"Fledex.Color.Names.buff/0","doc":"Defines the color rgb(255, 198, 127).","ref":"Fledex.Color.Names.html#buff/0"},{"type":"function","title":"Fledex.Color.Names.burgundy/0","doc":"Defines the color rgb(127, 0, 33).","ref":"Fledex.Color.Names.html#burgundy/0"},{"type":"function","title":"Fledex.Color.Names.burlywood/0","doc":"Defines the color rgb(221, 183, 135).","ref":"Fledex.Color.Names.html#burlywood/0"},{"type":"function","title":"Fledex.Color.Names.burnished_brown/0","doc":"Defines the color rgb(160, 122, 114).","ref":"Fledex.Color.Names.html#burnished_brown/0"},{"type":"function","title":"Fledex.Color.Names.burnt_orange/0","doc":"Defines the color rgb(204, 84, 0).","ref":"Fledex.Color.Names.html#burnt_orange/0"},{"type":"function","title":"Fledex.Color.Names.burnt_sienna/0","doc":"Defines the color rgb(232, 114, 81).","ref":"Fledex.Color.Names.html#burnt_sienna/0"},{"type":"function","title":"Fledex.Color.Names.burnt_umber/0","doc":"Defines the color rgb(137, 51, 35).","ref":"Fledex.Color.Names.html#burnt_umber/0"},{"type":"function","title":"Fledex.Color.Names.byzantine/0","doc":"Defines the color rgb(188, 51, 163).","ref":"Fledex.Color.Names.html#byzantine/0"},{"type":"function","title":"Fledex.Color.Names.byzantium/0","doc":"Defines the color rgb(112, 40, 99).","ref":"Fledex.Color.Names.html#byzantium/0"},{"type":"function","title":"Fledex.Color.Names.cadet_blue/0","doc":"Defines the color rgb(94, 158, 160).","ref":"Fledex.Color.Names.html#cadet_blue/0"},{"type":"function","title":"Fledex.Color.Names.cadet_grey/0","doc":"Defines the color rgb(145, 163, 175).","ref":"Fledex.Color.Names.html#cadet_grey/0"},{"type":"function","title":"Fledex.Color.Names.cadetblue/0","doc":"","ref":"Fledex.Color.Names.html#cadetblue/0"},{"type":"function","title":"Fledex.Color.Names.cadmium_green/0","doc":"Defines the color rgb(0, 107, 61).","ref":"Fledex.Color.Names.html#cadmium_green/0"},{"type":"function","title":"Fledex.Color.Names.cadmium_orange/0","doc":"Defines the color rgb(237, 135, 45).","ref":"Fledex.Color.Names.html#cadmium_orange/0"},{"type":"function","title":"Fledex.Color.Names.cafe_au_lait/0","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.html#cafe_au_lait/0"},{"type":"function","title":"Fledex.Color.Names.cafe_noir/0","doc":"Defines the color rgb(73, 53, 33).","ref":"Fledex.Color.Names.html#cafe_noir/0"},{"type":"function","title":"Fledex.Color.Names.cambridge_blue/0","doc":"Defines the color rgb(163, 193, 173).","ref":"Fledex.Color.Names.html#cambridge_blue/0"},{"type":"function","title":"Fledex.Color.Names.camel/0","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.html#camel/0"},{"type":"function","title":"Fledex.Color.Names.cameo_pink/0","doc":"Defines the color rgb(239, 186, 204).","ref":"Fledex.Color.Names.html#cameo_pink/0"},{"type":"function","title":"Fledex.Color.Names.canary/0","doc":"Defines the color rgb(255, 255, 153).","ref":"Fledex.Color.Names.html#canary/0"},{"type":"function","title":"Fledex.Color.Names.canary_yellow/0","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.html#canary_yellow/0"},{"type":"function","title":"Fledex.Color.Names.candy_pink/0","doc":"Defines the color rgb(226, 112, 122).","ref":"Fledex.Color.Names.html#candy_pink/0"},{"type":"function","title":"Fledex.Color.Names.cardinal/0","doc":"Defines the color rgb(196, 30, 58).","ref":"Fledex.Color.Names.html#cardinal/0"},{"type":"function","title":"Fledex.Color.Names.caribbean_green/0","doc":"Defines the color rgb(0, 204, 153).","ref":"Fledex.Color.Names.html#caribbean_green/0"},{"type":"function","title":"Fledex.Color.Names.carmine/0","doc":"Defines the color rgb(150, 0, 22).","ref":"Fledex.Color.Names.html#carmine/0"},{"type":"function","title":"Fledex.Color.Names.carmine_m_p/0","doc":"Defines the color rgb(214, 0, 63).","ref":"Fledex.Color.Names.html#carmine_m_p/0"},{"type":"function","title":"Fledex.Color.Names.carnation_pink/0","doc":"Defines the color rgb(255, 165, 201).","ref":"Fledex.Color.Names.html#carnation_pink/0"},{"type":"function","title":"Fledex.Color.Names.carnelian/0","doc":"Defines the color rgb(178, 28, 28).","ref":"Fledex.Color.Names.html#carnelian/0"},{"type":"function","title":"Fledex.Color.Names.carolina_blue/0","doc":"Defines the color rgb(86, 160, 211).","ref":"Fledex.Color.Names.html#carolina_blue/0"},{"type":"function","title":"Fledex.Color.Names.carrot_orange/0","doc":"Defines the color rgb(237, 145, 33).","ref":"Fledex.Color.Names.html#carrot_orange/0"},{"type":"function","title":"Fledex.Color.Names.catawba/0","doc":"Defines the color rgb(112, 53, 66).","ref":"Fledex.Color.Names.html#catawba/0"},{"type":"function","title":"Fledex.Color.Names.cedar_chest/0","doc":"Defines the color rgb(201, 89, 73).","ref":"Fledex.Color.Names.html#cedar_chest/0"},{"type":"function","title":"Fledex.Color.Names.celadon/0","doc":"Defines the color rgb(170, 224, 175).","ref":"Fledex.Color.Names.html#celadon/0"},{"type":"function","title":"Fledex.Color.Names.celeste/0","doc":"Defines the color rgb(178, 255, 255).","ref":"Fledex.Color.Names.html#celeste/0"},{"type":"function","title":"Fledex.Color.Names.cerise/0","doc":"Defines the color rgb(221, 48, 99).","ref":"Fledex.Color.Names.html#cerise/0"},{"type":"function","title":"Fledex.Color.Names.cerulean/0","doc":"Defines the color rgb(0, 122, 165).","ref":"Fledex.Color.Names.html#cerulean/0"},{"type":"function","title":"Fledex.Color.Names.cerulean_blue/0","doc":"Defines the color rgb(40, 81, 191).","ref":"Fledex.Color.Names.html#cerulean_blue/0"},{"type":"function","title":"Fledex.Color.Names.cerulean_crayola/0","doc":"Defines the color rgb(28, 170, 214).","ref":"Fledex.Color.Names.html#cerulean_crayola/0"},{"type":"function","title":"Fledex.Color.Names.cerulean_frost/0","doc":"Defines the color rgb(109, 155, 193).","ref":"Fledex.Color.Names.html#cerulean_frost/0"},{"type":"function","title":"Fledex.Color.Names.champagne/0","doc":"Defines the color rgb(247, 232, 206).","ref":"Fledex.Color.Names.html#champagne/0"},{"type":"function","title":"Fledex.Color.Names.champagne_pink/0","doc":"Defines the color rgb(242, 221, 206).","ref":"Fledex.Color.Names.html#champagne_pink/0"},{"type":"function","title":"Fledex.Color.Names.charcoal/0","doc":"Defines the color rgb(53, 68, 79).","ref":"Fledex.Color.Names.html#charcoal/0"},{"type":"function","title":"Fledex.Color.Names.charm_pink/0","doc":"Defines the color rgb(229, 142, 170).","ref":"Fledex.Color.Names.html#charm_pink/0"},{"type":"function","title":"Fledex.Color.Names.chartreuse/0","doc":"","ref":"Fledex.Color.Names.html#chartreuse/0"},{"type":"function","title":"Fledex.Color.Names.chartreuse_web/0","doc":"Defines the color rgb(127, 255, 0).","ref":"Fledex.Color.Names.html#chartreuse_web/0"},{"type":"function","title":"Fledex.Color.Names.cherry_blossom_pink/0","doc":"Defines the color rgb(255, 183, 196).","ref":"Fledex.Color.Names.html#cherry_blossom_pink/0"},{"type":"function","title":"Fledex.Color.Names.chestnut/0","doc":"Defines the color rgb(147, 68, 53).","ref":"Fledex.Color.Names.html#chestnut/0"},{"type":"function","title":"Fledex.Color.Names.chili_red/0","doc":"Defines the color rgb(226, 61, 40).","ref":"Fledex.Color.Names.html#chili_red/0"},{"type":"function","title":"Fledex.Color.Names.china_pink/0","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.html#china_pink/0"},{"type":"function","title":"Fledex.Color.Names.chinese_red/0","doc":"Defines the color rgb(170, 56, 30).","ref":"Fledex.Color.Names.html#chinese_red/0"},{"type":"function","title":"Fledex.Color.Names.chinese_violet/0","doc":"Defines the color rgb(132, 96, 135).","ref":"Fledex.Color.Names.html#chinese_violet/0"},{"type":"function","title":"Fledex.Color.Names.chinese_yellow/0","doc":"Defines the color rgb(255, 178, 0).","ref":"Fledex.Color.Names.html#chinese_yellow/0"},{"type":"function","title":"Fledex.Color.Names.chocolate/0","doc":"","ref":"Fledex.Color.Names.html#chocolate/0"},{"type":"function","title":"Fledex.Color.Names.chocolate_traditional/0","doc":"Defines the color rgb(122, 63, 0).","ref":"Fledex.Color.Names.html#chocolate_traditional/0"},{"type":"function","title":"Fledex.Color.Names.chocolate_web/0","doc":"Defines the color rgb(209, 104, 30).","ref":"Fledex.Color.Names.html#chocolate_web/0"},{"type":"function","title":"Fledex.Color.Names.cinereous/0","doc":"Defines the color rgb(153, 130, 122).","ref":"Fledex.Color.Names.html#cinereous/0"},{"type":"function","title":"Fledex.Color.Names.cinnabar/0","doc":"Defines the color rgb(226, 66, 51).","ref":"Fledex.Color.Names.html#cinnabar/0"},{"type":"function","title":"Fledex.Color.Names.cinnamon_satin/0","doc":"Defines the color rgb(204, 96, 124).","ref":"Fledex.Color.Names.html#cinnamon_satin/0"},{"type":"function","title":"Fledex.Color.Names.citrine/0","doc":"Defines the color rgb(226, 209, 10).","ref":"Fledex.Color.Names.html#citrine/0"},{"type":"function","title":"Fledex.Color.Names.citron/0","doc":"Defines the color rgb(158, 168, 30).","ref":"Fledex.Color.Names.html#citron/0"},{"type":"function","title":"Fledex.Color.Names.claret/0","doc":"Defines the color rgb(127, 22, 51).","ref":"Fledex.Color.Names.html#claret/0"},{"type":"function","title":"Fledex.Color.Names.coffee/0","doc":"Defines the color rgb(112, 79, 56).","ref":"Fledex.Color.Names.html#coffee/0"},{"type":"type","title":"Fledex.Color.Names.color_names_t/0","doc":"The allowed color names","ref":"Fledex.Color.Names.html#t:color_names_t/0"},{"type":"function","title":"Fledex.Color.Names.colors/0","doc":"Get all the data about the predefined colors","ref":"Fledex.Color.Names.html#colors/0"},{"type":"function","title":"Fledex.Color.Names.columbia_blue/0","doc":"Defines the color rgb(186, 216, 234).","ref":"Fledex.Color.Names.html#columbia_blue/0"},{"type":"function","title":"Fledex.Color.Names.congo_pink/0","doc":"Defines the color rgb(247, 130, 119).","ref":"Fledex.Color.Names.html#congo_pink/0"},{"type":"function","title":"Fledex.Color.Names.cool_grey/0","doc":"Defines the color rgb(140, 145, 170).","ref":"Fledex.Color.Names.html#cool_grey/0"},{"type":"function","title":"Fledex.Color.Names.copper/0","doc":"Defines the color rgb(183, 114, 51).","ref":"Fledex.Color.Names.html#copper/0"},{"type":"function","title":"Fledex.Color.Names.copper_crayola/0","doc":"Defines the color rgb(216, 137, 102).","ref":"Fledex.Color.Names.html#copper_crayola/0"},{"type":"function","title":"Fledex.Color.Names.copper_penny/0","doc":"Defines the color rgb(173, 112, 104).","ref":"Fledex.Color.Names.html#copper_penny/0"},{"type":"function","title":"Fledex.Color.Names.copper_red/0","doc":"Defines the color rgb(204, 109, 81).","ref":"Fledex.Color.Names.html#copper_red/0"},{"type":"function","title":"Fledex.Color.Names.copper_rose/0","doc":"Defines the color rgb(153, 102, 102).","ref":"Fledex.Color.Names.html#copper_rose/0"},{"type":"function","title":"Fledex.Color.Names.coquelicot/0","doc":"Defines the color rgb(255, 56, 0).","ref":"Fledex.Color.Names.html#coquelicot/0"},{"type":"function","title":"Fledex.Color.Names.coral/0","doc":"Defines the color rgb(255, 127, 79).","ref":"Fledex.Color.Names.html#coral/0"},{"type":"function","title":"Fledex.Color.Names.coral_pink/0","doc":"Defines the color rgb(247, 130, 119).","ref":"Fledex.Color.Names.html#coral_pink/0"},{"type":"function","title":"Fledex.Color.Names.cordovan/0","doc":"Defines the color rgb(137, 63, 68).","ref":"Fledex.Color.Names.html#cordovan/0"},{"type":"function","title":"Fledex.Color.Names.corn/0","doc":"Defines the color rgb(249, 237, 91).","ref":"Fledex.Color.Names.html#corn/0"},{"type":"function","title":"Fledex.Color.Names.cornflower_blue/0","doc":"Defines the color rgb(99, 147, 237).","ref":"Fledex.Color.Names.html#cornflower_blue/0"},{"type":"function","title":"Fledex.Color.Names.cornflowerblue/0","doc":"","ref":"Fledex.Color.Names.html#cornflowerblue/0"},{"type":"function","title":"Fledex.Color.Names.cornsilk/0","doc":"Defines the color rgb(255, 247, 219).","ref":"Fledex.Color.Names.html#cornsilk/0"},{"type":"function","title":"Fledex.Color.Names.cosmic_cobalt/0","doc":"Defines the color rgb(45, 45, 135).","ref":"Fledex.Color.Names.html#cosmic_cobalt/0"},{"type":"function","title":"Fledex.Color.Names.cosmic_latte/0","doc":"Defines the color rgb(255, 247, 232).","ref":"Fledex.Color.Names.html#cosmic_latte/0"},{"type":"function","title":"Fledex.Color.Names.cotton_candy/0","doc":"Defines the color rgb(255, 188, 216).","ref":"Fledex.Color.Names.html#cotton_candy/0"},{"type":"function","title":"Fledex.Color.Names.coyote_brown/0","doc":"Defines the color rgb(130, 96, 61).","ref":"Fledex.Color.Names.html#coyote_brown/0"},{"type":"function","title":"Fledex.Color.Names.cream/0","doc":"Defines the color rgb(255, 252, 209).","ref":"Fledex.Color.Names.html#cream/0"},{"type":"function","title":"Fledex.Color.Names.crimson/0","doc":"Defines the color rgb(219, 20, 61).","ref":"Fledex.Color.Names.html#crimson/0"},{"type":"function","title":"Fledex.Color.Names.crimson_ua/0","doc":"Defines the color rgb(158, 28, 51).","ref":"Fledex.Color.Names.html#crimson_ua/0"},{"type":"function","title":"Fledex.Color.Names.cultured_pearl/0","doc":"Defines the color rgb(244, 244, 244).","ref":"Fledex.Color.Names.html#cultured_pearl/0"},{"type":"function","title":"Fledex.Color.Names.cyan/0","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.html#cyan/0"},{"type":"function","title":"Fledex.Color.Names.cyan_process/0","doc":"Defines the color rgb(0, 183, 234).","ref":"Fledex.Color.Names.html#cyan_process/0"},{"type":"function","title":"Fledex.Color.Names.cyber_grape/0","doc":"Defines the color rgb(89, 66, 124).","ref":"Fledex.Color.Names.html#cyber_grape/0"},{"type":"function","title":"Fledex.Color.Names.cyber_yellow/0","doc":"Defines the color rgb(255, 211, 0).","ref":"Fledex.Color.Names.html#cyber_yellow/0"},{"type":"function","title":"Fledex.Color.Names.cyclamen/0","doc":"Defines the color rgb(244, 112, 160).","ref":"Fledex.Color.Names.html#cyclamen/0"},{"type":"function","title":"Fledex.Color.Names.dark_brown/0","doc":"Defines the color rgb(102, 66, 33).","ref":"Fledex.Color.Names.html#dark_brown/0"},{"type":"function","title":"Fledex.Color.Names.dark_byzantium/0","doc":"Defines the color rgb(91, 56, 84).","ref":"Fledex.Color.Names.html#dark_byzantium/0"},{"type":"function","title":"Fledex.Color.Names.dark_cyan/0","doc":"Defines the color rgb(0, 140, 140).","ref":"Fledex.Color.Names.html#dark_cyan/0"},{"type":"function","title":"Fledex.Color.Names.dark_electric_blue/0","doc":"Defines the color rgb(84, 104, 119).","ref":"Fledex.Color.Names.html#dark_electric_blue/0"},{"type":"function","title":"Fledex.Color.Names.dark_goldenrod/0","doc":"Defines the color rgb(183, 135, 10).","ref":"Fledex.Color.Names.html#dark_goldenrod/0"},{"type":"function","title":"Fledex.Color.Names.dark_green_x11/0","doc":"Defines the color rgb(0, 99, 0).","ref":"Fledex.Color.Names.html#dark_green_x11/0"},{"type":"function","title":"Fledex.Color.Names.dark_jungle_green/0","doc":"Defines the color rgb(25, 35, 33).","ref":"Fledex.Color.Names.html#dark_jungle_green/0"},{"type":"function","title":"Fledex.Color.Names.dark_khaki/0","doc":"Defines the color rgb(188, 183, 107).","ref":"Fledex.Color.Names.html#dark_khaki/0"},{"type":"function","title":"Fledex.Color.Names.dark_lava/0","doc":"Defines the color rgb(71, 61, 51).","ref":"Fledex.Color.Names.html#dark_lava/0"},{"type":"function","title":"Fledex.Color.Names.dark_liver_horses/0","doc":"Defines the color rgb(84, 61, 56).","ref":"Fledex.Color.Names.html#dark_liver_horses/0"},{"type":"function","title":"Fledex.Color.Names.dark_magenta/0","doc":"Defines the color rgb(140, 0, 140).","ref":"Fledex.Color.Names.html#dark_magenta/0"},{"type":"function","title":"Fledex.Color.Names.dark_olive_green/0","doc":"Defines the color rgb(84, 107, 45).","ref":"Fledex.Color.Names.html#dark_olive_green/0"},{"type":"function","title":"Fledex.Color.Names.dark_orange/0","doc":"Defines the color rgb(255, 140, 0).","ref":"Fledex.Color.Names.html#dark_orange/0"},{"type":"function","title":"Fledex.Color.Names.dark_orchid/0","doc":"Defines the color rgb(153, 51, 204).","ref":"Fledex.Color.Names.html#dark_orchid/0"},{"type":"function","title":"Fledex.Color.Names.dark_purple/0","doc":"Defines the color rgb(48, 25, 51).","ref":"Fledex.Color.Names.html#dark_purple/0"},{"type":"function","title":"Fledex.Color.Names.dark_red/0","doc":"Defines the color rgb(140, 0, 0).","ref":"Fledex.Color.Names.html#dark_red/0"},{"type":"function","title":"Fledex.Color.Names.dark_salmon/0","doc":"Defines the color rgb(232, 150, 122).","ref":"Fledex.Color.Names.html#dark_salmon/0"},{"type":"function","title":"Fledex.Color.Names.dark_sea_green/0","doc":"Defines the color rgb(142, 188, 142).","ref":"Fledex.Color.Names.html#dark_sea_green/0"},{"type":"function","title":"Fledex.Color.Names.dark_sienna/0","doc":"Defines the color rgb(61, 20, 20).","ref":"Fledex.Color.Names.html#dark_sienna/0"},{"type":"function","title":"Fledex.Color.Names.dark_sky_blue/0","doc":"Defines the color rgb(140, 191, 214).","ref":"Fledex.Color.Names.html#dark_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.dark_slate_blue/0","doc":"Defines the color rgb(71, 61, 140).","ref":"Fledex.Color.Names.html#dark_slate_blue/0"},{"type":"function","title":"Fledex.Color.Names.dark_slate_gray/0","doc":"Defines the color rgb(45, 79, 79).","ref":"Fledex.Color.Names.html#dark_slate_gray/0"},{"type":"function","title":"Fledex.Color.Names.dark_spring_green/0","doc":"Defines the color rgb(22, 114, 68).","ref":"Fledex.Color.Names.html#dark_spring_green/0"},{"type":"function","title":"Fledex.Color.Names.dark_turquoise/0","doc":"Defines the color rgb(0, 206, 209).","ref":"Fledex.Color.Names.html#dark_turquoise/0"},{"type":"function","title":"Fledex.Color.Names.dark_violet/0","doc":"Defines the color rgb(147, 0, 211).","ref":"Fledex.Color.Names.html#dark_violet/0"},{"type":"function","title":"Fledex.Color.Names.darkblue/0","doc":"","ref":"Fledex.Color.Names.html#darkblue/0"},{"type":"function","title":"Fledex.Color.Names.darkcyan/0","doc":"","ref":"Fledex.Color.Names.html#darkcyan/0"},{"type":"function","title":"Fledex.Color.Names.darkgoldenrod/0","doc":"","ref":"Fledex.Color.Names.html#darkgoldenrod/0"},{"type":"function","title":"Fledex.Color.Names.darkgray/0","doc":"","ref":"Fledex.Color.Names.html#darkgray/0"},{"type":"function","title":"Fledex.Color.Names.darkgreen/0","doc":"","ref":"Fledex.Color.Names.html#darkgreen/0"},{"type":"function","title":"Fledex.Color.Names.darkgrey/0","doc":"","ref":"Fledex.Color.Names.html#darkgrey/0"},{"type":"function","title":"Fledex.Color.Names.darkkhaki/0","doc":"","ref":"Fledex.Color.Names.html#darkkhaki/0"},{"type":"function","title":"Fledex.Color.Names.darkmagenta/0","doc":"","ref":"Fledex.Color.Names.html#darkmagenta/0"},{"type":"function","title":"Fledex.Color.Names.darkolivegreen/0","doc":"","ref":"Fledex.Color.Names.html#darkolivegreen/0"},{"type":"function","title":"Fledex.Color.Names.darkorange/0","doc":"","ref":"Fledex.Color.Names.html#darkorange/0"},{"type":"function","title":"Fledex.Color.Names.darkorchid/0","doc":"","ref":"Fledex.Color.Names.html#darkorchid/0"},{"type":"function","title":"Fledex.Color.Names.darkred/0","doc":"","ref":"Fledex.Color.Names.html#darkred/0"},{"type":"function","title":"Fledex.Color.Names.darksalmon/0","doc":"","ref":"Fledex.Color.Names.html#darksalmon/0"},{"type":"function","title":"Fledex.Color.Names.darkseagreen/0","doc":"","ref":"Fledex.Color.Names.html#darkseagreen/0"},{"type":"function","title":"Fledex.Color.Names.darkslateblue/0","doc":"","ref":"Fledex.Color.Names.html#darkslateblue/0"},{"type":"function","title":"Fledex.Color.Names.darkslategray/0","doc":"","ref":"Fledex.Color.Names.html#darkslategray/0"},{"type":"function","title":"Fledex.Color.Names.darkslategrey/0","doc":"","ref":"Fledex.Color.Names.html#darkslategrey/0"},{"type":"function","title":"Fledex.Color.Names.darkturquoise/0","doc":"","ref":"Fledex.Color.Names.html#darkturquoise/0"},{"type":"function","title":"Fledex.Color.Names.darkviolet/0","doc":"","ref":"Fledex.Color.Names.html#darkviolet/0"},{"type":"function","title":"Fledex.Color.Names.davy_s_grey/0","doc":"Defines the color rgb(84, 84, 84).","ref":"Fledex.Color.Names.html#davy_s_grey/0"},{"type":"function","title":"Fledex.Color.Names.deep_cerise/0","doc":"Defines the color rgb(216, 51, 135).","ref":"Fledex.Color.Names.html#deep_cerise/0"},{"type":"function","title":"Fledex.Color.Names.deep_champagne/0","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.html#deep_champagne/0"},{"type":"function","title":"Fledex.Color.Names.deep_chestnut/0","doc":"Defines the color rgb(186, 79, 71).","ref":"Fledex.Color.Names.html#deep_chestnut/0"},{"type":"function","title":"Fledex.Color.Names.deep_jungle_green/0","doc":"Defines the color rgb(0, 73, 73).","ref":"Fledex.Color.Names.html#deep_jungle_green/0"},{"type":"function","title":"Fledex.Color.Names.deep_pink/0","doc":"Defines the color rgb(255, 20, 147).","ref":"Fledex.Color.Names.html#deep_pink/0"},{"type":"function","title":"Fledex.Color.Names.deep_saffron/0","doc":"Defines the color rgb(255, 153, 51).","ref":"Fledex.Color.Names.html#deep_saffron/0"},{"type":"function","title":"Fledex.Color.Names.deep_sky_blue/0","doc":"Defines the color rgb(0, 191, 255).","ref":"Fledex.Color.Names.html#deep_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.deep_space_sparkle/0","doc":"Defines the color rgb(73, 99, 107).","ref":"Fledex.Color.Names.html#deep_space_sparkle/0"},{"type":"function","title":"Fledex.Color.Names.deep_taupe/0","doc":"Defines the color rgb(124, 94, 96).","ref":"Fledex.Color.Names.html#deep_taupe/0"},{"type":"function","title":"Fledex.Color.Names.deeppink/0","doc":"","ref":"Fledex.Color.Names.html#deeppink/0"},{"type":"function","title":"Fledex.Color.Names.deepskyblue/0","doc":"","ref":"Fledex.Color.Names.html#deepskyblue/0"},{"type":"function","title":"Fledex.Color.Names.denim/0","doc":"Defines the color rgb(20, 96, 188).","ref":"Fledex.Color.Names.html#denim/0"},{"type":"function","title":"Fledex.Color.Names.denim_blue/0","doc":"Defines the color rgb(33, 66, 181).","ref":"Fledex.Color.Names.html#denim_blue/0"},{"type":"function","title":"Fledex.Color.Names.desert/0","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.html#desert/0"},{"type":"function","title":"Fledex.Color.Names.desert_sand/0","doc":"Defines the color rgb(237, 201, 175).","ref":"Fledex.Color.Names.html#desert_sand/0"},{"type":"function","title":"Fledex.Color.Names.dim_gray/0","doc":"Defines the color rgb(104, 104, 104).","ref":"Fledex.Color.Names.html#dim_gray/0"},{"type":"function","title":"Fledex.Color.Names.dimgray/0","doc":"","ref":"Fledex.Color.Names.html#dimgray/0"},{"type":"function","title":"Fledex.Color.Names.dimgrey/0","doc":"","ref":"Fledex.Color.Names.html#dimgrey/0"},{"type":"function","title":"Fledex.Color.Names.dodger_blue/0","doc":"Defines the color rgb(30, 142, 255).","ref":"Fledex.Color.Names.html#dodger_blue/0"},{"type":"function","title":"Fledex.Color.Names.dodgerblue/0","doc":"","ref":"Fledex.Color.Names.html#dodgerblue/0"},{"type":"function","title":"Fledex.Color.Names.drab_dark_brown/0","doc":"Defines the color rgb(73, 63, 40).","ref":"Fledex.Color.Names.html#drab_dark_brown/0"},{"type":"function","title":"Fledex.Color.Names.duke_blue/0","doc":"Defines the color rgb(0, 0, 155).","ref":"Fledex.Color.Names.html#duke_blue/0"},{"type":"function","title":"Fledex.Color.Names.dutch_white/0","doc":"Defines the color rgb(239, 221, 186).","ref":"Fledex.Color.Names.html#dutch_white/0"},{"type":"function","title":"Fledex.Color.Names.ebony/0","doc":"Defines the color rgb(84, 91, 79).","ref":"Fledex.Color.Names.html#ebony/0"},{"type":"function","title":"Fledex.Color.Names.ecru/0","doc":"Defines the color rgb(193, 178, 127).","ref":"Fledex.Color.Names.html#ecru/0"},{"type":"function","title":"Fledex.Color.Names.eerie_black/0","doc":"Defines the color rgb(28, 28, 28).","ref":"Fledex.Color.Names.html#eerie_black/0"},{"type":"function","title":"Fledex.Color.Names.eggplant/0","doc":"Defines the color rgb(96, 63, 81).","ref":"Fledex.Color.Names.html#eggplant/0"},{"type":"function","title":"Fledex.Color.Names.eggshell/0","doc":"Defines the color rgb(239, 234, 214).","ref":"Fledex.Color.Names.html#eggshell/0"},{"type":"function","title":"Fledex.Color.Names.electric_lime/0","doc":"Defines the color rgb(204, 255, 0).","ref":"Fledex.Color.Names.html#electric_lime/0"},{"type":"function","title":"Fledex.Color.Names.electric_purple/0","doc":"Defines the color rgb(191, 0, 255).","ref":"Fledex.Color.Names.html#electric_purple/0"},{"type":"function","title":"Fledex.Color.Names.electric_violet/0","doc":"Defines the color rgb(142, 0, 255).","ref":"Fledex.Color.Names.html#electric_violet/0"},{"type":"function","title":"Fledex.Color.Names.emerald/0","doc":"Defines the color rgb(79, 198, 119).","ref":"Fledex.Color.Names.html#emerald/0"},{"type":"function","title":"Fledex.Color.Names.eminence/0","doc":"Defines the color rgb(107, 48, 130).","ref":"Fledex.Color.Names.html#eminence/0"},{"type":"function","title":"Fledex.Color.Names.english_lavender/0","doc":"Defines the color rgb(181, 130, 147).","ref":"Fledex.Color.Names.html#english_lavender/0"},{"type":"function","title":"Fledex.Color.Names.english_red/0","doc":"Defines the color rgb(170, 73, 81).","ref":"Fledex.Color.Names.html#english_red/0"},{"type":"function","title":"Fledex.Color.Names.english_vermillion/0","doc":"Defines the color rgb(204, 71, 73).","ref":"Fledex.Color.Names.html#english_vermillion/0"},{"type":"function","title":"Fledex.Color.Names.english_violet/0","doc":"Defines the color rgb(86, 61, 91).","ref":"Fledex.Color.Names.html#english_violet/0"},{"type":"function","title":"Fledex.Color.Names.erin/0","doc":"Defines the color rgb(0, 255, 63).","ref":"Fledex.Color.Names.html#erin/0"},{"type":"function","title":"Fledex.Color.Names.eton_blue/0","doc":"Defines the color rgb(150, 198, 163).","ref":"Fledex.Color.Names.html#eton_blue/0"},{"type":"function","title":"Fledex.Color.Names.fallow/0","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.html#fallow/0"},{"type":"function","title":"Fledex.Color.Names.falu_red/0","doc":"Defines the color rgb(127, 22, 22).","ref":"Fledex.Color.Names.html#falu_red/0"},{"type":"function","title":"Fledex.Color.Names.fandango/0","doc":"Defines the color rgb(181, 51, 137).","ref":"Fledex.Color.Names.html#fandango/0"},{"type":"function","title":"Fledex.Color.Names.fandango_pink/0","doc":"Defines the color rgb(221, 81, 132).","ref":"Fledex.Color.Names.html#fandango_pink/0"},{"type":"function","title":"Fledex.Color.Names.fawn/0","doc":"Defines the color rgb(229, 170, 112).","ref":"Fledex.Color.Names.html#fawn/0"},{"type":"function","title":"Fledex.Color.Names.fern_green/0","doc":"Defines the color rgb(79, 119, 66).","ref":"Fledex.Color.Names.html#fern_green/0"},{"type":"function","title":"Fledex.Color.Names.field_drab/0","doc":"Defines the color rgb(107, 84, 30).","ref":"Fledex.Color.Names.html#field_drab/0"},{"type":"function","title":"Fledex.Color.Names.fiery_rose/0","doc":"Defines the color rgb(255, 84, 112).","ref":"Fledex.Color.Names.html#fiery_rose/0"},{"type":"function","title":"Fledex.Color.Names.finn/0","doc":"Defines the color rgb(104, 48, 104).","ref":"Fledex.Color.Names.html#finn/0"},{"type":"function","title":"Fledex.Color.Names.fire_engine_red/0","doc":"Defines the color rgb(206, 33, 40).","ref":"Fledex.Color.Names.html#fire_engine_red/0"},{"type":"function","title":"Fledex.Color.Names.firebrick/0","doc":"Defines the color rgb(178, 33, 33).","ref":"Fledex.Color.Names.html#firebrick/0"},{"type":"function","title":"Fledex.Color.Names.flame/0","doc":"Defines the color rgb(226, 89, 33).","ref":"Fledex.Color.Names.html#flame/0"},{"type":"function","title":"Fledex.Color.Names.flax/0","doc":"Defines the color rgb(237, 219, 130).","ref":"Fledex.Color.Names.html#flax/0"},{"type":"function","title":"Fledex.Color.Names.flirt/0","doc":"Defines the color rgb(163, 0, 109).","ref":"Fledex.Color.Names.html#flirt/0"},{"type":"function","title":"Fledex.Color.Names.floral_white/0","doc":"Defines the color rgb(255, 249, 239).","ref":"Fledex.Color.Names.html#floral_white/0"},{"type":"function","title":"Fledex.Color.Names.floralwhite/0","doc":"","ref":"Fledex.Color.Names.html#floralwhite/0"},{"type":"function","title":"Fledex.Color.Names.forest_green_web/0","doc":"Defines the color rgb(33, 140, 33).","ref":"Fledex.Color.Names.html#forest_green_web/0"},{"type":"function","title":"Fledex.Color.Names.forestgreen/0","doc":"","ref":"Fledex.Color.Names.html#forestgreen/0"},{"type":"function","title":"Fledex.Color.Names.french_beige/0","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.html#french_beige/0"},{"type":"function","title":"Fledex.Color.Names.french_bistre/0","doc":"Defines the color rgb(132, 109, 76).","ref":"Fledex.Color.Names.html#french_bistre/0"},{"type":"function","title":"Fledex.Color.Names.french_blue/0","doc":"Defines the color rgb(0, 114, 186).","ref":"Fledex.Color.Names.html#french_blue/0"},{"type":"function","title":"Fledex.Color.Names.french_fuchsia/0","doc":"Defines the color rgb(252, 63, 145).","ref":"Fledex.Color.Names.html#french_fuchsia/0"},{"type":"function","title":"Fledex.Color.Names.french_lilac/0","doc":"Defines the color rgb(135, 96, 142).","ref":"Fledex.Color.Names.html#french_lilac/0"},{"type":"function","title":"Fledex.Color.Names.french_lime/0","doc":"Defines the color rgb(158, 252, 56).","ref":"Fledex.Color.Names.html#french_lime/0"},{"type":"function","title":"Fledex.Color.Names.french_mauve/0","doc":"Defines the color rgb(211, 114, 211).","ref":"Fledex.Color.Names.html#french_mauve/0"},{"type":"function","title":"Fledex.Color.Names.french_pink/0","doc":"Defines the color rgb(252, 107, 158).","ref":"Fledex.Color.Names.html#french_pink/0"},{"type":"function","title":"Fledex.Color.Names.french_raspberry/0","doc":"Defines the color rgb(198, 43, 71).","ref":"Fledex.Color.Names.html#french_raspberry/0"},{"type":"function","title":"Fledex.Color.Names.french_sky_blue/0","doc":"Defines the color rgb(119, 181, 255).","ref":"Fledex.Color.Names.html#french_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.french_violet/0","doc":"Defines the color rgb(135, 5, 206).","ref":"Fledex.Color.Names.html#french_violet/0"},{"type":"function","title":"Fledex.Color.Names.frostbite/0","doc":"Defines the color rgb(232, 53, 165).","ref":"Fledex.Color.Names.html#frostbite/0"},{"type":"function","title":"Fledex.Color.Names.fuchsia/0","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.html#fuchsia/0"},{"type":"function","title":"Fledex.Color.Names.fuchsia_crayola/0","doc":"Defines the color rgb(193, 84, 193).","ref":"Fledex.Color.Names.html#fuchsia_crayola/0"},{"type":"function","title":"Fledex.Color.Names.fulvous/0","doc":"Defines the color rgb(226, 132, 0).","ref":"Fledex.Color.Names.html#fulvous/0"},{"type":"function","title":"Fledex.Color.Names.fuzzy_wuzzy/0","doc":"Defines the color rgb(135, 66, 30).","ref":"Fledex.Color.Names.html#fuzzy_wuzzy/0"},{"type":"function","title":"Fledex.Color.Names.gainsboro/0","doc":"Defines the color rgb(219, 219, 219).","ref":"Fledex.Color.Names.html#gainsboro/0"},{"type":"function","title":"Fledex.Color.Names.gamboge/0","doc":"Defines the color rgb(226, 155, 15).","ref":"Fledex.Color.Names.html#gamboge/0"},{"type":"function","title":"Fledex.Color.Names.generic_viridian/0","doc":"Defines the color rgb(0, 127, 102).","ref":"Fledex.Color.Names.html#generic_viridian/0"},{"type":"function","title":"Fledex.Color.Names.ghost_white/0","doc":"Defines the color rgb(247, 247, 255).","ref":"Fledex.Color.Names.html#ghost_white/0"},{"type":"function","title":"Fledex.Color.Names.ghostwhite/0","doc":"","ref":"Fledex.Color.Names.html#ghostwhite/0"},{"type":"function","title":"Fledex.Color.Names.glaucous/0","doc":"Defines the color rgb(96, 130, 181).","ref":"Fledex.Color.Names.html#glaucous/0"},{"type":"function","title":"Fledex.Color.Names.glossy_grape/0","doc":"Defines the color rgb(170, 145, 178).","ref":"Fledex.Color.Names.html#glossy_grape/0"},{"type":"function","title":"Fledex.Color.Names.go_green/0","doc":"Defines the color rgb(0, 170, 102).","ref":"Fledex.Color.Names.html#go_green/0"},{"type":"function","title":"Fledex.Color.Names.gold/0","doc":"","ref":"Fledex.Color.Names.html#gold/0"},{"type":"function","title":"Fledex.Color.Names.gold_crayola/0","doc":"Defines the color rgb(229, 191, 137).","ref":"Fledex.Color.Names.html#gold_crayola/0"},{"type":"function","title":"Fledex.Color.Names.gold_fusion/0","doc":"Defines the color rgb(132, 117, 79).","ref":"Fledex.Color.Names.html#gold_fusion/0"},{"type":"function","title":"Fledex.Color.Names.gold_metallic/0","doc":"Defines the color rgb(211, 175, 56).","ref":"Fledex.Color.Names.html#gold_metallic/0"},{"type":"function","title":"Fledex.Color.Names.gold_web_golden/0","doc":"Defines the color rgb(255, 214, 0).","ref":"Fledex.Color.Names.html#gold_web_golden/0"},{"type":"function","title":"Fledex.Color.Names.golden_brown/0","doc":"Defines the color rgb(153, 102, 20).","ref":"Fledex.Color.Names.html#golden_brown/0"},{"type":"function","title":"Fledex.Color.Names.golden_poppy/0","doc":"Defines the color rgb(252, 193, 0).","ref":"Fledex.Color.Names.html#golden_poppy/0"},{"type":"function","title":"Fledex.Color.Names.golden_yellow/0","doc":"Defines the color rgb(255, 221, 0).","ref":"Fledex.Color.Names.html#golden_yellow/0"},{"type":"function","title":"Fledex.Color.Names.goldenrod/0","doc":"Defines the color rgb(216, 165, 33).","ref":"Fledex.Color.Names.html#goldenrod/0"},{"type":"function","title":"Fledex.Color.Names.gotham_green/0","doc":"Defines the color rgb(0, 86, 63).","ref":"Fledex.Color.Names.html#gotham_green/0"},{"type":"function","title":"Fledex.Color.Names.granite_gray/0","doc":"Defines the color rgb(102, 102, 102).","ref":"Fledex.Color.Names.html#granite_gray/0"},{"type":"function","title":"Fledex.Color.Names.granny_smith_apple/0","doc":"Defines the color rgb(168, 226, 160).","ref":"Fledex.Color.Names.html#granny_smith_apple/0"},{"type":"function","title":"Fledex.Color.Names.gray/0","doc":"","ref":"Fledex.Color.Names.html#gray/0"},{"type":"function","title":"Fledex.Color.Names.gray_web/0","doc":"Defines the color rgb(127, 127, 127).","ref":"Fledex.Color.Names.html#gray_web/0"},{"type":"function","title":"Fledex.Color.Names.gray_x11_gray/0","doc":"Defines the color rgb(191, 191, 191).","ref":"Fledex.Color.Names.html#gray_x11_gray/0"},{"type":"function","title":"Fledex.Color.Names.green/0","doc":"Defines the color rgb(0, 255, 0).","ref":"Fledex.Color.Names.html#green/0"},{"type":"function","title":"Fledex.Color.Names.green_blue/0","doc":"Defines the color rgb(17, 99, 181).","ref":"Fledex.Color.Names.html#green_blue/0"},{"type":"function","title":"Fledex.Color.Names.green_crayola/0","doc":"Defines the color rgb(28, 170, 119).","ref":"Fledex.Color.Names.html#green_crayola/0"},{"type":"function","title":"Fledex.Color.Names.green_lizard/0","doc":"Defines the color rgb(165, 244, 51).","ref":"Fledex.Color.Names.html#green_lizard/0"},{"type":"function","title":"Fledex.Color.Names.green_munsell/0","doc":"Defines the color rgb(0, 168, 119).","ref":"Fledex.Color.Names.html#green_munsell/0"},{"type":"function","title":"Fledex.Color.Names.green_ncs/0","doc":"Defines the color rgb(0, 158, 107).","ref":"Fledex.Color.Names.html#green_ncs/0"},{"type":"function","title":"Fledex.Color.Names.green_pantone/0","doc":"Defines the color rgb(0, 173, 66).","ref":"Fledex.Color.Names.html#green_pantone/0"},{"type":"function","title":"Fledex.Color.Names.green_pigment/0","doc":"Defines the color rgb(0, 165, 79).","ref":"Fledex.Color.Names.html#green_pigment/0"},{"type":"function","title":"Fledex.Color.Names.green_sheen/0","doc":"Defines the color rgb(109, 173, 160).","ref":"Fledex.Color.Names.html#green_sheen/0"},{"type":"function","title":"Fledex.Color.Names.green_web/0","doc":"Defines the color rgb(0, 127, 0).","ref":"Fledex.Color.Names.html#green_web/0"},{"type":"function","title":"Fledex.Color.Names.greenyellow/0","doc":"","ref":"Fledex.Color.Names.html#greenyellow/0"},{"type":"function","title":"Fledex.Color.Names.grey/0","doc":"","ref":"Fledex.Color.Names.html#grey/0"},{"type":"function","title":"Fledex.Color.Names.gunmetal/0","doc":"Defines the color rgb(40, 51, 56).","ref":"Fledex.Color.Names.html#gunmetal/0"},{"type":"function","title":"Fledex.Color.Names.hansa_yellow/0","doc":"Defines the color rgb(232, 214, 107).","ref":"Fledex.Color.Names.html#hansa_yellow/0"},{"type":"function","title":"Fledex.Color.Names.harlequin/0","doc":"Defines the color rgb(63, 255, 0).","ref":"Fledex.Color.Names.html#harlequin/0"},{"type":"function","title":"Fledex.Color.Names.harvest_gold/0","doc":"Defines the color rgb(216, 145, 0).","ref":"Fledex.Color.Names.html#harvest_gold/0"},{"type":"function","title":"Fledex.Color.Names.heat_wave/0","doc":"Defines the color rgb(255, 122, 0).","ref":"Fledex.Color.Names.html#heat_wave/0"},{"type":"function","title":"Fledex.Color.Names.heliotrope/0","doc":"Defines the color rgb(221, 114, 255).","ref":"Fledex.Color.Names.html#heliotrope/0"},{"type":"function","title":"Fledex.Color.Names.heliotrope_gray/0","doc":"Defines the color rgb(170, 153, 168).","ref":"Fledex.Color.Names.html#heliotrope_gray/0"},{"type":"function","title":"Fledex.Color.Names.hollywood_cerise/0","doc":"Defines the color rgb(244, 0, 160).","ref":"Fledex.Color.Names.html#hollywood_cerise/0"},{"type":"function","title":"Fledex.Color.Names.honeydew/0","doc":"","ref":"Fledex.Color.Names.html#honeydew/0"},{"type":"function","title":"Fledex.Color.Names.honolulu_blue/0","doc":"Defines the color rgb(0, 109, 175).","ref":"Fledex.Color.Names.html#honolulu_blue/0"},{"type":"function","title":"Fledex.Color.Names.hooker_s_green/0","doc":"Defines the color rgb(73, 119, 107).","ref":"Fledex.Color.Names.html#hooker_s_green/0"},{"type":"function","title":"Fledex.Color.Names.hot_magenta/0","doc":"Defines the color rgb(255, 28, 206).","ref":"Fledex.Color.Names.html#hot_magenta/0"},{"type":"function","title":"Fledex.Color.Names.hot_pink/0","doc":"Defines the color rgb(255, 104, 181).","ref":"Fledex.Color.Names.html#hot_pink/0"},{"type":"function","title":"Fledex.Color.Names.hotpink/0","doc":"","ref":"Fledex.Color.Names.html#hotpink/0"},{"type":"function","title":"Fledex.Color.Names.hunter_green/0","doc":"Defines the color rgb(53, 94, 58).","ref":"Fledex.Color.Names.html#hunter_green/0"},{"type":"function","title":"Fledex.Color.Names.iceberg/0","doc":"Defines the color rgb(112, 165, 209).","ref":"Fledex.Color.Names.html#iceberg/0"},{"type":"function","title":"Fledex.Color.Names.illuminating_emerald/0","doc":"Defines the color rgb(48, 145, 119).","ref":"Fledex.Color.Names.html#illuminating_emerald/0"},{"type":"function","title":"Fledex.Color.Names.imperial_red/0","doc":"Defines the color rgb(237, 40, 56).","ref":"Fledex.Color.Names.html#imperial_red/0"},{"type":"function","title":"Fledex.Color.Names.inchworm/0","doc":"Defines the color rgb(178, 237, 91).","ref":"Fledex.Color.Names.html#inchworm/0"},{"type":"function","title":"Fledex.Color.Names.independence/0","doc":"Defines the color rgb(76, 81, 109).","ref":"Fledex.Color.Names.html#independence/0"},{"type":"function","title":"Fledex.Color.Names.india_green/0","doc":"Defines the color rgb(17, 135, 7).","ref":"Fledex.Color.Names.html#india_green/0"},{"type":"function","title":"Fledex.Color.Names.indian_red/0","doc":"Defines the color rgb(204, 91, 91).","ref":"Fledex.Color.Names.html#indian_red/0"},{"type":"function","title":"Fledex.Color.Names.indian_yellow/0","doc":"Defines the color rgb(226, 168, 86).","ref":"Fledex.Color.Names.html#indian_yellow/0"},{"type":"function","title":"Fledex.Color.Names.indianred/0","doc":"","ref":"Fledex.Color.Names.html#indianred/0"},{"type":"function","title":"Fledex.Color.Names.indigo/0","doc":"Defines the color rgb(73, 0, 130).","ref":"Fledex.Color.Names.html#indigo/0"},{"type":"function","title":"Fledex.Color.Names.indigo_dye/0","doc":"Defines the color rgb(0, 63, 107).","ref":"Fledex.Color.Names.html#indigo_dye/0"},{"type":"function","title":"Fledex.Color.Names.info/2","doc":"Retrieve information about the color with the given name","ref":"Fledex.Color.Names.html#info/2"},{"type":"function","title":"Fledex.Color.Names.international_klein_blue/0","doc":"Defines the color rgb(17, 10, 142).","ref":"Fledex.Color.Names.html#international_klein_blue/0"},{"type":"function","title":"Fledex.Color.Names.international_orange_engineering/0","doc":"Defines the color rgb(186, 22, 12).","ref":"Fledex.Color.Names.html#international_orange_engineering/0"},{"type":"function","title":"Fledex.Color.Names.international_orange_golden_gate_bridge/0","doc":"Defines the color rgb(191, 53, 43).","ref":"Fledex.Color.Names.html#international_orange_golden_gate_bridge/0"},{"type":"function","title":"Fledex.Color.Names.irresistible/0","doc":"Defines the color rgb(178, 68, 107).","ref":"Fledex.Color.Names.html#irresistible/0"},{"type":"function","title":"Fledex.Color.Names.isabelline/0","doc":"Defines the color rgb(244, 239, 237).","ref":"Fledex.Color.Names.html#isabelline/0"},{"type":"function","title":"Fledex.Color.Names.italian_sky_blue/0","doc":"Defines the color rgb(178, 255, 255).","ref":"Fledex.Color.Names.html#italian_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.ivory/0","doc":"Defines the color rgb(255, 255, 239).","ref":"Fledex.Color.Names.html#ivory/0"},{"type":"function","title":"Fledex.Color.Names.japanese_carmine/0","doc":"Defines the color rgb(158, 40, 51).","ref":"Fledex.Color.Names.html#japanese_carmine/0"},{"type":"function","title":"Fledex.Color.Names.japanese_violet/0","doc":"Defines the color rgb(91, 51, 86).","ref":"Fledex.Color.Names.html#japanese_violet/0"},{"type":"function","title":"Fledex.Color.Names.jasmine/0","doc":"Defines the color rgb(247, 221, 124).","ref":"Fledex.Color.Names.html#jasmine/0"},{"type":"function","title":"Fledex.Color.Names.jazzberry_jam/0","doc":"Defines the color rgb(165, 10, 94).","ref":"Fledex.Color.Names.html#jazzberry_jam/0"},{"type":"function","title":"Fledex.Color.Names.jet/0","doc":"Defines the color rgb(51, 51, 51).","ref":"Fledex.Color.Names.html#jet/0"},{"type":"function","title":"Fledex.Color.Names.jonquil/0","doc":"Defines the color rgb(244, 201, 22).","ref":"Fledex.Color.Names.html#jonquil/0"},{"type":"function","title":"Fledex.Color.Names.june_bud/0","doc":"Defines the color rgb(188, 216, 86).","ref":"Fledex.Color.Names.html#june_bud/0"},{"type":"function","title":"Fledex.Color.Names.jungle_green/0","doc":"Defines the color rgb(40, 170, 135).","ref":"Fledex.Color.Names.html#jungle_green/0"},{"type":"function","title":"Fledex.Color.Names.kelly_green/0","doc":"Defines the color rgb(76, 186, 22).","ref":"Fledex.Color.Names.html#kelly_green/0"},{"type":"function","title":"Fledex.Color.Names.keppel/0","doc":"Defines the color rgb(58, 175, 158).","ref":"Fledex.Color.Names.html#keppel/0"},{"type":"function","title":"Fledex.Color.Names.key_lime/0","doc":"Defines the color rgb(232, 244, 140).","ref":"Fledex.Color.Names.html#key_lime/0"},{"type":"function","title":"Fledex.Color.Names.khaki/0","doc":"","ref":"Fledex.Color.Names.html#khaki/0"},{"type":"function","title":"Fledex.Color.Names.khaki_web/0","doc":"Defines the color rgb(193, 175, 145).","ref":"Fledex.Color.Names.html#khaki_web/0"},{"type":"function","title":"Fledex.Color.Names.khaki_x11_light_khaki/0","doc":"Defines the color rgb(239, 229, 140).","ref":"Fledex.Color.Names.html#khaki_x11_light_khaki/0"},{"type":"function","title":"Fledex.Color.Names.kobe/0","doc":"Defines the color rgb(135, 45, 22).","ref":"Fledex.Color.Names.html#kobe/0"},{"type":"function","title":"Fledex.Color.Names.kobi/0","doc":"Defines the color rgb(232, 158, 196).","ref":"Fledex.Color.Names.html#kobi/0"},{"type":"function","title":"Fledex.Color.Names.kobicha/0","doc":"Defines the color rgb(107, 68, 35).","ref":"Fledex.Color.Names.html#kobicha/0"},{"type":"function","title":"Fledex.Color.Names.ksu_purple/0","doc":"Defines the color rgb(79, 38, 130).","ref":"Fledex.Color.Names.html#ksu_purple/0"},{"type":"function","title":"Fledex.Color.Names.languid_lavender/0","doc":"Defines the color rgb(214, 201, 221).","ref":"Fledex.Color.Names.html#languid_lavender/0"},{"type":"function","title":"Fledex.Color.Names.lapis_lazuli/0","doc":"Defines the color rgb(38, 96, 155).","ref":"Fledex.Color.Names.html#lapis_lazuli/0"},{"type":"function","title":"Fledex.Color.Names.laser_lemon/0","doc":"Defines the color rgb(255, 255, 102).","ref":"Fledex.Color.Names.html#laser_lemon/0"},{"type":"function","title":"Fledex.Color.Names.laurel_green/0","doc":"Defines the color rgb(168, 186, 158).","ref":"Fledex.Color.Names.html#laurel_green/0"},{"type":"function","title":"Fledex.Color.Names.lava/0","doc":"Defines the color rgb(206, 15, 33).","ref":"Fledex.Color.Names.html#lava/0"},{"type":"function","title":"Fledex.Color.Names.lavender/0","doc":"","ref":"Fledex.Color.Names.html#lavender/0"},{"type":"function","title":"Fledex.Color.Names.lavender_blue/0","doc":"Defines the color rgb(204, 204, 255).","ref":"Fledex.Color.Names.html#lavender_blue/0"},{"type":"function","title":"Fledex.Color.Names.lavender_blush/0","doc":"Defines the color rgb(255, 239, 244).","ref":"Fledex.Color.Names.html#lavender_blush/0"},{"type":"function","title":"Fledex.Color.Names.lavender_floral/0","doc":"Defines the color rgb(181, 124, 219).","ref":"Fledex.Color.Names.html#lavender_floral/0"},{"type":"function","title":"Fledex.Color.Names.lavender_gray/0","doc":"Defines the color rgb(196, 193, 209).","ref":"Fledex.Color.Names.html#lavender_gray/0"},{"type":"function","title":"Fledex.Color.Names.lavender_web/0","doc":"Defines the color rgb(229, 229, 249).","ref":"Fledex.Color.Names.html#lavender_web/0"},{"type":"function","title":"Fledex.Color.Names.lavenderblush/0","doc":"","ref":"Fledex.Color.Names.html#lavenderblush/0"},{"type":"function","title":"Fledex.Color.Names.lawn_green/0","doc":"Defines the color rgb(124, 252, 0).","ref":"Fledex.Color.Names.html#lawn_green/0"},{"type":"function","title":"Fledex.Color.Names.lawngreen/0","doc":"","ref":"Fledex.Color.Names.html#lawngreen/0"},{"type":"function","title":"Fledex.Color.Names.lemon/0","doc":"Defines the color rgb(255, 247, 0).","ref":"Fledex.Color.Names.html#lemon/0"},{"type":"function","title":"Fledex.Color.Names.lemon_chiffon/0","doc":"Defines the color rgb(255, 249, 204).","ref":"Fledex.Color.Names.html#lemon_chiffon/0"},{"type":"function","title":"Fledex.Color.Names.lemon_curry/0","doc":"Defines the color rgb(204, 160, 28).","ref":"Fledex.Color.Names.html#lemon_curry/0"},{"type":"function","title":"Fledex.Color.Names.lemon_glacier/0","doc":"Defines the color rgb(252, 255, 0).","ref":"Fledex.Color.Names.html#lemon_glacier/0"},{"type":"function","title":"Fledex.Color.Names.lemon_meringue/0","doc":"Defines the color rgb(244, 234, 191).","ref":"Fledex.Color.Names.html#lemon_meringue/0"},{"type":"function","title":"Fledex.Color.Names.lemon_yellow/0","doc":"Defines the color rgb(255, 244, 79).","ref":"Fledex.Color.Names.html#lemon_yellow/0"},{"type":"function","title":"Fledex.Color.Names.lemon_yellow_crayola/0","doc":"Defines the color rgb(255, 255, 158).","ref":"Fledex.Color.Names.html#lemon_yellow_crayola/0"},{"type":"function","title":"Fledex.Color.Names.lemonchiffon/0","doc":"","ref":"Fledex.Color.Names.html#lemonchiffon/0"},{"type":"function","title":"Fledex.Color.Names.liberty/0","doc":"Defines the color rgb(84, 89, 165).","ref":"Fledex.Color.Names.html#liberty/0"},{"type":"function","title":"Fledex.Color.Names.light_blue/0","doc":"Defines the color rgb(173, 216, 229).","ref":"Fledex.Color.Names.html#light_blue/0"},{"type":"function","title":"Fledex.Color.Names.light_coral/0","doc":"Defines the color rgb(239, 127, 127).","ref":"Fledex.Color.Names.html#light_coral/0"},{"type":"function","title":"Fledex.Color.Names.light_cornflower_blue/0","doc":"Defines the color rgb(147, 204, 234).","ref":"Fledex.Color.Names.html#light_cornflower_blue/0"},{"type":"function","title":"Fledex.Color.Names.light_cyan/0","doc":"Defines the color rgb(224, 255, 255).","ref":"Fledex.Color.Names.html#light_cyan/0"},{"type":"function","title":"Fledex.Color.Names.light_french_beige/0","doc":"Defines the color rgb(198, 173, 127).","ref":"Fledex.Color.Names.html#light_french_beige/0"},{"type":"function","title":"Fledex.Color.Names.light_goldenrod_yellow/0","doc":"Defines the color rgb(249, 249, 209).","ref":"Fledex.Color.Names.html#light_goldenrod_yellow/0"},{"type":"function","title":"Fledex.Color.Names.light_gray/0","doc":"Defines the color rgb(211, 211, 211).","ref":"Fledex.Color.Names.html#light_gray/0"},{"type":"function","title":"Fledex.Color.Names.light_green/0","doc":"Defines the color rgb(142, 237, 142).","ref":"Fledex.Color.Names.html#light_green/0"},{"type":"function","title":"Fledex.Color.Names.light_orange/0","doc":"Defines the color rgb(255, 216, 175).","ref":"Fledex.Color.Names.html#light_orange/0"},{"type":"function","title":"Fledex.Color.Names.light_periwinkle/0","doc":"Defines the color rgb(196, 204, 224).","ref":"Fledex.Color.Names.html#light_periwinkle/0"},{"type":"function","title":"Fledex.Color.Names.light_pink/0","doc":"Defines the color rgb(255, 181, 193).","ref":"Fledex.Color.Names.html#light_pink/0"},{"type":"function","title":"Fledex.Color.Names.light_salmon/0","doc":"Defines the color rgb(255, 160, 122).","ref":"Fledex.Color.Names.html#light_salmon/0"},{"type":"function","title":"Fledex.Color.Names.light_sea_green/0","doc":"Defines the color rgb(33, 178, 170).","ref":"Fledex.Color.Names.html#light_sea_green/0"},{"type":"function","title":"Fledex.Color.Names.light_sky_blue/0","doc":"Defines the color rgb(135, 206, 249).","ref":"Fledex.Color.Names.html#light_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.light_slate_gray/0","doc":"Defines the color rgb(119, 135, 153).","ref":"Fledex.Color.Names.html#light_slate_gray/0"},{"type":"function","title":"Fledex.Color.Names.light_steel_blue/0","doc":"Defines the color rgb(175, 196, 221).","ref":"Fledex.Color.Names.html#light_steel_blue/0"},{"type":"function","title":"Fledex.Color.Names.light_yellow/0","doc":"Defines the color rgb(255, 255, 224).","ref":"Fledex.Color.Names.html#light_yellow/0"},{"type":"function","title":"Fledex.Color.Names.lightblue/0","doc":"","ref":"Fledex.Color.Names.html#lightblue/0"},{"type":"function","title":"Fledex.Color.Names.lightcoral/0","doc":"","ref":"Fledex.Color.Names.html#lightcoral/0"},{"type":"function","title":"Fledex.Color.Names.lightcyan/0","doc":"","ref":"Fledex.Color.Names.html#lightcyan/0"},{"type":"function","title":"Fledex.Color.Names.lightgoldenrodyellow/0","doc":"","ref":"Fledex.Color.Names.html#lightgoldenrodyellow/0"},{"type":"function","title":"Fledex.Color.Names.lightgray/0","doc":"","ref":"Fledex.Color.Names.html#lightgray/0"},{"type":"function","title":"Fledex.Color.Names.lightgreen/0","doc":"","ref":"Fledex.Color.Names.html#lightgreen/0"},{"type":"function","title":"Fledex.Color.Names.lightgrey/0","doc":"","ref":"Fledex.Color.Names.html#lightgrey/0"},{"type":"function","title":"Fledex.Color.Names.lightpink/0","doc":"","ref":"Fledex.Color.Names.html#lightpink/0"},{"type":"function","title":"Fledex.Color.Names.lightsalmon/0","doc":"","ref":"Fledex.Color.Names.html#lightsalmon/0"},{"type":"function","title":"Fledex.Color.Names.lightseagreen/0","doc":"","ref":"Fledex.Color.Names.html#lightseagreen/0"},{"type":"function","title":"Fledex.Color.Names.lightskyblue/0","doc":"","ref":"Fledex.Color.Names.html#lightskyblue/0"},{"type":"function","title":"Fledex.Color.Names.lightslategray/0","doc":"","ref":"Fledex.Color.Names.html#lightslategray/0"},{"type":"function","title":"Fledex.Color.Names.lightslategrey/0","doc":"","ref":"Fledex.Color.Names.html#lightslategrey/0"},{"type":"function","title":"Fledex.Color.Names.lightsteelblue/0","doc":"","ref":"Fledex.Color.Names.html#lightsteelblue/0"},{"type":"function","title":"Fledex.Color.Names.lightyellow/0","doc":"","ref":"Fledex.Color.Names.html#lightyellow/0"},{"type":"function","title":"Fledex.Color.Names.lilac/0","doc":"Defines the color rgb(198, 163, 198).","ref":"Fledex.Color.Names.html#lilac/0"},{"type":"function","title":"Fledex.Color.Names.lilac_luster/0","doc":"Defines the color rgb(173, 153, 170).","ref":"Fledex.Color.Names.html#lilac_luster/0"},{"type":"function","title":"Fledex.Color.Names.lime/0","doc":"","ref":"Fledex.Color.Names.html#lime/0"},{"type":"function","title":"Fledex.Color.Names.lime_color_wheel/0","doc":"Defines the color rgb(191, 255, 0).","ref":"Fledex.Color.Names.html#lime_color_wheel/0"},{"type":"function","title":"Fledex.Color.Names.lime_green/0","doc":"Defines the color rgb(51, 204, 51).","ref":"Fledex.Color.Names.html#lime_green/0"},{"type":"function","title":"Fledex.Color.Names.lime_web_x11_green/0","doc":"Defines the color rgb(0, 255, 0).","ref":"Fledex.Color.Names.html#lime_web_x11_green/0"},{"type":"function","title":"Fledex.Color.Names.limegreen/0","doc":"","ref":"Fledex.Color.Names.html#limegreen/0"},{"type":"function","title":"Fledex.Color.Names.lincoln_green/0","doc":"Defines the color rgb(25, 89, 5).","ref":"Fledex.Color.Names.html#lincoln_green/0"},{"type":"function","title":"Fledex.Color.Names.linen/0","doc":"Defines the color rgb(249, 239, 229).","ref":"Fledex.Color.Names.html#linen/0"},{"type":"function","title":"Fledex.Color.Names.lion/0","doc":"Defines the color rgb(221, 204, 155).","ref":"Fledex.Color.Names.html#lion/0"},{"type":"function","title":"Fledex.Color.Names.liseran_purple/0","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.html#liseran_purple/0"},{"type":"function","title":"Fledex.Color.Names.little_boy_blue/0","doc":"Defines the color rgb(107, 160, 219).","ref":"Fledex.Color.Names.html#little_boy_blue/0"},{"type":"function","title":"Fledex.Color.Names.liver/0","doc":"Defines the color rgb(102, 76, 71).","ref":"Fledex.Color.Names.html#liver/0"},{"type":"function","title":"Fledex.Color.Names.liver_chestnut/0","doc":"Defines the color rgb(153, 114, 86).","ref":"Fledex.Color.Names.html#liver_chestnut/0"},{"type":"function","title":"Fledex.Color.Names.liver_dogs/0","doc":"Defines the color rgb(183, 109, 40).","ref":"Fledex.Color.Names.html#liver_dogs/0"},{"type":"function","title":"Fledex.Color.Names.liver_organ/0","doc":"Defines the color rgb(107, 45, 30).","ref":"Fledex.Color.Names.html#liver_organ/0"},{"type":"function","title":"Fledex.Color.Names.livid/0","doc":"Defines the color rgb(102, 153, 204).","ref":"Fledex.Color.Names.html#livid/0"},{"type":"function","title":"Fledex.Color.Names.macaroni_and_cheese/0","doc":"Defines the color rgb(255, 188, 135).","ref":"Fledex.Color.Names.html#macaroni_and_cheese/0"},{"type":"function","title":"Fledex.Color.Names.madder_lake/0","doc":"Defines the color rgb(204, 51, 53).","ref":"Fledex.Color.Names.html#madder_lake/0"},{"type":"function","title":"Fledex.Color.Names.magenta/0","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.html#magenta/0"},{"type":"function","title":"Fledex.Color.Names.magenta_crayola/0","doc":"Defines the color rgb(244, 84, 165).","ref":"Fledex.Color.Names.html#magenta_crayola/0"},{"type":"function","title":"Fledex.Color.Names.magenta_dye/0","doc":"Defines the color rgb(201, 30, 122).","ref":"Fledex.Color.Names.html#magenta_dye/0"},{"type":"function","title":"Fledex.Color.Names.magenta_haze/0","doc":"Defines the color rgb(158, 68, 117).","ref":"Fledex.Color.Names.html#magenta_haze/0"},{"type":"function","title":"Fledex.Color.Names.magenta_pantone/0","doc":"Defines the color rgb(209, 63, 124).","ref":"Fledex.Color.Names.html#magenta_pantone/0"},{"type":"function","title":"Fledex.Color.Names.magenta_process/0","doc":"Defines the color rgb(255, 0, 142).","ref":"Fledex.Color.Names.html#magenta_process/0"},{"type":"function","title":"Fledex.Color.Names.magic_mint/0","doc":"Defines the color rgb(170, 239, 209).","ref":"Fledex.Color.Names.html#magic_mint/0"},{"type":"function","title":"Fledex.Color.Names.magnolia/0","doc":"Defines the color rgb(242, 232, 214).","ref":"Fledex.Color.Names.html#magnolia/0"},{"type":"function","title":"Fledex.Color.Names.mahogany/0","doc":"Defines the color rgb(191, 63, 0).","ref":"Fledex.Color.Names.html#mahogany/0"},{"type":"function","title":"Fledex.Color.Names.maize/0","doc":"Defines the color rgb(249, 237, 91).","ref":"Fledex.Color.Names.html#maize/0"},{"type":"function","title":"Fledex.Color.Names.maize_crayola/0","doc":"Defines the color rgb(242, 198, 73).","ref":"Fledex.Color.Names.html#maize_crayola/0"},{"type":"function","title":"Fledex.Color.Names.majorelle_blue/0","doc":"Defines the color rgb(96, 79, 219).","ref":"Fledex.Color.Names.html#majorelle_blue/0"},{"type":"function","title":"Fledex.Color.Names.malachite/0","doc":"Defines the color rgb(10, 216, 81).","ref":"Fledex.Color.Names.html#malachite/0"},{"type":"function","title":"Fledex.Color.Names.manatee/0","doc":"Defines the color rgb(150, 153, 170).","ref":"Fledex.Color.Names.html#manatee/0"},{"type":"function","title":"Fledex.Color.Names.mandarin/0","doc":"Defines the color rgb(242, 122, 71).","ref":"Fledex.Color.Names.html#mandarin/0"},{"type":"function","title":"Fledex.Color.Names.mango/0","doc":"Defines the color rgb(252, 191, 2).","ref":"Fledex.Color.Names.html#mango/0"},{"type":"function","title":"Fledex.Color.Names.mango_tango/0","doc":"Defines the color rgb(255, 130, 66).","ref":"Fledex.Color.Names.html#mango_tango/0"},{"type":"function","title":"Fledex.Color.Names.mantis/0","doc":"Defines the color rgb(114, 193, 102).","ref":"Fledex.Color.Names.html#mantis/0"},{"type":"function","title":"Fledex.Color.Names.mardi_gras/0","doc":"Defines the color rgb(135, 0, 132).","ref":"Fledex.Color.Names.html#mardi_gras/0"},{"type":"function","title":"Fledex.Color.Names.marigold/0","doc":"Defines the color rgb(234, 163, 33).","ref":"Fledex.Color.Names.html#marigold/0"},{"type":"function","title":"Fledex.Color.Names.maroon/0","doc":"","ref":"Fledex.Color.Names.html#maroon/0"},{"type":"function","title":"Fledex.Color.Names.maroon_crayola/0","doc":"Defines the color rgb(193, 33, 71).","ref":"Fledex.Color.Names.html#maroon_crayola/0"},{"type":"function","title":"Fledex.Color.Names.maroon_web/0","doc":"Defines the color rgb(127, 0, 0).","ref":"Fledex.Color.Names.html#maroon_web/0"},{"type":"function","title":"Fledex.Color.Names.maroon_x11/0","doc":"Defines the color rgb(175, 48, 96).","ref":"Fledex.Color.Names.html#maroon_x11/0"},{"type":"function","title":"Fledex.Color.Names.mauve/0","doc":"Defines the color rgb(224, 175, 255).","ref":"Fledex.Color.Names.html#mauve/0"},{"type":"function","title":"Fledex.Color.Names.mauve_taupe/0","doc":"Defines the color rgb(145, 94, 109).","ref":"Fledex.Color.Names.html#mauve_taupe/0"},{"type":"function","title":"Fledex.Color.Names.mauvelous/0","doc":"Defines the color rgb(239, 153, 170).","ref":"Fledex.Color.Names.html#mauvelous/0"},{"type":"function","title":"Fledex.Color.Names.maximum_blue/0","doc":"Defines the color rgb(71, 170, 204).","ref":"Fledex.Color.Names.html#maximum_blue/0"},{"type":"function","title":"Fledex.Color.Names.maximum_blue_green/0","doc":"Defines the color rgb(48, 191, 191).","ref":"Fledex.Color.Names.html#maximum_blue_green/0"},{"type":"function","title":"Fledex.Color.Names.maximum_blue_purple/0","doc":"Defines the color rgb(170, 170, 229).","ref":"Fledex.Color.Names.html#maximum_blue_purple/0"},{"type":"function","title":"Fledex.Color.Names.maximum_green/0","doc":"Defines the color rgb(94, 140, 48).","ref":"Fledex.Color.Names.html#maximum_green/0"},{"type":"function","title":"Fledex.Color.Names.maximum_green_yellow/0","doc":"Defines the color rgb(216, 229, 79).","ref":"Fledex.Color.Names.html#maximum_green_yellow/0"},{"type":"function","title":"Fledex.Color.Names.maximum_purple/0","doc":"Defines the color rgb(114, 51, 127).","ref":"Fledex.Color.Names.html#maximum_purple/0"},{"type":"function","title":"Fledex.Color.Names.maximum_red/0","doc":"Defines the color rgb(216, 33, 33).","ref":"Fledex.Color.Names.html#maximum_red/0"},{"type":"function","title":"Fledex.Color.Names.maximum_red_purple/0","doc":"Defines the color rgb(165, 58, 119).","ref":"Fledex.Color.Names.html#maximum_red_purple/0"},{"type":"function","title":"Fledex.Color.Names.maximum_yellow/0","doc":"Defines the color rgb(249, 249, 56).","ref":"Fledex.Color.Names.html#maximum_yellow/0"},{"type":"function","title":"Fledex.Color.Names.maximum_yellow_red/0","doc":"Defines the color rgb(242, 186, 73).","ref":"Fledex.Color.Names.html#maximum_yellow_red/0"},{"type":"function","title":"Fledex.Color.Names.may_green/0","doc":"Defines the color rgb(76, 145, 63).","ref":"Fledex.Color.Names.html#may_green/0"},{"type":"function","title":"Fledex.Color.Names.maya_blue/0","doc":"Defines the color rgb(114, 193, 249).","ref":"Fledex.Color.Names.html#maya_blue/0"},{"type":"function","title":"Fledex.Color.Names.medium_aquamarine/0","doc":"Defines the color rgb(102, 221, 170).","ref":"Fledex.Color.Names.html#medium_aquamarine/0"},{"type":"function","title":"Fledex.Color.Names.medium_blue/0","doc":"Defines the color rgb(0, 0, 204).","ref":"Fledex.Color.Names.html#medium_blue/0"},{"type":"function","title":"Fledex.Color.Names.medium_candy_apple_red/0","doc":"Defines the color rgb(226, 5, 43).","ref":"Fledex.Color.Names.html#medium_candy_apple_red/0"},{"type":"function","title":"Fledex.Color.Names.medium_carmine/0","doc":"Defines the color rgb(175, 63, 53).","ref":"Fledex.Color.Names.html#medium_carmine/0"},{"type":"function","title":"Fledex.Color.Names.medium_champagne/0","doc":"Defines the color rgb(242, 229, 170).","ref":"Fledex.Color.Names.html#medium_champagne/0"},{"type":"function","title":"Fledex.Color.Names.medium_orchid/0","doc":"Defines the color rgb(186, 84, 211).","ref":"Fledex.Color.Names.html#medium_orchid/0"},{"type":"function","title":"Fledex.Color.Names.medium_purple/0","doc":"Defines the color rgb(147, 112, 219).","ref":"Fledex.Color.Names.html#medium_purple/0"},{"type":"function","title":"Fledex.Color.Names.medium_sea_green/0","doc":"Defines the color rgb(61, 178, 112).","ref":"Fledex.Color.Names.html#medium_sea_green/0"},{"type":"function","title":"Fledex.Color.Names.medium_slate_blue/0","doc":"Defines the color rgb(122, 104, 237).","ref":"Fledex.Color.Names.html#medium_slate_blue/0"},{"type":"function","title":"Fledex.Color.Names.medium_spring_green/0","doc":"Defines the color rgb(0, 249, 153).","ref":"Fledex.Color.Names.html#medium_spring_green/0"},{"type":"function","title":"Fledex.Color.Names.medium_turquoise/0","doc":"Defines the color rgb(71, 209, 204).","ref":"Fledex.Color.Names.html#medium_turquoise/0"},{"type":"function","title":"Fledex.Color.Names.medium_violet_red/0","doc":"Defines the color rgb(198, 20, 132).","ref":"Fledex.Color.Names.html#medium_violet_red/0"},{"type":"function","title":"Fledex.Color.Names.mediumaquamarine/0","doc":"","ref":"Fledex.Color.Names.html#mediumaquamarine/0"},{"type":"function","title":"Fledex.Color.Names.mediumblue/0","doc":"","ref":"Fledex.Color.Names.html#mediumblue/0"},{"type":"function","title":"Fledex.Color.Names.mediumorchid/0","doc":"","ref":"Fledex.Color.Names.html#mediumorchid/0"},{"type":"function","title":"Fledex.Color.Names.mediumpurple/0","doc":"","ref":"Fledex.Color.Names.html#mediumpurple/0"},{"type":"function","title":"Fledex.Color.Names.mediumseagreen/0","doc":"","ref":"Fledex.Color.Names.html#mediumseagreen/0"},{"type":"function","title":"Fledex.Color.Names.mediumslateblue/0","doc":"","ref":"Fledex.Color.Names.html#mediumslateblue/0"},{"type":"function","title":"Fledex.Color.Names.mediumspringgreen/0","doc":"","ref":"Fledex.Color.Names.html#mediumspringgreen/0"},{"type":"function","title":"Fledex.Color.Names.mediumturquoise/0","doc":"","ref":"Fledex.Color.Names.html#mediumturquoise/0"},{"type":"function","title":"Fledex.Color.Names.mediumvioletred/0","doc":"","ref":"Fledex.Color.Names.html#mediumvioletred/0"},{"type":"function","title":"Fledex.Color.Names.mellow_apricot/0","doc":"Defines the color rgb(247, 183, 119).","ref":"Fledex.Color.Names.html#mellow_apricot/0"},{"type":"function","title":"Fledex.Color.Names.mellow_yellow/0","doc":"Defines the color rgb(247, 221, 124).","ref":"Fledex.Color.Names.html#mellow_yellow/0"},{"type":"function","title":"Fledex.Color.Names.melon/0","doc":"Defines the color rgb(255, 186, 173).","ref":"Fledex.Color.Names.html#melon/0"},{"type":"function","title":"Fledex.Color.Names.metallic_gold/0","doc":"Defines the color rgb(211, 175, 56).","ref":"Fledex.Color.Names.html#metallic_gold/0"},{"type":"function","title":"Fledex.Color.Names.metallic_seaweed/0","doc":"Defines the color rgb(10, 124, 140).","ref":"Fledex.Color.Names.html#metallic_seaweed/0"},{"type":"function","title":"Fledex.Color.Names.metallic_sunburst/0","doc":"Defines the color rgb(155, 124, 56).","ref":"Fledex.Color.Names.html#metallic_sunburst/0"},{"type":"function","title":"Fledex.Color.Names.mexican_pink/0","doc":"Defines the color rgb(226, 0, 124).","ref":"Fledex.Color.Names.html#mexican_pink/0"},{"type":"function","title":"Fledex.Color.Names.middle_blue/0","doc":"Defines the color rgb(124, 211, 229).","ref":"Fledex.Color.Names.html#middle_blue/0"},{"type":"function","title":"Fledex.Color.Names.middle_blue_green/0","doc":"Defines the color rgb(140, 216, 204).","ref":"Fledex.Color.Names.html#middle_blue_green/0"},{"type":"function","title":"Fledex.Color.Names.middle_blue_purple/0","doc":"Defines the color rgb(140, 114, 191).","ref":"Fledex.Color.Names.html#middle_blue_purple/0"},{"type":"function","title":"Fledex.Color.Names.middle_green/0","doc":"Defines the color rgb(76, 140, 86).","ref":"Fledex.Color.Names.html#middle_green/0"},{"type":"function","title":"Fledex.Color.Names.middle_green_yellow/0","doc":"Defines the color rgb(170, 191, 96).","ref":"Fledex.Color.Names.html#middle_green_yellow/0"},{"type":"function","title":"Fledex.Color.Names.middle_grey/0","doc":"Defines the color rgb(140, 135, 127).","ref":"Fledex.Color.Names.html#middle_grey/0"},{"type":"function","title":"Fledex.Color.Names.middle_purple/0","doc":"Defines the color rgb(216, 130, 181).","ref":"Fledex.Color.Names.html#middle_purple/0"},{"type":"function","title":"Fledex.Color.Names.middle_red/0","doc":"Defines the color rgb(229, 142, 114).","ref":"Fledex.Color.Names.html#middle_red/0"},{"type":"function","title":"Fledex.Color.Names.middle_red_purple/0","doc":"Defines the color rgb(165, 84, 84).","ref":"Fledex.Color.Names.html#middle_red_purple/0"},{"type":"function","title":"Fledex.Color.Names.middle_yellow/0","doc":"Defines the color rgb(255, 234, 0).","ref":"Fledex.Color.Names.html#middle_yellow/0"},{"type":"function","title":"Fledex.Color.Names.middle_yellow_red/0","doc":"Defines the color rgb(237, 175, 117).","ref":"Fledex.Color.Names.html#middle_yellow_red/0"},{"type":"function","title":"Fledex.Color.Names.midnight/0","doc":"Defines the color rgb(112, 38, 112).","ref":"Fledex.Color.Names.html#midnight/0"},{"type":"function","title":"Fledex.Color.Names.midnight_blue/0","doc":"Defines the color rgb(25, 25, 112).","ref":"Fledex.Color.Names.html#midnight_blue/0"},{"type":"function","title":"Fledex.Color.Names.midnight_green_eagle_green/0","doc":"Defines the color rgb(0, 73, 84).","ref":"Fledex.Color.Names.html#midnight_green_eagle_green/0"},{"type":"function","title":"Fledex.Color.Names.midnightblue/0","doc":"","ref":"Fledex.Color.Names.html#midnightblue/0"},{"type":"function","title":"Fledex.Color.Names.mikado_yellow/0","doc":"Defines the color rgb(255, 196, 12).","ref":"Fledex.Color.Names.html#mikado_yellow/0"},{"type":"function","title":"Fledex.Color.Names.mimi_pink/0","doc":"Defines the color rgb(255, 216, 232).","ref":"Fledex.Color.Names.html#mimi_pink/0"},{"type":"function","title":"Fledex.Color.Names.mindaro/0","doc":"Defines the color rgb(226, 249, 135).","ref":"Fledex.Color.Names.html#mindaro/0"},{"type":"function","title":"Fledex.Color.Names.ming/0","doc":"Defines the color rgb(53, 114, 124).","ref":"Fledex.Color.Names.html#ming/0"},{"type":"function","title":"Fledex.Color.Names.minion_yellow/0","doc":"Defines the color rgb(244, 219, 79).","ref":"Fledex.Color.Names.html#minion_yellow/0"},{"type":"function","title":"Fledex.Color.Names.mint/0","doc":"Defines the color rgb(61, 181, 137).","ref":"Fledex.Color.Names.html#mint/0"},{"type":"function","title":"Fledex.Color.Names.mint_cream/0","doc":"Defines the color rgb(244, 255, 249).","ref":"Fledex.Color.Names.html#mint_cream/0"},{"type":"function","title":"Fledex.Color.Names.mint_green/0","doc":"Defines the color rgb(153, 255, 153).","ref":"Fledex.Color.Names.html#mint_green/0"},{"type":"function","title":"Fledex.Color.Names.mintcream/0","doc":"","ref":"Fledex.Color.Names.html#mintcream/0"},{"type":"function","title":"Fledex.Color.Names.misty_moss/0","doc":"Defines the color rgb(186, 181, 119).","ref":"Fledex.Color.Names.html#misty_moss/0"},{"type":"function","title":"Fledex.Color.Names.misty_rose/0","doc":"Defines the color rgb(255, 226, 224).","ref":"Fledex.Color.Names.html#misty_rose/0"},{"type":"function","title":"Fledex.Color.Names.mistyrose/0","doc":"","ref":"Fledex.Color.Names.html#mistyrose/0"},{"type":"function","title":"Fledex.Color.Names.moccasin/0","doc":"","ref":"Fledex.Color.Names.html#moccasin/0"},{"type":"function","title":"Fledex.Color.Names.mode_beige/0","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.html#mode_beige/0"},{"type":"function","title":"Fledex.Color.Names.mona_lisa/0","doc":"Defines the color rgb(255, 147, 142).","ref":"Fledex.Color.Names.html#mona_lisa/0"},{"type":"function","title":"Fledex.Color.Names.morning_blue/0","doc":"Defines the color rgb(140, 163, 153).","ref":"Fledex.Color.Names.html#morning_blue/0"},{"type":"function","title":"Fledex.Color.Names.moss_green/0","doc":"Defines the color rgb(137, 153, 91).","ref":"Fledex.Color.Names.html#moss_green/0"},{"type":"function","title":"Fledex.Color.Names.mountain_meadow/0","doc":"Defines the color rgb(48, 186, 142).","ref":"Fledex.Color.Names.html#mountain_meadow/0"},{"type":"function","title":"Fledex.Color.Names.mountbatten_pink/0","doc":"Defines the color rgb(153, 122, 140).","ref":"Fledex.Color.Names.html#mountbatten_pink/0"},{"type":"function","title":"Fledex.Color.Names.msu_green/0","doc":"Defines the color rgb(22, 68, 58).","ref":"Fledex.Color.Names.html#msu_green/0"},{"type":"function","title":"Fledex.Color.Names.mulberry/0","doc":"Defines the color rgb(196, 73, 140).","ref":"Fledex.Color.Names.html#mulberry/0"},{"type":"function","title":"Fledex.Color.Names.mulberry_crayola/0","doc":"Defines the color rgb(198, 79, 155).","ref":"Fledex.Color.Names.html#mulberry_crayola/0"},{"type":"function","title":"Fledex.Color.Names.mustard/0","doc":"Defines the color rgb(255, 219, 89).","ref":"Fledex.Color.Names.html#mustard/0"},{"type":"function","title":"Fledex.Color.Names.myrtle_green/0","doc":"Defines the color rgb(48, 119, 114).","ref":"Fledex.Color.Names.html#myrtle_green/0"},{"type":"function","title":"Fledex.Color.Names.mystic/0","doc":"Defines the color rgb(214, 81, 130).","ref":"Fledex.Color.Names.html#mystic/0"},{"type":"function","title":"Fledex.Color.Names.mystic_maroon/0","doc":"Defines the color rgb(173, 66, 119).","ref":"Fledex.Color.Names.html#mystic_maroon/0"},{"type":"function","title":"Fledex.Color.Names.nadeshiko_pink/0","doc":"Defines the color rgb(244, 173, 198).","ref":"Fledex.Color.Names.html#nadeshiko_pink/0"},{"type":"function","title":"Fledex.Color.Names.names/0","doc":"Get a list of all the predefined color (atom) names.\n\nThe name can be used to either retrieve the info by calling `info/2` or by calling the function with that\nname (see also the description at the top and take a look at this [example livebook](3b_fledex_more_about_colors.livemd))","ref":"Fledex.Color.Names.html#names/0"},{"type":"function","title":"Fledex.Color.Names.naples_yellow/0","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.html#naples_yellow/0"},{"type":"function","title":"Fledex.Color.Names.navajo_white/0","doc":"Defines the color rgb(255, 221, 173).","ref":"Fledex.Color.Names.html#navajo_white/0"},{"type":"function","title":"Fledex.Color.Names.navajowhite/0","doc":"","ref":"Fledex.Color.Names.html#navajowhite/0"},{"type":"function","title":"Fledex.Color.Names.navy/0","doc":"","ref":"Fledex.Color.Names.html#navy/0"},{"type":"function","title":"Fledex.Color.Names.navy_blue/0","doc":"Defines the color rgb(0, 0, 127).","ref":"Fledex.Color.Names.html#navy_blue/0"},{"type":"function","title":"Fledex.Color.Names.navy_blue_crayola/0","doc":"Defines the color rgb(25, 114, 209).","ref":"Fledex.Color.Names.html#navy_blue_crayola/0"},{"type":"function","title":"Fledex.Color.Names.neon_blue/0","doc":"Defines the color rgb(68, 102, 255).","ref":"Fledex.Color.Names.html#neon_blue/0"},{"type":"function","title":"Fledex.Color.Names.neon_fuchsia/0","doc":"Defines the color rgb(255, 63, 99).","ref":"Fledex.Color.Names.html#neon_fuchsia/0"},{"type":"function","title":"Fledex.Color.Names.neon_green/0","doc":"Defines the color rgb(56, 255, 20).","ref":"Fledex.Color.Names.html#neon_green/0"},{"type":"function","title":"Fledex.Color.Names.new_york_pink/0","doc":"Defines the color rgb(214, 130, 127).","ref":"Fledex.Color.Names.html#new_york_pink/0"},{"type":"function","title":"Fledex.Color.Names.nickel/0","doc":"Defines the color rgb(114, 114, 114).","ref":"Fledex.Color.Names.html#nickel/0"},{"type":"function","title":"Fledex.Color.Names.non_photo_blue/0","doc":"Defines the color rgb(163, 221, 237).","ref":"Fledex.Color.Names.html#non_photo_blue/0"},{"type":"function","title":"Fledex.Color.Names.nyanza/0","doc":"Defines the color rgb(232, 255, 219).","ref":"Fledex.Color.Names.html#nyanza/0"},{"type":"function","title":"Fledex.Color.Names.ochre/0","doc":"Defines the color rgb(204, 119, 33).","ref":"Fledex.Color.Names.html#ochre/0"},{"type":"function","title":"Fledex.Color.Names.old_burgundy/0","doc":"Defines the color rgb(66, 48, 45).","ref":"Fledex.Color.Names.html#old_burgundy/0"},{"type":"function","title":"Fledex.Color.Names.old_gold/0","doc":"Defines the color rgb(206, 181, 58).","ref":"Fledex.Color.Names.html#old_gold/0"},{"type":"function","title":"Fledex.Color.Names.old_lace/0","doc":"Defines the color rgb(252, 244, 229).","ref":"Fledex.Color.Names.html#old_lace/0"},{"type":"function","title":"Fledex.Color.Names.old_lavender/0","doc":"Defines the color rgb(119, 104, 119).","ref":"Fledex.Color.Names.html#old_lavender/0"},{"type":"function","title":"Fledex.Color.Names.old_mauve/0","doc":"Defines the color rgb(102, 48, 71).","ref":"Fledex.Color.Names.html#old_mauve/0"},{"type":"function","title":"Fledex.Color.Names.old_rose/0","doc":"Defines the color rgb(191, 127, 130).","ref":"Fledex.Color.Names.html#old_rose/0"},{"type":"function","title":"Fledex.Color.Names.old_silver/0","doc":"Defines the color rgb(132, 132, 130).","ref":"Fledex.Color.Names.html#old_silver/0"},{"type":"function","title":"Fledex.Color.Names.oldlace/0","doc":"","ref":"Fledex.Color.Names.html#oldlace/0"},{"type":"function","title":"Fledex.Color.Names.olive/0","doc":"Defines the color rgb(127, 127, 0).","ref":"Fledex.Color.Names.html#olive/0"},{"type":"function","title":"Fledex.Color.Names.olive_drab_3/0","doc":"Defines the color rgb(107, 142, 35).","ref":"Fledex.Color.Names.html#olive_drab_3/0"},{"type":"function","title":"Fledex.Color.Names.olive_drab_7/0","doc":"Defines the color rgb(61, 51, 30).","ref":"Fledex.Color.Names.html#olive_drab_7/0"},{"type":"function","title":"Fledex.Color.Names.olive_green/0","doc":"Defines the color rgb(181, 178, 91).","ref":"Fledex.Color.Names.html#olive_green/0"},{"type":"function","title":"Fledex.Color.Names.olivedrab/0","doc":"","ref":"Fledex.Color.Names.html#olivedrab/0"},{"type":"function","title":"Fledex.Color.Names.olivine/0","doc":"Defines the color rgb(153, 186, 114).","ref":"Fledex.Color.Names.html#olivine/0"},{"type":"function","title":"Fledex.Color.Names.onyx/0","doc":"Defines the color rgb(53, 56, 56).","ref":"Fledex.Color.Names.html#onyx/0"},{"type":"function","title":"Fledex.Color.Names.opal/0","doc":"Defines the color rgb(168, 193, 188).","ref":"Fledex.Color.Names.html#opal/0"},{"type":"function","title":"Fledex.Color.Names.opera_mauve/0","doc":"Defines the color rgb(183, 132, 165).","ref":"Fledex.Color.Names.html#opera_mauve/0"},{"type":"function","title":"Fledex.Color.Names.orange/0","doc":"Defines the color rgb(255, 127, 0).","ref":"Fledex.Color.Names.html#orange/0"},{"type":"function","title":"Fledex.Color.Names.orange_crayola/0","doc":"Defines the color rgb(255, 117, 56).","ref":"Fledex.Color.Names.html#orange_crayola/0"},{"type":"function","title":"Fledex.Color.Names.orange_pantone/0","doc":"Defines the color rgb(255, 89, 0).","ref":"Fledex.Color.Names.html#orange_pantone/0"},{"type":"function","title":"Fledex.Color.Names.orange_peel/0","doc":"Defines the color rgb(255, 158, 0).","ref":"Fledex.Color.Names.html#orange_peel/0"},{"type":"function","title":"Fledex.Color.Names.orange_red/0","doc":"Defines the color rgb(255, 104, 30).","ref":"Fledex.Color.Names.html#orange_red/0"},{"type":"function","title":"Fledex.Color.Names.orange_red_crayola/0","doc":"Defines the color rgb(255, 84, 73).","ref":"Fledex.Color.Names.html#orange_red_crayola/0"},{"type":"function","title":"Fledex.Color.Names.orange_soda/0","doc":"Defines the color rgb(249, 91, 61).","ref":"Fledex.Color.Names.html#orange_soda/0"},{"type":"function","title":"Fledex.Color.Names.orange_web/0","doc":"Defines the color rgb(255, 165, 0).","ref":"Fledex.Color.Names.html#orange_web/0"},{"type":"function","title":"Fledex.Color.Names.orange_yellow/0","doc":"Defines the color rgb(244, 188, 30).","ref":"Fledex.Color.Names.html#orange_yellow/0"},{"type":"function","title":"Fledex.Color.Names.orange_yellow_crayola/0","doc":"Defines the color rgb(247, 214, 104).","ref":"Fledex.Color.Names.html#orange_yellow_crayola/0"},{"type":"function","title":"Fledex.Color.Names.orangered/0","doc":"","ref":"Fledex.Color.Names.html#orangered/0"},{"type":"function","title":"Fledex.Color.Names.orchid/0","doc":"Defines the color rgb(216, 112, 214).","ref":"Fledex.Color.Names.html#orchid/0"},{"type":"function","title":"Fledex.Color.Names.orchid_crayola/0","doc":"Defines the color rgb(226, 155, 209).","ref":"Fledex.Color.Names.html#orchid_crayola/0"},{"type":"function","title":"Fledex.Color.Names.orchid_pink/0","doc":"Defines the color rgb(242, 188, 204).","ref":"Fledex.Color.Names.html#orchid_pink/0"},{"type":"function","title":"Fledex.Color.Names.ou_crimson_red/0","doc":"Defines the color rgb(132, 22, 22).","ref":"Fledex.Color.Names.html#ou_crimson_red/0"},{"type":"function","title":"Fledex.Color.Names.outer_space_crayola/0","doc":"Defines the color rgb(45, 56, 58).","ref":"Fledex.Color.Names.html#outer_space_crayola/0"},{"type":"function","title":"Fledex.Color.Names.outrageous_orange/0","doc":"Defines the color rgb(255, 109, 73).","ref":"Fledex.Color.Names.html#outrageous_orange/0"},{"type":"function","title":"Fledex.Color.Names.oxblood/0","doc":"Defines the color rgb(73, 0, 0).","ref":"Fledex.Color.Names.html#oxblood/0"},{"type":"function","title":"Fledex.Color.Names.oxford_blue/0","doc":"Defines the color rgb(0, 33, 71).","ref":"Fledex.Color.Names.html#oxford_blue/0"},{"type":"function","title":"Fledex.Color.Names.pacific_blue/0","doc":"Defines the color rgb(28, 168, 201).","ref":"Fledex.Color.Names.html#pacific_blue/0"},{"type":"function","title":"Fledex.Color.Names.pakistan_green/0","doc":"Defines the color rgb(0, 102, 0).","ref":"Fledex.Color.Names.html#pakistan_green/0"},{"type":"function","title":"Fledex.Color.Names.palatinate_purple/0","doc":"Defines the color rgb(104, 40, 96).","ref":"Fledex.Color.Names.html#palatinate_purple/0"},{"type":"function","title":"Fledex.Color.Names.pale_aqua/0","doc":"Defines the color rgb(191, 211, 229).","ref":"Fledex.Color.Names.html#pale_aqua/0"},{"type":"function","title":"Fledex.Color.Names.pale_cerulean/0","doc":"Defines the color rgb(155, 196, 226).","ref":"Fledex.Color.Names.html#pale_cerulean/0"},{"type":"function","title":"Fledex.Color.Names.pale_dogwood/0","doc":"Defines the color rgb(237, 122, 155).","ref":"Fledex.Color.Names.html#pale_dogwood/0"},{"type":"function","title":"Fledex.Color.Names.pale_pink/0","doc":"Defines the color rgb(249, 216, 221).","ref":"Fledex.Color.Names.html#pale_pink/0"},{"type":"function","title":"Fledex.Color.Names.pale_purple_pantone/0","doc":"Defines the color rgb(249, 229, 249).","ref":"Fledex.Color.Names.html#pale_purple_pantone/0"},{"type":"function","title":"Fledex.Color.Names.pale_spring_bud/0","doc":"Defines the color rgb(237, 234, 188).","ref":"Fledex.Color.Names.html#pale_spring_bud/0"},{"type":"function","title":"Fledex.Color.Names.palegoldenrod/0","doc":"","ref":"Fledex.Color.Names.html#palegoldenrod/0"},{"type":"function","title":"Fledex.Color.Names.palegreen/0","doc":"","ref":"Fledex.Color.Names.html#palegreen/0"},{"type":"function","title":"Fledex.Color.Names.paleturquoise/0","doc":"","ref":"Fledex.Color.Names.html#paleturquoise/0"},{"type":"function","title":"Fledex.Color.Names.palevioletred/0","doc":"","ref":"Fledex.Color.Names.html#palevioletred/0"},{"type":"function","title":"Fledex.Color.Names.pansy_purple/0","doc":"Defines the color rgb(119, 22, 73).","ref":"Fledex.Color.Names.html#pansy_purple/0"},{"type":"function","title":"Fledex.Color.Names.paolo_veronese_green/0","doc":"Defines the color rgb(0, 155, 124).","ref":"Fledex.Color.Names.html#paolo_veronese_green/0"},{"type":"function","title":"Fledex.Color.Names.papaya_whip/0","doc":"Defines the color rgb(255, 239, 214).","ref":"Fledex.Color.Names.html#papaya_whip/0"},{"type":"function","title":"Fledex.Color.Names.papayawhip/0","doc":"","ref":"Fledex.Color.Names.html#papayawhip/0"},{"type":"function","title":"Fledex.Color.Names.paradise_pink/0","doc":"Defines the color rgb(229, 61, 96).","ref":"Fledex.Color.Names.html#paradise_pink/0"},{"type":"function","title":"Fledex.Color.Names.parchment/0","doc":"Defines the color rgb(242, 232, 209).","ref":"Fledex.Color.Names.html#parchment/0"},{"type":"function","title":"Fledex.Color.Names.paris_green/0","doc":"Defines the color rgb(79, 198, 119).","ref":"Fledex.Color.Names.html#paris_green/0"},{"type":"function","title":"Fledex.Color.Names.pastel_pink/0","doc":"Defines the color rgb(221, 165, 163).","ref":"Fledex.Color.Names.html#pastel_pink/0"},{"type":"function","title":"Fledex.Color.Names.patriarch/0","doc":"Defines the color rgb(127, 0, 127).","ref":"Fledex.Color.Names.html#patriarch/0"},{"type":"function","title":"Fledex.Color.Names.paua/0","doc":"Defines the color rgb(30, 0, 94).","ref":"Fledex.Color.Names.html#paua/0"},{"type":"function","title":"Fledex.Color.Names.payne_s_grey/0","doc":"Defines the color rgb(84, 104, 119).","ref":"Fledex.Color.Names.html#payne_s_grey/0"},{"type":"function","title":"Fledex.Color.Names.peach/0","doc":"Defines the color rgb(255, 229, 181).","ref":"Fledex.Color.Names.html#peach/0"},{"type":"function","title":"Fledex.Color.Names.peach_crayola/0","doc":"Defines the color rgb(255, 204, 163).","ref":"Fledex.Color.Names.html#peach_crayola/0"},{"type":"function","title":"Fledex.Color.Names.peach_puff/0","doc":"Defines the color rgb(255, 216, 186).","ref":"Fledex.Color.Names.html#peach_puff/0"},{"type":"function","title":"Fledex.Color.Names.peachpuff/0","doc":"","ref":"Fledex.Color.Names.html#peachpuff/0"},{"type":"function","title":"Fledex.Color.Names.pear/0","doc":"Defines the color rgb(209, 226, 48).","ref":"Fledex.Color.Names.html#pear/0"},{"type":"function","title":"Fledex.Color.Names.pearly_purple/0","doc":"Defines the color rgb(183, 104, 163).","ref":"Fledex.Color.Names.html#pearly_purple/0"},{"type":"function","title":"Fledex.Color.Names.periwinkle/0","doc":"Defines the color rgb(204, 204, 255).","ref":"Fledex.Color.Names.html#periwinkle/0"},{"type":"function","title":"Fledex.Color.Names.periwinkle_crayola/0","doc":"Defines the color rgb(193, 204, 229).","ref":"Fledex.Color.Names.html#periwinkle_crayola/0"},{"type":"function","title":"Fledex.Color.Names.permanent_geranium_lake/0","doc":"Defines the color rgb(224, 43, 43).","ref":"Fledex.Color.Names.html#permanent_geranium_lake/0"},{"type":"function","title":"Fledex.Color.Names.persian_blue/0","doc":"Defines the color rgb(28, 56, 186).","ref":"Fledex.Color.Names.html#persian_blue/0"},{"type":"function","title":"Fledex.Color.Names.persian_green/0","doc":"Defines the color rgb(0, 165, 147).","ref":"Fledex.Color.Names.html#persian_green/0"},{"type":"function","title":"Fledex.Color.Names.persian_indigo/0","doc":"Defines the color rgb(51, 17, 122).","ref":"Fledex.Color.Names.html#persian_indigo/0"},{"type":"function","title":"Fledex.Color.Names.persian_orange/0","doc":"Defines the color rgb(216, 142, 89).","ref":"Fledex.Color.Names.html#persian_orange/0"},{"type":"function","title":"Fledex.Color.Names.persian_pink/0","doc":"Defines the color rgb(247, 127, 191).","ref":"Fledex.Color.Names.html#persian_pink/0"},{"type":"function","title":"Fledex.Color.Names.persian_plum/0","doc":"Defines the color rgb(112, 28, 28).","ref":"Fledex.Color.Names.html#persian_plum/0"},{"type":"function","title":"Fledex.Color.Names.persian_red/0","doc":"Defines the color rgb(204, 51, 51).","ref":"Fledex.Color.Names.html#persian_red/0"},{"type":"function","title":"Fledex.Color.Names.persian_rose/0","doc":"Defines the color rgb(255, 40, 163).","ref":"Fledex.Color.Names.html#persian_rose/0"},{"type":"function","title":"Fledex.Color.Names.persimmon/0","doc":"Defines the color rgb(237, 89, 0).","ref":"Fledex.Color.Names.html#persimmon/0"},{"type":"function","title":"Fledex.Color.Names.peru/0","doc":"","ref":"Fledex.Color.Names.html#peru/0"},{"type":"function","title":"Fledex.Color.Names.pewter_blue/0","doc":"Defines the color rgb(140, 168, 183).","ref":"Fledex.Color.Names.html#pewter_blue/0"},{"type":"function","title":"Fledex.Color.Names.phlox/0","doc":"Defines the color rgb(221, 0, 255).","ref":"Fledex.Color.Names.html#phlox/0"},{"type":"function","title":"Fledex.Color.Names.phthalo_blue/0","doc":"Defines the color rgb(0, 15, 137).","ref":"Fledex.Color.Names.html#phthalo_blue/0"},{"type":"function","title":"Fledex.Color.Names.phthalo_green/0","doc":"Defines the color rgb(17, 53, 35).","ref":"Fledex.Color.Names.html#phthalo_green/0"},{"type":"function","title":"Fledex.Color.Names.picotee_blue/0","doc":"Defines the color rgb(45, 38, 135).","ref":"Fledex.Color.Names.html#picotee_blue/0"},{"type":"function","title":"Fledex.Color.Names.pictorial_carmine/0","doc":"Defines the color rgb(193, 10, 79).","ref":"Fledex.Color.Names.html#pictorial_carmine/0"},{"type":"function","title":"Fledex.Color.Names.piggy_pink/0","doc":"Defines the color rgb(252, 221, 229).","ref":"Fledex.Color.Names.html#piggy_pink/0"},{"type":"function","title":"Fledex.Color.Names.pine_green/0","doc":"Defines the color rgb(0, 119, 112).","ref":"Fledex.Color.Names.html#pine_green/0"},{"type":"function","title":"Fledex.Color.Names.pine_tree/0","doc":"Defines the color rgb(40, 45, 35).","ref":"Fledex.Color.Names.html#pine_tree/0"},{"type":"function","title":"Fledex.Color.Names.pink/0","doc":"Defines the color rgb(255, 191, 204).","ref":"Fledex.Color.Names.html#pink/0"},{"type":"function","title":"Fledex.Color.Names.pink_lace/0","doc":"Defines the color rgb(255, 221, 244).","ref":"Fledex.Color.Names.html#pink_lace/0"},{"type":"function","title":"Fledex.Color.Names.pink_lavender/0","doc":"Defines the color rgb(216, 178, 209).","ref":"Fledex.Color.Names.html#pink_lavender/0"},{"type":"function","title":"Fledex.Color.Names.pink_pantone/0","doc":"Defines the color rgb(214, 71, 147).","ref":"Fledex.Color.Names.html#pink_pantone/0"},{"type":"function","title":"Fledex.Color.Names.pink_sherbet/0","doc":"Defines the color rgb(247, 142, 165).","ref":"Fledex.Color.Names.html#pink_sherbet/0"},{"type":"function","title":"Fledex.Color.Names.pistachio/0","doc":"Defines the color rgb(147, 196, 114).","ref":"Fledex.Color.Names.html#pistachio/0"},{"type":"function","title":"Fledex.Color.Names.platinum/0","doc":"Defines the color rgb(229, 226, 226).","ref":"Fledex.Color.Names.html#platinum/0"},{"type":"function","title":"Fledex.Color.Names.plum/0","doc":"Defines the color rgb(142, 68, 132).","ref":"Fledex.Color.Names.html#plum/0"},{"type":"function","title":"Fledex.Color.Names.plum_web/0","doc":"Defines the color rgb(221, 160, 221).","ref":"Fledex.Color.Names.html#plum_web/0"},{"type":"function","title":"Fledex.Color.Names.plump_purple/0","doc":"Defines the color rgb(89, 68, 178).","ref":"Fledex.Color.Names.html#plump_purple/0"},{"type":"function","title":"Fledex.Color.Names.polished_pine/0","doc":"Defines the color rgb(91, 163, 147).","ref":"Fledex.Color.Names.html#polished_pine/0"},{"type":"function","title":"Fledex.Color.Names.pomp_and_power/0","doc":"Defines the color rgb(135, 96, 142).","ref":"Fledex.Color.Names.html#pomp_and_power/0"},{"type":"function","title":"Fledex.Color.Names.popstar/0","doc":"Defines the color rgb(191, 79, 96).","ref":"Fledex.Color.Names.html#popstar/0"},{"type":"function","title":"Fledex.Color.Names.portland_orange/0","doc":"Defines the color rgb(255, 89, 53).","ref":"Fledex.Color.Names.html#portland_orange/0"},{"type":"function","title":"Fledex.Color.Names.powder_blue/0","doc":"Defines the color rgb(175, 224, 229).","ref":"Fledex.Color.Names.html#powder_blue/0"},{"type":"function","title":"Fledex.Color.Names.powderblue/0","doc":"","ref":"Fledex.Color.Names.html#powderblue/0"},{"type":"function","title":"Fledex.Color.Names.princeton_orange/0","doc":"Defines the color rgb(244, 127, 38).","ref":"Fledex.Color.Names.html#princeton_orange/0"},{"type":"function","title":"Fledex.Color.Names.process_yellow/0","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.html#process_yellow/0"},{"type":"function","title":"Fledex.Color.Names.prune/0","doc":"Defines the color rgb(112, 28, 28).","ref":"Fledex.Color.Names.html#prune/0"},{"type":"function","title":"Fledex.Color.Names.prussian_blue/0","doc":"Defines the color rgb(0, 48, 84).","ref":"Fledex.Color.Names.html#prussian_blue/0"},{"type":"function","title":"Fledex.Color.Names.psychedelic_purple/0","doc":"Defines the color rgb(221, 0, 255).","ref":"Fledex.Color.Names.html#psychedelic_purple/0"},{"type":"function","title":"Fledex.Color.Names.puce/0","doc":"Defines the color rgb(204, 135, 153).","ref":"Fledex.Color.Names.html#puce/0"},{"type":"function","title":"Fledex.Color.Names.pullman_brown_ups_brown/0","doc":"Defines the color rgb(99, 63, 22).","ref":"Fledex.Color.Names.html#pullman_brown_ups_brown/0"},{"type":"function","title":"Fledex.Color.Names.pumpkin/0","doc":"Defines the color rgb(255, 117, 22).","ref":"Fledex.Color.Names.html#pumpkin/0"},{"type":"function","title":"Fledex.Color.Names.purple/0","doc":"Defines the color rgb(96, 0, 127).","ref":"Fledex.Color.Names.html#purple/0"},{"type":"function","title":"Fledex.Color.Names.purple_mountain_majesty/0","doc":"Defines the color rgb(150, 119, 181).","ref":"Fledex.Color.Names.html#purple_mountain_majesty/0"},{"type":"function","title":"Fledex.Color.Names.purple_munsell/0","doc":"Defines the color rgb(158, 0, 196).","ref":"Fledex.Color.Names.html#purple_munsell/0"},{"type":"function","title":"Fledex.Color.Names.purple_navy/0","doc":"Defines the color rgb(79, 81, 127).","ref":"Fledex.Color.Names.html#purple_navy/0"},{"type":"function","title":"Fledex.Color.Names.purple_pizzazz/0","doc":"Defines the color rgb(255, 79, 216).","ref":"Fledex.Color.Names.html#purple_pizzazz/0"},{"type":"function","title":"Fledex.Color.Names.purple_plum/0","doc":"Defines the color rgb(155, 81, 181).","ref":"Fledex.Color.Names.html#purple_plum/0"},{"type":"function","title":"Fledex.Color.Names.purple_web/0","doc":"Defines the color rgb(127, 0, 127).","ref":"Fledex.Color.Names.html#purple_web/0"},{"type":"function","title":"Fledex.Color.Names.purple_x11/0","doc":"Defines the color rgb(160, 33, 239).","ref":"Fledex.Color.Names.html#purple_x11/0"},{"type":"function","title":"Fledex.Color.Names.purpureus/0","doc":"Defines the color rgb(153, 79, 173).","ref":"Fledex.Color.Names.html#purpureus/0"},{"type":"function","title":"Fledex.Color.Names.queen_blue/0","doc":"Defines the color rgb(66, 107, 147).","ref":"Fledex.Color.Names.html#queen_blue/0"},{"type":"function","title":"Fledex.Color.Names.queen_pink/0","doc":"Defines the color rgb(232, 204, 214).","ref":"Fledex.Color.Names.html#queen_pink/0"},{"type":"function","title":"Fledex.Color.Names.quick_silver/0","doc":"Defines the color rgb(165, 165, 165).","ref":"Fledex.Color.Names.html#quick_silver/0"},{"type":"function","title":"Fledex.Color.Names.quinacridone_magenta/0","doc":"Defines the color rgb(142, 58, 89).","ref":"Fledex.Color.Names.html#quinacridone_magenta/0"},{"type":"function","title":"Fledex.Color.Names.radical_red/0","doc":"Defines the color rgb(255, 53, 94).","ref":"Fledex.Color.Names.html#radical_red/0"},{"type":"function","title":"Fledex.Color.Names.raisin_black/0","doc":"Defines the color rgb(35, 33, 35).","ref":"Fledex.Color.Names.html#raisin_black/0"},{"type":"function","title":"Fledex.Color.Names.rajah/0","doc":"Defines the color rgb(249, 170, 96).","ref":"Fledex.Color.Names.html#rajah/0"},{"type":"function","title":"Fledex.Color.Names.raspberry/0","doc":"Defines the color rgb(226, 10, 91).","ref":"Fledex.Color.Names.html#raspberry/0"},{"type":"function","title":"Fledex.Color.Names.raspberry_glace/0","doc":"Defines the color rgb(145, 94, 109).","ref":"Fledex.Color.Names.html#raspberry_glace/0"},{"type":"function","title":"Fledex.Color.Names.raspberry_rose/0","doc":"Defines the color rgb(178, 68, 107).","ref":"Fledex.Color.Names.html#raspberry_rose/0"},{"type":"function","title":"Fledex.Color.Names.raw_sienna/0","doc":"Defines the color rgb(214, 137, 89).","ref":"Fledex.Color.Names.html#raw_sienna/0"},{"type":"function","title":"Fledex.Color.Names.raw_umber/0","doc":"Defines the color rgb(130, 102, 68).","ref":"Fledex.Color.Names.html#raw_umber/0"},{"type":"function","title":"Fledex.Color.Names.razzle_dazzle_rose/0","doc":"Defines the color rgb(255, 51, 204).","ref":"Fledex.Color.Names.html#razzle_dazzle_rose/0"},{"type":"function","title":"Fledex.Color.Names.razzmatazz/0","doc":"Defines the color rgb(226, 38, 107).","ref":"Fledex.Color.Names.html#razzmatazz/0"},{"type":"function","title":"Fledex.Color.Names.razzmic_berry/0","doc":"Defines the color rgb(140, 79, 132).","ref":"Fledex.Color.Names.html#razzmic_berry/0"},{"type":"function","title":"Fledex.Color.Names.rebecca_purple/0","doc":"Defines the color rgb(102, 51, 153).","ref":"Fledex.Color.Names.html#rebecca_purple/0"},{"type":"function","title":"Fledex.Color.Names.rebeccapurple/0","doc":"","ref":"Fledex.Color.Names.html#rebeccapurple/0"},{"type":"function","title":"Fledex.Color.Names.red/0","doc":"Defines the color rgb(255, 0, 0).","ref":"Fledex.Color.Names.html#red/0"},{"type":"function","title":"Fledex.Color.Names.red_crayola/0","doc":"Defines the color rgb(237, 33, 76).","ref":"Fledex.Color.Names.html#red_crayola/0"},{"type":"function","title":"Fledex.Color.Names.red_munsell/0","doc":"Defines the color rgb(242, 0, 61).","ref":"Fledex.Color.Names.html#red_munsell/0"},{"type":"function","title":"Fledex.Color.Names.red_ncs/0","doc":"Defines the color rgb(196, 2, 51).","ref":"Fledex.Color.Names.html#red_ncs/0"},{"type":"function","title":"Fledex.Color.Names.red_orange/0","doc":"Defines the color rgb(255, 84, 73).","ref":"Fledex.Color.Names.html#red_orange/0"},{"type":"function","title":"Fledex.Color.Names.red_orange_color_wheel/0","doc":"Defines the color rgb(255, 68, 0).","ref":"Fledex.Color.Names.html#red_orange_color_wheel/0"},{"type":"function","title":"Fledex.Color.Names.red_orange_crayola/0","doc":"Defines the color rgb(255, 104, 30).","ref":"Fledex.Color.Names.html#red_orange_crayola/0"},{"type":"function","title":"Fledex.Color.Names.red_pantone/0","doc":"Defines the color rgb(237, 40, 56).","ref":"Fledex.Color.Names.html#red_pantone/0"},{"type":"function","title":"Fledex.Color.Names.red_pigment/0","doc":"Defines the color rgb(237, 28, 35).","ref":"Fledex.Color.Names.html#red_pigment/0"},{"type":"function","title":"Fledex.Color.Names.red_purple/0","doc":"Defines the color rgb(226, 0, 119).","ref":"Fledex.Color.Names.html#red_purple/0"},{"type":"function","title":"Fledex.Color.Names.red_ryb/0","doc":"Defines the color rgb(255, 38, 17).","ref":"Fledex.Color.Names.html#red_ryb/0"},{"type":"function","title":"Fledex.Color.Names.red_salsa/0","doc":"Defines the color rgb(252, 58, 73).","ref":"Fledex.Color.Names.html#red_salsa/0"},{"type":"function","title":"Fledex.Color.Names.red_violet/0","doc":"Defines the color rgb(198, 20, 132).","ref":"Fledex.Color.Names.html#red_violet/0"},{"type":"function","title":"Fledex.Color.Names.red_violet_color_wheel/0","doc":"Defines the color rgb(145, 43, 61).","ref":"Fledex.Color.Names.html#red_violet_color_wheel/0"},{"type":"function","title":"Fledex.Color.Names.red_violet_crayola/0","doc":"Defines the color rgb(191, 68, 142).","ref":"Fledex.Color.Names.html#red_violet_crayola/0"},{"type":"function","title":"Fledex.Color.Names.redwood/0","doc":"Defines the color rgb(163, 89, 81).","ref":"Fledex.Color.Names.html#redwood/0"},{"type":"function","title":"Fledex.Color.Names.resolution_blue/0","doc":"Defines the color rgb(0, 35, 135).","ref":"Fledex.Color.Names.html#resolution_blue/0"},{"type":"function","title":"Fledex.Color.Names.rhythm/0","doc":"Defines the color rgb(119, 117, 150).","ref":"Fledex.Color.Names.html#rhythm/0"},{"type":"function","title":"Fledex.Color.Names.rich_black/0","doc":"Defines the color rgb(0, 63, 63).","ref":"Fledex.Color.Names.html#rich_black/0"},{"type":"function","title":"Fledex.Color.Names.rich_black_fogra29/0","doc":"Defines the color rgb(0, 10, 17).","ref":"Fledex.Color.Names.html#rich_black_fogra29/0"},{"type":"function","title":"Fledex.Color.Names.rich_black_fogra39/0","doc":"Defines the color rgb(0, 2, 2).","ref":"Fledex.Color.Names.html#rich_black_fogra39/0"},{"type":"function","title":"Fledex.Color.Names.rifle_green/0","doc":"Defines the color rgb(68, 76, 56).","ref":"Fledex.Color.Names.html#rifle_green/0"},{"type":"function","title":"Fledex.Color.Names.robin_egg_blue/0","doc":"Defines the color rgb(0, 204, 204).","ref":"Fledex.Color.Names.html#robin_egg_blue/0"},{"type":"function","title":"Fledex.Color.Names.rocket_metallic/0","doc":"Defines the color rgb(137, 127, 127).","ref":"Fledex.Color.Names.html#rocket_metallic/0"},{"type":"function","title":"Fledex.Color.Names.rojo_spanish_red/0","doc":"Defines the color rgb(168, 17, 0).","ref":"Fledex.Color.Names.html#rojo_spanish_red/0"},{"type":"function","title":"Fledex.Color.Names.roman_silver/0","doc":"Defines the color rgb(130, 137, 150).","ref":"Fledex.Color.Names.html#roman_silver/0"},{"type":"function","title":"Fledex.Color.Names.rose/0","doc":"Defines the color rgb(255, 0, 127).","ref":"Fledex.Color.Names.html#rose/0"},{"type":"function","title":"Fledex.Color.Names.rose_bonbon/0","doc":"Defines the color rgb(249, 66, 158).","ref":"Fledex.Color.Names.html#rose_bonbon/0"},{"type":"function","title":"Fledex.Color.Names.rose_dust/0","doc":"Defines the color rgb(158, 94, 112).","ref":"Fledex.Color.Names.html#rose_dust/0"},{"type":"function","title":"Fledex.Color.Names.rose_ebony/0","doc":"Defines the color rgb(102, 71, 68).","ref":"Fledex.Color.Names.html#rose_ebony/0"},{"type":"function","title":"Fledex.Color.Names.rose_madder/0","doc":"Defines the color rgb(226, 38, 53).","ref":"Fledex.Color.Names.html#rose_madder/0"},{"type":"function","title":"Fledex.Color.Names.rose_pink/0","doc":"Defines the color rgb(255, 102, 204).","ref":"Fledex.Color.Names.html#rose_pink/0"},{"type":"function","title":"Fledex.Color.Names.rose_pompadour/0","doc":"Defines the color rgb(237, 122, 155).","ref":"Fledex.Color.Names.html#rose_pompadour/0"},{"type":"function","title":"Fledex.Color.Names.rose_red/0","doc":"Defines the color rgb(193, 30, 86).","ref":"Fledex.Color.Names.html#rose_red/0"},{"type":"function","title":"Fledex.Color.Names.rose_taupe/0","doc":"Defines the color rgb(142, 91, 91).","ref":"Fledex.Color.Names.html#rose_taupe/0"},{"type":"function","title":"Fledex.Color.Names.rose_vale/0","doc":"Defines the color rgb(170, 79, 81).","ref":"Fledex.Color.Names.html#rose_vale/0"},{"type":"function","title":"Fledex.Color.Names.rosewood/0","doc":"Defines the color rgb(102, 0, 10).","ref":"Fledex.Color.Names.html#rosewood/0"},{"type":"function","title":"Fledex.Color.Names.rosso_corsa/0","doc":"Defines the color rgb(211, 0, 0).","ref":"Fledex.Color.Names.html#rosso_corsa/0"},{"type":"function","title":"Fledex.Color.Names.rosy_brown/0","doc":"Defines the color rgb(188, 142, 142).","ref":"Fledex.Color.Names.html#rosy_brown/0"},{"type":"function","title":"Fledex.Color.Names.rosybrown/0","doc":"","ref":"Fledex.Color.Names.html#rosybrown/0"},{"type":"function","title":"Fledex.Color.Names.royal_blue_dark/0","doc":"Defines the color rgb(0, 35, 102).","ref":"Fledex.Color.Names.html#royal_blue_dark/0"},{"type":"function","title":"Fledex.Color.Names.royal_blue_light/0","doc":"Defines the color rgb(63, 104, 224).","ref":"Fledex.Color.Names.html#royal_blue_light/0"},{"type":"function","title":"Fledex.Color.Names.royal_purple/0","doc":"Defines the color rgb(119, 81, 168).","ref":"Fledex.Color.Names.html#royal_purple/0"},{"type":"function","title":"Fledex.Color.Names.royal_yellow/0","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.html#royal_yellow/0"},{"type":"function","title":"Fledex.Color.Names.royalblue/0","doc":"","ref":"Fledex.Color.Names.html#royalblue/0"},{"type":"function","title":"Fledex.Color.Names.ruber/0","doc":"Defines the color rgb(206, 68, 117).","ref":"Fledex.Color.Names.html#ruber/0"},{"type":"function","title":"Fledex.Color.Names.rubine_red/0","doc":"Defines the color rgb(209, 0, 86).","ref":"Fledex.Color.Names.html#rubine_red/0"},{"type":"function","title":"Fledex.Color.Names.ruby/0","doc":"Defines the color rgb(224, 17, 94).","ref":"Fledex.Color.Names.html#ruby/0"},{"type":"function","title":"Fledex.Color.Names.ruby_red/0","doc":"Defines the color rgb(155, 17, 30).","ref":"Fledex.Color.Names.html#ruby_red/0"},{"type":"function","title":"Fledex.Color.Names.rufous/0","doc":"Defines the color rgb(168, 28, 7).","ref":"Fledex.Color.Names.html#rufous/0"},{"type":"function","title":"Fledex.Color.Names.russet/0","doc":"Defines the color rgb(127, 68, 28).","ref":"Fledex.Color.Names.html#russet/0"},{"type":"function","title":"Fledex.Color.Names.russian_green/0","doc":"Defines the color rgb(102, 145, 102).","ref":"Fledex.Color.Names.html#russian_green/0"},{"type":"function","title":"Fledex.Color.Names.russian_violet/0","doc":"Defines the color rgb(51, 22, 76).","ref":"Fledex.Color.Names.html#russian_violet/0"},{"type":"function","title":"Fledex.Color.Names.rust/0","doc":"Defines the color rgb(183, 63, 12).","ref":"Fledex.Color.Names.html#rust/0"},{"type":"function","title":"Fledex.Color.Names.rusty_red/0","doc":"Defines the color rgb(216, 43, 66).","ref":"Fledex.Color.Names.html#rusty_red/0"},{"type":"function","title":"Fledex.Color.Names.sacramento_state_green/0","doc":"Defines the color rgb(5, 56, 38).","ref":"Fledex.Color.Names.html#sacramento_state_green/0"},{"type":"function","title":"Fledex.Color.Names.saddle_brown/0","doc":"Defines the color rgb(140, 68, 17).","ref":"Fledex.Color.Names.html#saddle_brown/0"},{"type":"function","title":"Fledex.Color.Names.saddlebrown/0","doc":"","ref":"Fledex.Color.Names.html#saddlebrown/0"},{"type":"function","title":"Fledex.Color.Names.safety_orange/0","doc":"Defines the color rgb(255, 119, 0).","ref":"Fledex.Color.Names.html#safety_orange/0"},{"type":"function","title":"Fledex.Color.Names.safety_orange_blaze_orange/0","doc":"Defines the color rgb(255, 102, 0).","ref":"Fledex.Color.Names.html#safety_orange_blaze_orange/0"},{"type":"function","title":"Fledex.Color.Names.safety_yellow/0","doc":"Defines the color rgb(237, 209, 2).","ref":"Fledex.Color.Names.html#safety_yellow/0"},{"type":"function","title":"Fledex.Color.Names.saffron/0","doc":"Defines the color rgb(244, 196, 48).","ref":"Fledex.Color.Names.html#saffron/0"},{"type":"function","title":"Fledex.Color.Names.sage/0","doc":"Defines the color rgb(188, 183, 137).","ref":"Fledex.Color.Names.html#sage/0"},{"type":"function","title":"Fledex.Color.Names.salmon/0","doc":"Defines the color rgb(249, 127, 114).","ref":"Fledex.Color.Names.html#salmon/0"},{"type":"function","title":"Fledex.Color.Names.salmon_pink/0","doc":"Defines the color rgb(255, 145, 163).","ref":"Fledex.Color.Names.html#salmon_pink/0"},{"type":"function","title":"Fledex.Color.Names.sand/0","doc":"Defines the color rgb(193, 178, 127).","ref":"Fledex.Color.Names.html#sand/0"},{"type":"function","title":"Fledex.Color.Names.sand_dune/0","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.html#sand_dune/0"},{"type":"function","title":"Fledex.Color.Names.sandy_brown/0","doc":"Defines the color rgb(244, 163, 96).","ref":"Fledex.Color.Names.html#sandy_brown/0"},{"type":"function","title":"Fledex.Color.Names.sandybrown/0","doc":"","ref":"Fledex.Color.Names.html#sandybrown/0"},{"type":"function","title":"Fledex.Color.Names.sap_green/0","doc":"Defines the color rgb(79, 124, 40).","ref":"Fledex.Color.Names.html#sap_green/0"},{"type":"function","title":"Fledex.Color.Names.sapphire/0","doc":"Defines the color rgb(15, 81, 186).","ref":"Fledex.Color.Names.html#sapphire/0"},{"type":"function","title":"Fledex.Color.Names.sapphire_blue/0","doc":"Defines the color rgb(0, 102, 165).","ref":"Fledex.Color.Names.html#sapphire_blue/0"},{"type":"function","title":"Fledex.Color.Names.sapphire_crayola/0","doc":"Defines the color rgb(45, 91, 160).","ref":"Fledex.Color.Names.html#sapphire_crayola/0"},{"type":"function","title":"Fledex.Color.Names.satin_sheen_gold/0","doc":"Defines the color rgb(204, 160, 53).","ref":"Fledex.Color.Names.html#satin_sheen_gold/0"},{"type":"function","title":"Fledex.Color.Names.scarlet/0","doc":"Defines the color rgb(255, 35, 0).","ref":"Fledex.Color.Names.html#scarlet/0"},{"type":"function","title":"Fledex.Color.Names.schauss_pink/0","doc":"Defines the color rgb(255, 145, 175).","ref":"Fledex.Color.Names.html#schauss_pink/0"},{"type":"function","title":"Fledex.Color.Names.school_bus_yellow/0","doc":"Defines the color rgb(255, 216, 0).","ref":"Fledex.Color.Names.html#school_bus_yellow/0"},{"type":"function","title":"Fledex.Color.Names.screamin_green/0","doc":"Defines the color rgb(102, 255, 102).","ref":"Fledex.Color.Names.html#screamin_green/0"},{"type":"function","title":"Fledex.Color.Names.sea_green/0","doc":"Defines the color rgb(45, 140, 86).","ref":"Fledex.Color.Names.html#sea_green/0"},{"type":"function","title":"Fledex.Color.Names.sea_green_crayola/0","doc":"Defines the color rgb(0, 255, 204).","ref":"Fledex.Color.Names.html#sea_green_crayola/0"},{"type":"function","title":"Fledex.Color.Names.seagreen/0","doc":"","ref":"Fledex.Color.Names.html#seagreen/0"},{"type":"function","title":"Fledex.Color.Names.seal_brown/0","doc":"Defines the color rgb(51, 20, 20).","ref":"Fledex.Color.Names.html#seal_brown/0"},{"type":"function","title":"Fledex.Color.Names.seance/0","doc":"Defines the color rgb(96, 33, 135).","ref":"Fledex.Color.Names.html#seance/0"},{"type":"function","title":"Fledex.Color.Names.seashell/0","doc":"Defines the color rgb(255, 244, 237).","ref":"Fledex.Color.Names.html#seashell/0"},{"type":"function","title":"Fledex.Color.Names.secret/0","doc":"Defines the color rgb(117, 66, 114).","ref":"Fledex.Color.Names.html#secret/0"},{"type":"function","title":"Fledex.Color.Names.selective_yellow/0","doc":"Defines the color rgb(255, 186, 0).","ref":"Fledex.Color.Names.html#selective_yellow/0"},{"type":"function","title":"Fledex.Color.Names.sepia/0","doc":"Defines the color rgb(112, 66, 20).","ref":"Fledex.Color.Names.html#sepia/0"},{"type":"function","title":"Fledex.Color.Names.shadow/0","doc":"Defines the color rgb(137, 119, 91).","ref":"Fledex.Color.Names.html#shadow/0"},{"type":"function","title":"Fledex.Color.Names.shadow_blue/0","doc":"Defines the color rgb(119, 140, 165).","ref":"Fledex.Color.Names.html#shadow_blue/0"},{"type":"function","title":"Fledex.Color.Names.shamrock_green/0","doc":"Defines the color rgb(0, 158, 96).","ref":"Fledex.Color.Names.html#shamrock_green/0"},{"type":"function","title":"Fledex.Color.Names.sheen_green/0","doc":"Defines the color rgb(142, 211, 0).","ref":"Fledex.Color.Names.html#sheen_green/0"},{"type":"function","title":"Fledex.Color.Names.shimmering_blush/0","doc":"Defines the color rgb(216, 135, 147).","ref":"Fledex.Color.Names.html#shimmering_blush/0"},{"type":"function","title":"Fledex.Color.Names.shiny_shamrock/0","doc":"Defines the color rgb(94, 165, 119).","ref":"Fledex.Color.Names.html#shiny_shamrock/0"},{"type":"function","title":"Fledex.Color.Names.shocking_pink/0","doc":"Defines the color rgb(252, 15, 191).","ref":"Fledex.Color.Names.html#shocking_pink/0"},{"type":"function","title":"Fledex.Color.Names.shocking_pink_crayola/0","doc":"Defines the color rgb(255, 112, 255).","ref":"Fledex.Color.Names.html#shocking_pink_crayola/0"},{"type":"function","title":"Fledex.Color.Names.sienna/0","doc":"Defines the color rgb(135, 45, 22).","ref":"Fledex.Color.Names.html#sienna/0"},{"type":"function","title":"Fledex.Color.Names.silver/0","doc":"Defines the color rgb(191, 191, 191).","ref":"Fledex.Color.Names.html#silver/0"},{"type":"function","title":"Fledex.Color.Names.silver_chalice/0","doc":"Defines the color rgb(170, 170, 170).","ref":"Fledex.Color.Names.html#silver_chalice/0"},{"type":"function","title":"Fledex.Color.Names.silver_crayola/0","doc":"Defines the color rgb(201, 191, 186).","ref":"Fledex.Color.Names.html#silver_crayola/0"},{"type":"function","title":"Fledex.Color.Names.silver_metallic/0","doc":"Defines the color rgb(170, 168, 173).","ref":"Fledex.Color.Names.html#silver_metallic/0"},{"type":"function","title":"Fledex.Color.Names.silver_pink/0","doc":"Defines the color rgb(196, 173, 173).","ref":"Fledex.Color.Names.html#silver_pink/0"},{"type":"function","title":"Fledex.Color.Names.silver_sand/0","doc":"Defines the color rgb(191, 193, 193).","ref":"Fledex.Color.Names.html#silver_sand/0"},{"type":"function","title":"Fledex.Color.Names.sinopia/0","doc":"Defines the color rgb(204, 63, 10).","ref":"Fledex.Color.Names.html#sinopia/0"},{"type":"function","title":"Fledex.Color.Names.sizzling_red/0","doc":"Defines the color rgb(255, 56, 84).","ref":"Fledex.Color.Names.html#sizzling_red/0"},{"type":"function","title":"Fledex.Color.Names.sizzling_sunrise/0","doc":"Defines the color rgb(255, 219, 0).","ref":"Fledex.Color.Names.html#sizzling_sunrise/0"},{"type":"function","title":"Fledex.Color.Names.skobeloff/0","doc":"Defines the color rgb(0, 114, 114).","ref":"Fledex.Color.Names.html#skobeloff/0"},{"type":"function","title":"Fledex.Color.Names.sky_blue/0","doc":"Defines the color rgb(135, 206, 234).","ref":"Fledex.Color.Names.html#sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.sky_blue_crayola/0","doc":"Defines the color rgb(117, 214, 234).","ref":"Fledex.Color.Names.html#sky_blue_crayola/0"},{"type":"function","title":"Fledex.Color.Names.sky_magenta/0","doc":"Defines the color rgb(206, 112, 175).","ref":"Fledex.Color.Names.html#sky_magenta/0"},{"type":"function","title":"Fledex.Color.Names.skyblue/0","doc":"","ref":"Fledex.Color.Names.html#skyblue/0"},{"type":"function","title":"Fledex.Color.Names.slate_blue/0","doc":"Defines the color rgb(107, 89, 204).","ref":"Fledex.Color.Names.html#slate_blue/0"},{"type":"function","title":"Fledex.Color.Names.slate_gray/0","doc":"Defines the color rgb(112, 127, 142).","ref":"Fledex.Color.Names.html#slate_gray/0"},{"type":"function","title":"Fledex.Color.Names.slateblue/0","doc":"","ref":"Fledex.Color.Names.html#slateblue/0"},{"type":"function","title":"Fledex.Color.Names.slategray/0","doc":"","ref":"Fledex.Color.Names.html#slategray/0"},{"type":"function","title":"Fledex.Color.Names.slategrey/0","doc":"","ref":"Fledex.Color.Names.html#slategrey/0"},{"type":"function","title":"Fledex.Color.Names.slimy_green/0","doc":"Defines the color rgb(40, 150, 22).","ref":"Fledex.Color.Names.html#slimy_green/0"},{"type":"function","title":"Fledex.Color.Names.smitten/0","doc":"Defines the color rgb(198, 63, 135).","ref":"Fledex.Color.Names.html#smitten/0"},{"type":"function","title":"Fledex.Color.Names.smoky_black/0","doc":"Defines the color rgb(15, 12, 7).","ref":"Fledex.Color.Names.html#smoky_black/0"},{"type":"function","title":"Fledex.Color.Names.snow/0","doc":"Defines the color rgb(255, 249, 249).","ref":"Fledex.Color.Names.html#snow/0"},{"type":"function","title":"Fledex.Color.Names.solid_pink/0","doc":"Defines the color rgb(137, 56, 66).","ref":"Fledex.Color.Names.html#solid_pink/0"},{"type":"function","title":"Fledex.Color.Names.sonic_silver/0","doc":"Defines the color rgb(117, 117, 117).","ref":"Fledex.Color.Names.html#sonic_silver/0"},{"type":"function","title":"Fledex.Color.Names.space_cadet/0","doc":"Defines the color rgb(28, 40, 81).","ref":"Fledex.Color.Names.html#space_cadet/0"},{"type":"function","title":"Fledex.Color.Names.spanish_bistre/0","doc":"Defines the color rgb(127, 117, 51).","ref":"Fledex.Color.Names.html#spanish_bistre/0"},{"type":"function","title":"Fledex.Color.Names.spanish_blue/0","doc":"Defines the color rgb(0, 112, 183).","ref":"Fledex.Color.Names.html#spanish_blue/0"},{"type":"function","title":"Fledex.Color.Names.spanish_carmine/0","doc":"Defines the color rgb(209, 0, 71).","ref":"Fledex.Color.Names.html#spanish_carmine/0"},{"type":"function","title":"Fledex.Color.Names.spanish_gray/0","doc":"Defines the color rgb(153, 153, 153).","ref":"Fledex.Color.Names.html#spanish_gray/0"},{"type":"function","title":"Fledex.Color.Names.spanish_green/0","doc":"Defines the color rgb(0, 145, 79).","ref":"Fledex.Color.Names.html#spanish_green/0"},{"type":"function","title":"Fledex.Color.Names.spanish_orange/0","doc":"Defines the color rgb(232, 96, 0).","ref":"Fledex.Color.Names.html#spanish_orange/0"},{"type":"function","title":"Fledex.Color.Names.spanish_pink/0","doc":"Defines the color rgb(247, 191, 191).","ref":"Fledex.Color.Names.html#spanish_pink/0"},{"type":"function","title":"Fledex.Color.Names.spanish_red/0","doc":"Defines the color rgb(229, 0, 38).","ref":"Fledex.Color.Names.html#spanish_red/0"},{"type":"function","title":"Fledex.Color.Names.spanish_sky_blue/0","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.html#spanish_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.spanish_violet/0","doc":"Defines the color rgb(76, 40, 130).","ref":"Fledex.Color.Names.html#spanish_violet/0"},{"type":"function","title":"Fledex.Color.Names.spanish_viridian/0","doc":"Defines the color rgb(0, 127, 91).","ref":"Fledex.Color.Names.html#spanish_viridian/0"},{"type":"function","title":"Fledex.Color.Names.spring_bud/0","doc":"Defines the color rgb(165, 252, 0).","ref":"Fledex.Color.Names.html#spring_bud/0"},{"type":"function","title":"Fledex.Color.Names.spring_frost/0","doc":"Defines the color rgb(135, 255, 40).","ref":"Fledex.Color.Names.html#spring_frost/0"},{"type":"function","title":"Fledex.Color.Names.spring_green/0","doc":"Defines the color rgb(0, 255, 127).","ref":"Fledex.Color.Names.html#spring_green/0"},{"type":"function","title":"Fledex.Color.Names.spring_green_crayola/0","doc":"Defines the color rgb(237, 234, 188).","ref":"Fledex.Color.Names.html#spring_green_crayola/0"},{"type":"function","title":"Fledex.Color.Names.springgreen/0","doc":"","ref":"Fledex.Color.Names.html#springgreen/0"},{"type":"function","title":"Fledex.Color.Names.st_patrick_s_blue/0","doc":"Defines the color rgb(35, 40, 122).","ref":"Fledex.Color.Names.html#st_patrick_s_blue/0"},{"type":"function","title":"Fledex.Color.Names.star_command_blue/0","doc":"Defines the color rgb(0, 122, 183).","ref":"Fledex.Color.Names.html#star_command_blue/0"},{"type":"function","title":"Fledex.Color.Names.steel_blue/0","doc":"Defines the color rgb(68, 130, 181).","ref":"Fledex.Color.Names.html#steel_blue/0"},{"type":"function","title":"Fledex.Color.Names.steel_pink/0","doc":"Defines the color rgb(204, 51, 204).","ref":"Fledex.Color.Names.html#steel_pink/0"},{"type":"function","title":"Fledex.Color.Names.steelblue/0","doc":"","ref":"Fledex.Color.Names.html#steelblue/0"},{"type":"function","title":"Fledex.Color.Names.stil_de_grain_yellow/0","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.html#stil_de_grain_yellow/0"},{"type":"function","title":"Fledex.Color.Names.straw/0","doc":"Defines the color rgb(226, 216, 112).","ref":"Fledex.Color.Names.html#straw/0"},{"type":"function","title":"Fledex.Color.Names.strawberry/0","doc":"Defines the color rgb(249, 79, 84).","ref":"Fledex.Color.Names.html#strawberry/0"},{"type":"function","title":"Fledex.Color.Names.strawberry_blonde/0","doc":"Defines the color rgb(255, 147, 96).","ref":"Fledex.Color.Names.html#strawberry_blonde/0"},{"type":"function","title":"Fledex.Color.Names.strong_lime_green/0","doc":"Defines the color rgb(51, 204, 51).","ref":"Fledex.Color.Names.html#strong_lime_green/0"},{"type":"function","title":"Fledex.Color.Names.sugar_plum/0","doc":"Defines the color rgb(145, 79, 117).","ref":"Fledex.Color.Names.html#sugar_plum/0"},{"type":"function","title":"Fledex.Color.Names.sunglow/0","doc":"Defines the color rgb(255, 204, 51).","ref":"Fledex.Color.Names.html#sunglow/0"},{"type":"function","title":"Fledex.Color.Names.sunray/0","doc":"Defines the color rgb(226, 170, 86).","ref":"Fledex.Color.Names.html#sunray/0"},{"type":"function","title":"Fledex.Color.Names.sunset/0","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.html#sunset/0"},{"type":"function","title":"Fledex.Color.Names.super_pink/0","doc":"Defines the color rgb(206, 107, 168).","ref":"Fledex.Color.Names.html#super_pink/0"},{"type":"function","title":"Fledex.Color.Names.sweet_brown/0","doc":"Defines the color rgb(168, 56, 48).","ref":"Fledex.Color.Names.html#sweet_brown/0"},{"type":"function","title":"Fledex.Color.Names.syracuse_orange/0","doc":"Defines the color rgb(211, 68, 0).","ref":"Fledex.Color.Names.html#syracuse_orange/0"},{"type":"function","title":"Fledex.Color.Names.tan/0","doc":"Defines the color rgb(209, 181, 140).","ref":"Fledex.Color.Names.html#tan/0"},{"type":"function","title":"Fledex.Color.Names.tan_crayola/0","doc":"Defines the color rgb(216, 153, 107).","ref":"Fledex.Color.Names.html#tan_crayola/0"},{"type":"function","title":"Fledex.Color.Names.tangerine/0","doc":"Defines the color rgb(242, 132, 0).","ref":"Fledex.Color.Names.html#tangerine/0"},{"type":"function","title":"Fledex.Color.Names.tango_pink/0","doc":"Defines the color rgb(226, 112, 122).","ref":"Fledex.Color.Names.html#tango_pink/0"},{"type":"function","title":"Fledex.Color.Names.tart_orange/0","doc":"Defines the color rgb(249, 76, 68).","ref":"Fledex.Color.Names.html#tart_orange/0"},{"type":"function","title":"Fledex.Color.Names.taupe/0","doc":"Defines the color rgb(71, 61, 51).","ref":"Fledex.Color.Names.html#taupe/0"},{"type":"function","title":"Fledex.Color.Names.taupe_gray/0","doc":"Defines the color rgb(140, 132, 137).","ref":"Fledex.Color.Names.html#taupe_gray/0"},{"type":"function","title":"Fledex.Color.Names.tea_green/0","doc":"Defines the color rgb(209, 239, 191).","ref":"Fledex.Color.Names.html#tea_green/0"},{"type":"function","title":"Fledex.Color.Names.tea_rose/0","doc":"Defines the color rgb(244, 193, 193).","ref":"Fledex.Color.Names.html#tea_rose/0"},{"type":"function","title":"Fledex.Color.Names.teal/0","doc":"Defines the color rgb(0, 127, 127).","ref":"Fledex.Color.Names.html#teal/0"},{"type":"function","title":"Fledex.Color.Names.teal_blue/0","doc":"Defines the color rgb(53, 117, 135).","ref":"Fledex.Color.Names.html#teal_blue/0"},{"type":"function","title":"Fledex.Color.Names.telemagenta/0","doc":"Defines the color rgb(206, 51, 117).","ref":"Fledex.Color.Names.html#telemagenta/0"},{"type":"function","title":"Fledex.Color.Names.tenne_tawny/0","doc":"Defines the color rgb(204, 86, 0).","ref":"Fledex.Color.Names.html#tenne_tawny/0"},{"type":"function","title":"Fledex.Color.Names.terra_cotta/0","doc":"Defines the color rgb(226, 114, 91).","ref":"Fledex.Color.Names.html#terra_cotta/0"},{"type":"function","title":"Fledex.Color.Names.thistle/0","doc":"Defines the color rgb(216, 191, 216).","ref":"Fledex.Color.Names.html#thistle/0"},{"type":"function","title":"Fledex.Color.Names.thulian_pink/0","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.html#thulian_pink/0"},{"type":"function","title":"Fledex.Color.Names.tickle_me_pink/0","doc":"Defines the color rgb(252, 137, 170).","ref":"Fledex.Color.Names.html#tickle_me_pink/0"},{"type":"function","title":"Fledex.Color.Names.tiffany_blue/0","doc":"Defines the color rgb(10, 186, 181).","ref":"Fledex.Color.Names.html#tiffany_blue/0"},{"type":"function","title":"Fledex.Color.Names.timberwolf/0","doc":"Defines the color rgb(219, 214, 209).","ref":"Fledex.Color.Names.html#timberwolf/0"},{"type":"function","title":"Fledex.Color.Names.titanium_yellow/0","doc":"Defines the color rgb(237, 229, 0).","ref":"Fledex.Color.Names.html#titanium_yellow/0"},{"type":"function","title":"Fledex.Color.Names.tomato/0","doc":"Defines the color rgb(255, 99, 71).","ref":"Fledex.Color.Names.html#tomato/0"},{"type":"function","title":"Fledex.Color.Names.tourmaline/0","doc":"Defines the color rgb(135, 160, 168).","ref":"Fledex.Color.Names.html#tourmaline/0"},{"type":"function","title":"Fledex.Color.Names.tropical_rainforest/0","doc":"Defines the color rgb(0, 117, 94).","ref":"Fledex.Color.Names.html#tropical_rainforest/0"},{"type":"function","title":"Fledex.Color.Names.true_blue/0","doc":"Defines the color rgb(0, 114, 206).","ref":"Fledex.Color.Names.html#true_blue/0"},{"type":"function","title":"Fledex.Color.Names.trypan_blue/0","doc":"Defines the color rgb(28, 5, 178).","ref":"Fledex.Color.Names.html#trypan_blue/0"},{"type":"function","title":"Fledex.Color.Names.tufts_blue/0","doc":"Defines the color rgb(61, 142, 221).","ref":"Fledex.Color.Names.html#tufts_blue/0"},{"type":"function","title":"Fledex.Color.Names.tumbleweed/0","doc":"Defines the color rgb(221, 170, 135).","ref":"Fledex.Color.Names.html#tumbleweed/0"},{"type":"function","title":"Fledex.Color.Names.turquoise/0","doc":"Defines the color rgb(63, 224, 209).","ref":"Fledex.Color.Names.html#turquoise/0"},{"type":"function","title":"Fledex.Color.Names.turquoise_blue/0","doc":"Defines the color rgb(0, 255, 239).","ref":"Fledex.Color.Names.html#turquoise_blue/0"},{"type":"function","title":"Fledex.Color.Names.turquoise_green/0","doc":"Defines the color rgb(160, 214, 181).","ref":"Fledex.Color.Names.html#turquoise_green/0"},{"type":"function","title":"Fledex.Color.Names.turtle_green/0","doc":"Defines the color rgb(137, 153, 91).","ref":"Fledex.Color.Names.html#turtle_green/0"},{"type":"function","title":"Fledex.Color.Names.tuscan/0","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.html#tuscan/0"},{"type":"function","title":"Fledex.Color.Names.tuscan_brown/0","doc":"Defines the color rgb(112, 79, 56).","ref":"Fledex.Color.Names.html#tuscan_brown/0"},{"type":"function","title":"Fledex.Color.Names.tuscan_red/0","doc":"Defines the color rgb(124, 71, 71).","ref":"Fledex.Color.Names.html#tuscan_red/0"},{"type":"function","title":"Fledex.Color.Names.tuscan_tan/0","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.html#tuscan_tan/0"},{"type":"function","title":"Fledex.Color.Names.tuscany/0","doc":"Defines the color rgb(191, 153, 153).","ref":"Fledex.Color.Names.html#tuscany/0"},{"type":"function","title":"Fledex.Color.Names.twilight_lavender/0","doc":"Defines the color rgb(137, 73, 107).","ref":"Fledex.Color.Names.html#twilight_lavender/0"},{"type":"function","title":"Fledex.Color.Names.tyrian_purple/0","doc":"Defines the color rgb(102, 2, 61).","ref":"Fledex.Color.Names.html#tyrian_purple/0"},{"type":"function","title":"Fledex.Color.Names.ua_blue/0","doc":"Defines the color rgb(0, 51, 170).","ref":"Fledex.Color.Names.html#ua_blue/0"},{"type":"function","title":"Fledex.Color.Names.ua_red/0","doc":"Defines the color rgb(216, 0, 76).","ref":"Fledex.Color.Names.html#ua_red/0"},{"type":"function","title":"Fledex.Color.Names.ultra_pink/0","doc":"Defines the color rgb(255, 112, 255).","ref":"Fledex.Color.Names.html#ultra_pink/0"},{"type":"function","title":"Fledex.Color.Names.ultra_red/0","doc":"Defines the color rgb(252, 107, 132).","ref":"Fledex.Color.Names.html#ultra_red/0"},{"type":"function","title":"Fledex.Color.Names.ultramarine/0","doc":"Defines the color rgb(17, 10, 142).","ref":"Fledex.Color.Names.html#ultramarine/0"},{"type":"function","title":"Fledex.Color.Names.ultramarine_blue/0","doc":"Defines the color rgb(63, 102, 244).","ref":"Fledex.Color.Names.html#ultramarine_blue/0"},{"type":"function","title":"Fledex.Color.Names.umber/0","doc":"Defines the color rgb(99, 81, 71).","ref":"Fledex.Color.Names.html#umber/0"},{"type":"function","title":"Fledex.Color.Names.unbleached_silk/0","doc":"Defines the color rgb(255, 221, 201).","ref":"Fledex.Color.Names.html#unbleached_silk/0"},{"type":"function","title":"Fledex.Color.Names.united_nations_blue/0","doc":"Defines the color rgb(91, 145, 229).","ref":"Fledex.Color.Names.html#united_nations_blue/0"},{"type":"function","title":"Fledex.Color.Names.university_of_pennsylvania_red/0","doc":"Defines the color rgb(165, 0, 33).","ref":"Fledex.Color.Names.html#university_of_pennsylvania_red/0"},{"type":"function","title":"Fledex.Color.Names.unmellow_yellow/0","doc":"Defines the color rgb(255, 255, 102).","ref":"Fledex.Color.Names.html#unmellow_yellow/0"},{"type":"function","title":"Fledex.Color.Names.up_forest_green/0","doc":"Defines the color rgb(0, 68, 33).","ref":"Fledex.Color.Names.html#up_forest_green/0"},{"type":"function","title":"Fledex.Color.Names.up_maroon/0","doc":"Defines the color rgb(122, 17, 17).","ref":"Fledex.Color.Names.html#up_maroon/0"},{"type":"function","title":"Fledex.Color.Names.upsdell_red/0","doc":"Defines the color rgb(173, 33, 40).","ref":"Fledex.Color.Names.html#upsdell_red/0"},{"type":"function","title":"Fledex.Color.Names.uranian_blue/0","doc":"Defines the color rgb(175, 219, 244).","ref":"Fledex.Color.Names.html#uranian_blue/0"},{"type":"function","title":"Fledex.Color.Names.usafa_blue/0","doc":"Defines the color rgb(0, 79, 153).","ref":"Fledex.Color.Names.html#usafa_blue/0"},{"type":"function","title":"Fledex.Color.Names.van_dyke_brown/0","doc":"Defines the color rgb(102, 66, 40).","ref":"Fledex.Color.Names.html#van_dyke_brown/0"},{"type":"function","title":"Fledex.Color.Names.vanilla/0","doc":"Defines the color rgb(242, 229, 170).","ref":"Fledex.Color.Names.html#vanilla/0"},{"type":"function","title":"Fledex.Color.Names.vanilla_ice/0","doc":"Defines the color rgb(242, 142, 168).","ref":"Fledex.Color.Names.html#vanilla_ice/0"},{"type":"function","title":"Fledex.Color.Names.vegas_gold/0","doc":"Defines the color rgb(196, 178, 89).","ref":"Fledex.Color.Names.html#vegas_gold/0"},{"type":"function","title":"Fledex.Color.Names.venetian_red/0","doc":"Defines the color rgb(198, 7, 20).","ref":"Fledex.Color.Names.html#venetian_red/0"},{"type":"function","title":"Fledex.Color.Names.verdigris/0","doc":"Defines the color rgb(66, 178, 173).","ref":"Fledex.Color.Names.html#verdigris/0"},{"type":"function","title":"Fledex.Color.Names.vermilion2/0","doc":"Defines the color rgb(216, 56, 30).","ref":"Fledex.Color.Names.html#vermilion2/0"},{"type":"function","title":"Fledex.Color.Names.vermilion/0","doc":"Defines the color rgb(226, 66, 51).","ref":"Fledex.Color.Names.html#vermilion/0"},{"type":"function","title":"Fledex.Color.Names.veronica/0","doc":"Defines the color rgb(160, 33, 239).","ref":"Fledex.Color.Names.html#veronica/0"},{"type":"function","title":"Fledex.Color.Names.violet/0","doc":"Defines the color rgb(142, 0, 255).","ref":"Fledex.Color.Names.html#violet/0"},{"type":"function","title":"Fledex.Color.Names.violet_blue/0","doc":"Defines the color rgb(51, 73, 178).","ref":"Fledex.Color.Names.html#violet_blue/0"},{"type":"function","title":"Fledex.Color.Names.violet_blue_crayola/0","doc":"Defines the color rgb(117, 109, 198).","ref":"Fledex.Color.Names.html#violet_blue_crayola/0"},{"type":"function","title":"Fledex.Color.Names.violet_color_wheel/0","doc":"Defines the color rgb(127, 0, 255).","ref":"Fledex.Color.Names.html#violet_color_wheel/0"},{"type":"function","title":"Fledex.Color.Names.violet_crayola/0","doc":"Defines the color rgb(150, 61, 127).","ref":"Fledex.Color.Names.html#violet_crayola/0"},{"type":"function","title":"Fledex.Color.Names.violet_red/0","doc":"Defines the color rgb(247, 84, 147).","ref":"Fledex.Color.Names.html#violet_red/0"},{"type":"function","title":"Fledex.Color.Names.violet_red_perbang/0","doc":"Defines the color rgb(239, 89, 155).","ref":"Fledex.Color.Names.html#violet_red_perbang/0"},{"type":"function","title":"Fledex.Color.Names.violet_ryb/0","doc":"Defines the color rgb(135, 0, 175).","ref":"Fledex.Color.Names.html#violet_ryb/0"},{"type":"function","title":"Fledex.Color.Names.violet_web/0","doc":"Defines the color rgb(237, 130, 237).","ref":"Fledex.Color.Names.html#violet_web/0"},{"type":"function","title":"Fledex.Color.Names.viridian/0","doc":"Defines the color rgb(63, 130, 109).","ref":"Fledex.Color.Names.html#viridian/0"},{"type":"function","title":"Fledex.Color.Names.viridian_green/0","doc":"Defines the color rgb(0, 150, 153).","ref":"Fledex.Color.Names.html#viridian_green/0"},{"type":"function","title":"Fledex.Color.Names.vivid_burgundy/0","doc":"Defines the color rgb(158, 28, 53).","ref":"Fledex.Color.Names.html#vivid_burgundy/0"},{"type":"function","title":"Fledex.Color.Names.vivid_sky_blue/0","doc":"Defines the color rgb(0, 204, 255).","ref":"Fledex.Color.Names.html#vivid_sky_blue/0"},{"type":"function","title":"Fledex.Color.Names.vivid_tangerine/0","doc":"Defines the color rgb(255, 160, 137).","ref":"Fledex.Color.Names.html#vivid_tangerine/0"},{"type":"function","title":"Fledex.Color.Names.vivid_violet/0","doc":"Defines the color rgb(158, 0, 255).","ref":"Fledex.Color.Names.html#vivid_violet/0"},{"type":"function","title":"Fledex.Color.Names.volt/0","doc":"Defines the color rgb(204, 255, 0).","ref":"Fledex.Color.Names.html#volt/0"},{"type":"function","title":"Fledex.Color.Names.warm_black/0","doc":"Defines the color rgb(0, 66, 66).","ref":"Fledex.Color.Names.html#warm_black/0"},{"type":"function","title":"Fledex.Color.Names.weezy_blue/0","doc":"Defines the color rgb(22, 155, 204).","ref":"Fledex.Color.Names.html#weezy_blue/0"},{"type":"function","title":"Fledex.Color.Names.wheat/0","doc":"Defines the color rgb(244, 221, 178).","ref":"Fledex.Color.Names.html#wheat/0"},{"type":"function","title":"Fledex.Color.Names.white/0","doc":"Defines the color rgb(255, 255, 255).","ref":"Fledex.Color.Names.html#white/0"},{"type":"function","title":"Fledex.Color.Names.whitesmoke/0","doc":"","ref":"Fledex.Color.Names.html#whitesmoke/0"},{"type":"function","title":"Fledex.Color.Names.wild_blue_yonder/0","doc":"Defines the color rgb(163, 173, 209).","ref":"Fledex.Color.Names.html#wild_blue_yonder/0"},{"type":"function","title":"Fledex.Color.Names.wild_orchid/0","doc":"Defines the color rgb(211, 112, 163).","ref":"Fledex.Color.Names.html#wild_orchid/0"},{"type":"function","title":"Fledex.Color.Names.wild_strawberry/0","doc":"Defines the color rgb(255, 66, 163).","ref":"Fledex.Color.Names.html#wild_strawberry/0"},{"type":"function","title":"Fledex.Color.Names.wild_watermelon/0","doc":"Defines the color rgb(252, 107, 132).","ref":"Fledex.Color.Names.html#wild_watermelon/0"},{"type":"function","title":"Fledex.Color.Names.windsor_tan/0","doc":"Defines the color rgb(165, 84, 2).","ref":"Fledex.Color.Names.html#windsor_tan/0"},{"type":"function","title":"Fledex.Color.Names.wine/0","doc":"Defines the color rgb(114, 45, 56).","ref":"Fledex.Color.Names.html#wine/0"},{"type":"function","title":"Fledex.Color.Names.wine_dregs/0","doc":"Defines the color rgb(102, 48, 71).","ref":"Fledex.Color.Names.html#wine_dregs/0"},{"type":"function","title":"Fledex.Color.Names.winter_sky/0","doc":"Defines the color rgb(255, 0, 124).","ref":"Fledex.Color.Names.html#winter_sky/0"},{"type":"function","title":"Fledex.Color.Names.wintergreen_dream/0","doc":"Defines the color rgb(86, 135, 124).","ref":"Fledex.Color.Names.html#wintergreen_dream/0"},{"type":"function","title":"Fledex.Color.Names.wisteria/0","doc":"Defines the color rgb(201, 160, 219).","ref":"Fledex.Color.Names.html#wisteria/0"},{"type":"function","title":"Fledex.Color.Names.wood_brown/0","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.html#wood_brown/0"},{"type":"function","title":"Fledex.Color.Names.xanadu/0","doc":"Defines the color rgb(114, 135, 119).","ref":"Fledex.Color.Names.html#xanadu/0"},{"type":"function","title":"Fledex.Color.Names.xanthic/0","doc":"Defines the color rgb(237, 237, 10).","ref":"Fledex.Color.Names.html#xanthic/0"},{"type":"function","title":"Fledex.Color.Names.xanthous/0","doc":"Defines the color rgb(242, 181, 45).","ref":"Fledex.Color.Names.html#xanthous/0"},{"type":"function","title":"Fledex.Color.Names.yale_blue/0","doc":"Defines the color rgb(0, 53, 107).","ref":"Fledex.Color.Names.html#yale_blue/0"},{"type":"function","title":"Fledex.Color.Names.yellow/0","doc":"Defines the color rgb(255, 255, 0).","ref":"Fledex.Color.Names.html#yellow/0"},{"type":"function","title":"Fledex.Color.Names.yellow_crayola/0","doc":"Defines the color rgb(252, 232, 130).","ref":"Fledex.Color.Names.html#yellow_crayola/0"},{"type":"function","title":"Fledex.Color.Names.yellow_green/0","doc":"Defines the color rgb(153, 204, 51).","ref":"Fledex.Color.Names.html#yellow_green/0"},{"type":"function","title":"Fledex.Color.Names.yellow_green_color_wheel/0","doc":"Defines the color rgb(48, 178, 25).","ref":"Fledex.Color.Names.html#yellow_green_color_wheel/0"},{"type":"function","title":"Fledex.Color.Names.yellow_green_crayola/0","doc":"Defines the color rgb(196, 226, 132).","ref":"Fledex.Color.Names.html#yellow_green_crayola/0"},{"type":"function","title":"Fledex.Color.Names.yellow_munsell/0","doc":"Defines the color rgb(239, 204, 0).","ref":"Fledex.Color.Names.html#yellow_munsell/0"},{"type":"function","title":"Fledex.Color.Names.yellow_ncs/0","doc":"Defines the color rgb(255, 211, 0).","ref":"Fledex.Color.Names.html#yellow_ncs/0"},{"type":"function","title":"Fledex.Color.Names.yellow_orange/0","doc":"Defines the color rgb(255, 173, 66).","ref":"Fledex.Color.Names.html#yellow_orange/0"},{"type":"function","title":"Fledex.Color.Names.yellow_orange_color_wheel/0","doc":"Defines the color rgb(255, 147, 5).","ref":"Fledex.Color.Names.html#yellow_orange_color_wheel/0"},{"type":"function","title":"Fledex.Color.Names.yellow_pantone/0","doc":"Defines the color rgb(255, 221, 0).","ref":"Fledex.Color.Names.html#yellow_pantone/0"},{"type":"function","title":"Fledex.Color.Names.yellow_process/0","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.html#yellow_process/0"},{"type":"function","title":"Fledex.Color.Names.yellow_ryb/0","doc":"Defines the color rgb(255, 255, 51).","ref":"Fledex.Color.Names.html#yellow_ryb/0"},{"type":"function","title":"Fledex.Color.Names.yellow_sunshine/0","doc":"Defines the color rgb(255, 247, 0).","ref":"Fledex.Color.Names.html#yellow_sunshine/0"},{"type":"function","title":"Fledex.Color.Names.yellowgreen/0","doc":"","ref":"Fledex.Color.Names.html#yellowgreen/0"},{"type":"function","title":"Fledex.Color.Names.yinmn_blue/0","doc":"Defines the color rgb(45, 79, 142).","ref":"Fledex.Color.Names.html#yinmn_blue/0"},{"type":"function","title":"Fledex.Color.Names.zaffre/0","doc":"Defines the color rgb(0, 20, 168).","ref":"Fledex.Color.Names.html#zaffre/0"},{"type":"function","title":"Fledex.Color.Names.zomp/0","doc":"Defines the color rgb(56, 165, 142).","ref":"Fledex.Color.Names.html#zomp/0"},{"type":"module","title":"Fledex.Color.Names.CSS","doc":"Do not use this module directly, but use Fledex.Color.Names instead","ref":"Fledex.Color.Names.CSS.html"},{"type":"function","title":"Fledex.Color.Names.CSS.aliceblue/1","doc":"Defines the color rgb(240, 248, 255).","ref":"Fledex.Color.Names.CSS.html#aliceblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.antiquewhite/1","doc":"Defines the color rgb(250, 235, 215).","ref":"Fledex.Color.Names.CSS.html#antiquewhite/1"},{"type":"function","title":"Fledex.Color.Names.CSS.aqua/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.CSS.html#aqua/1"},{"type":"function","title":"Fledex.Color.Names.CSS.aquamarine/1","doc":"Defines the color rgb(127, 255, 212).","ref":"Fledex.Color.Names.CSS.html#aquamarine/1"},{"type":"function","title":"Fledex.Color.Names.CSS.azure/1","doc":"Defines the color rgb(240, 255, 255).","ref":"Fledex.Color.Names.CSS.html#azure/1"},{"type":"function","title":"Fledex.Color.Names.CSS.beige/1","doc":"Defines the color rgb(245, 245, 220).","ref":"Fledex.Color.Names.CSS.html#beige/1"},{"type":"function","title":"Fledex.Color.Names.CSS.bisque/1","doc":"Defines the color rgb(255, 228, 196).","ref":"Fledex.Color.Names.CSS.html#bisque/1"},{"type":"function","title":"Fledex.Color.Names.CSS.black/1","doc":"Defines the color rgb(0, 0, 0).","ref":"Fledex.Color.Names.CSS.html#black/1"},{"type":"function","title":"Fledex.Color.Names.CSS.blanchedalmond/1","doc":"Defines the color rgb(255, 235, 205).","ref":"Fledex.Color.Names.CSS.html#blanchedalmond/1"},{"type":"function","title":"Fledex.Color.Names.CSS.blue/1","doc":"Defines the color rgb(0, 0, 255).","ref":"Fledex.Color.Names.CSS.html#blue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.blueviolet/1","doc":"Defines the color rgb(138, 43, 226).","ref":"Fledex.Color.Names.CSS.html#blueviolet/1"},{"type":"function","title":"Fledex.Color.Names.CSS.brown/1","doc":"Defines the color rgb(165, 42, 42).","ref":"Fledex.Color.Names.CSS.html#brown/1"},{"type":"function","title":"Fledex.Color.Names.CSS.burlywood/1","doc":"Defines the color rgb(222, 184, 135).","ref":"Fledex.Color.Names.CSS.html#burlywood/1"},{"type":"function","title":"Fledex.Color.Names.CSS.cadetblue/1","doc":"Defines the color rgb(95, 158, 160).","ref":"Fledex.Color.Names.CSS.html#cadetblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.chartreuse/1","doc":"Defines the color rgb(127, 255, 0).","ref":"Fledex.Color.Names.CSS.html#chartreuse/1"},{"type":"function","title":"Fledex.Color.Names.CSS.chocolate/1","doc":"Defines the color rgb(210, 105, 30).","ref":"Fledex.Color.Names.CSS.html#chocolate/1"},{"type":"type","title":"Fledex.Color.Names.CSS.color_names_t/0","doc":"The allowed color names","ref":"Fledex.Color.Names.CSS.html#t:color_names_t/0"},{"type":"function","title":"Fledex.Color.Names.CSS.colors/0","doc":"Get all the data about the predefined colors","ref":"Fledex.Color.Names.CSS.html#colors/0"},{"type":"function","title":"Fledex.Color.Names.CSS.coral/1","doc":"Defines the color rgb(255, 127, 80).","ref":"Fledex.Color.Names.CSS.html#coral/1"},{"type":"function","title":"Fledex.Color.Names.CSS.cornflowerblue/1","doc":"Defines the color rgb(100, 149, 237).","ref":"Fledex.Color.Names.CSS.html#cornflowerblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.cornsilk/1","doc":"Defines the color rgb(255, 248, 220).","ref":"Fledex.Color.Names.CSS.html#cornsilk/1"},{"type":"function","title":"Fledex.Color.Names.CSS.crimson/1","doc":"Defines the color rgb(220, 20, 60).","ref":"Fledex.Color.Names.CSS.html#crimson/1"},{"type":"function","title":"Fledex.Color.Names.CSS.cyan/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.CSS.html#cyan/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkblue/1","doc":"Defines the color rgb(0, 0, 139).","ref":"Fledex.Color.Names.CSS.html#darkblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkcyan/1","doc":"Defines the color rgb(0, 139, 139).","ref":"Fledex.Color.Names.CSS.html#darkcyan/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkgoldenrod/1","doc":"Defines the color rgb(184, 134, 11).","ref":"Fledex.Color.Names.CSS.html#darkgoldenrod/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkgray/1","doc":"Defines the color rgb(169, 169, 169).","ref":"Fledex.Color.Names.CSS.html#darkgray/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkgreen/1","doc":"Defines the color rgb(0, 100, 0).","ref":"Fledex.Color.Names.CSS.html#darkgreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkgrey/1","doc":"Defines the color rgb(169, 169, 169).","ref":"Fledex.Color.Names.CSS.html#darkgrey/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkkhaki/1","doc":"Defines the color rgb(189, 183, 107).","ref":"Fledex.Color.Names.CSS.html#darkkhaki/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkmagenta/1","doc":"Defines the color rgb(139, 0, 139).","ref":"Fledex.Color.Names.CSS.html#darkmagenta/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkolivegreen/1","doc":"Defines the color rgb(85, 107, 47).","ref":"Fledex.Color.Names.CSS.html#darkolivegreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkorange/1","doc":"Defines the color rgb(255, 140, 0).","ref":"Fledex.Color.Names.CSS.html#darkorange/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkorchid/1","doc":"Defines the color rgb(153, 50, 204).","ref":"Fledex.Color.Names.CSS.html#darkorchid/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkred/1","doc":"Defines the color rgb(139, 0, 0).","ref":"Fledex.Color.Names.CSS.html#darkred/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darksalmon/1","doc":"Defines the color rgb(233, 150, 122).","ref":"Fledex.Color.Names.CSS.html#darksalmon/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkseagreen/1","doc":"Defines the color rgb(143, 188, 143).","ref":"Fledex.Color.Names.CSS.html#darkseagreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkslateblue/1","doc":"Defines the color rgb(72, 61, 139).","ref":"Fledex.Color.Names.CSS.html#darkslateblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkslategray/1","doc":"Defines the color rgb(47, 79, 79).","ref":"Fledex.Color.Names.CSS.html#darkslategray/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkslategrey/1","doc":"Defines the color rgb(47, 79, 79).","ref":"Fledex.Color.Names.CSS.html#darkslategrey/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkturquoise/1","doc":"Defines the color rgb(0, 206, 209).","ref":"Fledex.Color.Names.CSS.html#darkturquoise/1"},{"type":"function","title":"Fledex.Color.Names.CSS.darkviolet/1","doc":"Defines the color rgb(148, 0, 211).","ref":"Fledex.Color.Names.CSS.html#darkviolet/1"},{"type":"function","title":"Fledex.Color.Names.CSS.deeppink/1","doc":"Defines the color rgb(255, 20, 147).","ref":"Fledex.Color.Names.CSS.html#deeppink/1"},{"type":"function","title":"Fledex.Color.Names.CSS.deepskyblue/1","doc":"Defines the color rgb(0, 191, 255).","ref":"Fledex.Color.Names.CSS.html#deepskyblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.dimgray/1","doc":"Defines the color rgb(105, 105, 105).","ref":"Fledex.Color.Names.CSS.html#dimgray/1"},{"type":"function","title":"Fledex.Color.Names.CSS.dimgrey/1","doc":"Defines the color rgb(105, 105, 105).","ref":"Fledex.Color.Names.CSS.html#dimgrey/1"},{"type":"function","title":"Fledex.Color.Names.CSS.dodgerblue/1","doc":"Defines the color rgb(30, 144, 255).","ref":"Fledex.Color.Names.CSS.html#dodgerblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.firebrick/1","doc":"Defines the color rgb(178, 34, 34).","ref":"Fledex.Color.Names.CSS.html#firebrick/1"},{"type":"function","title":"Fledex.Color.Names.CSS.floralwhite/1","doc":"Defines the color rgb(255, 250, 240).","ref":"Fledex.Color.Names.CSS.html#floralwhite/1"},{"type":"function","title":"Fledex.Color.Names.CSS.forestgreen/1","doc":"Defines the color rgb(34, 139, 34).","ref":"Fledex.Color.Names.CSS.html#forestgreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.fuchsia/1","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.CSS.html#fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.CSS.gainsboro/1","doc":"Defines the color rgb(220, 220, 220).","ref":"Fledex.Color.Names.CSS.html#gainsboro/1"},{"type":"function","title":"Fledex.Color.Names.CSS.ghostwhite/1","doc":"Defines the color rgb(248, 248, 255).","ref":"Fledex.Color.Names.CSS.html#ghostwhite/1"},{"type":"function","title":"Fledex.Color.Names.CSS.gold/1","doc":"Defines the color rgb(255, 215, 0).","ref":"Fledex.Color.Names.CSS.html#gold/1"},{"type":"function","title":"Fledex.Color.Names.CSS.goldenrod/1","doc":"Defines the color rgb(218, 165, 32).","ref":"Fledex.Color.Names.CSS.html#goldenrod/1"},{"type":"function","title":"Fledex.Color.Names.CSS.gray/1","doc":"Defines the color rgb(128, 128, 128).","ref":"Fledex.Color.Names.CSS.html#gray/1"},{"type":"function","title":"Fledex.Color.Names.CSS.green/1","doc":"Defines the color rgb(0, 128, 0).","ref":"Fledex.Color.Names.CSS.html#green/1"},{"type":"function","title":"Fledex.Color.Names.CSS.greenyellow/1","doc":"Defines the color rgb(173, 255, 47).","ref":"Fledex.Color.Names.CSS.html#greenyellow/1"},{"type":"function","title":"Fledex.Color.Names.CSS.grey/1","doc":"Defines the color rgb(128, 128, 128).","ref":"Fledex.Color.Names.CSS.html#grey/1"},{"type":"function","title":"Fledex.Color.Names.CSS.honeydew/1","doc":"Defines the color rgb(240, 255, 240).","ref":"Fledex.Color.Names.CSS.html#honeydew/1"},{"type":"function","title":"Fledex.Color.Names.CSS.hotpink/1","doc":"Defines the color rgb(255, 105, 180).","ref":"Fledex.Color.Names.CSS.html#hotpink/1"},{"type":"function","title":"Fledex.Color.Names.CSS.indianred/1","doc":"Defines the color rgb(205, 92, 92).","ref":"Fledex.Color.Names.CSS.html#indianred/1"},{"type":"function","title":"Fledex.Color.Names.CSS.indigo/1","doc":"Defines the color rgb(75, 0, 130).","ref":"Fledex.Color.Names.CSS.html#indigo/1"},{"type":"macro","title":"Fledex.Color.Names.CSS.is_color_name/1","doc":"Check whether the atom is a valid color name","ref":"Fledex.Color.Names.CSS.html#is_color_name/1"},{"type":"function","title":"Fledex.Color.Names.CSS.ivory/1","doc":"Defines the color rgb(255, 255, 240).","ref":"Fledex.Color.Names.CSS.html#ivory/1"},{"type":"function","title":"Fledex.Color.Names.CSS.khaki/1","doc":"Defines the color rgb(240, 230, 140).","ref":"Fledex.Color.Names.CSS.html#khaki/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lavender/1","doc":"Defines the color rgb(230, 230, 250).","ref":"Fledex.Color.Names.CSS.html#lavender/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lavenderblush/1","doc":"Defines the color rgb(255, 240, 245).","ref":"Fledex.Color.Names.CSS.html#lavenderblush/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lawngreen/1","doc":"Defines the color rgb(124, 252, 0).","ref":"Fledex.Color.Names.CSS.html#lawngreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lemonchiffon/1","doc":"Defines the color rgb(255, 250, 205).","ref":"Fledex.Color.Names.CSS.html#lemonchiffon/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightblue/1","doc":"Defines the color rgb(173, 216, 230).","ref":"Fledex.Color.Names.CSS.html#lightblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightcoral/1","doc":"Defines the color rgb(240, 128, 128).","ref":"Fledex.Color.Names.CSS.html#lightcoral/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightcyan/1","doc":"Defines the color rgb(224, 255, 255).","ref":"Fledex.Color.Names.CSS.html#lightcyan/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightgoldenrodyellow/1","doc":"Defines the color rgb(250, 250, 210).","ref":"Fledex.Color.Names.CSS.html#lightgoldenrodyellow/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightgray/1","doc":"Defines the color rgb(211, 211, 211).","ref":"Fledex.Color.Names.CSS.html#lightgray/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightgreen/1","doc":"Defines the color rgb(144, 238, 144).","ref":"Fledex.Color.Names.CSS.html#lightgreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightgrey/1","doc":"Defines the color rgb(211, 211, 211).","ref":"Fledex.Color.Names.CSS.html#lightgrey/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightpink/1","doc":"Defines the color rgb(255, 182, 193).","ref":"Fledex.Color.Names.CSS.html#lightpink/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightsalmon/1","doc":"Defines the color rgb(255, 160, 122).","ref":"Fledex.Color.Names.CSS.html#lightsalmon/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightseagreen/1","doc":"Defines the color rgb(32, 178, 170).","ref":"Fledex.Color.Names.CSS.html#lightseagreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightskyblue/1","doc":"Defines the color rgb(135, 206, 250).","ref":"Fledex.Color.Names.CSS.html#lightskyblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightslategray/1","doc":"Defines the color rgb(119, 136, 153).","ref":"Fledex.Color.Names.CSS.html#lightslategray/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightslategrey/1","doc":"Defines the color rgb(119, 136, 153).","ref":"Fledex.Color.Names.CSS.html#lightslategrey/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightsteelblue/1","doc":"Defines the color rgb(176, 196, 222).","ref":"Fledex.Color.Names.CSS.html#lightsteelblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lightyellow/1","doc":"Defines the color rgb(255, 255, 224).","ref":"Fledex.Color.Names.CSS.html#lightyellow/1"},{"type":"function","title":"Fledex.Color.Names.CSS.lime/1","doc":"Defines the color rgb(0, 255, 0).","ref":"Fledex.Color.Names.CSS.html#lime/1"},{"type":"function","title":"Fledex.Color.Names.CSS.limegreen/1","doc":"Defines the color rgb(50, 205, 50).","ref":"Fledex.Color.Names.CSS.html#limegreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.linen/1","doc":"Defines the color rgb(250, 240, 230).","ref":"Fledex.Color.Names.CSS.html#linen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.magenta/1","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.CSS.html#magenta/1"},{"type":"function","title":"Fledex.Color.Names.CSS.maroon/1","doc":"Defines the color rgb(128, 0, 0).","ref":"Fledex.Color.Names.CSS.html#maroon/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumaquamarine/1","doc":"Defines the color rgb(102, 205, 170).","ref":"Fledex.Color.Names.CSS.html#mediumaquamarine/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumblue/1","doc":"Defines the color rgb(0, 0, 205).","ref":"Fledex.Color.Names.CSS.html#mediumblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumorchid/1","doc":"Defines the color rgb(186, 85, 211).","ref":"Fledex.Color.Names.CSS.html#mediumorchid/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumpurple/1","doc":"Defines the color rgb(147, 112, 219).","ref":"Fledex.Color.Names.CSS.html#mediumpurple/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumseagreen/1","doc":"Defines the color rgb(60, 179, 113).","ref":"Fledex.Color.Names.CSS.html#mediumseagreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumslateblue/1","doc":"Defines the color rgb(123, 104, 238).","ref":"Fledex.Color.Names.CSS.html#mediumslateblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumspringgreen/1","doc":"Defines the color rgb(0, 250, 154).","ref":"Fledex.Color.Names.CSS.html#mediumspringgreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumturquoise/1","doc":"Defines the color rgb(72, 209, 204).","ref":"Fledex.Color.Names.CSS.html#mediumturquoise/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mediumvioletred/1","doc":"Defines the color rgb(199, 21, 133).","ref":"Fledex.Color.Names.CSS.html#mediumvioletred/1"},{"type":"function","title":"Fledex.Color.Names.CSS.midnightblue/1","doc":"Defines the color rgb(25, 25, 112).","ref":"Fledex.Color.Names.CSS.html#midnightblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mintcream/1","doc":"Defines the color rgb(245, 255, 250).","ref":"Fledex.Color.Names.CSS.html#mintcream/1"},{"type":"function","title":"Fledex.Color.Names.CSS.mistyrose/1","doc":"Defines the color rgb(255, 228, 225).","ref":"Fledex.Color.Names.CSS.html#mistyrose/1"},{"type":"function","title":"Fledex.Color.Names.CSS.moccasin/1","doc":"Defines the color rgb(255, 228, 181).","ref":"Fledex.Color.Names.CSS.html#moccasin/1"},{"type":"function","title":"Fledex.Color.Names.CSS.names/0","doc":"Get a list of all the predefined color (atom) names.\n\nThe name can be used to either retrieve the info by calling `info/2` or by calling the function with that\nname (see also the description at the top and take a look at this [example livebook](3b_fledex_more_about_colors.livemd))","ref":"Fledex.Color.Names.CSS.html#names/0"},{"type":"function","title":"Fledex.Color.Names.CSS.navajowhite/1","doc":"Defines the color rgb(255, 222, 173).","ref":"Fledex.Color.Names.CSS.html#navajowhite/1"},{"type":"function","title":"Fledex.Color.Names.CSS.navy/1","doc":"Defines the color rgb(0, 0, 128).","ref":"Fledex.Color.Names.CSS.html#navy/1"},{"type":"function","title":"Fledex.Color.Names.CSS.oldlace/1","doc":"Defines the color rgb(253, 245, 230).","ref":"Fledex.Color.Names.CSS.html#oldlace/1"},{"type":"function","title":"Fledex.Color.Names.CSS.olive/1","doc":"Defines the color rgb(128, 128, 0).","ref":"Fledex.Color.Names.CSS.html#olive/1"},{"type":"function","title":"Fledex.Color.Names.CSS.olivedrab/1","doc":"Defines the color rgb(107, 142, 35).","ref":"Fledex.Color.Names.CSS.html#olivedrab/1"},{"type":"function","title":"Fledex.Color.Names.CSS.orange/1","doc":"Defines the color rgb(255, 165, 0).","ref":"Fledex.Color.Names.CSS.html#orange/1"},{"type":"function","title":"Fledex.Color.Names.CSS.orangered/1","doc":"Defines the color rgb(255, 69, 0).","ref":"Fledex.Color.Names.CSS.html#orangered/1"},{"type":"function","title":"Fledex.Color.Names.CSS.orchid/1","doc":"Defines the color rgb(218, 112, 214).","ref":"Fledex.Color.Names.CSS.html#orchid/1"},{"type":"function","title":"Fledex.Color.Names.CSS.palegoldenrod/1","doc":"Defines the color rgb(238, 232, 170).","ref":"Fledex.Color.Names.CSS.html#palegoldenrod/1"},{"type":"function","title":"Fledex.Color.Names.CSS.palegreen/1","doc":"Defines the color rgb(152, 251, 152).","ref":"Fledex.Color.Names.CSS.html#palegreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.paleturquoise/1","doc":"Defines the color rgb(175, 238, 238).","ref":"Fledex.Color.Names.CSS.html#paleturquoise/1"},{"type":"function","title":"Fledex.Color.Names.CSS.palevioletred/1","doc":"Defines the color rgb(219, 112, 147).","ref":"Fledex.Color.Names.CSS.html#palevioletred/1"},{"type":"function","title":"Fledex.Color.Names.CSS.papayawhip/1","doc":"Defines the color rgb(255, 239, 213).","ref":"Fledex.Color.Names.CSS.html#papayawhip/1"},{"type":"function","title":"Fledex.Color.Names.CSS.peachpuff/1","doc":"Defines the color rgb(255, 218, 185).","ref":"Fledex.Color.Names.CSS.html#peachpuff/1"},{"type":"function","title":"Fledex.Color.Names.CSS.peru/1","doc":"Defines the color rgb(205, 133, 63).","ref":"Fledex.Color.Names.CSS.html#peru/1"},{"type":"function","title":"Fledex.Color.Names.CSS.pink/1","doc":"Defines the color rgb(255, 192, 203).","ref":"Fledex.Color.Names.CSS.html#pink/1"},{"type":"function","title":"Fledex.Color.Names.CSS.plum/1","doc":"Defines the color rgb(221, 160, 221).","ref":"Fledex.Color.Names.CSS.html#plum/1"},{"type":"function","title":"Fledex.Color.Names.CSS.powderblue/1","doc":"Defines the color rgb(176, 224, 230).","ref":"Fledex.Color.Names.CSS.html#powderblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.purple/1","doc":"Defines the color rgb(128, 0, 128).","ref":"Fledex.Color.Names.CSS.html#purple/1"},{"type":"function","title":"Fledex.Color.Names.CSS.rebeccapurple/1","doc":"Defines the color rgb(102, 51, 153).","ref":"Fledex.Color.Names.CSS.html#rebeccapurple/1"},{"type":"function","title":"Fledex.Color.Names.CSS.red/1","doc":"Defines the color rgb(255, 0, 0).","ref":"Fledex.Color.Names.CSS.html#red/1"},{"type":"function","title":"Fledex.Color.Names.CSS.rosybrown/1","doc":"Defines the color rgb(188, 143, 143).","ref":"Fledex.Color.Names.CSS.html#rosybrown/1"},{"type":"function","title":"Fledex.Color.Names.CSS.royalblue/1","doc":"Defines the color rgb(65, 105, 225).","ref":"Fledex.Color.Names.CSS.html#royalblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.saddlebrown/1","doc":"Defines the color rgb(139, 69, 19).","ref":"Fledex.Color.Names.CSS.html#saddlebrown/1"},{"type":"function","title":"Fledex.Color.Names.CSS.salmon/1","doc":"Defines the color rgb(250, 128, 114).","ref":"Fledex.Color.Names.CSS.html#salmon/1"},{"type":"function","title":"Fledex.Color.Names.CSS.sandybrown/1","doc":"Defines the color rgb(244, 164, 96).","ref":"Fledex.Color.Names.CSS.html#sandybrown/1"},{"type":"function","title":"Fledex.Color.Names.CSS.seagreen/1","doc":"Defines the color rgb(46, 139, 87).","ref":"Fledex.Color.Names.CSS.html#seagreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.seashell/1","doc":"Defines the color rgb(255, 245, 238).","ref":"Fledex.Color.Names.CSS.html#seashell/1"},{"type":"function","title":"Fledex.Color.Names.CSS.sienna/1","doc":"Defines the color rgb(160, 82, 45).","ref":"Fledex.Color.Names.CSS.html#sienna/1"},{"type":"function","title":"Fledex.Color.Names.CSS.silver/1","doc":"Defines the color rgb(192, 192, 192).","ref":"Fledex.Color.Names.CSS.html#silver/1"},{"type":"function","title":"Fledex.Color.Names.CSS.skyblue/1","doc":"Defines the color rgb(135, 206, 235).","ref":"Fledex.Color.Names.CSS.html#skyblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.slateblue/1","doc":"Defines the color rgb(106, 90, 205).","ref":"Fledex.Color.Names.CSS.html#slateblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.slategray/1","doc":"Defines the color rgb(112, 128, 144).","ref":"Fledex.Color.Names.CSS.html#slategray/1"},{"type":"function","title":"Fledex.Color.Names.CSS.slategrey/1","doc":"Defines the color rgb(112, 128, 144).","ref":"Fledex.Color.Names.CSS.html#slategrey/1"},{"type":"function","title":"Fledex.Color.Names.CSS.snow/1","doc":"Defines the color rgb(255, 250, 250).","ref":"Fledex.Color.Names.CSS.html#snow/1"},{"type":"function","title":"Fledex.Color.Names.CSS.springgreen/1","doc":"Defines the color rgb(0, 255, 127).","ref":"Fledex.Color.Names.CSS.html#springgreen/1"},{"type":"function","title":"Fledex.Color.Names.CSS.steelblue/1","doc":"Defines the color rgb(70, 130, 180).","ref":"Fledex.Color.Names.CSS.html#steelblue/1"},{"type":"function","title":"Fledex.Color.Names.CSS.tan/1","doc":"Defines the color rgb(210, 180, 140).","ref":"Fledex.Color.Names.CSS.html#tan/1"},{"type":"function","title":"Fledex.Color.Names.CSS.teal/1","doc":"Defines the color rgb(0, 128, 128).","ref":"Fledex.Color.Names.CSS.html#teal/1"},{"type":"function","title":"Fledex.Color.Names.CSS.thistle/1","doc":"Defines the color rgb(216, 191, 216).","ref":"Fledex.Color.Names.CSS.html#thistle/1"},{"type":"function","title":"Fledex.Color.Names.CSS.tomato/1","doc":"Defines the color rgb(255, 99, 71).","ref":"Fledex.Color.Names.CSS.html#tomato/1"},{"type":"function","title":"Fledex.Color.Names.CSS.turquoise/1","doc":"Defines the color rgb(64, 224, 208).","ref":"Fledex.Color.Names.CSS.html#turquoise/1"},{"type":"function","title":"Fledex.Color.Names.CSS.violet/1","doc":"Defines the color rgb(238, 130, 238).","ref":"Fledex.Color.Names.CSS.html#violet/1"},{"type":"function","title":"Fledex.Color.Names.CSS.wheat/1","doc":"Defines the color rgb(245, 222, 179).","ref":"Fledex.Color.Names.CSS.html#wheat/1"},{"type":"function","title":"Fledex.Color.Names.CSS.white/1","doc":"Defines the color rgb(255, 255, 255).","ref":"Fledex.Color.Names.CSS.html#white/1"},{"type":"function","title":"Fledex.Color.Names.CSS.whitesmoke/1","doc":"Defines the color rgb(245, 245, 245).","ref":"Fledex.Color.Names.CSS.html#whitesmoke/1"},{"type":"function","title":"Fledex.Color.Names.CSS.yellow/1","doc":"Defines the color rgb(255, 255, 0).","ref":"Fledex.Color.Names.CSS.html#yellow/1"},{"type":"function","title":"Fledex.Color.Names.CSS.yellowgreen/1","doc":"Defines the color rgb(154, 205, 50).","ref":"Fledex.Color.Names.CSS.html#yellowgreen/1"},{"type":"module","title":"Fledex.Color.Names.DocUtils","doc":"","ref":"Fledex.Color.Names.DocUtils.html"},{"type":"function","title":"Fledex.Color.Names.DocUtils.extract_doc/3","doc":"Extracts the docs from a function","ref":"Fledex.Color.Names.DocUtils.html#extract_doc/3"},{"type":"function","title":"Fledex.Color.Names.DocUtils.extract_function_doc/3","doc":"","ref":"Fledex.Color.Names.DocUtils.html#extract_function_doc/3"},{"type":"function","title":"Fledex.Color.Names.DocUtils.get_docs/2","doc":"Extract docs from a module, filtered by the kinds (list of :function, :type, ...)","ref":"Fledex.Color.Names.DocUtils.html#get_docs/2"},{"type":"module","title":"Fledex.Color.Names.Dsl","doc":"","ref":"Fledex.Color.Names.Dsl.html"},{"type":"function","title":"Fledex.Color.Names.Dsl.create_color_functions/6","doc":"","ref":"Fledex.Color.Names.Dsl.html#create_color_functions/6"},{"type":"module","title":"Fledex.Color.Names.Guards","doc":"","ref":"Fledex.Color.Names.Guards.html"},{"type":"macro","title":"Fledex.Color.Names.Guards.is_color_name/1","doc":"Check whether the atom is a valid color name.\n  Note: RAL colors are not included (intentionaly)","ref":"Fledex.Color.Names.Guards.html#is_color_name/1"},{"type":"module","title":"Fledex.Color.Names.LoadUtils","doc":"","ref":"Fledex.Color.Names.LoadUtils.html"},{"type":"function","title":"Fledex.Color.Names.LoadUtils.a2i/1","doc":"","ref":"Fledex.Color.Names.LoadUtils.html#a2i/1"},{"type":"function","title":"Fledex.Color.Names.LoadUtils.clean/1","doc":"","ref":"Fledex.Color.Names.LoadUtils.html#clean/1"},{"type":"function","title":"Fledex.Color.Names.LoadUtils.clean_and_convert/1","doc":"","ref":"Fledex.Color.Names.LoadUtils.html#clean_and_convert/1"},{"type":"function","title":"Fledex.Color.Names.LoadUtils.convert_to_atom/1","doc":"","ref":"Fledex.Color.Names.LoadUtils.html#convert_to_atom/1"},{"type":"function","title":"Fledex.Color.Names.LoadUtils.line_splitter/3","doc":"","ref":"Fledex.Color.Names.LoadUtils.html#line_splitter/3"},{"type":"function","title":"Fledex.Color.Names.LoadUtils.load_color_file/6","doc":"","ref":"Fledex.Color.Names.LoadUtils.html#load_color_file/6"},{"type":"function","title":"Fledex.Color.Names.LoadUtils.to_byte/1","doc":"","ref":"Fledex.Color.Names.LoadUtils.html#to_byte/1"},{"type":"module","title":"Fledex.Color.Names.RAL","doc":"Do not use this module directly, but use Fledex.Color.Names instead","ref":"Fledex.Color.Names.RAL.html"},{"type":"type","title":"Fledex.Color.Names.RAL.color_names_t/0","doc":"The allowed color names","ref":"Fledex.Color.Names.RAL.html#t:color_names_t/0"},{"type":"function","title":"Fledex.Color.Names.RAL.colors/0","doc":"Get all the data about the predefined colors","ref":"Fledex.Color.Names.RAL.html#colors/0"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l15c00/1","doc":"Defines the color rgb(33, 33, 34).","ref":"Fledex.Color.Names.RAL.html#h000l15c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l20c00/1","doc":"Defines the color rgb(43, 43, 43).","ref":"Fledex.Color.Names.RAL.html#h000l20c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l25c00/1","doc":"Defines the color rgb(58, 58, 58).","ref":"Fledex.Color.Names.RAL.html#h000l25c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l30c00/1","doc":"Defines the color rgb(68, 68, 67).","ref":"Fledex.Color.Names.RAL.html#h000l30c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l35c00/1","doc":"Defines the color rgb(80, 80, 80).","ref":"Fledex.Color.Names.RAL.html#h000l35c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l40c00/1","doc":"Defines the color rgb(93, 92, 91).","ref":"Fledex.Color.Names.RAL.html#h000l40c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l45c00/1","doc":"Defines the color rgb(107, 106, 105).","ref":"Fledex.Color.Names.RAL.html#h000l45c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l50c00/1","doc":"Defines the color rgb(118, 118, 117).","ref":"Fledex.Color.Names.RAL.html#h000l50c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l55c00/1","doc":"Defines the color rgb(130, 130, 130).","ref":"Fledex.Color.Names.RAL.html#h000l55c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l60c00/1","doc":"Defines the color rgb(143, 143, 142).","ref":"Fledex.Color.Names.RAL.html#h000l60c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l65c00/1","doc":"Defines the color rgb(158, 159, 158).","ref":"Fledex.Color.Names.RAL.html#h000l65c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l70c00/1","doc":"Defines the color rgb(172, 173, 172).","ref":"Fledex.Color.Names.RAL.html#h000l70c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l75c00/1","doc":"Defines the color rgb(186, 186, 186).","ref":"Fledex.Color.Names.RAL.html#h000l75c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l80c00/1","doc":"Defines the color rgb(201, 200, 199).","ref":"Fledex.Color.Names.RAL.html#h000l80c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l85c00/1","doc":"Defines the color rgb(214, 214, 212).","ref":"Fledex.Color.Names.RAL.html#h000l85c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h000l90c00/1","doc":"Defines the color rgb(226, 227, 224).","ref":"Fledex.Color.Names.RAL.html#h000l90c00/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l20c10/1","doc":"Defines the color rgb(62, 42, 44).","ref":"Fledex.Color.Names.RAL.html#h010l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l20c15/1","doc":"Defines the color rgb(66, 35, 41).","ref":"Fledex.Color.Names.RAL.html#h010l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l20c20/1","doc":"Defines the color rgb(72, 32, 41).","ref":"Fledex.Color.Names.RAL.html#h010l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l20c25/1","doc":"Defines the color rgb(75, 28, 40).","ref":"Fledex.Color.Names.RAL.html#h010l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l30c10/1","doc":"Defines the color rgb(88, 64, 67).","ref":"Fledex.Color.Names.RAL.html#h010l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l30c15/1","doc":"Defines the color rgb(93, 59, 65).","ref":"Fledex.Color.Names.RAL.html#h010l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l30c20/1","doc":"Defines the color rgb(100, 57, 65).","ref":"Fledex.Color.Names.RAL.html#h010l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l30c25/1","doc":"Defines the color rgb(108, 51, 63).","ref":"Fledex.Color.Names.RAL.html#h010l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l30c30/1","doc":"Defines the color rgb(113, 47, 62).","ref":"Fledex.Color.Names.RAL.html#h010l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l30c35/1","doc":"Defines the color rgb(115, 41, 59).","ref":"Fledex.Color.Names.RAL.html#h010l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l30c40/1","doc":"Defines the color rgb(123, 32, 57).","ref":"Fledex.Color.Names.RAL.html#h010l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l30c44/1","doc":"Defines the color rgb(130, 25, 58).","ref":"Fledex.Color.Names.RAL.html#h010l30c44/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c10/1","doc":"Defines the color rgb(111, 88, 91).","ref":"Fledex.Color.Names.RAL.html#h010l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c15/1","doc":"Defines the color rgb(119, 83, 89).","ref":"Fledex.Color.Names.RAL.html#h010l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c20/1","doc":"Defines the color rgb(127, 81, 88).","ref":"Fledex.Color.Names.RAL.html#h010l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c25/1","doc":"Defines the color rgb(134, 77, 88).","ref":"Fledex.Color.Names.RAL.html#h010l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c30/1","doc":"Defines the color rgb(141, 72, 86).","ref":"Fledex.Color.Names.RAL.html#h010l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c35/1","doc":"Defines the color rgb(144, 67, 83).","ref":"Fledex.Color.Names.RAL.html#h010l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c40/1","doc":"Defines the color rgb(152, 61, 83).","ref":"Fledex.Color.Names.RAL.html#h010l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c45/1","doc":"Defines the color rgb(159, 55, 83).","ref":"Fledex.Color.Names.RAL.html#h010l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c50/1","doc":"Defines the color rgb(165, 49, 82).","ref":"Fledex.Color.Names.RAL.html#h010l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l40c53/1","doc":"Defines the color rgb(169, 43, 79).","ref":"Fledex.Color.Names.RAL.html#h010l40c53/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c10/1","doc":"Defines the color rgb(136, 113, 117).","ref":"Fledex.Color.Names.RAL.html#h010l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c15/1","doc":"Defines the color rgb(143, 109, 115).","ref":"Fledex.Color.Names.RAL.html#h010l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c20/1","doc":"Defines the color rgb(152, 105, 113).","ref":"Fledex.Color.Names.RAL.html#h010l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c25/1","doc":"Defines the color rgb(160, 101, 112).","ref":"Fledex.Color.Names.RAL.html#h010l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c30/1","doc":"Defines the color rgb(169, 96, 110).","ref":"Fledex.Color.Names.RAL.html#h010l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c35/1","doc":"Defines the color rgb(174, 91, 108).","ref":"Fledex.Color.Names.RAL.html#h010l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c40/1","doc":"Defines the color rgb(179, 88, 108).","ref":"Fledex.Color.Names.RAL.html#h010l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c45/1","doc":"Defines the color rgb(184, 81, 106).","ref":"Fledex.Color.Names.RAL.html#h010l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l50c50/1","doc":"Defines the color rgb(194, 76, 106).","ref":"Fledex.Color.Names.RAL.html#h010l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l60c10/1","doc":"Defines the color rgb(163, 138, 141).","ref":"Fledex.Color.Names.RAL.html#h010l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l60c15/1","doc":"Defines the color rgb(173, 135, 141).","ref":"Fledex.Color.Names.RAL.html#h010l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l60c20/1","doc":"Defines the color rgb(182, 132, 140).","ref":"Fledex.Color.Names.RAL.html#h010l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l60c25/1","doc":"Defines the color rgb(189, 127, 138).","ref":"Fledex.Color.Names.RAL.html#h010l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l60c30/1","doc":"Defines the color rgb(196, 122, 136).","ref":"Fledex.Color.Names.RAL.html#h010l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l60c35/1","doc":"Defines the color rgb(205, 118, 135).","ref":"Fledex.Color.Names.RAL.html#h010l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l60c40/1","doc":"Defines the color rgb(212, 113, 134).","ref":"Fledex.Color.Names.RAL.html#h010l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l60c45/1","doc":"Defines the color rgb(220, 108, 132).","ref":"Fledex.Color.Names.RAL.html#h010l60c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l70c10/1","doc":"Defines the color rgb(192, 166, 170).","ref":"Fledex.Color.Names.RAL.html#h010l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l70c15/1","doc":"Defines the color rgb(200, 162, 167).","ref":"Fledex.Color.Names.RAL.html#h010l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l70c20/1","doc":"Defines the color rgb(210, 158, 166).","ref":"Fledex.Color.Names.RAL.html#h010l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l70c25/1","doc":"Defines the color rgb(219, 154, 165).","ref":"Fledex.Color.Names.RAL.html#h010l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l70c30/1","doc":"Defines the color rgb(226, 151, 164).","ref":"Fledex.Color.Names.RAL.html#h010l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l70c35/1","doc":"Defines the color rgb(234, 145, 161).","ref":"Fledex.Color.Names.RAL.html#h010l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l80c10/1","doc":"Defines the color rgb(220, 192, 195).","ref":"Fledex.Color.Names.RAL.html#h010l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l80c15/1","doc":"Defines the color rgb(228, 189, 194).","ref":"Fledex.Color.Names.RAL.html#h010l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l80c20/1","doc":"Defines the color rgb(239, 185, 192).","ref":"Fledex.Color.Names.RAL.html#h010l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l85c05/1","doc":"Defines the color rgb(223, 211, 212).","ref":"Fledex.Color.Names.RAL.html#h010l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l85c10/1","doc":"Defines the color rgb(230, 207, 210).","ref":"Fledex.Color.Names.RAL.html#h010l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l85c15/1","doc":"Defines the color rgb(240, 205, 210).","ref":"Fledex.Color.Names.RAL.html#h010l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l85c20/1","doc":"Defines the color rgb(249, 203, 211).","ref":"Fledex.Color.Names.RAL.html#h010l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l90c05/1","doc":"Defines the color rgb(239, 224, 222).","ref":"Fledex.Color.Names.RAL.html#h010l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l90c10/1","doc":"Defines the color rgb(242, 218, 214).","ref":"Fledex.Color.Names.RAL.html#h010l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h010l93c05/1","doc":"Defines the color rgb(243, 232, 234).","ref":"Fledex.Color.Names.RAL.html#h010l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l20c05/1","doc":"Defines the color rgb(52, 42, 42).","ref":"Fledex.Color.Names.RAL.html#h020l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l20c10/1","doc":"Defines the color rgb(60, 39, 39).","ref":"Fledex.Color.Names.RAL.html#h020l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l20c20/1","doc":"Defines the color rgb(74, 33, 37).","ref":"Fledex.Color.Names.RAL.html#h020l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l20c29/1","doc":"Defines the color rgb(83, 24, 31).","ref":"Fledex.Color.Names.RAL.html#h020l20c29/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l30c05/1","doc":"Defines the color rgb(77, 65, 65).","ref":"Fledex.Color.Names.RAL.html#h020l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l30c10/1","doc":"Defines the color rgb(85, 61, 62).","ref":"Fledex.Color.Names.RAL.html#h020l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l30c20/1","doc":"Defines the color rgb(99, 54, 57).","ref":"Fledex.Color.Names.RAL.html#h020l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l30c30/1","doc":"Defines the color rgb(109, 44, 50).","ref":"Fledex.Color.Names.RAL.html#h020l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l30c40/1","doc":"Defines the color rgb(123, 35, 49).","ref":"Fledex.Color.Names.RAL.html#h020l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l30c48/1","doc":"Defines the color rgb(132, 23, 44).","ref":"Fledex.Color.Names.RAL.html#h020l30c48/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l40c05/1","doc":"Defines the color rgb(103, 91, 91).","ref":"Fledex.Color.Names.RAL.html#h020l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l40c10/1","doc":"Defines the color rgb(110, 86, 87).","ref":"Fledex.Color.Names.RAL.html#h020l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l40c20/1","doc":"Defines the color rgb(125, 79, 81).","ref":"Fledex.Color.Names.RAL.html#h020l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l40c30/1","doc":"Defines the color rgb(138, 71, 76).","ref":"Fledex.Color.Names.RAL.html#h020l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l40c40/1","doc":"Defines the color rgb(148, 61, 70).","ref":"Fledex.Color.Names.RAL.html#h020l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l40c50/1","doc":"Defines the color rgb(160, 46, 62).","ref":"Fledex.Color.Names.RAL.html#h020l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l50c05/1","doc":"Defines the color rgb(128, 116, 115).","ref":"Fledex.Color.Names.RAL.html#h020l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l50c10/1","doc":"Defines the color rgb(136, 110, 112).","ref":"Fledex.Color.Names.RAL.html#h020l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l50c20/1","doc":"Defines the color rgb(153, 104, 106).","ref":"Fledex.Color.Names.RAL.html#h020l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l50c30/1","doc":"Defines the color rgb(167, 96, 101).","ref":"Fledex.Color.Names.RAL.html#h020l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l50c40/1","doc":"Defines the color rgb(177, 87, 95).","ref":"Fledex.Color.Names.RAL.html#h020l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l50c50/1","doc":"Defines the color rgb(190, 76, 90).","ref":"Fledex.Color.Names.RAL.html#h020l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l50c58/1","doc":"Defines the color rgb(206, 68, 88).","ref":"Fledex.Color.Names.RAL.html#h020l50c58/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l60c05/1","doc":"Defines the color rgb(153, 141, 141).","ref":"Fledex.Color.Names.RAL.html#h020l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l60c10/1","doc":"Defines the color rgb(163, 137, 138).","ref":"Fledex.Color.Names.RAL.html#h020l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l60c20/1","doc":"Defines the color rgb(180, 130, 134).","ref":"Fledex.Color.Names.RAL.html#h020l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l60c30/1","doc":"Defines the color rgb(195, 121, 127).","ref":"Fledex.Color.Names.RAL.html#h020l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l60c40/1","doc":"Defines the color rgb(209, 113, 123).","ref":"Fledex.Color.Names.RAL.html#h020l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l70c05/1","doc":"Defines the color rgb(181, 168, 168).","ref":"Fledex.Color.Names.RAL.html#h020l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l70c10/1","doc":"Defines the color rgb(189, 163, 165).","ref":"Fledex.Color.Names.RAL.html#h020l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l70c20/1","doc":"Defines the color rgb(211, 158, 162).","ref":"Fledex.Color.Names.RAL.html#h020l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l70c30/1","doc":"Defines the color rgb(227, 150, 155).","ref":"Fledex.Color.Names.RAL.html#h020l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l80c05/1","doc":"Defines the color rgb(211, 197, 196).","ref":"Fledex.Color.Names.RAL.html#h020l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l80c10/1","doc":"Defines the color rgb(219, 191, 192).","ref":"Fledex.Color.Names.RAL.html#h020l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l80c20/1","doc":"Defines the color rgb(238, 186, 188).","ref":"Fledex.Color.Names.RAL.html#h020l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l85c05/1","doc":"Defines the color rgb(224, 210, 209).","ref":"Fledex.Color.Names.RAL.html#h020l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l85c10/1","doc":"Defines the color rgb(233, 207, 207).","ref":"Fledex.Color.Names.RAL.html#h020l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l85c20/1","doc":"Defines the color rgb(253, 202, 202).","ref":"Fledex.Color.Names.RAL.html#h020l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l90c05/1","doc":"Defines the color rgb(240, 226, 222).","ref":"Fledex.Color.Names.RAL.html#h020l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l90c10/1","doc":"Defines the color rgb(244, 220, 216).","ref":"Fledex.Color.Names.RAL.html#h020l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h020l93c05/1","doc":"Defines the color rgb(248, 232, 228).","ref":"Fledex.Color.Names.RAL.html#h020l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l30c10/1","doc":"Defines the color rgb(85, 64, 62).","ref":"Fledex.Color.Names.RAL.html#h030l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l30c20/1","doc":"Defines the color rgb(98, 56, 54).","ref":"Fledex.Color.Names.RAL.html#h030l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l30c30/1","doc":"Defines the color rgb(110, 47, 44).","ref":"Fledex.Color.Names.RAL.html#h030l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l30c40/1","doc":"Defines the color rgb(124, 41, 42).","ref":"Fledex.Color.Names.RAL.html#h030l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l30c45/1","doc":"Defines the color rgb(125, 30, 32).","ref":"Fledex.Color.Names.RAL.html#h030l30c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l40c10/1","doc":"Defines the color rgb(108, 87, 85).","ref":"Fledex.Color.Names.RAL.html#h030l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l40c20/1","doc":"Defines the color rgb(126, 83, 80).","ref":"Fledex.Color.Names.RAL.html#h030l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l40c30/1","doc":"Defines the color rgb(139, 75, 71).","ref":"Fledex.Color.Names.RAL.html#h030l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l40c40/1","doc":"Defines the color rgb(151, 65, 62).","ref":"Fledex.Color.Names.RAL.html#h030l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l40c50/1","doc":"Defines the color rgb(163, 55, 55).","ref":"Fledex.Color.Names.RAL.html#h030l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l40c60/1","doc":"Defines the color rgb(172, 44, 50).","ref":"Fledex.Color.Names.RAL.html#h030l40c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l50c10/1","doc":"Defines the color rgb(136, 111, 109).","ref":"Fledex.Color.Names.RAL.html#h030l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l50c20/1","doc":"Defines the color rgb(151, 106, 102).","ref":"Fledex.Color.Names.RAL.html#h030l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l50c30/1","doc":"Defines the color rgb(166, 97, 93).","ref":"Fledex.Color.Names.RAL.html#h030l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l50c40/1","doc":"Defines the color rgb(180, 90, 86).","ref":"Fledex.Color.Names.RAL.html#h030l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l50c50/1","doc":"Defines the color rgb(191, 81, 78).","ref":"Fledex.Color.Names.RAL.html#h030l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l50c60/1","doc":"Defines the color rgb(203, 69, 67).","ref":"Fledex.Color.Names.RAL.html#h030l50c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l60c10/1","doc":"Defines the color rgb(162, 138, 136).","ref":"Fledex.Color.Names.RAL.html#h030l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l60c20/1","doc":"Defines the color rgb(179, 131, 127).","ref":"Fledex.Color.Names.RAL.html#h030l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l60c30/1","doc":"Defines the color rgb(194, 122, 116).","ref":"Fledex.Color.Names.RAL.html#h030l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l60c40/1","doc":"Defines the color rgb(208, 117, 111).","ref":"Fledex.Color.Names.RAL.html#h030l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l60c50/1","doc":"Defines the color rgb(222, 107, 102).","ref":"Fledex.Color.Names.RAL.html#h030l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l70c10/1","doc":"Defines the color rgb(190, 164, 162).","ref":"Fledex.Color.Names.RAL.html#h030l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l70c20/1","doc":"Defines the color rgb(208, 156, 151).","ref":"Fledex.Color.Names.RAL.html#h030l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l70c30/1","doc":"Defines the color rgb(225, 149, 143).","ref":"Fledex.Color.Names.RAL.html#h030l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l70c40/1","doc":"Defines the color rgb(239, 142, 135).","ref":"Fledex.Color.Names.RAL.html#h030l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l80c10/1","doc":"Defines the color rgb(218, 192, 188).","ref":"Fledex.Color.Names.RAL.html#h030l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l80c20/1","doc":"Defines the color rgb(236, 185, 179).","ref":"Fledex.Color.Names.RAL.html#h030l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l85c05/1","doc":"Defines the color rgb(224, 209, 203).","ref":"Fledex.Color.Names.RAL.html#h030l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l85c10/1","doc":"Defines the color rgb(231, 207, 202).","ref":"Fledex.Color.Names.RAL.html#h030l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l85c20/1","doc":"Defines the color rgb(249, 205, 196).","ref":"Fledex.Color.Names.RAL.html#h030l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l90c05/1","doc":"Defines the color rgb(238, 224, 220).","ref":"Fledex.Color.Names.RAL.html#h030l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l90c10/1","doc":"Defines the color rgb(246, 223, 216).","ref":"Fledex.Color.Names.RAL.html#h030l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h030l93c05/1","doc":"Defines the color rgb(249, 234, 229).","ref":"Fledex.Color.Names.RAL.html#h030l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l20c19/1","doc":"Defines the color rgb(71, 36, 26).","ref":"Fledex.Color.Names.RAL.html#h040l20c19/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l30c05/1","doc":"Defines the color rgb(77, 66, 62).","ref":"Fledex.Color.Names.RAL.html#h040l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l30c10/1","doc":"Defines the color rgb(83, 62, 57).","ref":"Fledex.Color.Names.RAL.html#h040l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l30c20/1","doc":"Defines the color rgb(96, 57, 47).","ref":"Fledex.Color.Names.RAL.html#h040l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l30c30/1","doc":"Defines the color rgb(107, 50, 38).","ref":"Fledex.Color.Names.RAL.html#h040l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l30c40/1","doc":"Defines the color rgb(119, 47, 33).","ref":"Fledex.Color.Names.RAL.html#h040l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l40c05/1","doc":"Defines the color rgb(103, 91, 88).","ref":"Fledex.Color.Names.RAL.html#h040l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l40c10/1","doc":"Defines the color rgb(108, 87, 81).","ref":"Fledex.Color.Names.RAL.html#h040l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l40c20/1","doc":"Defines the color rgb(123, 83, 73).","ref":"Fledex.Color.Names.RAL.html#h040l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l40c30/1","doc":"Defines the color rgb(133, 75, 60).","ref":"Fledex.Color.Names.RAL.html#h040l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l40c40/1","doc":"Defines the color rgb(145, 65, 47).","ref":"Fledex.Color.Names.RAL.html#h040l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l40c50/1","doc":"Defines the color rgb(157, 61, 39).","ref":"Fledex.Color.Names.RAL.html#h040l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l40c60/1","doc":"Defines the color rgb(165, 49, 26).","ref":"Fledex.Color.Names.RAL.html#h040l40c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l40c67/1","doc":"Defines the color rgb(173, 43, 16).","ref":"Fledex.Color.Names.RAL.html#h040l40c67/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l50c05/1","doc":"Defines the color rgb(126, 115, 111).","ref":"Fledex.Color.Names.RAL.html#h040l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l50c10/1","doc":"Defines the color rgb(135, 112, 107).","ref":"Fledex.Color.Names.RAL.html#h040l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l50c20/1","doc":"Defines the color rgb(149, 106, 96).","ref":"Fledex.Color.Names.RAL.html#h040l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l50c30/1","doc":"Defines the color rgb(164, 100, 84).","ref":"Fledex.Color.Names.RAL.html#h040l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l50c40/1","doc":"Defines the color rgb(176, 93, 74).","ref":"Fledex.Color.Names.RAL.html#h040l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l50c50/1","doc":"Defines the color rgb(189, 85, 62).","ref":"Fledex.Color.Names.RAL.html#h040l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l50c60/1","doc":"Defines the color rgb(202, 78, 51).","ref":"Fledex.Color.Names.RAL.html#h040l50c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l50c70/1","doc":"Defines the color rgb(209, 70, 44).","ref":"Fledex.Color.Names.RAL.html#h040l50c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l60c05/1","doc":"Defines the color rgb(153, 142, 138).","ref":"Fledex.Color.Names.RAL.html#h040l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l60c10/1","doc":"Defines the color rgb(163, 138, 131).","ref":"Fledex.Color.Names.RAL.html#h040l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l60c20/1","doc":"Defines the color rgb(176, 130, 119).","ref":"Fledex.Color.Names.RAL.html#h040l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l60c30/1","doc":"Defines the color rgb(194, 126, 111).","ref":"Fledex.Color.Names.RAL.html#h040l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l60c40/1","doc":"Defines the color rgb(204, 118, 97).","ref":"Fledex.Color.Names.RAL.html#h040l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l60c50/1","doc":"Defines the color rgb(218, 113, 87).","ref":"Fledex.Color.Names.RAL.html#h040l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l60c60/1","doc":"Defines the color rgb(228, 105, 76).","ref":"Fledex.Color.Names.RAL.html#h040l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l70c05/1","doc":"Defines the color rgb(180, 168, 164).","ref":"Fledex.Color.Names.RAL.html#h040l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l70c10/1","doc":"Defines the color rgb(191, 165, 158).","ref":"Fledex.Color.Names.RAL.html#h040l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l70c20/1","doc":"Defines the color rgb(208, 159, 147).","ref":"Fledex.Color.Names.RAL.html#h040l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l70c30/1","doc":"Defines the color rgb(224, 152, 135).","ref":"Fledex.Color.Names.RAL.html#h040l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l70c40/1","doc":"Defines the color rgb(232, 145, 125).","ref":"Fledex.Color.Names.RAL.html#h040l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l70c50/1","doc":"Defines the color rgb(250, 137, 112).","ref":"Fledex.Color.Names.RAL.html#h040l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l80c05/1","doc":"Defines the color rgb(211, 197, 192).","ref":"Fledex.Color.Names.RAL.html#h040l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l80c10/1","doc":"Defines the color rgb(221, 194, 186).","ref":"Fledex.Color.Names.RAL.html#h040l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l80c20/1","doc":"Defines the color rgb(241, 190, 176).","ref":"Fledex.Color.Names.RAL.html#h040l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l80c30/1","doc":"Defines the color rgb(254, 183, 165).","ref":"Fledex.Color.Names.RAL.html#h040l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l85c05/1","doc":"Defines the color rgb(227, 212, 207).","ref":"Fledex.Color.Names.RAL.html#h040l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l85c10/1","doc":"Defines the color rgb(236, 211, 203).","ref":"Fledex.Color.Names.RAL.html#h040l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l85c20/1","doc":"Defines the color rgb(253, 205, 189).","ref":"Fledex.Color.Names.RAL.html#h040l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l90c05/1","doc":"Defines the color rgb(240, 225, 219).","ref":"Fledex.Color.Names.RAL.html#h040l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l90c10/1","doc":"Defines the color rgb(247, 224, 214).","ref":"Fledex.Color.Names.RAL.html#h040l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h040l93c05/1","doc":"Defines the color rgb(251, 237, 229).","ref":"Fledex.Color.Names.RAL.html#h040l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l20c10/1","doc":"Defines the color rgb(61, 45, 36).","ref":"Fledex.Color.Names.RAL.html#h050l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l20c16/1","doc":"Defines the color rgb(68, 40, 27).","ref":"Fledex.Color.Names.RAL.html#h050l20c16/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l30c10/1","doc":"Defines the color rgb(82, 62, 53).","ref":"Fledex.Color.Names.RAL.html#h050l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l30c20/1","doc":"Defines the color rgb(96, 59, 42).","ref":"Fledex.Color.Names.RAL.html#h050l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l30c30/1","doc":"Defines the color rgb(108, 56, 33).","ref":"Fledex.Color.Names.RAL.html#h050l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l30c36/1","doc":"Defines the color rgb(114, 55, 28).","ref":"Fledex.Color.Names.RAL.html#h050l30c36/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l40c10/1","doc":"Defines the color rgb(111, 91, 82).","ref":"Fledex.Color.Names.RAL.html#h050l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l40c20/1","doc":"Defines the color rgb(122, 85, 68).","ref":"Fledex.Color.Names.RAL.html#h050l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l40c30/1","doc":"Defines the color rgb(132, 80, 56).","ref":"Fledex.Color.Names.RAL.html#h050l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l40c40/1","doc":"Defines the color rgb(143, 72, 38).","ref":"Fledex.Color.Names.RAL.html#h050l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l40c50/1","doc":"Defines the color rgb(153, 69, 31).","ref":"Fledex.Color.Names.RAL.html#h050l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l50c10/1","doc":"Defines the color rgb(137, 117, 107).","ref":"Fledex.Color.Names.RAL.html#h050l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l50c20/1","doc":"Defines the color rgb(150, 111, 93).","ref":"Fledex.Color.Names.RAL.html#h050l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l50c30/1","doc":"Defines the color rgb(163, 106, 79).","ref":"Fledex.Color.Names.RAL.html#h050l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l50c40/1","doc":"Defines the color rgb(173, 99, 66).","ref":"Fledex.Color.Names.RAL.html#h050l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l50c50/1","doc":"Defines the color rgb(185, 94, 51).","ref":"Fledex.Color.Names.RAL.html#h050l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l50c60/1","doc":"Defines the color rgb(189, 86, 32).","ref":"Fledex.Color.Names.RAL.html#h050l50c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l50c70/1","doc":"Defines the color rgb(205, 77, 4).","ref":"Fledex.Color.Names.RAL.html#h050l50c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l50c78/1","doc":"Defines the color rgb(212, 88, 20).","ref":"Fledex.Color.Names.RAL.html#h050l50c78/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l60c10/1","doc":"Defines the color rgb(164, 141, 131).","ref":"Fledex.Color.Names.RAL.html#h050l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l60c20/1","doc":"Defines the color rgb(177, 135, 117).","ref":"Fledex.Color.Names.RAL.html#h050l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l60c30/1","doc":"Defines the color rgb(194, 132, 104).","ref":"Fledex.Color.Names.RAL.html#h050l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l60c40/1","doc":"Defines the color rgb(204, 126, 91).","ref":"Fledex.Color.Names.RAL.html#h050l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l60c50/1","doc":"Defines the color rgb(216, 121, 76).","ref":"Fledex.Color.Names.RAL.html#h050l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l60c60/1","doc":"Defines the color rgb(229, 116, 59).","ref":"Fledex.Color.Names.RAL.html#h050l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l60c70/1","doc":"Defines the color rgb(233, 103, 45).","ref":"Fledex.Color.Names.RAL.html#h050l60c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l60c80/1","doc":"Defines the color rgb(246, 97, 26).","ref":"Fledex.Color.Names.RAL.html#h050l60c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l70c10/1","doc":"Defines the color rgb(193, 171, 160).","ref":"Fledex.Color.Names.RAL.html#h050l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l70c20/1","doc":"Defines the color rgb(208, 165, 146).","ref":"Fledex.Color.Names.RAL.html#h050l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l70c30/1","doc":"Defines the color rgb(222, 159, 131).","ref":"Fledex.Color.Names.RAL.html#h050l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l70c40/1","doc":"Defines the color rgb(237, 154, 118).","ref":"Fledex.Color.Names.RAL.html#h050l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l70c50/1","doc":"Defines the color rgb(246, 146, 104).","ref":"Fledex.Color.Names.RAL.html#h050l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l70c60/1","doc":"Defines the color rgb(255, 139, 88).","ref":"Fledex.Color.Names.RAL.html#h050l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l80c10/1","doc":"Defines the color rgb(223, 199, 188).","ref":"Fledex.Color.Names.RAL.html#h050l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l80c20/1","doc":"Defines the color rgb(238, 192, 171).","ref":"Fledex.Color.Names.RAL.html#h050l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l80c30/1","doc":"Defines the color rgb(252, 185, 157).","ref":"Fledex.Color.Names.RAL.html#h050l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l85c05/1","doc":"Defines the color rgb(228, 213, 205).","ref":"Fledex.Color.Names.RAL.html#h050l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l85c10/1","doc":"Defines the color rgb(233, 208, 196).","ref":"Fledex.Color.Names.RAL.html#h050l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l85c20/1","doc":"Defines the color rgb(249, 204, 183).","ref":"Fledex.Color.Names.RAL.html#h050l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l90c05/1","doc":"Defines the color rgb(243, 228, 220).","ref":"Fledex.Color.Names.RAL.html#h050l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l90c10/1","doc":"Defines the color rgb(255, 230, 216).","ref":"Fledex.Color.Names.RAL.html#h050l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h050l93c05/1","doc":"Defines the color rgb(251, 237, 229).","ref":"Fledex.Color.Names.RAL.html#h050l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l20c05/1","doc":"Defines the color rgb(50, 43, 38).","ref":"Fledex.Color.Names.RAL.html#h060l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l30c05/1","doc":"Defines the color rgb(76, 67, 61).","ref":"Fledex.Color.Names.RAL.html#h060l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l30c10/1","doc":"Defines the color rgb(81, 64, 53).","ref":"Fledex.Color.Names.RAL.html#h060l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l30c20/1","doc":"Defines the color rgb(90, 61, 41).","ref":"Fledex.Color.Names.RAL.html#h060l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l30c27/1","doc":"Defines the color rgb(98, 60, 31).","ref":"Fledex.Color.Names.RAL.html#h060l30c27/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l40c05/1","doc":"Defines the color rgb(101, 91, 85).","ref":"Fledex.Color.Names.RAL.html#h060l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l40c10/1","doc":"Defines the color rgb(106, 88, 77).","ref":"Fledex.Color.Names.RAL.html#h060l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l40c20/1","doc":"Defines the color rgb(118, 86, 64).","ref":"Fledex.Color.Names.RAL.html#h060l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l40c30/1","doc":"Defines the color rgb(127, 81, 49).","ref":"Fledex.Color.Names.RAL.html#h060l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l40c40/1","doc":"Defines the color rgb(138, 80, 36).","ref":"Fledex.Color.Names.RAL.html#h060l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l50c05/1","doc":"Defines the color rgb(127, 116, 110).","ref":"Fledex.Color.Names.RAL.html#h060l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l50c10/1","doc":"Defines the color rgb(133, 114, 102).","ref":"Fledex.Color.Names.RAL.html#h060l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l50c20/1","doc":"Defines the color rgb(144, 110, 88).","ref":"Fledex.Color.Names.RAL.html#h060l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l50c30/1","doc":"Defines the color rgb(157, 108, 74).","ref":"Fledex.Color.Names.RAL.html#h060l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l50c40/1","doc":"Defines the color rgb(165, 102, 57).","ref":"Fledex.Color.Names.RAL.html#h060l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l50c50/1","doc":"Defines the color rgb(175, 100, 43).","ref":"Fledex.Color.Names.RAL.html#h060l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l50c60/1","doc":"Defines the color rgb(178, 91, 9).","ref":"Fledex.Color.Names.RAL.html#h060l50c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l50c70/1","doc":"Defines the color rgb(189, 92, 0).","ref":"Fledex.Color.Names.RAL.html#h060l50c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c05/1","doc":"Defines the color rgb(154, 144, 138).","ref":"Fledex.Color.Names.RAL.html#h060l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c10/1","doc":"Defines the color rgb(161, 141, 128).","ref":"Fledex.Color.Names.RAL.html#h060l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c20/1","doc":"Defines the color rgb(176, 137, 113).","ref":"Fledex.Color.Names.RAL.html#h060l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c30/1","doc":"Defines the color rgb(185, 133, 99).","ref":"Fledex.Color.Names.RAL.html#h060l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c40/1","doc":"Defines the color rgb(200, 133, 84).","ref":"Fledex.Color.Names.RAL.html#h060l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c50/1","doc":"Defines the color rgb(202, 122, 64).","ref":"Fledex.Color.Names.RAL.html#h060l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c60/1","doc":"Defines the color rgb(213, 118, 43).","ref":"Fledex.Color.Names.RAL.html#h060l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c70/1","doc":"Defines the color rgb(219, 114, 16).","ref":"Fledex.Color.Names.RAL.html#h060l60c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l60c80/1","doc":"Defines the color rgb(229, 109, 0).","ref":"Fledex.Color.Names.RAL.html#h060l60c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l70c05/1","doc":"Defines the color rgb(181, 171, 164).","ref":"Fledex.Color.Names.RAL.html#h060l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l70c10/1","doc":"Defines the color rgb(189, 168, 156).","ref":"Fledex.Color.Names.RAL.html#h060l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l70c20/1","doc":"Defines the color rgb(200, 163, 138).","ref":"Fledex.Color.Names.RAL.html#h060l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l70c30/1","doc":"Defines the color rgb(209, 156, 121).","ref":"Fledex.Color.Names.RAL.html#h060l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l70c40/1","doc":"Defines the color rgb(224, 155, 110).","ref":"Fledex.Color.Names.RAL.html#h060l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l70c50/1","doc":"Defines the color rgb(235, 151, 94).","ref":"Fledex.Color.Names.RAL.html#h060l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l70c60/1","doc":"Defines the color rgb(240, 143, 72).","ref":"Fledex.Color.Names.RAL.html#h060l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l70c70/1","doc":"Defines the color rgb(252, 140, 53).","ref":"Fledex.Color.Names.RAL.html#h060l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l80c05/1","doc":"Defines the color rgb(209, 198, 190).","ref":"Fledex.Color.Names.RAL.html#h060l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l80c10/1","doc":"Defines the color rgb(215, 195, 181).","ref":"Fledex.Color.Names.RAL.html#h060l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l80c20/1","doc":"Defines the color rgb(230, 191, 166).","ref":"Fledex.Color.Names.RAL.html#h060l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l80c30/1","doc":"Defines the color rgb(244, 186, 148).","ref":"Fledex.Color.Names.RAL.html#h060l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l80c40/1","doc":"Defines the color rgb(253, 180, 130).","ref":"Fledex.Color.Names.RAL.html#h060l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l85c05/1","doc":"Defines the color rgb(227, 214, 204).","ref":"Fledex.Color.Names.RAL.html#h060l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l85c10/1","doc":"Defines the color rgb(235, 213, 197).","ref":"Fledex.Color.Names.RAL.html#h060l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l85c20/1","doc":"Defines the color rgb(246, 208, 182).","ref":"Fledex.Color.Names.RAL.html#h060l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l85c30/1","doc":"Defines the color rgb(255, 204, 165).","ref":"Fledex.Color.Names.RAL.html#h060l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l90c05/1","doc":"Defines the color rgb(239, 227, 216).","ref":"Fledex.Color.Names.RAL.html#h060l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l90c10/1","doc":"Defines the color rgb(247, 224, 210).","ref":"Fledex.Color.Names.RAL.html#h060l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l90c15/1","doc":"Defines the color rgb(253, 220, 200).","ref":"Fledex.Color.Names.RAL.html#h060l90c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h060l93c05/1","doc":"Defines the color rgb(249, 237, 228).","ref":"Fledex.Color.Names.RAL.html#h060l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l30c10/1","doc":"Defines the color rgb(77, 63, 51).","ref":"Fledex.Color.Names.RAL.html#h070l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l30c20/1","doc":"Defines the color rgb(87, 65, 40).","ref":"Fledex.Color.Names.RAL.html#h070l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l40c10/1","doc":"Defines the color rgb(103, 89, 76).","ref":"Fledex.Color.Names.RAL.html#h070l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l40c20/1","doc":"Defines the color rgb(113, 86, 59).","ref":"Fledex.Color.Names.RAL.html#h070l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l40c30/1","doc":"Defines the color rgb(122, 85, 46).","ref":"Fledex.Color.Names.RAL.html#h070l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l40c40/1","doc":"Defines the color rgb(128, 82, 26).","ref":"Fledex.Color.Names.RAL.html#h070l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l50c10/1","doc":"Defines the color rgb(129, 114, 101).","ref":"Fledex.Color.Names.RAL.html#h070l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l50c20/1","doc":"Defines the color rgb(140, 111, 84).","ref":"Fledex.Color.Names.RAL.html#h070l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l50c30/1","doc":"Defines the color rgb(148, 107, 65).","ref":"Fledex.Color.Names.RAL.html#h070l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l50c40/1","doc":"Defines the color rgb(157, 105, 47).","ref":"Fledex.Color.Names.RAL.html#h070l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l50c50/1","doc":"Defines the color rgb(158, 105, 40).","ref":"Fledex.Color.Names.RAL.html#h070l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l50c55/1","doc":"Defines the color rgb(167, 105, 36).","ref":"Fledex.Color.Names.RAL.html#h070l50c55/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l60c10/1","doc":"Defines the color rgb(155, 139, 124).","ref":"Fledex.Color.Names.RAL.html#h070l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l60c20/1","doc":"Defines the color rgb(166, 138, 110).","ref":"Fledex.Color.Names.RAL.html#h070l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l60c30/1","doc":"Defines the color rgb(175, 133, 92).","ref":"Fledex.Color.Names.RAL.html#h070l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l60c40/1","doc":"Defines the color rgb(184, 131, 73).","ref":"Fledex.Color.Names.RAL.html#h070l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l60c50/1","doc":"Defines the color rgb(193, 129, 54).","ref":"Fledex.Color.Names.RAL.html#h070l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l60c60/1","doc":"Defines the color rgb(203, 129, 45).","ref":"Fledex.Color.Names.RAL.html#h070l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l60c70/1","doc":"Defines the color rgb(205, 123, 0).","ref":"Fledex.Color.Names.RAL.html#h070l60c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l60c75/1","doc":"Defines the color rgb(208, 122, 4).","ref":"Fledex.Color.Names.RAL.html#h070l60c75/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l70c10/1","doc":"Defines the color rgb(184, 168, 153).","ref":"Fledex.Color.Names.RAL.html#h070l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l70c20/1","doc":"Defines the color rgb(194, 164, 135).","ref":"Fledex.Color.Names.RAL.html#h070l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l70c30/1","doc":"Defines the color rgb(206, 162, 119).","ref":"Fledex.Color.Names.RAL.html#h070l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l70c40/1","doc":"Defines the color rgb(215, 158, 98).","ref":"Fledex.Color.Names.RAL.html#h070l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l70c50/1","doc":"Defines the color rgb(222, 156, 82).","ref":"Fledex.Color.Names.RAL.html#h070l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l70c60/1","doc":"Defines the color rgb(233, 154, 60).","ref":"Fledex.Color.Names.RAL.html#h070l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l70c70/1","doc":"Defines the color rgb(235, 147, 31).","ref":"Fledex.Color.Names.RAL.html#h070l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l70c80/1","doc":"Defines the color rgb(240, 143, 0).","ref":"Fledex.Color.Names.RAL.html#h070l70c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l80c10/1","doc":"Defines the color rgb(212, 195, 179).","ref":"Fledex.Color.Names.RAL.html#h070l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l80c20/1","doc":"Defines the color rgb(227, 194, 163).","ref":"Fledex.Color.Names.RAL.html#h070l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l80c30/1","doc":"Defines the color rgb(236, 190, 145).","ref":"Fledex.Color.Names.RAL.html#h070l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l80c40/1","doc":"Defines the color rgb(247, 189, 129).","ref":"Fledex.Color.Names.RAL.html#h070l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l80c50/1","doc":"Defines the color rgb(255, 184, 107).","ref":"Fledex.Color.Names.RAL.html#h070l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l80c60/1","doc":"Defines the color rgb(255, 182, 87).","ref":"Fledex.Color.Names.RAL.html#h070l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l85c05/1","doc":"Defines the color rgb(223, 213, 202).","ref":"Fledex.Color.Names.RAL.html#h070l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l85c10/1","doc":"Defines the color rgb(231, 213, 197).","ref":"Fledex.Color.Names.RAL.html#h070l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l85c20/1","doc":"Defines the color rgb(242, 209, 177).","ref":"Fledex.Color.Names.RAL.html#h070l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l85c30/1","doc":"Defines the color rgb(253, 207, 161).","ref":"Fledex.Color.Names.RAL.html#h070l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l90c05/1","doc":"Defines the color rgb(237, 228, 217).","ref":"Fledex.Color.Names.RAL.html#h070l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l90c10/1","doc":"Defines the color rgb(243, 226, 209).","ref":"Fledex.Color.Names.RAL.html#h070l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l90c20/1","doc":"Defines the color rgb(255, 222, 190).","ref":"Fledex.Color.Names.RAL.html#h070l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h070l93c05/1","doc":"Defines the color rgb(249, 239, 228).","ref":"Fledex.Color.Names.RAL.html#h070l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l40c10/1","doc":"Defines the color rgb(102, 91, 78).","ref":"Fledex.Color.Names.RAL.html#h075l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l40c20/1","doc":"Defines the color rgb(109, 86, 60).","ref":"Fledex.Color.Names.RAL.html#h075l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l40c30/1","doc":"Defines the color rgb(115, 83, 42).","ref":"Fledex.Color.Names.RAL.html#h075l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l40c38/1","doc":"Defines the color rgb(121, 84, 25).","ref":"Fledex.Color.Names.RAL.html#h075l40c38/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l50c10/1","doc":"Defines the color rgb(128, 115, 101).","ref":"Fledex.Color.Names.RAL.html#h075l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l50c20/1","doc":"Defines the color rgb(138, 112, 84).","ref":"Fledex.Color.Names.RAL.html#h075l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l50c30/1","doc":"Defines the color rgb(147, 112, 67).","ref":"Fledex.Color.Names.RAL.html#h075l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l50c40/1","doc":"Defines the color rgb(154, 108, 49).","ref":"Fledex.Color.Names.RAL.html#h075l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l50c50/1","doc":"Defines the color rgb(158, 106, 25).","ref":"Fledex.Color.Names.RAL.html#h075l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l50c58/1","doc":"Defines the color rgb(160, 102, 0).","ref":"Fledex.Color.Names.RAL.html#h075l50c58/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l60c10/1","doc":"Defines the color rgb(157, 142, 127).","ref":"Fledex.Color.Names.RAL.html#h075l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l60c20/1","doc":"Defines the color rgb(166, 139, 110).","ref":"Fledex.Color.Names.RAL.html#h075l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l60c30/1","doc":"Defines the color rgb(174, 137, 93).","ref":"Fledex.Color.Names.RAL.html#h075l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l60c40/1","doc":"Defines the color rgb(182, 136, 77).","ref":"Fledex.Color.Names.RAL.html#h075l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l60c50/1","doc":"Defines the color rgb(187, 132, 52).","ref":"Fledex.Color.Names.RAL.html#h075l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l60c60/1","doc":"Defines the color rgb(193, 129, 22).","ref":"Fledex.Color.Names.RAL.html#h075l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l60c70/1","doc":"Defines the color rgb(200, 127, 0).","ref":"Fledex.Color.Names.RAL.html#h075l60c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l70c10/1","doc":"Defines the color rgb(183, 169, 154).","ref":"Fledex.Color.Names.RAL.html#h075l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l70c20/1","doc":"Defines the color rgb(194, 165, 133).","ref":"Fledex.Color.Names.RAL.html#h075l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l70c30/1","doc":"Defines the color rgb(202, 163, 117).","ref":"Fledex.Color.Names.RAL.html#h075l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l70c40/1","doc":"Defines the color rgb(210, 161, 97).","ref":"Fledex.Color.Names.RAL.html#h075l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l70c50/1","doc":"Defines the color rgb(217, 159, 80).","ref":"Fledex.Color.Names.RAL.html#h075l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l70c60/1","doc":"Defines the color rgb(225, 156, 53).","ref":"Fledex.Color.Names.RAL.html#h075l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l70c70/1","doc":"Defines the color rgb(233, 154, 16).","ref":"Fledex.Color.Names.RAL.html#h075l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l70c80/1","doc":"Defines the color rgb(233, 151, 0).","ref":"Fledex.Color.Names.RAL.html#h075l70c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l80c10/1","doc":"Defines the color rgb(214, 197, 180).","ref":"Fledex.Color.Names.RAL.html#h075l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l80c20/1","doc":"Defines the color rgb(224, 195, 162).","ref":"Fledex.Color.Names.RAL.html#h075l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l80c30/1","doc":"Defines the color rgb(231, 191, 142).","ref":"Fledex.Color.Names.RAL.html#h075l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l80c40/1","doc":"Defines the color rgb(240, 189, 126).","ref":"Fledex.Color.Names.RAL.html#h075l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l80c50/1","doc":"Defines the color rgb(247, 185, 105).","ref":"Fledex.Color.Names.RAL.html#h075l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l80c60/1","doc":"Defines the color rgb(255, 183, 86).","ref":"Fledex.Color.Names.RAL.html#h075l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l85c10/1","doc":"Defines the color rgb(230, 214, 196).","ref":"Fledex.Color.Names.RAL.html#h075l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l85c20/1","doc":"Defines the color rgb(241, 211, 178).","ref":"Fledex.Color.Names.RAL.html#h075l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l85c30/1","doc":"Defines the color rgb(250, 208, 161).","ref":"Fledex.Color.Names.RAL.html#h075l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l85c40/1","doc":"Defines the color rgb(255, 206, 143).","ref":"Fledex.Color.Names.RAL.html#h075l85c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l90c10/1","doc":"Defines the color rgb(246, 228, 208).","ref":"Fledex.Color.Names.RAL.html#h075l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l90c20/1","doc":"Defines the color rgb(253, 222, 189).","ref":"Fledex.Color.Names.RAL.html#h075l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h075l93c05/1","doc":"Defines the color rgb(246, 238, 229).","ref":"Fledex.Color.Names.RAL.html#h075l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l20c05/1","doc":"Defines the color rgb(50, 45, 37).","ref":"Fledex.Color.Names.RAL.html#h080l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l20c10/1","doc":"Defines the color rgb(54, 44, 29).","ref":"Fledex.Color.Names.RAL.html#h080l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l30c05/1","doc":"Defines the color rgb(73, 67, 59).","ref":"Fledex.Color.Names.RAL.html#h080l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l30c10/1","doc":"Defines the color rgb(75, 64, 49).","ref":"Fledex.Color.Names.RAL.html#h080l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l30c20/1","doc":"Defines the color rgb(82, 63, 33).","ref":"Fledex.Color.Names.RAL.html#h080l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l30c26/1","doc":"Defines the color rgb(87, 63, 22).","ref":"Fledex.Color.Names.RAL.html#h080l30c26/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l40c05/1","doc":"Defines the color rgb(99, 93, 84).","ref":"Fledex.Color.Names.RAL.html#h080l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l40c10/1","doc":"Defines the color rgb(102, 91, 77).","ref":"Fledex.Color.Names.RAL.html#h080l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l40c20/1","doc":"Defines the color rgb(108, 87, 56).","ref":"Fledex.Color.Names.RAL.html#h080l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l40c30/1","doc":"Defines the color rgb(114, 87, 40).","ref":"Fledex.Color.Names.RAL.html#h080l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l40c40/1","doc":"Defines the color rgb(122, 86, 14).","ref":"Fledex.Color.Names.RAL.html#h080l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l50c05/1","doc":"Defines the color rgb(123, 117, 108).","ref":"Fledex.Color.Names.RAL.html#h080l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l50c10/1","doc":"Defines the color rgb(128, 116, 101).","ref":"Fledex.Color.Names.RAL.html#h080l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l50c20/1","doc":"Defines the color rgb(135, 114, 84).","ref":"Fledex.Color.Names.RAL.html#h080l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l50c30/1","doc":"Defines the color rgb(141, 112, 64).","ref":"Fledex.Color.Names.RAL.html#h080l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l50c40/1","doc":"Defines the color rgb(146, 110, 46).","ref":"Fledex.Color.Names.RAL.html#h080l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l50c50/1","doc":"Defines the color rgb(152, 110, 25).","ref":"Fledex.Color.Names.RAL.html#h080l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l60c05/1","doc":"Defines the color rgb(150, 144, 135).","ref":"Fledex.Color.Names.RAL.html#h080l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l60c10/1","doc":"Defines the color rgb(153, 141, 124).","ref":"Fledex.Color.Names.RAL.html#h080l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l60c20/1","doc":"Defines the color rgb(163, 140, 107).","ref":"Fledex.Color.Names.RAL.html#h080l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l60c30/1","doc":"Defines the color rgb(170, 138, 88).","ref":"Fledex.Color.Names.RAL.html#h080l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l60c40/1","doc":"Defines the color rgb(174, 136, 75).","ref":"Fledex.Color.Names.RAL.html#h080l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l60c50/1","doc":"Defines the color rgb(181, 135, 53).","ref":"Fledex.Color.Names.RAL.html#h080l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l60c60/1","doc":"Defines the color rgb(187, 134, 16).","ref":"Fledex.Color.Names.RAL.html#h080l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l60c70/1","doc":"Defines the color rgb(190, 132, 0).","ref":"Fledex.Color.Names.RAL.html#h080l60c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c05/1","doc":"Defines the color rgb(176, 170, 161).","ref":"Fledex.Color.Names.RAL.html#h080l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c10/1","doc":"Defines the color rgb(181, 169, 152).","ref":"Fledex.Color.Names.RAL.html#h080l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c20/1","doc":"Defines the color rgb(191, 167, 133).","ref":"Fledex.Color.Names.RAL.html#h080l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c30/1","doc":"Defines the color rgb(197, 165, 116).","ref":"Fledex.Color.Names.RAL.html#h080l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c40/1","doc":"Defines the color rgb(206, 164, 97).","ref":"Fledex.Color.Names.RAL.html#h080l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c50/1","doc":"Defines the color rgb(212, 162, 78).","ref":"Fledex.Color.Names.RAL.html#h080l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c60/1","doc":"Defines the color rgb(218, 161, 53).","ref":"Fledex.Color.Names.RAL.html#h080l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c70/1","doc":"Defines the color rgb(223, 160, 26).","ref":"Fledex.Color.Names.RAL.html#h080l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c80/1","doc":"Defines the color rgb(225, 156, 0).","ref":"Fledex.Color.Names.RAL.html#h080l70c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l70c88/1","doc":"Defines the color rgb(229, 155, 0).","ref":"Fledex.Color.Names.RAL.html#h080l70c88/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c05/1","doc":"Defines the color rgb(205, 199, 189).","ref":"Fledex.Color.Names.RAL.html#h080l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c10/1","doc":"Defines the color rgb(213, 198, 180).","ref":"Fledex.Color.Names.RAL.html#h080l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c20/1","doc":"Defines the color rgb(220, 195, 159).","ref":"Fledex.Color.Names.RAL.html#h080l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c30/1","doc":"Defines the color rgb(227, 192, 141).","ref":"Fledex.Color.Names.RAL.html#h080l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c40/1","doc":"Defines the color rgb(236, 191, 122).","ref":"Fledex.Color.Names.RAL.html#h080l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c50/1","doc":"Defines the color rgb(243, 190, 103).","ref":"Fledex.Color.Names.RAL.html#h080l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c60/1","doc":"Defines the color rgb(249, 188, 79).","ref":"Fledex.Color.Names.RAL.html#h080l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c70/1","doc":"Defines the color rgb(252, 185, 55).","ref":"Fledex.Color.Names.RAL.html#h080l80c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c80/1","doc":"Defines the color rgb(255, 183, 11).","ref":"Fledex.Color.Names.RAL.html#h080l80c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l80c90/1","doc":"Defines the color rgb(255, 183, 0).","ref":"Fledex.Color.Names.RAL.html#h080l80c90/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l85c05/1","doc":"Defines the color rgb(221, 214, 202).","ref":"Fledex.Color.Names.RAL.html#h080l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l85c10/1","doc":"Defines the color rgb(226, 213, 194).","ref":"Fledex.Color.Names.RAL.html#h080l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l85c20/1","doc":"Defines the color rgb(237, 212, 177).","ref":"Fledex.Color.Names.RAL.html#h080l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l85c30/1","doc":"Defines the color rgb(243, 209, 159).","ref":"Fledex.Color.Names.RAL.html#h080l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l85c40/1","doc":"Defines the color rgb(252, 207, 139).","ref":"Fledex.Color.Names.RAL.html#h080l85c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l90c05/1","doc":"Defines the color rgb(238, 230, 217).","ref":"Fledex.Color.Names.RAL.html#h080l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l90c10/1","doc":"Defines the color rgb(240, 225, 205).","ref":"Fledex.Color.Names.RAL.html#h080l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l90c20/1","doc":"Defines the color rgb(247, 223, 186).","ref":"Fledex.Color.Names.RAL.html#h080l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l90c30/1","doc":"Defines the color rgb(255, 222, 169).","ref":"Fledex.Color.Names.RAL.html#h080l90c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h080l93c05/1","doc":"Defines the color rgb(245, 237, 226).","ref":"Fledex.Color.Names.RAL.html#h080l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l40c10/1","doc":"Defines the color rgb(102, 93, 78).","ref":"Fledex.Color.Names.RAL.html#h085l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l40c20/1","doc":"Defines the color rgb(106, 90, 57).","ref":"Fledex.Color.Names.RAL.html#h085l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l40c30/1","doc":"Defines the color rgb(113, 91, 46).","ref":"Fledex.Color.Names.RAL.html#h085l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l50c10/1","doc":"Defines the color rgb(126, 116, 99).","ref":"Fledex.Color.Names.RAL.html#h085l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l50c20/1","doc":"Defines the color rgb(134, 116, 82).","ref":"Fledex.Color.Names.RAL.html#h085l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l50c30/1","doc":"Defines the color rgb(140, 115, 64).","ref":"Fledex.Color.Names.RAL.html#h085l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l50c40/1","doc":"Defines the color rgb(142, 113, 46).","ref":"Fledex.Color.Names.RAL.html#h085l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l50c50/1","doc":"Defines the color rgb(147, 112, 22).","ref":"Fledex.Color.Names.RAL.html#h085l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l60c10/1","doc":"Defines the color rgb(153, 143, 127).","ref":"Fledex.Color.Names.RAL.html#h085l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l60c20/1","doc":"Defines the color rgb(161, 142, 107).","ref":"Fledex.Color.Names.RAL.html#h085l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l60c30/1","doc":"Defines the color rgb(167, 140, 89).","ref":"Fledex.Color.Names.RAL.html#h085l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l60c40/1","doc":"Defines the color rgb(172, 139, 70).","ref":"Fledex.Color.Names.RAL.html#h085l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l60c50/1","doc":"Defines the color rgb(177, 139, 50).","ref":"Fledex.Color.Names.RAL.html#h085l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l60c60/1","doc":"Defines the color rgb(182, 139, 19).","ref":"Fledex.Color.Names.RAL.html#h085l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l70c10/1","doc":"Defines the color rgb(179, 169, 150).","ref":"Fledex.Color.Names.RAL.html#h085l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l70c20/1","doc":"Defines the color rgb(188, 168, 133).","ref":"Fledex.Color.Names.RAL.html#h085l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l70c30/1","doc":"Defines the color rgb(194, 167, 112).","ref":"Fledex.Color.Names.RAL.html#h085l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l70c40/1","doc":"Defines the color rgb(199, 165, 95).","ref":"Fledex.Color.Names.RAL.html#h085l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l70c50/1","doc":"Defines the color rgb(205, 164, 73).","ref":"Fledex.Color.Names.RAL.html#h085l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l70c60/1","doc":"Defines the color rgb(208, 163, 46).","ref":"Fledex.Color.Names.RAL.html#h085l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l70c70/1","doc":"Defines the color rgb(212, 162, 7).","ref":"Fledex.Color.Names.RAL.html#h085l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l70c75/1","doc":"Defines the color rgb(217, 164, 0).","ref":"Fledex.Color.Names.RAL.html#h085l70c75/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c10/1","doc":"Defines the color rgb(208, 197, 177).","ref":"Fledex.Color.Names.RAL.html#h085l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c20/1","doc":"Defines the color rgb(216, 196, 159).","ref":"Fledex.Color.Names.RAL.html#h085l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c30/1","doc":"Defines the color rgb(225, 195, 139).","ref":"Fledex.Color.Names.RAL.html#h085l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c40/1","doc":"Defines the color rgb(229, 194, 121).","ref":"Fledex.Color.Names.RAL.html#h085l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c50/1","doc":"Defines the color rgb(234, 192, 100).","ref":"Fledex.Color.Names.RAL.html#h085l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c60/1","doc":"Defines the color rgb(239, 191, 77).","ref":"Fledex.Color.Names.RAL.html#h085l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c70/1","doc":"Defines the color rgb(243, 189, 50).","ref":"Fledex.Color.Names.RAL.html#h085l80c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c80/1","doc":"Defines the color rgb(245, 187, 0).","ref":"Fledex.Color.Names.RAL.html#h085l80c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l80c85/1","doc":"Defines the color rgb(246, 187, 0).","ref":"Fledex.Color.Names.RAL.html#h085l80c85/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l85c10/1","doc":"Defines the color rgb(223, 212, 191).","ref":"Fledex.Color.Names.RAL.html#h085l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l85c20/1","doc":"Defines the color rgb(232, 211, 175).","ref":"Fledex.Color.Names.RAL.html#h085l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l85c30/1","doc":"Defines the color rgb(240, 210, 157).","ref":"Fledex.Color.Names.RAL.html#h085l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l85c40/1","doc":"Defines the color rgb(247, 210, 140).","ref":"Fledex.Color.Names.RAL.html#h085l85c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l90c10/1","doc":"Defines the color rgb(241, 229, 209).","ref":"Fledex.Color.Names.RAL.html#h085l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l90c20/1","doc":"Defines the color rgb(247, 224, 186).","ref":"Fledex.Color.Names.RAL.html#h085l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l90c30/1","doc":"Defines the color rgb(253, 221, 167).","ref":"Fledex.Color.Names.RAL.html#h085l90c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h085l93c05/1","doc":"Defines the color rgb(244, 239, 228).","ref":"Fledex.Color.Names.RAL.html#h085l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l30c10/1","doc":"Defines the color rgb(75, 68, 51).","ref":"Fledex.Color.Names.RAL.html#h090l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l30c20/1","doc":"Defines the color rgb(81, 68, 33).","ref":"Fledex.Color.Names.RAL.html#h090l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l40c10/1","doc":"Defines the color rgb(101, 94, 78).","ref":"Fledex.Color.Names.RAL.html#h090l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l40c20/1","doc":"Defines the color rgb(105, 92, 57).","ref":"Fledex.Color.Names.RAL.html#h090l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l40c30/1","doc":"Defines the color rgb(110, 94, 44).","ref":"Fledex.Color.Names.RAL.html#h090l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l50c10/1","doc":"Defines the color rgb(124, 118, 102).","ref":"Fledex.Color.Names.RAL.html#h090l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l50c20/1","doc":"Defines the color rgb(129, 117, 83).","ref":"Fledex.Color.Names.RAL.html#h090l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l50c30/1","doc":"Defines the color rgb(136, 118, 63).","ref":"Fledex.Color.Names.RAL.html#h090l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l50c40/1","doc":"Defines the color rgb(139, 118, 44).","ref":"Fledex.Color.Names.RAL.html#h090l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l60c10/1","doc":"Defines the color rgb(150, 143, 127).","ref":"Fledex.Color.Names.RAL.html#h090l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l60c20/1","doc":"Defines the color rgb(158, 143, 107).","ref":"Fledex.Color.Names.RAL.html#h090l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l60c30/1","doc":"Defines the color rgb(162, 143, 92).","ref":"Fledex.Color.Names.RAL.html#h090l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l60c40/1","doc":"Defines the color rgb(165, 141, 69).","ref":"Fledex.Color.Names.RAL.html#h090l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l60c50/1","doc":"Defines the color rgb(165, 139, 44).","ref":"Fledex.Color.Names.RAL.html#h090l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l60c60/1","doc":"Defines the color rgb(173, 143, 15).","ref":"Fledex.Color.Names.RAL.html#h090l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l70c10/1","doc":"Defines the color rgb(178, 170, 152).","ref":"Fledex.Color.Names.RAL.html#h090l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l70c20/1","doc":"Defines the color rgb(184, 169, 131).","ref":"Fledex.Color.Names.RAL.html#h090l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l70c30/1","doc":"Defines the color rgb(188, 168, 114).","ref":"Fledex.Color.Names.RAL.html#h090l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l70c40/1","doc":"Defines the color rgb(196, 170, 94).","ref":"Fledex.Color.Names.RAL.html#h090l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l70c50/1","doc":"Defines the color rgb(199, 169, 74).","ref":"Fledex.Color.Names.RAL.html#h090l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l70c60/1","doc":"Defines the color rgb(202, 168, 47).","ref":"Fledex.Color.Names.RAL.html#h090l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l70c70/1","doc":"Defines the color rgb(204, 168, 0).","ref":"Fledex.Color.Names.RAL.html#h090l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l70c80/1","doc":"Defines the color rgb(208, 167, 0).","ref":"Fledex.Color.Names.RAL.html#h090l70c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c10/1","doc":"Defines the color rgb(207, 197, 176).","ref":"Fledex.Color.Names.RAL.html#h090l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c20/1","doc":"Defines the color rgb(212, 196, 158).","ref":"Fledex.Color.Names.RAL.html#h090l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c30/1","doc":"Defines the color rgb(220, 198, 142).","ref":"Fledex.Color.Names.RAL.html#h090l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c40/1","doc":"Defines the color rgb(225, 199, 125).","ref":"Fledex.Color.Names.RAL.html#h090l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c50/1","doc":"Defines the color rgb(230, 197, 98).","ref":"Fledex.Color.Names.RAL.html#h090l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c60/1","doc":"Defines the color rgb(232, 194, 71).","ref":"Fledex.Color.Names.RAL.html#h090l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c70/1","doc":"Defines the color rgb(237, 197, 55).","ref":"Fledex.Color.Names.RAL.html#h090l80c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c80/1","doc":"Defines the color rgb(236, 193, 0).","ref":"Fledex.Color.Names.RAL.html#h090l80c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l80c90/1","doc":"Defines the color rgb(242, 194, 0).","ref":"Fledex.Color.Names.RAL.html#h090l80c90/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l85c05/1","doc":"Defines the color rgb(219, 214, 203).","ref":"Fledex.Color.Names.RAL.html#h090l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l85c10/1","doc":"Defines the color rgb(225, 215, 194).","ref":"Fledex.Color.Names.RAL.html#h090l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l85c20/1","doc":"Defines the color rgb(231, 214, 175).","ref":"Fledex.Color.Names.RAL.html#h090l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l85c30/1","doc":"Defines the color rgb(237, 214, 157).","ref":"Fledex.Color.Names.RAL.html#h090l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l85c40/1","doc":"Defines the color rgb(241, 212, 138).","ref":"Fledex.Color.Names.RAL.html#h090l85c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l85c50/1","doc":"Defines the color rgb(246, 213, 118).","ref":"Fledex.Color.Names.RAL.html#h090l85c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l90c05/1","doc":"Defines the color rgb(234, 228, 216).","ref":"Fledex.Color.Names.RAL.html#h090l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l90c10/1","doc":"Defines the color rgb(236, 228, 208).","ref":"Fledex.Color.Names.RAL.html#h090l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l90c20/1","doc":"Defines the color rgb(244, 227, 187).","ref":"Fledex.Color.Names.RAL.html#h090l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l90c30/1","doc":"Defines the color rgb(248, 225, 168).","ref":"Fledex.Color.Names.RAL.html#h090l90c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l90c40/1","doc":"Defines the color rgb(254, 225, 147).","ref":"Fledex.Color.Names.RAL.html#h090l90c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l90c50/1","doc":"Defines the color rgb(255, 222, 126).","ref":"Fledex.Color.Names.RAL.html#h090l90c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l90c60/1","doc":"Defines the color rgb(255, 219, 103).","ref":"Fledex.Color.Names.RAL.html#h090l90c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h090l93c05/1","doc":"Defines the color rgb(242, 238, 226).","ref":"Fledex.Color.Names.RAL.html#h090l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l40c10/1","doc":"Defines the color rgb(99, 93, 76).","ref":"Fledex.Color.Names.RAL.html#h095l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l40c20/1","doc":"Defines the color rgb(102, 91, 56).","ref":"Fledex.Color.Names.RAL.html#h095l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l40c30/1","doc":"Defines the color rgb(104, 92, 39).","ref":"Fledex.Color.Names.RAL.html#h095l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l50c10/1","doc":"Defines the color rgb(122, 117, 100).","ref":"Fledex.Color.Names.RAL.html#h095l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l50c20/1","doc":"Defines the color rgb(128, 117, 83).","ref":"Fledex.Color.Names.RAL.html#h095l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l50c30/1","doc":"Defines the color rgb(132, 118, 64).","ref":"Fledex.Color.Names.RAL.html#h095l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l50c40/1","doc":"Defines the color rgb(135, 118, 43).","ref":"Fledex.Color.Names.RAL.html#h095l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l50c50/1","doc":"Defines the color rgb(137, 119, 20).","ref":"Fledex.Color.Names.RAL.html#h095l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l60c10/1","doc":"Defines the color rgb(150, 144, 126).","ref":"Fledex.Color.Names.RAL.html#h095l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l60c20/1","doc":"Defines the color rgb(154, 143, 108).","ref":"Fledex.Color.Names.RAL.html#h095l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l60c30/1","doc":"Defines the color rgb(158, 143, 87).","ref":"Fledex.Color.Names.RAL.html#h095l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l60c40/1","doc":"Defines the color rgb(161, 143, 68).","ref":"Fledex.Color.Names.RAL.html#h095l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l60c50/1","doc":"Defines the color rgb(163, 145, 47).","ref":"Fledex.Color.Names.RAL.html#h095l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l60c60/1","doc":"Defines the color rgb(161, 141, 13).","ref":"Fledex.Color.Names.RAL.html#h095l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l60c70/1","doc":"Defines the color rgb(163, 142, 0).","ref":"Fledex.Color.Names.RAL.html#h095l60c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l70c10/1","doc":"Defines the color rgb(178, 171, 152).","ref":"Fledex.Color.Names.RAL.html#h095l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l70c20/1","doc":"Defines the color rgb(183, 172, 135).","ref":"Fledex.Color.Names.RAL.html#h095l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l70c30/1","doc":"Defines the color rgb(187, 171, 117).","ref":"Fledex.Color.Names.RAL.html#h095l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l70c40/1","doc":"Defines the color rgb(189, 170, 93).","ref":"Fledex.Color.Names.RAL.html#h095l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l70c50/1","doc":"Defines the color rgb(190, 170, 74).","ref":"Fledex.Color.Names.RAL.html#h095l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l70c60/1","doc":"Defines the color rgb(190, 169, 50).","ref":"Fledex.Color.Names.RAL.html#h095l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l70c70/1","doc":"Defines the color rgb(195, 170, 0).","ref":"Fledex.Color.Names.RAL.html#h095l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l80c10/1","doc":"Defines the color rgb(205, 199, 180).","ref":"Fledex.Color.Names.RAL.html#h095l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l80c20/1","doc":"Defines the color rgb(211, 199, 161).","ref":"Fledex.Color.Names.RAL.html#h095l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l80c30/1","doc":"Defines the color rgb(218, 201, 142).","ref":"Fledex.Color.Names.RAL.html#h095l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l80c40/1","doc":"Defines the color rgb(221, 200, 122).","ref":"Fledex.Color.Names.RAL.html#h095l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l80c50/1","doc":"Defines the color rgb(221, 199, 101).","ref":"Fledex.Color.Names.RAL.html#h095l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l80c60/1","doc":"Defines the color rgb(219, 196, 77).","ref":"Fledex.Color.Names.RAL.html#h095l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l80c70/1","doc":"Defines the color rgb(223, 198, 51).","ref":"Fledex.Color.Names.RAL.html#h095l80c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l80c80/1","doc":"Defines the color rgb(218, 193, 0).","ref":"Fledex.Color.Names.RAL.html#h095l80c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l85c10/1","doc":"Defines the color rgb(222, 216, 196).","ref":"Fledex.Color.Names.RAL.html#h095l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l85c20/1","doc":"Defines the color rgb(229, 217, 180).","ref":"Fledex.Color.Names.RAL.html#h095l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l85c30/1","doc":"Defines the color rgb(233, 215, 158).","ref":"Fledex.Color.Names.RAL.html#h095l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l85c40/1","doc":"Defines the color rgb(238, 216, 139).","ref":"Fledex.Color.Names.RAL.html#h095l85c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l85c50/1","doc":"Defines the color rgb(239, 214, 120).","ref":"Fledex.Color.Names.RAL.html#h095l85c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l90c10/1","doc":"Defines the color rgb(236, 228, 206).","ref":"Fledex.Color.Names.RAL.html#h095l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l90c20/1","doc":"Defines the color rgb(241, 227, 188).","ref":"Fledex.Color.Names.RAL.html#h095l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l90c30/1","doc":"Defines the color rgb(246, 226, 167).","ref":"Fledex.Color.Names.RAL.html#h095l90c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l90c40/1","doc":"Defines the color rgb(247, 225, 144).","ref":"Fledex.Color.Names.RAL.html#h095l90c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l90c50/1","doc":"Defines the color rgb(254, 227, 127).","ref":"Fledex.Color.Names.RAL.html#h095l90c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l90c59/1","doc":"Defines the color rgb(255, 227, 109).","ref":"Fledex.Color.Names.RAL.html#h095l90c59/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h095l93c05/1","doc":"Defines the color rgb(240, 238, 227).","ref":"Fledex.Color.Names.RAL.html#h095l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l20c05/1","doc":"Defines the color rgb(48, 47, 39).","ref":"Fledex.Color.Names.RAL.html#h100l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l30c05/1","doc":"Defines the color rgb(69, 67, 59).","ref":"Fledex.Color.Names.RAL.html#h100l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l30c10/1","doc":"Defines the color rgb(71, 66, 48).","ref":"Fledex.Color.Names.RAL.html#h100l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l30c20/1","doc":"Defines the color rgb(76, 70, 35).","ref":"Fledex.Color.Names.RAL.html#h100l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l40c05/1","doc":"Defines the color rgb(93, 91, 83).","ref":"Fledex.Color.Names.RAL.html#h100l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l40c10/1","doc":"Defines the color rgb(97, 93, 76).","ref":"Fledex.Color.Names.RAL.html#h100l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l40c20/1","doc":"Defines the color rgb(99, 93, 59).","ref":"Fledex.Color.Names.RAL.html#h100l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l40c30/1","doc":"Defines the color rgb(102, 93, 37).","ref":"Fledex.Color.Names.RAL.html#h100l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l40c40/1","doc":"Defines the color rgb(102, 94, 13).","ref":"Fledex.Color.Names.RAL.html#h100l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l50c05/1","doc":"Defines the color rgb(120, 118, 109).","ref":"Fledex.Color.Names.RAL.html#h100l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l50c10/1","doc":"Defines the color rgb(122, 117, 98).","ref":"Fledex.Color.Names.RAL.html#h100l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l50c20/1","doc":"Defines the color rgb(125, 120, 83).","ref":"Fledex.Color.Names.RAL.html#h100l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l50c30/1","doc":"Defines the color rgb(125, 118, 64).","ref":"Fledex.Color.Names.RAL.html#h100l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l50c40/1","doc":"Defines the color rgb(129, 118, 43).","ref":"Fledex.Color.Names.RAL.html#h100l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l50c50/1","doc":"Defines the color rgb(127, 119, 17).","ref":"Fledex.Color.Names.RAL.html#h100l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l60c05/1","doc":"Defines the color rgb(147, 144, 135).","ref":"Fledex.Color.Names.RAL.html#h100l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l60c10/1","doc":"Defines the color rgb(146, 142, 124).","ref":"Fledex.Color.Names.RAL.html#h100l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l60c20/1","doc":"Defines the color rgb(152, 145, 108).","ref":"Fledex.Color.Names.RAL.html#h100l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l60c30/1","doc":"Defines the color rgb(152, 144, 87).","ref":"Fledex.Color.Names.RAL.html#h100l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l60c40/1","doc":"Defines the color rgb(155, 146, 70).","ref":"Fledex.Color.Names.RAL.html#h100l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l60c50/1","doc":"Defines the color rgb(156, 147, 47).","ref":"Fledex.Color.Names.RAL.html#h100l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l60c60/1","doc":"Defines the color rgb(152, 142, 1).","ref":"Fledex.Color.Names.RAL.html#h100l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l70c05/1","doc":"Defines the color rgb(174, 173, 163).","ref":"Fledex.Color.Names.RAL.html#h100l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l70c10/1","doc":"Defines the color rgb(176, 172, 152).","ref":"Fledex.Color.Names.RAL.html#h100l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l70c20/1","doc":"Defines the color rgb(179, 172, 133).","ref":"Fledex.Color.Names.RAL.html#h100l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l70c30/1","doc":"Defines the color rgb(180, 172, 113).","ref":"Fledex.Color.Names.RAL.html#h100l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l70c40/1","doc":"Defines the color rgb(184, 174, 96).","ref":"Fledex.Color.Names.RAL.html#h100l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l70c50/1","doc":"Defines the color rgb(182, 172, 75).","ref":"Fledex.Color.Names.RAL.html#h100l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l70c60/1","doc":"Defines the color rgb(181, 172, 49).","ref":"Fledex.Color.Names.RAL.html#h100l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c05/1","doc":"Defines the color rgb(200, 199, 188).","ref":"Fledex.Color.Names.RAL.html#h100l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c10/1","doc":"Defines the color rgb(204, 199, 177).","ref":"Fledex.Color.Names.RAL.html#h100l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c20/1","doc":"Defines the color rgb(210, 202, 161).","ref":"Fledex.Color.Names.RAL.html#h100l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c30/1","doc":"Defines the color rgb(210, 200, 140).","ref":"Fledex.Color.Names.RAL.html#h100l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c40/1","doc":"Defines the color rgb(212, 201, 120).","ref":"Fledex.Color.Names.RAL.html#h100l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c50/1","doc":"Defines the color rgb(212, 201, 100).","ref":"Fledex.Color.Names.RAL.html#h100l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c60/1","doc":"Defines the color rgb(216, 203, 75).","ref":"Fledex.Color.Names.RAL.html#h100l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c70/1","doc":"Defines the color rgb(216, 203, 50).","ref":"Fledex.Color.Names.RAL.html#h100l80c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l80c80/1","doc":"Defines the color rgb(212, 204, 0).","ref":"Fledex.Color.Names.RAL.html#h100l80c80/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l85c05/1","doc":"Defines the color rgb(219, 217, 205).","ref":"Fledex.Color.Names.RAL.html#h100l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l85c10/1","doc":"Defines the color rgb(221, 216, 194).","ref":"Fledex.Color.Names.RAL.html#h100l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l85c20/1","doc":"Defines the color rgb(224, 216, 176).","ref":"Fledex.Color.Names.RAL.html#h100l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l85c30/1","doc":"Defines the color rgb(228, 217, 159).","ref":"Fledex.Color.Names.RAL.html#h100l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l90c05/1","doc":"Defines the color rgb(232, 229, 216).","ref":"Fledex.Color.Names.RAL.html#h100l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l90c10/1","doc":"Defines the color rgb(234, 229, 207).","ref":"Fledex.Color.Names.RAL.html#h100l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l90c20/1","doc":"Defines the color rgb(239, 229, 187).","ref":"Fledex.Color.Names.RAL.html#h100l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l90c30/1","doc":"Defines the color rgb(239, 228, 165).","ref":"Fledex.Color.Names.RAL.html#h100l90c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l90c40/1","doc":"Defines the color rgb(243, 230, 146).","ref":"Fledex.Color.Names.RAL.html#h100l90c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l90c50/1","doc":"Defines the color rgb(242, 228, 125).","ref":"Fledex.Color.Names.RAL.html#h100l90c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h100l93c05/1","doc":"Defines the color rgb(241, 239, 228).","ref":"Fledex.Color.Names.RAL.html#h100l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l20c10/1","doc":"Defines the color rgb(47, 46, 31).","ref":"Fledex.Color.Names.RAL.html#h110l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l30c10/1","doc":"Defines the color rgb(69, 70, 54).","ref":"Fledex.Color.Names.RAL.html#h110l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l30c20/1","doc":"Defines the color rgb(70, 72, 38).","ref":"Fledex.Color.Names.RAL.html#h110l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l40c10/1","doc":"Defines the color rgb(94, 95, 77).","ref":"Fledex.Color.Names.RAL.html#h110l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l40c20/1","doc":"Defines the color rgb(92, 93, 57).","ref":"Fledex.Color.Names.RAL.html#h110l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l40c30/1","doc":"Defines the color rgb(94, 96, 42).","ref":"Fledex.Color.Names.RAL.html#h110l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l40c40/1","doc":"Defines the color rgb(92, 97, 22).","ref":"Fledex.Color.Names.RAL.html#h110l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l50c10/1","doc":"Defines the color rgb(118, 119, 100).","ref":"Fledex.Color.Names.RAL.html#h110l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l50c20/1","doc":"Defines the color rgb(118, 120, 83).","ref":"Fledex.Color.Names.RAL.html#h110l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l50c30/1","doc":"Defines the color rgb(119, 122, 68).","ref":"Fledex.Color.Names.RAL.html#h110l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l50c40/1","doc":"Defines the color rgb(116, 122, 44).","ref":"Fledex.Color.Names.RAL.html#h110l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l50c50/1","doc":"Defines the color rgb(113, 121, 16).","ref":"Fledex.Color.Names.RAL.html#h110l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l50c55/1","doc":"Defines the color rgb(113, 124, 0).","ref":"Fledex.Color.Names.RAL.html#h110l50c55/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l60c10/1","doc":"Defines the color rgb(144, 145, 126).","ref":"Fledex.Color.Names.RAL.html#h110l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l60c20/1","doc":"Defines the color rgb(142, 145, 109).","ref":"Fledex.Color.Names.RAL.html#h110l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l60c30/1","doc":"Defines the color rgb(145, 149, 95).","ref":"Fledex.Color.Names.RAL.html#h110l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l60c40/1","doc":"Defines the color rgb(142, 149, 73).","ref":"Fledex.Color.Names.RAL.html#h110l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l60c50/1","doc":"Defines the color rgb(140, 150, 50).","ref":"Fledex.Color.Names.RAL.html#h110l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l60c60/1","doc":"Defines the color rgb(139, 153, 22).","ref":"Fledex.Color.Names.RAL.html#h110l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l60c65/1","doc":"Defines the color rgb(140, 153, 0).","ref":"Fledex.Color.Names.RAL.html#h110l60c65/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l70c10/1","doc":"Defines the color rgb(172, 173, 152).","ref":"Fledex.Color.Names.RAL.html#h110l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l70c20/1","doc":"Defines the color rgb(171, 174, 134).","ref":"Fledex.Color.Names.RAL.html#h110l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l70c30/1","doc":"Defines the color rgb(169, 173, 116).","ref":"Fledex.Color.Names.RAL.html#h110l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l70c40/1","doc":"Defines the color rgb(169, 176, 98).","ref":"Fledex.Color.Names.RAL.html#h110l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l70c50/1","doc":"Defines the color rgb(170, 179, 80).","ref":"Fledex.Color.Names.RAL.html#h110l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l70c60/1","doc":"Defines the color rgb(166, 178, 55).","ref":"Fledex.Color.Names.RAL.html#h110l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l70c70/1","doc":"Defines the color rgb(158, 177, 0).","ref":"Fledex.Color.Names.RAL.html#h110l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l70c77/1","doc":"Defines the color rgb(157, 175, 0).","ref":"Fledex.Color.Names.RAL.html#h110l70c77/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l80c10/1","doc":"Defines the color rgb(197, 198, 179).","ref":"Fledex.Color.Names.RAL.html#h110l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l80c20/1","doc":"Defines the color rgb(201, 202, 161).","ref":"Fledex.Color.Names.RAL.html#h110l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l80c30/1","doc":"Defines the color rgb(200, 203, 142).","ref":"Fledex.Color.Names.RAL.html#h110l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l80c40/1","doc":"Defines the color rgb(198, 205, 125).","ref":"Fledex.Color.Names.RAL.html#h110l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l80c50/1","doc":"Defines the color rgb(199, 207, 104).","ref":"Fledex.Color.Names.RAL.html#h110l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l80c60/1","doc":"Defines the color rgb(196, 208, 86).","ref":"Fledex.Color.Names.RAL.html#h110l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l80c70/1","doc":"Defines the color rgb(192, 208, 54).","ref":"Fledex.Color.Names.RAL.html#h110l80c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l85c10/1","doc":"Defines the color rgb(215, 216, 195).","ref":"Fledex.Color.Names.RAL.html#h110l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l85c20/1","doc":"Defines the color rgb(217, 217, 177).","ref":"Fledex.Color.Names.RAL.html#h110l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l85c30/1","doc":"Defines the color rgb(218, 219, 160).","ref":"Fledex.Color.Names.RAL.html#h110l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l85c40/1","doc":"Defines the color rgb(216, 219, 139).","ref":"Fledex.Color.Names.RAL.html#h110l85c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l85c50/1","doc":"Defines the color rgb(214, 219, 118).","ref":"Fledex.Color.Names.RAL.html#h110l85c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l90c05/1","doc":"Defines the color rgb(228, 227, 216).","ref":"Fledex.Color.Names.RAL.html#h110l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l90c10/1","doc":"Defines the color rgb(230, 230, 208).","ref":"Fledex.Color.Names.RAL.html#h110l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l90c20/1","doc":"Defines the color rgb(230, 230, 188).","ref":"Fledex.Color.Names.RAL.html#h110l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l90c30/1","doc":"Defines the color rgb(229, 231, 167).","ref":"Fledex.Color.Names.RAL.html#h110l90c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l90c40/1","doc":"Defines the color rgb(229, 232, 150).","ref":"Fledex.Color.Names.RAL.html#h110l90c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l93c05/1","doc":"Defines the color rgb(238, 238, 227).","ref":"Fledex.Color.Names.RAL.html#h110l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h110l96c02/1","doc":"Defines the color rgb(246, 247, 241).","ref":"Fledex.Color.Names.RAL.html#h110l96c02/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l30c05/1","doc":"Defines the color rgb(65, 67, 58).","ref":"Fledex.Color.Names.RAL.html#h120l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l30c10/1","doc":"Defines the color rgb(65, 70, 52).","ref":"Fledex.Color.Names.RAL.html#h120l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l30c20/1","doc":"Defines the color rgb(62, 72, 38).","ref":"Fledex.Color.Names.RAL.html#h120l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l40c05/1","doc":"Defines the color rgb(90, 92, 83).","ref":"Fledex.Color.Names.RAL.html#h120l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l40c10/1","doc":"Defines the color rgb(89, 94, 76).","ref":"Fledex.Color.Names.RAL.html#h120l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l40c20/1","doc":"Defines the color rgb(86, 96, 61).","ref":"Fledex.Color.Names.RAL.html#h120l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l40c30/1","doc":"Defines the color rgb(84, 98, 46).","ref":"Fledex.Color.Names.RAL.html#h120l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l40c40/1","doc":"Defines the color rgb(78, 99, 20).","ref":"Fledex.Color.Names.RAL.html#h120l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l50c05/1","doc":"Defines the color rgb(117, 118, 108).","ref":"Fledex.Color.Names.RAL.html#h120l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l50c10/1","doc":"Defines the color rgb(115, 120, 102).","ref":"Fledex.Color.Names.RAL.html#h120l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l50c20/1","doc":"Defines the color rgb(113, 123, 86).","ref":"Fledex.Color.Names.RAL.html#h120l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l50c30/1","doc":"Defines the color rgb(110, 124, 69).","ref":"Fledex.Color.Names.RAL.html#h120l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l50c40/1","doc":"Defines the color rgb(105, 125, 54).","ref":"Fledex.Color.Names.RAL.html#h120l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l50c50/1","doc":"Defines the color rgb(99, 126, 29).","ref":"Fledex.Color.Names.RAL.html#h120l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l60c05/1","doc":"Defines the color rgb(146, 148, 137).","ref":"Fledex.Color.Names.RAL.html#h120l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l60c10/1","doc":"Defines the color rgb(140, 145, 128).","ref":"Fledex.Color.Names.RAL.html#h120l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l60c20/1","doc":"Defines the color rgb(138, 148, 111).","ref":"Fledex.Color.Names.RAL.html#h120l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l60c30/1","doc":"Defines the color rgb(135, 152, 96).","ref":"Fledex.Color.Names.RAL.html#h120l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l60c40/1","doc":"Defines the color rgb(130, 153, 76).","ref":"Fledex.Color.Names.RAL.html#h120l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l60c50/1","doc":"Defines the color rgb(126, 155, 57).","ref":"Fledex.Color.Names.RAL.html#h120l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l60c60/1","doc":"Defines the color rgb(119, 154, 32).","ref":"Fledex.Color.Names.RAL.html#h120l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l60c63/1","doc":"Defines the color rgb(118, 156, 24).","ref":"Fledex.Color.Names.RAL.html#h120l60c63/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c05/1","doc":"Defines the color rgb(170, 172, 162).","ref":"Fledex.Color.Names.RAL.html#h120l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c10/1","doc":"Defines the color rgb(169, 173, 153).","ref":"Fledex.Color.Names.RAL.html#h120l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c20/1","doc":"Defines the color rgb(165, 175, 137).","ref":"Fledex.Color.Names.RAL.html#h120l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c30/1","doc":"Defines the color rgb(162, 179, 122).","ref":"Fledex.Color.Names.RAL.html#h120l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c40/1","doc":"Defines the color rgb(157, 181, 103).","ref":"Fledex.Color.Names.RAL.html#h120l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c50/1","doc":"Defines the color rgb(152, 182, 82).","ref":"Fledex.Color.Names.RAL.html#h120l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c60/1","doc":"Defines the color rgb(145, 179, 60).","ref":"Fledex.Color.Names.RAL.html#h120l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c70/1","doc":"Defines the color rgb(142, 184, 38).","ref":"Fledex.Color.Names.RAL.html#h120l70c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l70c75/1","doc":"Defines the color rgb(136, 180, 7).","ref":"Fledex.Color.Names.RAL.html#h120l70c75/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l80c05/1","doc":"Defines the color rgb(198, 200, 190).","ref":"Fledex.Color.Names.RAL.html#h120l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l80c10/1","doc":"Defines the color rgb(195, 200, 179).","ref":"Fledex.Color.Names.RAL.html#h120l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l80c20/1","doc":"Defines the color rgb(194, 205, 165).","ref":"Fledex.Color.Names.RAL.html#h120l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l80c30/1","doc":"Defines the color rgb(188, 205, 145).","ref":"Fledex.Color.Names.RAL.html#h120l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l80c40/1","doc":"Defines the color rgb(185, 208, 128).","ref":"Fledex.Color.Names.RAL.html#h120l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l80c50/1","doc":"Defines the color rgb(179, 210, 109).","ref":"Fledex.Color.Names.RAL.html#h120l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l80c60/1","doc":"Defines the color rgb(176, 212, 93).","ref":"Fledex.Color.Names.RAL.html#h120l80c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l85c05/1","doc":"Defines the color rgb(214, 216, 205).","ref":"Fledex.Color.Names.RAL.html#h120l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l85c10/1","doc":"Defines the color rgb(211, 217, 197).","ref":"Fledex.Color.Names.RAL.html#h120l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l85c20/1","doc":"Defines the color rgb(210, 219, 180).","ref":"Fledex.Color.Names.RAL.html#h120l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l85c30/1","doc":"Defines the color rgb(206, 220, 160).","ref":"Fledex.Color.Names.RAL.html#h120l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l90c05/1","doc":"Defines the color rgb(225, 227, 215).","ref":"Fledex.Color.Names.RAL.html#h120l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l90c10/1","doc":"Defines the color rgb(227, 231, 209).","ref":"Fledex.Color.Names.RAL.html#h120l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l90c20/1","doc":"Defines the color rgb(222, 232, 190).","ref":"Fledex.Color.Names.RAL.html#h120l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l90c30/1","doc":"Defines the color rgb(217, 235, 172).","ref":"Fledex.Color.Names.RAL.html#h120l90c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h120l93c05/1","doc":"Defines the color rgb(236, 239, 227).","ref":"Fledex.Color.Names.RAL.html#h120l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l30c10/1","doc":"Defines the color rgb(63, 70, 53).","ref":"Fledex.Color.Names.RAL.html#h130l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l30c20/1","doc":"Defines the color rgb(57, 72, 39).","ref":"Fledex.Color.Names.RAL.html#h130l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l40c10/1","doc":"Defines the color rgb(89, 96, 79).","ref":"Fledex.Color.Names.RAL.html#h130l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l40c20/1","doc":"Defines the color rgb(79, 96, 62).","ref":"Fledex.Color.Names.RAL.html#h130l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l40c30/1","doc":"Defines the color rgb(75, 99, 49).","ref":"Fledex.Color.Names.RAL.html#h130l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l50c10/1","doc":"Defines the color rgb(111, 119, 102).","ref":"Fledex.Color.Names.RAL.html#h130l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l50c20/1","doc":"Defines the color rgb(106, 123, 89).","ref":"Fledex.Color.Names.RAL.html#h130l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l50c30/1","doc":"Defines the color rgb(97, 125, 72).","ref":"Fledex.Color.Names.RAL.html#h130l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l50c40/1","doc":"Defines the color rgb(89, 128, 57).","ref":"Fledex.Color.Names.RAL.html#h130l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l50c50/1","doc":"Defines the color rgb(79, 129, 41).","ref":"Fledex.Color.Names.RAL.html#h130l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l60c10/1","doc":"Defines the color rgb(138, 147, 129).","ref":"Fledex.Color.Names.RAL.html#h130l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l60c20/1","doc":"Defines the color rgb(131, 149, 115).","ref":"Fledex.Color.Names.RAL.html#h130l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l60c30/1","doc":"Defines the color rgb(124, 152, 101).","ref":"Fledex.Color.Names.RAL.html#h130l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l60c40/1","doc":"Defines the color rgb(116, 154, 84).","ref":"Fledex.Color.Names.RAL.html#h130l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l60c50/1","doc":"Defines the color rgb(107, 156, 66).","ref":"Fledex.Color.Names.RAL.html#h130l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l60c60/1","doc":"Defines the color rgb(96, 158, 47).","ref":"Fledex.Color.Names.RAL.html#h130l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l70c10/1","doc":"Defines the color rgb(165, 175, 157).","ref":"Fledex.Color.Names.RAL.html#h130l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l70c20/1","doc":"Defines the color rgb(160, 178, 142).","ref":"Fledex.Color.Names.RAL.html#h130l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l70c30/1","doc":"Defines the color rgb(150, 180, 126).","ref":"Fledex.Color.Names.RAL.html#h130l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l70c40/1","doc":"Defines the color rgb(143, 182, 109).","ref":"Fledex.Color.Names.RAL.html#h130l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l70c50/1","doc":"Defines the color rgb(135, 185, 96).","ref":"Fledex.Color.Names.RAL.html#h130l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l70c60/1","doc":"Defines the color rgb(126, 186, 77).","ref":"Fledex.Color.Names.RAL.html#h130l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l80c10/1","doc":"Defines the color rgb(193, 202, 183).","ref":"Fledex.Color.Names.RAL.html#h130l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l80c20/1","doc":"Defines the color rgb(186, 204, 168).","ref":"Fledex.Color.Names.RAL.html#h130l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l80c30/1","doc":"Defines the color rgb(179, 207, 153).","ref":"Fledex.Color.Names.RAL.html#h130l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l80c40/1","doc":"Defines the color rgb(172, 211, 139).","ref":"Fledex.Color.Names.RAL.html#h130l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l80c50/1","doc":"Defines the color rgb(164, 213, 121).","ref":"Fledex.Color.Names.RAL.html#h130l80c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l85c05/1","doc":"Defines the color rgb(211, 217, 206).","ref":"Fledex.Color.Names.RAL.html#h130l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l85c10/1","doc":"Defines the color rgb(209, 219, 199).","ref":"Fledex.Color.Names.RAL.html#h130l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l85c20/1","doc":"Defines the color rgb(203, 220, 183).","ref":"Fledex.Color.Names.RAL.html#h130l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l85c30/1","doc":"Defines the color rgb(200, 224, 171).","ref":"Fledex.Color.Names.RAL.html#h130l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l90c05/1","doc":"Defines the color rgb(223, 227, 216).","ref":"Fledex.Color.Names.RAL.html#h130l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l90c10/1","doc":"Defines the color rgb(224, 233, 211).","ref":"Fledex.Color.Names.RAL.html#h130l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l90c20/1","doc":"Defines the color rgb(214, 233, 195).","ref":"Fledex.Color.Names.RAL.html#h130l90c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h130l93c05/1","doc":"Defines the color rgb(235, 240, 228).","ref":"Fledex.Color.Names.RAL.html#h130l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l20c05/1","doc":"Defines the color rgb(40, 46, 39).","ref":"Fledex.Color.Names.RAL.html#h140l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l20c10/1","doc":"Defines the color rgb(40, 49, 35).","ref":"Fledex.Color.Names.RAL.html#h140l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l20c20/1","doc":"Defines the color rgb(37, 54, 30).","ref":"Fledex.Color.Names.RAL.html#h140l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l30c05/1","doc":"Defines the color rgb(66, 71, 64).","ref":"Fledex.Color.Names.RAL.html#h140l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l30c10/1","doc":"Defines the color rgb(62, 73, 57).","ref":"Fledex.Color.Names.RAL.html#h140l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l30c20/1","doc":"Defines the color rgb(54, 76, 46).","ref":"Fledex.Color.Names.RAL.html#h140l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l30c30/1","doc":"Defines the color rgb(42, 79, 33).","ref":"Fledex.Color.Names.RAL.html#h140l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l30c40/1","doc":"Defines the color rgb(27, 79, 28).","ref":"Fledex.Color.Names.RAL.html#h140l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l40c05/1","doc":"Defines the color rgb(89, 95, 87).","ref":"Fledex.Color.Names.RAL.html#h140l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l40c10/1","doc":"Defines the color rgb(85, 97, 81).","ref":"Fledex.Color.Names.RAL.html#h140l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l40c20/1","doc":"Defines the color rgb(72, 98, 65).","ref":"Fledex.Color.Names.RAL.html#h140l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l40c30/1","doc":"Defines the color rgb(64, 102, 53).","ref":"Fledex.Color.Names.RAL.html#h140l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l40c40/1","doc":"Defines the color rgb(50, 106, 43).","ref":"Fledex.Color.Names.RAL.html#h140l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l40c50/1","doc":"Defines the color rgb(41, 109, 35).","ref":"Fledex.Color.Names.RAL.html#h140l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l50c05/1","doc":"Defines the color rgb(113, 119, 110).","ref":"Fledex.Color.Names.RAL.html#h140l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l50c10/1","doc":"Defines the color rgb(109, 121, 105).","ref":"Fledex.Color.Names.RAL.html#h140l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l50c20/1","doc":"Defines the color rgb(99, 124, 91).","ref":"Fledex.Color.Names.RAL.html#h140l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l50c30/1","doc":"Defines the color rgb(90, 128, 79).","ref":"Fledex.Color.Names.RAL.html#h140l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l50c40/1","doc":"Defines the color rgb(74, 129, 64).","ref":"Fledex.Color.Names.RAL.html#h140l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l50c50/1","doc":"Defines the color rgb(65, 134, 56).","ref":"Fledex.Color.Names.RAL.html#h140l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l50c60/1","doc":"Defines the color rgb(43, 135, 37).","ref":"Fledex.Color.Names.RAL.html#h140l50c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l60c05/1","doc":"Defines the color rgb(139, 145, 138).","ref":"Fledex.Color.Names.RAL.html#h140l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l60c10/1","doc":"Defines the color rgb(133, 147, 130).","ref":"Fledex.Color.Names.RAL.html#h140l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l60c20/1","doc":"Defines the color rgb(126, 153, 119).","ref":"Fledex.Color.Names.RAL.html#h140l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l60c30/1","doc":"Defines the color rgb(115, 156, 105).","ref":"Fledex.Color.Names.RAL.html#h140l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l60c40/1","doc":"Defines the color rgb(106, 158, 92).","ref":"Fledex.Color.Names.RAL.html#h140l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l60c50/1","doc":"Defines the color rgb(90, 159, 77).","ref":"Fledex.Color.Names.RAL.html#h140l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l60c60/1","doc":"Defines the color rgb(77, 162, 65).","ref":"Fledex.Color.Names.RAL.html#h140l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l60c70/1","doc":"Defines the color rgb(59, 162, 52).","ref":"Fledex.Color.Names.RAL.html#h140l60c70/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l70c05/1","doc":"Defines the color rgb(165, 172, 164).","ref":"Fledex.Color.Names.RAL.html#h140l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l70c10/1","doc":"Defines the color rgb(159, 174, 158).","ref":"Fledex.Color.Names.RAL.html#h140l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l70c20/1","doc":"Defines the color rgb(151, 179, 145).","ref":"Fledex.Color.Names.RAL.html#h140l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l70c30/1","doc":"Defines the color rgb(140, 182, 132).","ref":"Fledex.Color.Names.RAL.html#h140l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l70c40/1","doc":"Defines the color rgb(132, 185, 119).","ref":"Fledex.Color.Names.RAL.html#h140l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l70c50/1","doc":"Defines the color rgb(118, 187, 104).","ref":"Fledex.Color.Names.RAL.html#h140l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l70c60/1","doc":"Defines the color rgb(105, 189, 90).","ref":"Fledex.Color.Names.RAL.html#h140l70c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l80c05/1","doc":"Defines the color rgb(195, 202, 191).","ref":"Fledex.Color.Names.RAL.html#h140l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l80c10/1","doc":"Defines the color rgb(188, 203, 185).","ref":"Fledex.Color.Names.RAL.html#h140l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l80c20/1","doc":"Defines the color rgb(179, 206, 171).","ref":"Fledex.Color.Names.RAL.html#h140l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l80c30/1","doc":"Defines the color rgb(168, 209, 158).","ref":"Fledex.Color.Names.RAL.html#h140l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l80c40/1","doc":"Defines the color rgb(153, 213, 144).","ref":"Fledex.Color.Names.RAL.html#h140l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l85c05/1","doc":"Defines the color rgb(210, 218, 208).","ref":"Fledex.Color.Names.RAL.html#h140l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l85c10/1","doc":"Defines the color rgb(206, 220, 202).","ref":"Fledex.Color.Names.RAL.html#h140l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l85c20/1","doc":"Defines the color rgb(197, 224, 189).","ref":"Fledex.Color.Names.RAL.html#h140l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l85c30/1","doc":"Defines the color rgb(184, 226, 176).","ref":"Fledex.Color.Names.RAL.html#h140l85c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l90c05/1","doc":"Defines the color rgb(223, 230, 218).","ref":"Fledex.Color.Names.RAL.html#h140l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l90c10/1","doc":"Defines the color rgb(219, 233, 213).","ref":"Fledex.Color.Names.RAL.html#h140l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h140l93c05/1","doc":"Defines the color rgb(234, 241, 230).","ref":"Fledex.Color.Names.RAL.html#h140l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l30c10/1","doc":"Defines the color rgb(61, 75, 61).","ref":"Fledex.Color.Names.RAL.html#h150l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l30c20/1","doc":"Defines the color rgb(46, 78, 54).","ref":"Fledex.Color.Names.RAL.html#h150l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l30c30/1","doc":"Defines the color rgb(30, 79, 43).","ref":"Fledex.Color.Names.RAL.html#h150l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l40c10/1","doc":"Defines the color rgb(82, 97, 83).","ref":"Fledex.Color.Names.RAL.html#h150l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l40c20/1","doc":"Defines the color rgb(71, 101, 74).","ref":"Fledex.Color.Names.RAL.html#h150l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l40c30/1","doc":"Defines the color rgb(51, 103, 63).","ref":"Fledex.Color.Names.RAL.html#h150l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l40c40/1","doc":"Defines the color rgb(28, 106, 53).","ref":"Fledex.Color.Names.RAL.html#h150l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l40c50/1","doc":"Defines the color rgb(0, 108, 46).","ref":"Fledex.Color.Names.RAL.html#h150l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l50c10/1","doc":"Defines the color rgb(105, 121, 106).","ref":"Fledex.Color.Names.RAL.html#h150l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l50c20/1","doc":"Defines the color rgb(93, 125, 97).","ref":"Fledex.Color.Names.RAL.html#h150l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l50c30/1","doc":"Defines the color rgb(83, 128, 89).","ref":"Fledex.Color.Names.RAL.html#h150l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l50c40/1","doc":"Defines the color rgb(63, 134, 83).","ref":"Fledex.Color.Names.RAL.html#h150l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l50c50/1","doc":"Defines the color rgb(33, 136, 69).","ref":"Fledex.Color.Names.RAL.html#h150l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l50c60/1","doc":"Defines the color rgb(0, 139, 60).","ref":"Fledex.Color.Names.RAL.html#h150l50c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l60c10/1","doc":"Defines the color rgb(133, 149, 135).","ref":"Fledex.Color.Names.RAL.html#h150l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l60c20/1","doc":"Defines the color rgb(119, 153, 125).","ref":"Fledex.Color.Names.RAL.html#h150l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l60c30/1","doc":"Defines the color rgb(105, 155, 114).","ref":"Fledex.Color.Names.RAL.html#h150l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l60c40/1","doc":"Defines the color rgb(89, 159, 104).","ref":"Fledex.Color.Names.RAL.html#h150l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l60c50/1","doc":"Defines the color rgb(73, 164, 98).","ref":"Fledex.Color.Names.RAL.html#h150l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l60c60/1","doc":"Defines the color rgb(28, 163, 80).","ref":"Fledex.Color.Names.RAL.html#h150l60c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l70c10/1","doc":"Defines the color rgb(158, 175, 160).","ref":"Fledex.Color.Names.RAL.html#h150l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l70c20/1","doc":"Defines the color rgb(146, 180, 152).","ref":"Fledex.Color.Names.RAL.html#h150l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l70c30/1","doc":"Defines the color rgb(131, 186, 142).","ref":"Fledex.Color.Names.RAL.html#h150l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l70c40/1","doc":"Defines the color rgb(116, 187, 131).","ref":"Fledex.Color.Names.RAL.html#h150l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l70c50/1","doc":"Defines the color rgb(98, 190, 119).","ref":"Fledex.Color.Names.RAL.html#h150l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l80c10/1","doc":"Defines the color rgb(187, 204, 189).","ref":"Fledex.Color.Names.RAL.html#h150l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l80c20/1","doc":"Defines the color rgb(173, 208, 179).","ref":"Fledex.Color.Names.RAL.html#h150l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l80c30/1","doc":"Defines the color rgb(159, 212, 170).","ref":"Fledex.Color.Names.RAL.html#h150l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l80c40/1","doc":"Defines the color rgb(143, 216, 159).","ref":"Fledex.Color.Names.RAL.html#h150l80c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l85c05/1","doc":"Defines the color rgb(206, 217, 207).","ref":"Fledex.Color.Names.RAL.html#h150l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l85c10/1","doc":"Defines the color rgb(203, 220, 203).","ref":"Fledex.Color.Names.RAL.html#h150l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l85c20/1","doc":"Defines the color rgb(193, 224, 193).","ref":"Fledex.Color.Names.RAL.html#h150l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l90c05/1","doc":"Defines the color rgb(220, 229, 217).","ref":"Fledex.Color.Names.RAL.html#h150l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l90c10/1","doc":"Defines the color rgb(215, 233, 215).","ref":"Fledex.Color.Names.RAL.html#h150l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h150l93c05/1","doc":"Defines the color rgb(231, 241, 230).","ref":"Fledex.Color.Names.RAL.html#h150l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l20c05/1","doc":"Defines the color rgb(43, 50, 45).","ref":"Fledex.Color.Names.RAL.html#h160l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l20c10/1","doc":"Defines the color rgb(36, 52, 42).","ref":"Fledex.Color.Names.RAL.html#h160l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l20c15/1","doc":"Defines the color rgb(24, 52, 37).","ref":"Fledex.Color.Names.RAL.html#h160l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l20c20/1","doc":"Defines the color rgb(16, 50, 34).","ref":"Fledex.Color.Names.RAL.html#h160l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l30c05/1","doc":"Defines the color rgb(62, 71, 64).","ref":"Fledex.Color.Names.RAL.html#h160l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l30c10/1","doc":"Defines the color rgb(56, 73, 62).","ref":"Fledex.Color.Names.RAL.html#h160l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l30c15/1","doc":"Defines the color rgb(47, 73, 57).","ref":"Fledex.Color.Names.RAL.html#h160l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l30c20/1","doc":"Defines the color rgb(37, 75, 55).","ref":"Fledex.Color.Names.RAL.html#h160l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l30c25/1","doc":"Defines the color rgb(26, 76, 50).","ref":"Fledex.Color.Names.RAL.html#h160l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l30c30/1","doc":"Defines the color rgb(1, 78, 46).","ref":"Fledex.Color.Names.RAL.html#h160l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l30c35/1","doc":"Defines the color rgb(0, 81, 44).","ref":"Fledex.Color.Names.RAL.html#h160l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l30c40/1","doc":"Defines the color rgb(0, 82, 40).","ref":"Fledex.Color.Names.RAL.html#h160l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c05/1","doc":"Defines the color rgb(87, 96, 90).","ref":"Fledex.Color.Names.RAL.html#h160l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c10/1","doc":"Defines the color rgb(78, 97, 87).","ref":"Fledex.Color.Names.RAL.html#h160l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c15/1","doc":"Defines the color rgb(70, 99, 83).","ref":"Fledex.Color.Names.RAL.html#h160l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c20/1","doc":"Defines the color rgb(62, 100, 79).","ref":"Fledex.Color.Names.RAL.html#h160l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c25/1","doc":"Defines the color rgb(51, 101, 74).","ref":"Fledex.Color.Names.RAL.html#h160l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c30/1","doc":"Defines the color rgb(40, 104, 72).","ref":"Fledex.Color.Names.RAL.html#h160l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c35/1","doc":"Defines the color rgb(22, 106, 69).","ref":"Fledex.Color.Names.RAL.html#h160l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c40/1","doc":"Defines the color rgb(0, 108, 68).","ref":"Fledex.Color.Names.RAL.html#h160l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c45/1","doc":"Defines the color rgb(0, 105, 60).","ref":"Fledex.Color.Names.RAL.html#h160l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c50/1","doc":"Defines the color rgb(0, 107, 56).","ref":"Fledex.Color.Names.RAL.html#h160l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l40c55/1","doc":"Defines the color rgb(0, 111, 55).","ref":"Fledex.Color.Names.RAL.html#h160l40c55/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c05/1","doc":"Defines the color rgb(111, 120, 114).","ref":"Fledex.Color.Names.RAL.html#h160l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c10/1","doc":"Defines the color rgb(102, 122, 110).","ref":"Fledex.Color.Names.RAL.html#h160l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c15/1","doc":"Defines the color rgb(95, 125, 108).","ref":"Fledex.Color.Names.RAL.html#h160l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c20/1","doc":"Defines the color rgb(86, 127, 105).","ref":"Fledex.Color.Names.RAL.html#h160l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c25/1","doc":"Defines the color rgb(77, 128, 100).","ref":"Fledex.Color.Names.RAL.html#h160l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c30/1","doc":"Defines the color rgb(67, 130, 97).","ref":"Fledex.Color.Names.RAL.html#h160l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c35/1","doc":"Defines the color rgb(59, 132, 94).","ref":"Fledex.Color.Names.RAL.html#h160l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c40/1","doc":"Defines the color rgb(36, 133, 91).","ref":"Fledex.Color.Names.RAL.html#h160l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c45/1","doc":"Defines the color rgb(19, 136, 89).","ref":"Fledex.Color.Names.RAL.html#h160l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c50/1","doc":"Defines the color rgb(0, 136, 84).","ref":"Fledex.Color.Names.RAL.html#h160l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c55/1","doc":"Defines the color rgb(0, 139, 82).","ref":"Fledex.Color.Names.RAL.html#h160l50c55/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l50c60/1","doc":"Defines the color rgb(0, 138, 76).","ref":"Fledex.Color.Names.RAL.html#h160l50c60/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c05/1","doc":"Defines the color rgb(136, 146, 140).","ref":"Fledex.Color.Names.RAL.html#h160l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c10/1","doc":"Defines the color rgb(127, 148, 136).","ref":"Fledex.Color.Names.RAL.html#h160l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c15/1","doc":"Defines the color rgb(120, 152, 133).","ref":"Fledex.Color.Names.RAL.html#h160l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c20/1","doc":"Defines the color rgb(111, 152, 129).","ref":"Fledex.Color.Names.RAL.html#h160l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c25/1","doc":"Defines the color rgb(103, 154, 124).","ref":"Fledex.Color.Names.RAL.html#h160l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c30/1","doc":"Defines the color rgb(94, 157, 123).","ref":"Fledex.Color.Names.RAL.html#h160l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c35/1","doc":"Defines the color rgb(83, 160, 121).","ref":"Fledex.Color.Names.RAL.html#h160l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c40/1","doc":"Defines the color rgb(69, 160, 116).","ref":"Fledex.Color.Names.RAL.html#h160l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c45/1","doc":"Defines the color rgb(58, 163, 114).","ref":"Fledex.Color.Names.RAL.html#h160l60c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c50/1","doc":"Defines the color rgb(26, 163, 109).","ref":"Fledex.Color.Names.RAL.html#h160l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c55/1","doc":"Defines the color rgb(0, 162, 103).","ref":"Fledex.Color.Names.RAL.html#h160l60c55/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l60c58/1","doc":"Defines the color rgb(0, 164, 101).","ref":"Fledex.Color.Names.RAL.html#h160l60c58/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c05/1","doc":"Defines the color rgb(163, 174, 167).","ref":"Fledex.Color.Names.RAL.html#h160l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c10/1","doc":"Defines the color rgb(153, 175, 163).","ref":"Fledex.Color.Names.RAL.html#h160l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c15/1","doc":"Defines the color rgb(144, 177, 157).","ref":"Fledex.Color.Names.RAL.html#h160l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c20/1","doc":"Defines the color rgb(138, 179, 155).","ref":"Fledex.Color.Names.RAL.html#h160l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c25/1","doc":"Defines the color rgb(129, 184, 154).","ref":"Fledex.Color.Names.RAL.html#h160l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c30/1","doc":"Defines the color rgb(117, 185, 150).","ref":"Fledex.Color.Names.RAL.html#h160l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c35/1","doc":"Defines the color rgb(106, 186, 146).","ref":"Fledex.Color.Names.RAL.html#h160l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c40/1","doc":"Defines the color rgb(96, 189, 142).","ref":"Fledex.Color.Names.RAL.html#h160l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c45/1","doc":"Defines the color rgb(81, 191, 138).","ref":"Fledex.Color.Names.RAL.html#h160l70c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l70c50/1","doc":"Defines the color rgb(68, 192, 137).","ref":"Fledex.Color.Names.RAL.html#h160l70c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l80c05/1","doc":"Defines the color rgb(188, 200, 193).","ref":"Fledex.Color.Names.RAL.html#h160l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l80c10/1","doc":"Defines the color rgb(181, 203, 189).","ref":"Fledex.Color.Names.RAL.html#h160l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l80c15/1","doc":"Defines the color rgb(171, 206, 186).","ref":"Fledex.Color.Names.RAL.html#h160l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l80c20/1","doc":"Defines the color rgb(163, 208, 182).","ref":"Fledex.Color.Names.RAL.html#h160l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l80c25/1","doc":"Defines the color rgb(156, 210, 180).","ref":"Fledex.Color.Names.RAL.html#h160l80c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l80c30/1","doc":"Defines the color rgb(148, 214, 178).","ref":"Fledex.Color.Names.RAL.html#h160l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l85c05/1","doc":"Defines the color rgb(204, 216, 208).","ref":"Fledex.Color.Names.RAL.html#h160l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l85c10/1","doc":"Defines the color rgb(197, 218, 204).","ref":"Fledex.Color.Names.RAL.html#h160l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l85c15/1","doc":"Defines the color rgb(189, 221, 200).","ref":"Fledex.Color.Names.RAL.html#h160l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l90c05/1","doc":"Defines the color rgb(219, 229, 219).","ref":"Fledex.Color.Names.RAL.html#h160l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l90c10/1","doc":"Defines the color rgb(210, 232, 216).","ref":"Fledex.Color.Names.RAL.html#h160l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l90c15/1","doc":"Defines the color rgb(201, 234, 212).","ref":"Fledex.Color.Names.RAL.html#h160l90c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h160l93c05/1","doc":"Defines the color rgb(226, 239, 232).","ref":"Fledex.Color.Names.RAL.html#h160l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l20c10/1","doc":"Defines the color rgb(28, 49, 41).","ref":"Fledex.Color.Names.RAL.html#h170l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l20c15/1","doc":"Defines the color rgb(18, 51, 40).","ref":"Fledex.Color.Names.RAL.html#h170l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l20c20/1","doc":"Defines the color rgb(0, 53, 39).","ref":"Fledex.Color.Names.RAL.html#h170l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l20c25/1","doc":"Defines the color rgb(0, 55, 35).","ref":"Fledex.Color.Names.RAL.html#h170l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l30c10/1","doc":"Defines the color rgb(53, 74, 65).","ref":"Fledex.Color.Names.RAL.html#h170l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l30c15/1","doc":"Defines the color rgb(40, 75, 62).","ref":"Fledex.Color.Names.RAL.html#h170l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l30c20/1","doc":"Defines the color rgb(30, 75, 59).","ref":"Fledex.Color.Names.RAL.html#h170l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l30c25/1","doc":"Defines the color rgb(4, 79, 59).","ref":"Fledex.Color.Names.RAL.html#h170l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l30c30/1","doc":"Defines the color rgb(0, 79, 57).","ref":"Fledex.Color.Names.RAL.html#h170l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l30c35/1","doc":"Defines the color rgb(0, 82, 57).","ref":"Fledex.Color.Names.RAL.html#h170l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l30c40/1","doc":"Defines the color rgb(0, 84, 55).","ref":"Fledex.Color.Names.RAL.html#h170l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c10/1","doc":"Defines the color rgb(75, 96, 87).","ref":"Fledex.Color.Names.RAL.html#h170l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c15/1","doc":"Defines the color rgb(66, 98, 85).","ref":"Fledex.Color.Names.RAL.html#h170l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c20/1","doc":"Defines the color rgb(53, 101, 84).","ref":"Fledex.Color.Names.RAL.html#h170l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c25/1","doc":"Defines the color rgb(43, 101, 81).","ref":"Fledex.Color.Names.RAL.html#h170l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c30/1","doc":"Defines the color rgb(28, 106, 81).","ref":"Fledex.Color.Names.RAL.html#h170l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c35/1","doc":"Defines the color rgb(0, 106, 77).","ref":"Fledex.Color.Names.RAL.html#h170l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c40/1","doc":"Defines the color rgb(0, 107, 77).","ref":"Fledex.Color.Names.RAL.html#h170l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c45/1","doc":"Defines the color rgb(0, 108, 75).","ref":"Fledex.Color.Names.RAL.html#h170l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l40c50/1","doc":"Defines the color rgb(0, 108, 71).","ref":"Fledex.Color.Names.RAL.html#h170l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c10/1","doc":"Defines the color rgb(99, 122, 114).","ref":"Fledex.Color.Names.RAL.html#h170l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c15/1","doc":"Defines the color rgb(91, 126, 112).","ref":"Fledex.Color.Names.RAL.html#h170l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c20/1","doc":"Defines the color rgb(80, 127, 109).","ref":"Fledex.Color.Names.RAL.html#h170l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c25/1","doc":"Defines the color rgb(70, 129, 108).","ref":"Fledex.Color.Names.RAL.html#h170l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c30/1","doc":"Defines the color rgb(53, 131, 106).","ref":"Fledex.Color.Names.RAL.html#h170l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c35/1","doc":"Defines the color rgb(32, 132, 104).","ref":"Fledex.Color.Names.RAL.html#h170l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c40/1","doc":"Defines the color rgb(0, 134, 100).","ref":"Fledex.Color.Names.RAL.html#h170l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c45/1","doc":"Defines the color rgb(0, 135, 100).","ref":"Fledex.Color.Names.RAL.html#h170l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c50/1","doc":"Defines the color rgb(0, 139, 98).","ref":"Fledex.Color.Names.RAL.html#h170l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l50c55/1","doc":"Defines the color rgb(0, 138, 96).","ref":"Fledex.Color.Names.RAL.html#h170l50c55/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c10/1","doc":"Defines the color rgb(124, 148, 139).","ref":"Fledex.Color.Names.RAL.html#h170l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c15/1","doc":"Defines the color rgb(118, 151, 137).","ref":"Fledex.Color.Names.RAL.html#h170l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c20/1","doc":"Defines the color rgb(105, 154, 136).","ref":"Fledex.Color.Names.RAL.html#h170l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c25/1","doc":"Defines the color rgb(94, 155, 134).","ref":"Fledex.Color.Names.RAL.html#h170l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c30/1","doc":"Defines the color rgb(80, 157, 131).","ref":"Fledex.Color.Names.RAL.html#h170l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c35/1","doc":"Defines the color rgb(63, 162, 130).","ref":"Fledex.Color.Names.RAL.html#h170l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c40/1","doc":"Defines the color rgb(44, 161, 128).","ref":"Fledex.Color.Names.RAL.html#h170l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c45/1","doc":"Defines the color rgb(0, 162, 125).","ref":"Fledex.Color.Names.RAL.html#h170l60c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l60c50/1","doc":"Defines the color rgb(0, 166, 126).","ref":"Fledex.Color.Names.RAL.html#h170l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l70c10/1","doc":"Defines the color rgb(152, 177, 166).","ref":"Fledex.Color.Names.RAL.html#h170l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l70c15/1","doc":"Defines the color rgb(143, 178, 163).","ref":"Fledex.Color.Names.RAL.html#h170l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l70c20/1","doc":"Defines the color rgb(132, 182, 162).","ref":"Fledex.Color.Names.RAL.html#h170l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l70c25/1","doc":"Defines the color rgb(124, 184, 161).","ref":"Fledex.Color.Names.RAL.html#h170l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l70c30/1","doc":"Defines the color rgb(108, 187, 160).","ref":"Fledex.Color.Names.RAL.html#h170l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l70c35/1","doc":"Defines the color rgb(95, 187, 156).","ref":"Fledex.Color.Names.RAL.html#h170l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l70c40/1","doc":"Defines the color rgb(82, 188, 154).","ref":"Fledex.Color.Names.RAL.html#h170l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l80c10/1","doc":"Defines the color rgb(180, 204, 194).","ref":"Fledex.Color.Names.RAL.html#h170l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l80c15/1","doc":"Defines the color rgb(168, 207, 192).","ref":"Fledex.Color.Names.RAL.html#h170l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l80c20/1","doc":"Defines the color rgb(159, 211, 191).","ref":"Fledex.Color.Names.RAL.html#h170l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l80c25/1","doc":"Defines the color rgb(147, 211, 188).","ref":"Fledex.Color.Names.RAL.html#h170l80c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l85c05/1","doc":"Defines the color rgb(205, 218, 211).","ref":"Fledex.Color.Names.RAL.html#h170l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l85c10/1","doc":"Defines the color rgb(197, 221, 208).","ref":"Fledex.Color.Names.RAL.html#h170l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l85c15/1","doc":"Defines the color rgb(186, 223, 205).","ref":"Fledex.Color.Names.RAL.html#h170l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l85c20/1","doc":"Defines the color rgb(177, 226, 203).","ref":"Fledex.Color.Names.RAL.html#h170l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l90c05/1","doc":"Defines the color rgb(217, 229, 221).","ref":"Fledex.Color.Names.RAL.html#h170l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l90c10/1","doc":"Defines the color rgb(207, 233, 220).","ref":"Fledex.Color.Names.RAL.html#h170l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h170l93c05/1","doc":"Defines the color rgb(228, 240, 232).","ref":"Fledex.Color.Names.RAL.html#h170l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l20c05/1","doc":"Defines the color rgb(40, 51, 48).","ref":"Fledex.Color.Names.RAL.html#h180l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l20c10/1","doc":"Defines the color rgb(27, 50, 44).","ref":"Fledex.Color.Names.RAL.html#h180l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l20c15/1","doc":"Defines the color rgb(9, 51, 44).","ref":"Fledex.Color.Names.RAL.html#h180l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l20c20/1","doc":"Defines the color rgb(0, 53, 44).","ref":"Fledex.Color.Names.RAL.html#h180l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l30c05/1","doc":"Defines the color rgb(63, 74, 71).","ref":"Fledex.Color.Names.RAL.html#h180l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l30c10/1","doc":"Defines the color rgb(50, 73, 67).","ref":"Fledex.Color.Names.RAL.html#h180l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l30c15/1","doc":"Defines the color rgb(39, 76, 67).","ref":"Fledex.Color.Names.RAL.html#h180l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l30c20/1","doc":"Defines the color rgb(24, 77, 67).","ref":"Fledex.Color.Names.RAL.html#h180l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l30c25/1","doc":"Defines the color rgb(0, 80, 67).","ref":"Fledex.Color.Names.RAL.html#h180l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l30c30/1","doc":"Defines the color rgb(0, 80, 66).","ref":"Fledex.Color.Names.RAL.html#h180l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l30c35/1","doc":"Defines the color rgb(0, 83, 65).","ref":"Fledex.Color.Names.RAL.html#h180l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c05/1","doc":"Defines the color rgb(84, 95, 91).","ref":"Fledex.Color.Names.RAL.html#h180l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c10/1","doc":"Defines the color rgb(74, 99, 92).","ref":"Fledex.Color.Names.RAL.html#h180l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c15/1","doc":"Defines the color rgb(62, 100, 91).","ref":"Fledex.Color.Names.RAL.html#h180l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c20/1","doc":"Defines the color rgb(48, 103, 92).","ref":"Fledex.Color.Names.RAL.html#h180l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c25/1","doc":"Defines the color rgb(30, 103, 90).","ref":"Fledex.Color.Names.RAL.html#h180l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c30/1","doc":"Defines the color rgb(0, 106, 91).","ref":"Fledex.Color.Names.RAL.html#h180l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c35/1","doc":"Defines the color rgb(0, 107, 87).","ref":"Fledex.Color.Names.RAL.html#h180l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c40/1","doc":"Defines the color rgb(0, 107, 86).","ref":"Fledex.Color.Names.RAL.html#h180l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l40c45/1","doc":"Defines the color rgb(0, 109, 87).","ref":"Fledex.Color.Names.RAL.html#h180l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c05/1","doc":"Defines the color rgb(110, 122, 119).","ref":"Fledex.Color.Names.RAL.html#h180l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c10/1","doc":"Defines the color rgb(97, 122, 116).","ref":"Fledex.Color.Names.RAL.html#h180l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c15/1","doc":"Defines the color rgb(85, 125, 115).","ref":"Fledex.Color.Names.RAL.html#h180l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c20/1","doc":"Defines the color rgb(73, 127, 115).","ref":"Fledex.Color.Names.RAL.html#h180l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c25/1","doc":"Defines the color rgb(57, 129, 116).","ref":"Fledex.Color.Names.RAL.html#h180l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c30/1","doc":"Defines the color rgb(35, 132, 114).","ref":"Fledex.Color.Names.RAL.html#h180l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c35/1","doc":"Defines the color rgb(0, 133, 114).","ref":"Fledex.Color.Names.RAL.html#h180l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c40/1","doc":"Defines the color rgb(0, 133, 113).","ref":"Fledex.Color.Names.RAL.html#h180l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c45/1","doc":"Defines the color rgb(0, 138, 112).","ref":"Fledex.Color.Names.RAL.html#h180l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l50c50/1","doc":"Defines the color rgb(0, 138, 111).","ref":"Fledex.Color.Names.RAL.html#h180l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c05/1","doc":"Defines the color rgb(133, 146, 143).","ref":"Fledex.Color.Names.RAL.html#h180l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c10/1","doc":"Defines the color rgb(122, 149, 142).","ref":"Fledex.Color.Names.RAL.html#h180l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c15/1","doc":"Defines the color rgb(111, 151, 142).","ref":"Fledex.Color.Names.RAL.html#h180l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c20/1","doc":"Defines the color rgb(99, 154, 142).","ref":"Fledex.Color.Names.RAL.html#h180l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c25/1","doc":"Defines the color rgb(84, 155, 140).","ref":"Fledex.Color.Names.RAL.html#h180l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c30/1","doc":"Defines the color rgb(67, 158, 141).","ref":"Fledex.Color.Names.RAL.html#h180l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c35/1","doc":"Defines the color rgb(46, 161, 140).","ref":"Fledex.Color.Names.RAL.html#h180l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c40/1","doc":"Defines the color rgb(0, 163, 140).","ref":"Fledex.Color.Names.RAL.html#h180l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c45/1","doc":"Defines the color rgb(0, 165, 140).","ref":"Fledex.Color.Names.RAL.html#h180l60c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l60c50/1","doc":"Defines the color rgb(0, 166, 139).","ref":"Fledex.Color.Names.RAL.html#h180l60c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l70c05/1","doc":"Defines the color rgb(160, 173, 169).","ref":"Fledex.Color.Names.RAL.html#h180l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l70c10/1","doc":"Defines the color rgb(147, 176, 169).","ref":"Fledex.Color.Names.RAL.html#h180l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l70c15/1","doc":"Defines the color rgb(136, 178, 169).","ref":"Fledex.Color.Names.RAL.html#h180l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l70c20/1","doc":"Defines the color rgb(125, 182, 168).","ref":"Fledex.Color.Names.RAL.html#h180l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l70c25/1","doc":"Defines the color rgb(111, 183, 168).","ref":"Fledex.Color.Names.RAL.html#h180l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l70c30/1","doc":"Defines the color rgb(98, 186, 168).","ref":"Fledex.Color.Names.RAL.html#h180l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l70c35/1","doc":"Defines the color rgb(76, 188, 167).","ref":"Fledex.Color.Names.RAL.html#h180l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l70c40/1","doc":"Defines the color rgb(54, 191, 168).","ref":"Fledex.Color.Names.RAL.html#h180l70c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l80c05/1","doc":"Defines the color rgb(188, 201, 195).","ref":"Fledex.Color.Names.RAL.html#h180l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l80c10/1","doc":"Defines the color rgb(177, 204, 197).","ref":"Fledex.Color.Names.RAL.html#h180l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l80c15/1","doc":"Defines the color rgb(167, 208, 197).","ref":"Fledex.Color.Names.RAL.html#h180l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l80c20/1","doc":"Defines the color rgb(150, 209, 195).","ref":"Fledex.Color.Names.RAL.html#h180l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l80c25/1","doc":"Defines the color rgb(139, 212, 195).","ref":"Fledex.Color.Names.RAL.html#h180l80c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l80c30/1","doc":"Defines the color rgb(130, 217, 197).","ref":"Fledex.Color.Names.RAL.html#h180l80c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l85c05/1","doc":"Defines the color rgb(203, 217, 212).","ref":"Fledex.Color.Names.RAL.html#h180l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l85c10/1","doc":"Defines the color rgb(194, 221, 211).","ref":"Fledex.Color.Names.RAL.html#h180l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l85c15/1","doc":"Defines the color rgb(186, 225, 211).","ref":"Fledex.Color.Names.RAL.html#h180l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l85c20/1","doc":"Defines the color rgb(171, 226, 207).","ref":"Fledex.Color.Names.RAL.html#h180l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l90c05/1","doc":"Defines the color rgb(217, 231, 226).","ref":"Fledex.Color.Names.RAL.html#h180l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l90c10/1","doc":"Defines the color rgb(205, 235, 225).","ref":"Fledex.Color.Names.RAL.html#h180l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h180l93c05/1","doc":"Defines the color rgb(229, 241, 236).","ref":"Fledex.Color.Names.RAL.html#h180l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l20c20/1","doc":"Defines the color rgb(0, 56, 51).","ref":"Fledex.Color.Names.RAL.html#h190l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l30c15/1","doc":"Defines the color rgb(37, 77, 72).","ref":"Fledex.Color.Names.RAL.html#h190l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l30c20/1","doc":"Defines the color rgb(16, 79, 74).","ref":"Fledex.Color.Names.RAL.html#h190l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l30c25/1","doc":"Defines the color rgb(0, 80, 75).","ref":"Fledex.Color.Names.RAL.html#h190l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l30c30/1","doc":"Defines the color rgb(0, 82, 76).","ref":"Fledex.Color.Names.RAL.html#h190l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l30c35/1","doc":"Defines the color rgb(0, 83, 76).","ref":"Fledex.Color.Names.RAL.html#h190l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l40c10/1","doc":"Defines the color rgb(73, 98, 94).","ref":"Fledex.Color.Names.RAL.html#h190l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l40c15/1","doc":"Defines the color rgb(60, 100, 97).","ref":"Fledex.Color.Names.RAL.html#h190l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l40c20/1","doc":"Defines the color rgb(41, 102, 97).","ref":"Fledex.Color.Names.RAL.html#h190l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l40c25/1","doc":"Defines the color rgb(11, 104, 99).","ref":"Fledex.Color.Names.RAL.html#h190l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l40c30/1","doc":"Defines the color rgb(0, 107, 100).","ref":"Fledex.Color.Names.RAL.html#h190l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l40c35/1","doc":"Defines the color rgb(0, 108, 101).","ref":"Fledex.Color.Names.RAL.html#h190l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l40c40/1","doc":"Defines the color rgb(0, 110, 102).","ref":"Fledex.Color.Names.RAL.html#h190l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l40c45/1","doc":"Defines the color rgb(0, 113, 103).","ref":"Fledex.Color.Names.RAL.html#h190l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l50c10/1","doc":"Defines the color rgb(97, 124, 120).","ref":"Fledex.Color.Names.RAL.html#h190l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l50c15/1","doc":"Defines the color rgb(84, 126, 121).","ref":"Fledex.Color.Names.RAL.html#h190l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l50c20/1","doc":"Defines the color rgb(70, 128, 123).","ref":"Fledex.Color.Names.RAL.html#h190l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l50c25/1","doc":"Defines the color rgb(49, 130, 123).","ref":"Fledex.Color.Names.RAL.html#h190l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l50c30/1","doc":"Defines the color rgb(8, 132, 124).","ref":"Fledex.Color.Names.RAL.html#h190l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l50c35/1","doc":"Defines the color rgb(0, 134, 125).","ref":"Fledex.Color.Names.RAL.html#h190l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l50c40/1","doc":"Defines the color rgb(0, 137, 128).","ref":"Fledex.Color.Names.RAL.html#h190l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l50c45/1","doc":"Defines the color rgb(0, 138, 129).","ref":"Fledex.Color.Names.RAL.html#h190l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l60c10/1","doc":"Defines the color rgb(122, 150, 147).","ref":"Fledex.Color.Names.RAL.html#h190l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l60c15/1","doc":"Defines the color rgb(111, 152, 146).","ref":"Fledex.Color.Names.RAL.html#h190l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l60c20/1","doc":"Defines the color rgb(99, 155, 149).","ref":"Fledex.Color.Names.RAL.html#h190l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l60c25/1","doc":"Defines the color rgb(79, 158, 150).","ref":"Fledex.Color.Names.RAL.html#h190l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l60c30/1","doc":"Defines the color rgb(58, 160, 152).","ref":"Fledex.Color.Names.RAL.html#h190l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l60c35/1","doc":"Defines the color rgb(22, 162, 154).","ref":"Fledex.Color.Names.RAL.html#h190l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l60c40/1","doc":"Defines the color rgb(0, 164, 154).","ref":"Fledex.Color.Names.RAL.html#h190l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l60c45/1","doc":"Defines the color rgb(0, 164, 153).","ref":"Fledex.Color.Names.RAL.html#h190l60c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l70c10/1","doc":"Defines the color rgb(149, 176, 173).","ref":"Fledex.Color.Names.RAL.html#h190l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l70c15/1","doc":"Defines the color rgb(137, 179, 173).","ref":"Fledex.Color.Names.RAL.html#h190l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l70c20/1","doc":"Defines the color rgb(122, 181, 174).","ref":"Fledex.Color.Names.RAL.html#h190l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l70c25/1","doc":"Defines the color rgb(107, 184, 177).","ref":"Fledex.Color.Names.RAL.html#h190l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l70c30/1","doc":"Defines the color rgb(93, 188, 180).","ref":"Fledex.Color.Names.RAL.html#h190l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l70c35/1","doc":"Defines the color rgb(69, 188, 179).","ref":"Fledex.Color.Names.RAL.html#h190l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l80c10/1","doc":"Defines the color rgb(175, 205, 199).","ref":"Fledex.Color.Names.RAL.html#h190l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l80c15/1","doc":"Defines the color rgb(165, 208, 203).","ref":"Fledex.Color.Names.RAL.html#h190l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l80c20/1","doc":"Defines the color rgb(151, 209, 203).","ref":"Fledex.Color.Names.RAL.html#h190l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l80c25/1","doc":"Defines the color rgb(136, 212, 204).","ref":"Fledex.Color.Names.RAL.html#h190l80c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l85c05/1","doc":"Defines the color rgb(198, 219, 214).","ref":"Fledex.Color.Names.RAL.html#h190l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l85c10/1","doc":"Defines the color rgb(187, 222, 215).","ref":"Fledex.Color.Names.RAL.html#h190l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l85c15/1","doc":"Defines the color rgb(171, 226, 214).","ref":"Fledex.Color.Names.RAL.html#h190l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l85c20/1","doc":"Defines the color rgb(157, 229, 216).","ref":"Fledex.Color.Names.RAL.html#h190l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l90c05/1","doc":"Defines the color rgb(218, 230, 226).","ref":"Fledex.Color.Names.RAL.html#h190l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l90c10/1","doc":"Defines the color rgb(205, 234, 229).","ref":"Fledex.Color.Names.RAL.html#h190l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h190l93c05/1","doc":"Defines the color rgb(229, 241, 236).","ref":"Fledex.Color.Names.RAL.html#h190l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l20c05/1","doc":"Defines the color rgb(38, 49, 48).","ref":"Fledex.Color.Names.RAL.html#h200l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l20c10/1","doc":"Defines the color rgb(25, 50, 50).","ref":"Fledex.Color.Names.RAL.html#h200l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l20c15/1","doc":"Defines the color rgb(4, 49, 50).","ref":"Fledex.Color.Names.RAL.html#h200l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l20c20/1","doc":"Defines the color rgb(0, 54, 54).","ref":"Fledex.Color.Names.RAL.html#h200l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l20c23/1","doc":"Defines the color rgb(0, 56, 57).","ref":"Fledex.Color.Names.RAL.html#h200l20c23/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l30c05/1","doc":"Defines the color rgb(58, 70, 69).","ref":"Fledex.Color.Names.RAL.html#h200l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l30c10/1","doc":"Defines the color rgb(48, 75, 74).","ref":"Fledex.Color.Names.RAL.html#h200l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l30c15/1","doc":"Defines the color rgb(35, 78, 77).","ref":"Fledex.Color.Names.RAL.html#h200l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l30c20/1","doc":"Defines the color rgb(14, 79, 79).","ref":"Fledex.Color.Names.RAL.html#h200l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l30c25/1","doc":"Defines the color rgb(0, 78, 78).","ref":"Fledex.Color.Names.RAL.html#h200l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l30c30/1","doc":"Defines the color rgb(0, 81, 82).","ref":"Fledex.Color.Names.RAL.html#h200l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l30c33/1","doc":"Defines the color rgb(0, 84, 86).","ref":"Fledex.Color.Names.RAL.html#h200l30c33/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l40c05/1","doc":"Defines the color rgb(82, 96, 95).","ref":"Fledex.Color.Names.RAL.html#h200l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l40c10/1","doc":"Defines the color rgb(72, 98, 98).","ref":"Fledex.Color.Names.RAL.html#h200l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l40c15/1","doc":"Defines the color rgb(58, 99, 100).","ref":"Fledex.Color.Names.RAL.html#h200l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l40c20/1","doc":"Defines the color rgb(41, 103, 103).","ref":"Fledex.Color.Names.RAL.html#h200l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l40c25/1","doc":"Defines the color rgb(10, 105, 106).","ref":"Fledex.Color.Names.RAL.html#h200l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l40c30/1","doc":"Defines the color rgb(0, 107, 108).","ref":"Fledex.Color.Names.RAL.html#h200l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l40c35/1","doc":"Defines the color rgb(0, 108, 110).","ref":"Fledex.Color.Names.RAL.html#h200l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l40c40/1","doc":"Defines the color rgb(0, 111, 114).","ref":"Fledex.Color.Names.RAL.html#h200l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c05/1","doc":"Defines the color rgb(106, 119, 119).","ref":"Fledex.Color.Names.RAL.html#h200l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c10/1","doc":"Defines the color rgb(96, 123, 123).","ref":"Fledex.Color.Names.RAL.html#h200l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c15/1","doc":"Defines the color rgb(83, 126, 126).","ref":"Fledex.Color.Names.RAL.html#h200l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c20/1","doc":"Defines the color rgb(66, 127, 128).","ref":"Fledex.Color.Names.RAL.html#h200l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c25/1","doc":"Defines the color rgb(45, 130, 132).","ref":"Fledex.Color.Names.RAL.html#h200l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c30/1","doc":"Defines the color rgb(0, 132, 134).","ref":"Fledex.Color.Names.RAL.html#h200l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c35/1","doc":"Defines the color rgb(0, 136, 139).","ref":"Fledex.Color.Names.RAL.html#h200l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c40/1","doc":"Defines the color rgb(0, 137, 140).","ref":"Fledex.Color.Names.RAL.html#h200l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l50c45/1","doc":"Defines the color rgb(0, 138, 142).","ref":"Fledex.Color.Names.RAL.html#h200l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l60c05/1","doc":"Defines the color rgb(132, 146, 146).","ref":"Fledex.Color.Names.RAL.html#h200l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l60c10/1","doc":"Defines the color rgb(122, 149, 149).","ref":"Fledex.Color.Names.RAL.html#h200l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l60c15/1","doc":"Defines the color rgb(108, 152, 152).","ref":"Fledex.Color.Names.RAL.html#h200l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l60c20/1","doc":"Defines the color rgb(95, 155, 156).","ref":"Fledex.Color.Names.RAL.html#h200l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l60c25/1","doc":"Defines the color rgb(73, 156, 157).","ref":"Fledex.Color.Names.RAL.html#h200l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l60c30/1","doc":"Defines the color rgb(49, 159, 159).","ref":"Fledex.Color.Names.RAL.html#h200l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l60c35/1","doc":"Defines the color rgb(0, 161, 163).","ref":"Fledex.Color.Names.RAL.html#h200l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l60c40/1","doc":"Defines the color rgb(0, 164, 166).","ref":"Fledex.Color.Names.RAL.html#h200l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l70c05/1","doc":"Defines the color rgb(160, 173, 172).","ref":"Fledex.Color.Names.RAL.html#h200l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l70c10/1","doc":"Defines the color rgb(148, 178, 178).","ref":"Fledex.Color.Names.RAL.html#h200l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l70c15/1","doc":"Defines the color rgb(133, 179, 178).","ref":"Fledex.Color.Names.RAL.html#h200l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l70c20/1","doc":"Defines the color rgb(122, 182, 182).","ref":"Fledex.Color.Names.RAL.html#h200l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l70c25/1","doc":"Defines the color rgb(106, 185, 187).","ref":"Fledex.Color.Names.RAL.html#h200l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l80c05/1","doc":"Defines the color rgb(188, 201, 199).","ref":"Fledex.Color.Names.RAL.html#h200l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l80c10/1","doc":"Defines the color rgb(174, 204, 203).","ref":"Fledex.Color.Names.RAL.html#h200l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l80c15/1","doc":"Defines the color rgb(162, 205, 203).","ref":"Fledex.Color.Names.RAL.html#h200l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l80c20/1","doc":"Defines the color rgb(148, 211, 209).","ref":"Fledex.Color.Names.RAL.html#h200l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l80c25/1","doc":"Defines the color rgb(133, 212, 212).","ref":"Fledex.Color.Names.RAL.html#h200l80c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l85c05/1","doc":"Defines the color rgb(203, 217, 216).","ref":"Fledex.Color.Names.RAL.html#h200l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l85c10/1","doc":"Defines the color rgb(193, 220, 219).","ref":"Fledex.Color.Names.RAL.html#h200l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l85c15/1","doc":"Defines the color rgb(180, 224, 222).","ref":"Fledex.Color.Names.RAL.html#h200l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l85c20/1","doc":"Defines the color rgb(166, 227, 224).","ref":"Fledex.Color.Names.RAL.html#h200l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l90c05/1","doc":"Defines the color rgb(217, 231, 228).","ref":"Fledex.Color.Names.RAL.html#h200l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l90c10/1","doc":"Defines the color rgb(204, 233, 228).","ref":"Fledex.Color.Names.RAL.html#h200l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h200l93c05/1","doc":"Defines the color rgb(229, 241, 237).","ref":"Fledex.Color.Names.RAL.html#h200l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l30c10/1","doc":"Defines the color rgb(50, 73, 75).","ref":"Fledex.Color.Names.RAL.html#h210l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l30c15/1","doc":"Defines the color rgb(33, 76, 79).","ref":"Fledex.Color.Names.RAL.html#h210l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l30c20/1","doc":"Defines the color rgb(0, 79, 84).","ref":"Fledex.Color.Names.RAL.html#h210l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l30c25/1","doc":"Defines the color rgb(0, 79, 87).","ref":"Fledex.Color.Names.RAL.html#h210l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l30c30/1","doc":"Defines the color rgb(0, 80, 90).","ref":"Fledex.Color.Names.RAL.html#h210l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l40c10/1","doc":"Defines the color rgb(70, 97, 99).","ref":"Fledex.Color.Names.RAL.html#h210l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l40c15/1","doc":"Defines the color rgb(58, 100, 104).","ref":"Fledex.Color.Names.RAL.html#h210l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l40c20/1","doc":"Defines the color rgb(38, 102, 107).","ref":"Fledex.Color.Names.RAL.html#h210l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l40c25/1","doc":"Defines the color rgb(0, 102, 109).","ref":"Fledex.Color.Names.RAL.html#h210l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l40c30/1","doc":"Defines the color rgb(0, 105, 115).","ref":"Fledex.Color.Names.RAL.html#h210l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l40c35/1","doc":"Defines the color rgb(0, 108, 120).","ref":"Fledex.Color.Names.RAL.html#h210l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l40c38/1","doc":"Defines the color rgb(0, 106, 119).","ref":"Fledex.Color.Names.RAL.html#h210l40c38/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l50c10/1","doc":"Defines the color rgb(95, 123, 126).","ref":"Fledex.Color.Names.RAL.html#h210l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l50c15/1","doc":"Defines the color rgb(84, 125, 128).","ref":"Fledex.Color.Names.RAL.html#h210l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l50c20/1","doc":"Defines the color rgb(66, 127, 133).","ref":"Fledex.Color.Names.RAL.html#h210l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l50c25/1","doc":"Defines the color rgb(43, 130, 136).","ref":"Fledex.Color.Names.RAL.html#h210l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l50c30/1","doc":"Defines the color rgb(0, 131, 141).","ref":"Fledex.Color.Names.RAL.html#h210l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l50c35/1","doc":"Defines the color rgb(0, 134, 145).","ref":"Fledex.Color.Names.RAL.html#h210l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l50c40/1","doc":"Defines the color rgb(0, 136, 148).","ref":"Fledex.Color.Names.RAL.html#h210l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l50c45/1","doc":"Defines the color rgb(0, 137, 151).","ref":"Fledex.Color.Names.RAL.html#h210l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l60c10/1","doc":"Defines the color rgb(122, 149, 152).","ref":"Fledex.Color.Names.RAL.html#h210l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l60c15/1","doc":"Defines the color rgb(108, 150, 154).","ref":"Fledex.Color.Names.RAL.html#h210l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l60c20/1","doc":"Defines the color rgb(95, 156, 162).","ref":"Fledex.Color.Names.RAL.html#h210l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l60c25/1","doc":"Defines the color rgb(74, 159, 167).","ref":"Fledex.Color.Names.RAL.html#h210l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l60c30/1","doc":"Defines the color rgb(48, 160, 170).","ref":"Fledex.Color.Names.RAL.html#h210l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l60c35/1","doc":"Defines the color rgb(0, 161, 172).","ref":"Fledex.Color.Names.RAL.html#h210l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l60c40/1","doc":"Defines the color rgb(0, 164, 177).","ref":"Fledex.Color.Names.RAL.html#h210l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l70c10/1","doc":"Defines the color rgb(149, 177, 179).","ref":"Fledex.Color.Names.RAL.html#h210l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l70c15/1","doc":"Defines the color rgb(137, 179, 182).","ref":"Fledex.Color.Names.RAL.html#h210l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l70c20/1","doc":"Defines the color rgb(121, 182, 188).","ref":"Fledex.Color.Names.RAL.html#h210l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l70c25/1","doc":"Defines the color rgb(105, 184, 192).","ref":"Fledex.Color.Names.RAL.html#h210l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l70c30/1","doc":"Defines the color rgb(83, 188, 197).","ref":"Fledex.Color.Names.RAL.html#h210l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l70c35/1","doc":"Defines the color rgb(53, 189, 200).","ref":"Fledex.Color.Names.RAL.html#h210l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l80c10/1","doc":"Defines the color rgb(180, 206, 207).","ref":"Fledex.Color.Names.RAL.html#h210l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l80c15/1","doc":"Defines the color rgb(165, 209, 211).","ref":"Fledex.Color.Names.RAL.html#h210l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l80c20/1","doc":"Defines the color rgb(150, 210, 214).","ref":"Fledex.Color.Names.RAL.html#h210l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l80c25/1","doc":"Defines the color rgb(136, 214, 220).","ref":"Fledex.Color.Names.RAL.html#h210l80c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l85c05/1","doc":"Defines the color rgb(202, 218, 218).","ref":"Fledex.Color.Names.RAL.html#h210l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l85c10/1","doc":"Defines the color rgb(188, 224, 223).","ref":"Fledex.Color.Names.RAL.html#h210l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l85c15/1","doc":"Defines the color rgb(182, 225, 225).","ref":"Fledex.Color.Names.RAL.html#h210l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l85c20/1","doc":"Defines the color rgb(167, 227, 226).","ref":"Fledex.Color.Names.RAL.html#h210l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l90c05/1","doc":"Defines the color rgb(217, 231, 229).","ref":"Fledex.Color.Names.RAL.html#h210l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h210l90c10/1","doc":"Defines the color rgb(204, 234, 231).","ref":"Fledex.Color.Names.RAL.html#h210l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l20c05/1","doc":"Defines the color rgb(38, 48, 50).","ref":"Fledex.Color.Names.RAL.html#h220l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l20c10/1","doc":"Defines the color rgb(26, 51, 56).","ref":"Fledex.Color.Names.RAL.html#h220l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l20c15/1","doc":"Defines the color rgb(1, 52, 58).","ref":"Fledex.Color.Names.RAL.html#h220l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l20c20/1","doc":"Defines the color rgb(0, 55, 64).","ref":"Fledex.Color.Names.RAL.html#h220l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l30c05/1","doc":"Defines the color rgb(60, 71, 72).","ref":"Fledex.Color.Names.RAL.html#h220l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l30c10/1","doc":"Defines the color rgb(49, 74, 78).","ref":"Fledex.Color.Names.RAL.html#h220l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l30c15/1","doc":"Defines the color rgb(37, 77, 84).","ref":"Fledex.Color.Names.RAL.html#h220l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l30c20/1","doc":"Defines the color rgb(8, 77, 88).","ref":"Fledex.Color.Names.RAL.html#h220l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l30c25/1","doc":"Defines the color rgb(0, 81, 93).","ref":"Fledex.Color.Names.RAL.html#h220l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l30c30/1","doc":"Defines the color rgb(0, 81, 96).","ref":"Fledex.Color.Names.RAL.html#h220l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l40c05/1","doc":"Defines the color rgb(83, 95, 98).","ref":"Fledex.Color.Names.RAL.html#h220l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l40c10/1","doc":"Defines the color rgb(74, 98, 103).","ref":"Fledex.Color.Names.RAL.html#h220l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l40c15/1","doc":"Defines the color rgb(59, 100, 108).","ref":"Fledex.Color.Names.RAL.html#h220l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l40c20/1","doc":"Defines the color rgb(42, 102, 113).","ref":"Fledex.Color.Names.RAL.html#h220l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l40c25/1","doc":"Defines the color rgb(6, 105, 118).","ref":"Fledex.Color.Names.RAL.html#h220l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l40c30/1","doc":"Defines the color rgb(0, 107, 125).","ref":"Fledex.Color.Names.RAL.html#h220l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l40c35/1","doc":"Defines the color rgb(0, 108, 129).","ref":"Fledex.Color.Names.RAL.html#h220l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l40c40/1","doc":"Defines the color rgb(0, 111, 134).","ref":"Fledex.Color.Names.RAL.html#h220l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l50c05/1","doc":"Defines the color rgb(110, 122, 124).","ref":"Fledex.Color.Names.RAL.html#h220l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l50c10/1","doc":"Defines the color rgb(99, 123, 128).","ref":"Fledex.Color.Names.RAL.html#h220l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l50c15/1","doc":"Defines the color rgb(84, 125, 134).","ref":"Fledex.Color.Names.RAL.html#h220l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l50c20/1","doc":"Defines the color rgb(66, 128, 138).","ref":"Fledex.Color.Names.RAL.html#h220l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l50c25/1","doc":"Defines the color rgb(48, 129, 143).","ref":"Fledex.Color.Names.RAL.html#h220l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l50c30/1","doc":"Defines the color rgb(0, 129, 147).","ref":"Fledex.Color.Names.RAL.html#h220l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l50c35/1","doc":"Defines the color rgb(0, 134, 154).","ref":"Fledex.Color.Names.RAL.html#h220l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l50c40/1","doc":"Defines the color rgb(0, 136, 159).","ref":"Fledex.Color.Names.RAL.html#h220l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l60c05/1","doc":"Defines the color rgb(135, 146, 148).","ref":"Fledex.Color.Names.RAL.html#h220l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l60c10/1","doc":"Defines the color rgb(124, 149, 155).","ref":"Fledex.Color.Names.RAL.html#h220l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l60c15/1","doc":"Defines the color rgb(112, 152, 160).","ref":"Fledex.Color.Names.RAL.html#h220l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l60c20/1","doc":"Defines the color rgb(93, 154, 166).","ref":"Fledex.Color.Names.RAL.html#h220l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l60c25/1","doc":"Defines the color rgb(75, 156, 171).","ref":"Fledex.Color.Names.RAL.html#h220l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l60c30/1","doc":"Defines the color rgb(50, 160, 177).","ref":"Fledex.Color.Names.RAL.html#h220l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l60c35/1","doc":"Defines the color rgb(0, 159, 179).","ref":"Fledex.Color.Names.RAL.html#h220l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l60c40/1","doc":"Defines the color rgb(0, 161, 185).","ref":"Fledex.Color.Names.RAL.html#h220l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l70c05/1","doc":"Defines the color rgb(161, 174, 177).","ref":"Fledex.Color.Names.RAL.html#h220l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l70c10/1","doc":"Defines the color rgb(151, 178, 183).","ref":"Fledex.Color.Names.RAL.html#h220l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l70c15/1","doc":"Defines the color rgb(138, 181, 189).","ref":"Fledex.Color.Names.RAL.html#h220l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l70c20/1","doc":"Defines the color rgb(123, 182, 193).","ref":"Fledex.Color.Names.RAL.html#h220l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l70c25/1","doc":"Defines the color rgb(103, 183, 198).","ref":"Fledex.Color.Names.RAL.html#h220l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l70c30/1","doc":"Defines the color rgb(83, 184, 201).","ref":"Fledex.Color.Names.RAL.html#h220l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l70c35/1","doc":"Defines the color rgb(50, 188, 209).","ref":"Fledex.Color.Names.RAL.html#h220l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l80c05/1","doc":"Defines the color rgb(188, 202, 202).","ref":"Fledex.Color.Names.RAL.html#h220l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l80c10/1","doc":"Defines the color rgb(178, 207, 211).","ref":"Fledex.Color.Names.RAL.html#h220l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l80c15/1","doc":"Defines the color rgb(161, 206, 215).","ref":"Fledex.Color.Names.RAL.html#h220l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l80c20/1","doc":"Defines the color rgb(153, 211, 223).","ref":"Fledex.Color.Names.RAL.html#h220l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l80c25/1","doc":"Defines the color rgb(139, 214, 226).","ref":"Fledex.Color.Names.RAL.html#h220l80c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l85c05/1","doc":"Defines the color rgb(205, 219, 221).","ref":"Fledex.Color.Names.RAL.html#h220l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l85c10/1","doc":"Defines the color rgb(193, 222, 226).","ref":"Fledex.Color.Names.RAL.html#h220l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l85c15/1","doc":"Defines the color rgb(179, 224, 231).","ref":"Fledex.Color.Names.RAL.html#h220l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l90c05/1","doc":"Defines the color rgb(217, 231, 230).","ref":"Fledex.Color.Names.RAL.html#h220l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h220l90c10/1","doc":"Defines the color rgb(207, 234, 233).","ref":"Fledex.Color.Names.RAL.html#h220l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l20c10/1","doc":"Defines the color rgb(28, 51, 57).","ref":"Fledex.Color.Names.RAL.html#h230l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l20c15/1","doc":"Defines the color rgb(17, 53, 63).","ref":"Fledex.Color.Names.RAL.html#h230l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l20c20/1","doc":"Defines the color rgb(0, 52, 66).","ref":"Fledex.Color.Names.RAL.html#h230l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l30c10/1","doc":"Defines the color rgb(55, 75, 82).","ref":"Fledex.Color.Names.RAL.html#h230l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l30c15/1","doc":"Defines the color rgb(38, 75, 86).","ref":"Fledex.Color.Names.RAL.html#h230l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l30c20/1","doc":"Defines the color rgb(15, 77, 92).","ref":"Fledex.Color.Names.RAL.html#h230l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l30c25/1","doc":"Defines the color rgb(0, 79, 99).","ref":"Fledex.Color.Names.RAL.html#h230l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l40c10/1","doc":"Defines the color rgb(74, 97, 105).","ref":"Fledex.Color.Names.RAL.html#h230l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l40c15/1","doc":"Defines the color rgb(63, 98, 110).","ref":"Fledex.Color.Names.RAL.html#h230l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l40c20/1","doc":"Defines the color rgb(46, 102, 118).","ref":"Fledex.Color.Names.RAL.html#h230l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l40c25/1","doc":"Defines the color rgb(2, 102, 123).","ref":"Fledex.Color.Names.RAL.html#h230l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l40c30/1","doc":"Defines the color rgb(0, 105, 129).","ref":"Fledex.Color.Names.RAL.html#h230l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l40c35/1","doc":"Defines the color rgb(0, 107, 136).","ref":"Fledex.Color.Names.RAL.html#h230l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l40c40/1","doc":"Defines the color rgb(0, 107, 139).","ref":"Fledex.Color.Names.RAL.html#h230l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l50c10/1","doc":"Defines the color rgb(99, 122, 130).","ref":"Fledex.Color.Names.RAL.html#h230l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l50c15/1","doc":"Defines the color rgb(87, 126, 137).","ref":"Fledex.Color.Names.RAL.html#h230l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l50c20/1","doc":"Defines the color rgb(73, 128, 144).","ref":"Fledex.Color.Names.RAL.html#h230l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l50c25/1","doc":"Defines the color rgb(53, 128, 148).","ref":"Fledex.Color.Names.RAL.html#h230l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l50c30/1","doc":"Defines the color rgb(0, 132, 157).","ref":"Fledex.Color.Names.RAL.html#h230l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l50c35/1","doc":"Defines the color rgb(0, 132, 160).","ref":"Fledex.Color.Names.RAL.html#h230l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l50c40/1","doc":"Defines the color rgb(0, 133, 167).","ref":"Fledex.Color.Names.RAL.html#h230l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l60c10/1","doc":"Defines the color rgb(126, 150, 159).","ref":"Fledex.Color.Names.RAL.html#h230l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l60c15/1","doc":"Defines the color rgb(113, 150, 162).","ref":"Fledex.Color.Names.RAL.html#h230l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l60c20/1","doc":"Defines the color rgb(98, 153, 170).","ref":"Fledex.Color.Names.RAL.html#h230l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l60c25/1","doc":"Defines the color rgb(78, 154, 176).","ref":"Fledex.Color.Names.RAL.html#h230l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l60c30/1","doc":"Defines the color rgb(57, 155, 180).","ref":"Fledex.Color.Names.RAL.html#h230l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l60c35/1","doc":"Defines the color rgb(0, 159, 189).","ref":"Fledex.Color.Names.RAL.html#h230l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l60c40/1","doc":"Defines the color rgb(0, 160, 195).","ref":"Fledex.Color.Names.RAL.html#h230l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l70c10/1","doc":"Defines the color rgb(155, 178, 186).","ref":"Fledex.Color.Names.RAL.html#h230l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l70c15/1","doc":"Defines the color rgb(138, 179, 191).","ref":"Fledex.Color.Names.RAL.html#h230l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l70c20/1","doc":"Defines the color rgb(124, 181, 198).","ref":"Fledex.Color.Names.RAL.html#h230l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l70c25/1","doc":"Defines the color rgb(111, 183, 204).","ref":"Fledex.Color.Names.RAL.html#h230l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l70c30/1","doc":"Defines the color rgb(91, 185, 210).","ref":"Fledex.Color.Names.RAL.html#h230l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l80c10/1","doc":"Defines the color rgb(179, 205, 212).","ref":"Fledex.Color.Names.RAL.html#h230l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l80c15/1","doc":"Defines the color rgb(166, 204, 216).","ref":"Fledex.Color.Names.RAL.html#h230l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l80c20/1","doc":"Defines the color rgb(155, 208, 225).","ref":"Fledex.Color.Names.RAL.html#h230l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l85c05/1","doc":"Defines the color rgb(208, 220, 222).","ref":"Fledex.Color.Names.RAL.html#h230l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l85c10/1","doc":"Defines the color rgb(194, 220, 227).","ref":"Fledex.Color.Names.RAL.html#h230l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l85c15/1","doc":"Defines the color rgb(185, 222, 233).","ref":"Fledex.Color.Names.RAL.html#h230l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l85c20/1","doc":"Defines the color rgb(172, 225, 240).","ref":"Fledex.Color.Names.RAL.html#h230l85c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h230l90c05/1","doc":"Defines the color rgb(218, 230, 229).","ref":"Fledex.Color.Names.RAL.html#h230l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l20c05/1","doc":"Defines the color rgb(41, 49, 53).","ref":"Fledex.Color.Names.RAL.html#h240l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l20c10/1","doc":"Defines the color rgb(30, 50, 59).","ref":"Fledex.Color.Names.RAL.html#h240l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l20c15/1","doc":"Defines the color rgb(15, 51, 65).","ref":"Fledex.Color.Names.RAL.html#h240l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l20c20/1","doc":"Defines the color rgb(0, 52, 71).","ref":"Fledex.Color.Names.RAL.html#h240l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l20c22/1","doc":"Defines the color rgb(0, 52, 74).","ref":"Fledex.Color.Names.RAL.html#h240l20c22/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l30c05/1","doc":"Defines the color rgb(62, 71, 75).","ref":"Fledex.Color.Names.RAL.html#h240l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l30c10/1","doc":"Defines the color rgb(52, 73, 83).","ref":"Fledex.Color.Names.RAL.html#h240l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l30c15/1","doc":"Defines the color rgb(42, 75, 90).","ref":"Fledex.Color.Names.RAL.html#h240l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l30c20/1","doc":"Defines the color rgb(23, 76, 96).","ref":"Fledex.Color.Names.RAL.html#h240l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l30c25/1","doc":"Defines the color rgb(0, 77, 103).","ref":"Fledex.Color.Names.RAL.html#h240l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l30c30/1","doc":"Defines the color rgb(0, 79, 109).","ref":"Fledex.Color.Names.RAL.html#h240l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l30c35/1","doc":"Defines the color rgb(0, 81, 113).","ref":"Fledex.Color.Names.RAL.html#h240l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l40c05/1","doc":"Defines the color rgb(85, 94, 100).","ref":"Fledex.Color.Names.RAL.html#h240l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l40c10/1","doc":"Defines the color rgb(76, 96, 107).","ref":"Fledex.Color.Names.RAL.html#h240l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l40c15/1","doc":"Defines the color rgb(64, 99, 116).","ref":"Fledex.Color.Names.RAL.html#h240l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l40c20/1","doc":"Defines the color rgb(47, 100, 121).","ref":"Fledex.Color.Names.RAL.html#h240l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l40c25/1","doc":"Defines the color rgb(21, 102, 129).","ref":"Fledex.Color.Names.RAL.html#h240l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l40c30/1","doc":"Defines the color rgb(0, 102, 135).","ref":"Fledex.Color.Names.RAL.html#h240l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l40c35/1","doc":"Defines the color rgb(0, 104, 141).","ref":"Fledex.Color.Names.RAL.html#h240l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l40c40/1","doc":"Defines the color rgb(0, 106, 147).","ref":"Fledex.Color.Names.RAL.html#h240l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l50c05/1","doc":"Defines the color rgb(111, 120, 125).","ref":"Fledex.Color.Names.RAL.html#h240l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l50c10/1","doc":"Defines the color rgb(99, 121, 133).","ref":"Fledex.Color.Names.RAL.html#h240l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l50c15/1","doc":"Defines the color rgb(88, 124, 141).","ref":"Fledex.Color.Names.RAL.html#h240l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l50c20/1","doc":"Defines the color rgb(73, 125, 147).","ref":"Fledex.Color.Names.RAL.html#h240l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l50c25/1","doc":"Defines the color rgb(54, 127, 154).","ref":"Fledex.Color.Names.RAL.html#h240l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l50c30/1","doc":"Defines the color rgb(24, 128, 161).","ref":"Fledex.Color.Names.RAL.html#h240l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l50c35/1","doc":"Defines the color rgb(0, 129, 168).","ref":"Fledex.Color.Names.RAL.html#h240l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l50c40/1","doc":"Defines the color rgb(0, 130, 173).","ref":"Fledex.Color.Names.RAL.html#h240l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l60c05/1","doc":"Defines the color rgb(136, 147, 152).","ref":"Fledex.Color.Names.RAL.html#h240l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l60c10/1","doc":"Defines the color rgb(123, 146, 158).","ref":"Fledex.Color.Names.RAL.html#h240l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l60c15/1","doc":"Defines the color rgb(113, 149, 166).","ref":"Fledex.Color.Names.RAL.html#h240l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l60c20/1","doc":"Defines the color rgb(101, 152, 175).","ref":"Fledex.Color.Names.RAL.html#h240l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l60c25/1","doc":"Defines the color rgb(85, 153, 182).","ref":"Fledex.Color.Names.RAL.html#h240l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l60c30/1","doc":"Defines the color rgb(62, 154, 189).","ref":"Fledex.Color.Names.RAL.html#h240l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l60c35/1","doc":"Defines the color rgb(20, 156, 196).","ref":"Fledex.Color.Names.RAL.html#h240l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l60c40/1","doc":"Defines the color rgb(0, 159, 200).","ref":"Fledex.Color.Names.RAL.html#h240l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l70c05/1","doc":"Defines the color rgb(162, 173, 179).","ref":"Fledex.Color.Names.RAL.html#h240l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l70c10/1","doc":"Defines the color rgb(152, 175, 186).","ref":"Fledex.Color.Names.RAL.html#h240l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l70c15/1","doc":"Defines the color rgb(140, 177, 194).","ref":"Fledex.Color.Names.RAL.html#h240l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l70c20/1","doc":"Defines the color rgb(128, 178, 201).","ref":"Fledex.Color.Names.RAL.html#h240l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l70c25/1","doc":"Defines the color rgb(113, 181, 209).","ref":"Fledex.Color.Names.RAL.html#h240l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l70c30/1","doc":"Defines the color rgb(95, 181, 214).","ref":"Fledex.Color.Names.RAL.html#h240l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l80c05/1","doc":"Defines the color rgb(188, 200, 204).","ref":"Fledex.Color.Names.RAL.html#h240l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l80c10/1","doc":"Defines the color rgb(181, 205, 215).","ref":"Fledex.Color.Names.RAL.html#h240l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l80c15/1","doc":"Defines the color rgb(169, 205, 221).","ref":"Fledex.Color.Names.RAL.html#h240l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l80c20/1","doc":"Defines the color rgb(155, 208, 229).","ref":"Fledex.Color.Names.RAL.html#h240l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l85c05/1","doc":"Defines the color rgb(206, 218, 222).","ref":"Fledex.Color.Names.RAL.html#h240l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l85c10/1","doc":"Defines the color rgb(195, 219, 228).","ref":"Fledex.Color.Names.RAL.html#h240l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l85c15/1","doc":"Defines the color rgb(183, 221, 237).","ref":"Fledex.Color.Names.RAL.html#h240l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l90c05/1","doc":"Defines the color rgb(218, 231, 233).","ref":"Fledex.Color.Names.RAL.html#h240l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h240l90c10/1","doc":"Defines the color rgb(208, 235, 241).","ref":"Fledex.Color.Names.RAL.html#h240l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l20c20/1","doc":"Defines the color rgb(0, 50, 73).","ref":"Fledex.Color.Names.RAL.html#h250l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l20c25/1","doc":"Defines the color rgb(0, 51, 79).","ref":"Fledex.Color.Names.RAL.html#h250l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l30c15/1","doc":"Defines the color rgb(41, 72, 90).","ref":"Fledex.Color.Names.RAL.html#h250l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l30c20/1","doc":"Defines the color rgb(21, 73, 98).","ref":"Fledex.Color.Names.RAL.html#h250l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l30c25/1","doc":"Defines the color rgb(0, 76, 106).","ref":"Fledex.Color.Names.RAL.html#h250l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l30c30/1","doc":"Defines the color rgb(0, 76, 113).","ref":"Fledex.Color.Names.RAL.html#h250l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l40c10/1","doc":"Defines the color rgb(78, 96, 109).","ref":"Fledex.Color.Names.RAL.html#h250l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l40c15/1","doc":"Defines the color rgb(67, 97, 117).","ref":"Fledex.Color.Names.RAL.html#h250l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l40c20/1","doc":"Defines the color rgb(50, 96, 122).","ref":"Fledex.Color.Names.RAL.html#h250l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l40c25/1","doc":"Defines the color rgb(29, 99, 131).","ref":"Fledex.Color.Names.RAL.html#h250l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l40c30/1","doc":"Defines the color rgb(0, 101, 140).","ref":"Fledex.Color.Names.RAL.html#h250l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l40c35/1","doc":"Defines the color rgb(0, 100, 145).","ref":"Fledex.Color.Names.RAL.html#h250l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l40c40/1","doc":"Defines the color rgb(0, 103, 150).","ref":"Fledex.Color.Names.RAL.html#h250l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l50c10/1","doc":"Defines the color rgb(103, 121, 134).","ref":"Fledex.Color.Names.RAL.html#h250l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l50c15/1","doc":"Defines the color rgb(91, 121, 142).","ref":"Fledex.Color.Names.RAL.html#h250l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l50c20/1","doc":"Defines the color rgb(81, 123, 149).","ref":"Fledex.Color.Names.RAL.html#h250l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l50c25/1","doc":"Defines the color rgb(66, 124, 157).","ref":"Fledex.Color.Names.RAL.html#h250l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l50c30/1","doc":"Defines the color rgb(43, 125, 166).","ref":"Fledex.Color.Names.RAL.html#h250l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l50c35/1","doc":"Defines the color rgb(0, 127, 174).","ref":"Fledex.Color.Names.RAL.html#h250l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l50c40/1","doc":"Defines the color rgb(0, 129, 181).","ref":"Fledex.Color.Names.RAL.html#h250l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l60c10/1","doc":"Defines the color rgb(127, 146, 160).","ref":"Fledex.Color.Names.RAL.html#h250l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l60c15/1","doc":"Defines the color rgb(118, 148, 169).","ref":"Fledex.Color.Names.RAL.html#h250l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l60c20/1","doc":"Defines the color rgb(106, 149, 177).","ref":"Fledex.Color.Names.RAL.html#h250l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l60c25/1","doc":"Defines the color rgb(93, 150, 185).","ref":"Fledex.Color.Names.RAL.html#h250l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l60c30/1","doc":"Defines the color rgb(75, 152, 192).","ref":"Fledex.Color.Names.RAL.html#h250l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l60c35/1","doc":"Defines the color rgb(55, 153, 200).","ref":"Fledex.Color.Names.RAL.html#h250l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l60c40/1","doc":"Defines the color rgb(14, 155, 209).","ref":"Fledex.Color.Names.RAL.html#h250l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l70c10/1","doc":"Defines the color rgb(153, 174, 187).","ref":"Fledex.Color.Names.RAL.html#h250l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l70c15/1","doc":"Defines the color rgb(144, 176, 196).","ref":"Fledex.Color.Names.RAL.html#h250l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l70c20/1","doc":"Defines the color rgb(133, 176, 204).","ref":"Fledex.Color.Names.RAL.html#h250l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l70c25/1","doc":"Defines the color rgb(122, 178, 212).","ref":"Fledex.Color.Names.RAL.html#h250l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l70c30/1","doc":"Defines the color rgb(107, 179, 219).","ref":"Fledex.Color.Names.RAL.html#h250l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l80c10/1","doc":"Defines the color rgb(182, 202, 215).","ref":"Fledex.Color.Names.RAL.html#h250l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l80c15/1","doc":"Defines the color rgb(174, 205, 224).","ref":"Fledex.Color.Names.RAL.html#h250l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l80c20/1","doc":"Defines the color rgb(159, 202, 229).","ref":"Fledex.Color.Names.RAL.html#h250l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l85c05/1","doc":"Defines the color rgb(205, 214, 219).","ref":"Fledex.Color.Names.RAL.html#h250l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l85c10/1","doc":"Defines the color rgb(195, 216, 228).","ref":"Fledex.Color.Names.RAL.html#h250l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l85c15/1","doc":"Defines the color rgb(188, 218, 236).","ref":"Fledex.Color.Names.RAL.html#h250l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h250l90c05/1","doc":"Defines the color rgb(218, 227, 231).","ref":"Fledex.Color.Names.RAL.html#h250l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l20c05/1","doc":"Defines the color rgb(43, 48, 54).","ref":"Fledex.Color.Names.RAL.html#h260l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l20c10/1","doc":"Defines the color rgb(36, 49, 61).","ref":"Fledex.Color.Names.RAL.html#h260l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l20c15/1","doc":"Defines the color rgb(21, 48, 67).","ref":"Fledex.Color.Names.RAL.html#h260l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l20c20/1","doc":"Defines the color rgb(9, 50, 74).","ref":"Fledex.Color.Names.RAL.html#h260l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l30c05/1","doc":"Defines the color rgb(64, 70, 77).","ref":"Fledex.Color.Names.RAL.html#h260l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l30c10/1","doc":"Defines the color rgb(58, 72, 86).","ref":"Fledex.Color.Names.RAL.html#h260l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l30c15/1","doc":"Defines the color rgb(49, 72, 92).","ref":"Fledex.Color.Names.RAL.html#h260l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l30c20/1","doc":"Defines the color rgb(38, 73, 99).","ref":"Fledex.Color.Names.RAL.html#h260l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l30c25/1","doc":"Defines the color rgb(17, 74, 107).","ref":"Fledex.Color.Names.RAL.html#h260l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l30c30/1","doc":"Defines the color rgb(0, 76, 115).","ref":"Fledex.Color.Names.RAL.html#h260l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l30c35/1","doc":"Defines the color rgb(0, 77, 124).","ref":"Fledex.Color.Names.RAL.html#h260l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c05/1","doc":"Defines the color rgb(87, 93, 100).","ref":"Fledex.Color.Names.RAL.html#h260l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c10/1","doc":"Defines the color rgb(82, 97, 111).","ref":"Fledex.Color.Names.RAL.html#h260l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c15/1","doc":"Defines the color rgb(75, 97, 118).","ref":"Fledex.Color.Names.RAL.html#h260l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c20/1","doc":"Defines the color rgb(61, 95, 124).","ref":"Fledex.Color.Names.RAL.html#h260l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c25/1","doc":"Defines the color rgb(50, 98, 133).","ref":"Fledex.Color.Names.RAL.html#h260l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c30/1","doc":"Defines the color rgb(33, 99, 139).","ref":"Fledex.Color.Names.RAL.html#h260l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c35/1","doc":"Defines the color rgb(0, 99, 146).","ref":"Fledex.Color.Names.RAL.html#h260l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c40/1","doc":"Defines the color rgb(0, 101, 157).","ref":"Fledex.Color.Names.RAL.html#h260l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l40c45/1","doc":"Defines the color rgb(0, 102, 163).","ref":"Fledex.Color.Names.RAL.html#h260l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l50c05/1","doc":"Defines the color rgb(111, 117, 125).","ref":"Fledex.Color.Names.RAL.html#h260l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l50c10/1","doc":"Defines the color rgb(106, 119, 134).","ref":"Fledex.Color.Names.RAL.html#h260l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l50c15/1","doc":"Defines the color rgb(98, 120, 142).","ref":"Fledex.Color.Names.RAL.html#h260l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l50c20/1","doc":"Defines the color rgb(92, 123, 151).","ref":"Fledex.Color.Names.RAL.html#h260l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l50c25/1","doc":"Defines the color rgb(80, 124, 160).","ref":"Fledex.Color.Names.RAL.html#h260l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l50c30/1","doc":"Defines the color rgb(62, 125, 170).","ref":"Fledex.Color.Names.RAL.html#h260l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l50c35/1","doc":"Defines the color rgb(43, 124, 175).","ref":"Fledex.Color.Names.RAL.html#h260l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l50c40/1","doc":"Defines the color rgb(0, 127, 185).","ref":"Fledex.Color.Names.RAL.html#h260l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l60c05/1","doc":"Defines the color rgb(138, 144, 152).","ref":"Fledex.Color.Names.RAL.html#h260l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l60c10/1","doc":"Defines the color rgb(131, 145, 160).","ref":"Fledex.Color.Names.RAL.html#h260l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l60c15/1","doc":"Defines the color rgb(126, 149, 171).","ref":"Fledex.Color.Names.RAL.html#h260l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l60c20/1","doc":"Defines the color rgb(116, 148, 177).","ref":"Fledex.Color.Names.RAL.html#h260l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l60c25/1","doc":"Defines the color rgb(106, 150, 186).","ref":"Fledex.Color.Names.RAL.html#h260l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l60c30/1","doc":"Defines the color rgb(94, 150, 195).","ref":"Fledex.Color.Names.RAL.html#h260l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l60c35/1","doc":"Defines the color rgb(79, 152, 203).","ref":"Fledex.Color.Names.RAL.html#h260l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l70c05/1","doc":"Defines the color rgb(167, 174, 180).","ref":"Fledex.Color.Names.RAL.html#h260l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l70c10/1","doc":"Defines the color rgb(160, 174, 188).","ref":"Fledex.Color.Names.RAL.html#h260l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l70c15/1","doc":"Defines the color rgb(150, 174, 197).","ref":"Fledex.Color.Names.RAL.html#h260l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l70c20/1","doc":"Defines the color rgb(143, 176, 206).","ref":"Fledex.Color.Names.RAL.html#h260l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l70c25/1","doc":"Defines the color rgb(131, 176, 214).","ref":"Fledex.Color.Names.RAL.html#h260l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l80c05/1","doc":"Defines the color rgb(192, 200, 207).","ref":"Fledex.Color.Names.RAL.html#h260l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l80c10/1","doc":"Defines the color rgb(185, 201, 215).","ref":"Fledex.Color.Names.RAL.html#h260l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l80c15/1","doc":"Defines the color rgb(177, 201, 223).","ref":"Fledex.Color.Names.RAL.html#h260l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l85c05/1","doc":"Defines the color rgb(207, 213, 219).","ref":"Fledex.Color.Names.RAL.html#h260l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l85c10/1","doc":"Defines the color rgb(201, 217, 231).","ref":"Fledex.Color.Names.RAL.html#h260l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h260l90c05/1","doc":"Defines the color rgb(220, 227, 231).","ref":"Fledex.Color.Names.RAL.html#h260l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l20c20/1","doc":"Defines the color rgb(17, 47, 75).","ref":"Fledex.Color.Names.RAL.html#h270l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l20c25/1","doc":"Defines the color rgb(0, 46, 81).","ref":"Fledex.Color.Names.RAL.html#h270l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l20c29/1","doc":"Defines the color rgb(0, 49, 90).","ref":"Fledex.Color.Names.RAL.html#h270l20c29/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l30c15/1","doc":"Defines the color rgb(54, 71, 92).","ref":"Fledex.Color.Names.RAL.html#h270l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l30c20/1","doc":"Defines the color rgb(46, 71, 100).","ref":"Fledex.Color.Names.RAL.html#h270l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l30c25/1","doc":"Defines the color rgb(36, 72, 108).","ref":"Fledex.Color.Names.RAL.html#h270l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l30c30/1","doc":"Defines the color rgb(16, 71, 115).","ref":"Fledex.Color.Names.RAL.html#h270l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l30c35/1","doc":"Defines the color rgb(0, 71, 122).","ref":"Fledex.Color.Names.RAL.html#h270l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l30c40/1","doc":"Defines the color rgb(0, 72, 131).","ref":"Fledex.Color.Names.RAL.html#h270l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l40c15/1","doc":"Defines the color rgb(79, 95, 118).","ref":"Fledex.Color.Names.RAL.html#h270l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l40c20/1","doc":"Defines the color rgb(70, 95, 126).","ref":"Fledex.Color.Names.RAL.html#h270l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l40c25/1","doc":"Defines the color rgb(63, 96, 134).","ref":"Fledex.Color.Names.RAL.html#h270l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l40c30/1","doc":"Defines the color rgb(51, 95, 141).","ref":"Fledex.Color.Names.RAL.html#h270l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l40c35/1","doc":"Defines the color rgb(33, 95, 150).","ref":"Fledex.Color.Names.RAL.html#h270l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l40c40/1","doc":"Defines the color rgb(0, 95, 157).","ref":"Fledex.Color.Names.RAL.html#h270l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l50c10/1","doc":"Defines the color rgb(109, 120, 136).","ref":"Fledex.Color.Names.RAL.html#h270l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l50c15/1","doc":"Defines the color rgb(105, 121, 145).","ref":"Fledex.Color.Names.RAL.html#h270l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l50c20/1","doc":"Defines the color rgb(96, 121, 153).","ref":"Fledex.Color.Names.RAL.html#h270l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l50c25/1","doc":"Defines the color rgb(90, 122, 162).","ref":"Fledex.Color.Names.RAL.html#h270l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l50c30/1","doc":"Defines the color rgb(78, 120, 169).","ref":"Fledex.Color.Names.RAL.html#h270l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l50c35/1","doc":"Defines the color rgb(66, 120, 175).","ref":"Fledex.Color.Names.RAL.html#h270l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l50c40/1","doc":"Defines the color rgb(50, 122, 185).","ref":"Fledex.Color.Names.RAL.html#h270l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l60c10/1","doc":"Defines the color rgb(133, 145, 162).","ref":"Fledex.Color.Names.RAL.html#h270l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l60c15/1","doc":"Defines the color rgb(130, 147, 172).","ref":"Fledex.Color.Names.RAL.html#h270l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l60c20/1","doc":"Defines the color rgb(123, 147, 180).","ref":"Fledex.Color.Names.RAL.html#h270l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l60c25/1","doc":"Defines the color rgb(116, 148, 188).","ref":"Fledex.Color.Names.RAL.html#h270l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l60c30/1","doc":"Defines the color rgb(107, 148, 197).","ref":"Fledex.Color.Names.RAL.html#h270l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l60c35/1","doc":"Defines the color rgb(95, 147, 204).","ref":"Fledex.Color.Names.RAL.html#h270l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l70c10/1","doc":"Defines the color rgb(162, 174, 191).","ref":"Fledex.Color.Names.RAL.html#h270l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l70c15/1","doc":"Defines the color rgb(156, 173, 199).","ref":"Fledex.Color.Names.RAL.html#h270l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l70c20/1","doc":"Defines the color rgb(150, 174, 208).","ref":"Fledex.Color.Names.RAL.html#h270l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l70c25/1","doc":"Defines the color rgb(140, 172, 214).","ref":"Fledex.Color.Names.RAL.html#h270l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l80c10/1","doc":"Defines the color rgb(190, 200, 216).","ref":"Fledex.Color.Names.RAL.html#h270l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l80c15/1","doc":"Defines the color rgb(182, 199, 224).","ref":"Fledex.Color.Names.RAL.html#h270l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l85c05/1","doc":"Defines the color rgb(210, 214, 219).","ref":"Fledex.Color.Names.RAL.html#h270l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l85c10/1","doc":"Defines the color rgb(204, 214, 230).","ref":"Fledex.Color.Names.RAL.html#h270l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l85c15/1","doc":"Defines the color rgb(197, 214, 238).","ref":"Fledex.Color.Names.RAL.html#h270l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h270l90c05/1","doc":"Defines the color rgb(223, 227, 232).","ref":"Fledex.Color.Names.RAL.html#h270l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l20c05/1","doc":"Defines the color rgb(49, 50, 56).","ref":"Fledex.Color.Names.RAL.html#h280l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l20c10/1","doc":"Defines the color rgb(43, 48, 62).","ref":"Fledex.Color.Names.RAL.html#h280l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l20c15/1","doc":"Defines the color rgb(38, 49, 69).","ref":"Fledex.Color.Names.RAL.html#h280l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l20c20/1","doc":"Defines the color rgb(32, 47, 75).","ref":"Fledex.Color.Names.RAL.html#h280l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l20c25/1","doc":"Defines the color rgb(27, 48, 83).","ref":"Fledex.Color.Names.RAL.html#h280l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l20c30/1","doc":"Defines the color rgb(13, 47, 90).","ref":"Fledex.Color.Names.RAL.html#h280l20c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l30c05/1","doc":"Defines the color rgb(67, 69, 76).","ref":"Fledex.Color.Names.RAL.html#h280l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l30c10/1","doc":"Defines the color rgb(65, 71, 86).","ref":"Fledex.Color.Names.RAL.html#h280l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l30c15/1","doc":"Defines the color rgb(61, 71, 94).","ref":"Fledex.Color.Names.RAL.html#h280l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l30c20/1","doc":"Defines the color rgb(56, 72, 102).","ref":"Fledex.Color.Names.RAL.html#h280l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l30c25/1","doc":"Defines the color rgb(51, 71, 109).","ref":"Fledex.Color.Names.RAL.html#h280l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l30c30/1","doc":"Defines the color rgb(38, 70, 116).","ref":"Fledex.Color.Names.RAL.html#h280l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l30c35/1","doc":"Defines the color rgb(33, 70, 122).","ref":"Fledex.Color.Names.RAL.html#h280l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l30c40/1","doc":"Defines the color rgb(19, 70, 130).","ref":"Fledex.Color.Names.RAL.html#h280l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c05/1","doc":"Defines the color rgb(91, 93, 101).","ref":"Fledex.Color.Names.RAL.html#h280l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c10/1","doc":"Defines the color rgb(88, 93, 109).","ref":"Fledex.Color.Names.RAL.html#h280l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c15/1","doc":"Defines the color rgb(84, 94, 118).","ref":"Fledex.Color.Names.RAL.html#h280l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c20/1","doc":"Defines the color rgb(79, 94, 126).","ref":"Fledex.Color.Names.RAL.html#h280l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c25/1","doc":"Defines the color rgb(76, 94, 135).","ref":"Fledex.Color.Names.RAL.html#h280l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c30/1","doc":"Defines the color rgb(68, 94, 141).","ref":"Fledex.Color.Names.RAL.html#h280l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c35/1","doc":"Defines the color rgb(60, 94, 149).","ref":"Fledex.Color.Names.RAL.html#h280l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c40/1","doc":"Defines the color rgb(46, 93, 157).","ref":"Fledex.Color.Names.RAL.html#h280l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l40c45/1","doc":"Defines the color rgb(30, 93, 165).","ref":"Fledex.Color.Names.RAL.html#h280l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l50c05/1","doc":"Defines the color rgb(115, 119, 127).","ref":"Fledex.Color.Names.RAL.html#h280l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l50c10/1","doc":"Defines the color rgb(113, 119, 135).","ref":"Fledex.Color.Names.RAL.html#h280l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l50c15/1","doc":"Defines the color rgb(109, 119, 143).","ref":"Fledex.Color.Names.RAL.html#h280l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l50c20/1","doc":"Defines the color rgb(104, 118, 152).","ref":"Fledex.Color.Names.RAL.html#h280l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l50c25/1","doc":"Defines the color rgb(100, 119, 160).","ref":"Fledex.Color.Names.RAL.html#h280l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l50c30/1","doc":"Defines the color rgb(95, 118, 168).","ref":"Fledex.Color.Names.RAL.html#h280l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l50c35/1","doc":"Defines the color rgb(87, 118, 175).","ref":"Fledex.Color.Names.RAL.html#h280l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l50c40/1","doc":"Defines the color rgb(80, 119, 186).","ref":"Fledex.Color.Names.RAL.html#h280l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l60c05/1","doc":"Defines the color rgb(141, 144, 152).","ref":"Fledex.Color.Names.RAL.html#h280l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l60c10/1","doc":"Defines the color rgb(137, 143, 160).","ref":"Fledex.Color.Names.RAL.html#h280l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l60c15/1","doc":"Defines the color rgb(134, 143, 169).","ref":"Fledex.Color.Names.RAL.html#h280l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l60c20/1","doc":"Defines the color rgb(131, 144, 179).","ref":"Fledex.Color.Names.RAL.html#h280l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l60c25/1","doc":"Defines the color rgb(126, 143, 187).","ref":"Fledex.Color.Names.RAL.html#h280l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l60c30/1","doc":"Defines the color rgb(121, 144, 194).","ref":"Fledex.Color.Names.RAL.html#h280l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l60c35/1","doc":"Defines the color rgb(115, 145, 204).","ref":"Fledex.Color.Names.RAL.html#h280l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l70c05/1","doc":"Defines the color rgb(167, 169, 177).","ref":"Fledex.Color.Names.RAL.html#h280l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l70c10/1","doc":"Defines the color rgb(166, 172, 188).","ref":"Fledex.Color.Names.RAL.html#h280l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l70c15/1","doc":"Defines the color rgb(162, 172, 197).","ref":"Fledex.Color.Names.RAL.html#h280l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l70c20/1","doc":"Defines the color rgb(158, 171, 208).","ref":"Fledex.Color.Names.RAL.html#h280l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l70c25/1","doc":"Defines the color rgb(155, 172, 216).","ref":"Fledex.Color.Names.RAL.html#h280l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l80c05/1","doc":"Defines the color rgb(198, 200, 208).","ref":"Fledex.Color.Names.RAL.html#h280l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l80c10/1","doc":"Defines the color rgb(193, 199, 215).","ref":"Fledex.Color.Names.RAL.html#h280l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l80c15/1","doc":"Defines the color rgb(188, 198, 223).","ref":"Fledex.Color.Names.RAL.html#h280l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l85c05/1","doc":"Defines the color rgb(211, 215, 220).","ref":"Fledex.Color.Names.RAL.html#h280l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l85c10/1","doc":"Defines the color rgb(206, 214, 230).","ref":"Fledex.Color.Names.RAL.html#h280l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l90c05/1","doc":"Defines the color rgb(223, 227, 232).","ref":"Fledex.Color.Names.RAL.html#h280l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h280l93c05/1","doc":"Defines the color rgb(234, 237, 242).","ref":"Fledex.Color.Names.RAL.html#h280l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l20c10/1","doc":"Defines the color rgb(39, 42, 59).","ref":"Fledex.Color.Names.RAL.html#h290l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l20c15/1","doc":"Defines the color rgb(43, 44, 66).","ref":"Fledex.Color.Names.RAL.html#h290l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l20c20/1","doc":"Defines the color rgb(42, 46, 76).","ref":"Fledex.Color.Names.RAL.html#h290l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l20c25/1","doc":"Defines the color rgb(36, 44, 82).","ref":"Fledex.Color.Names.RAL.html#h290l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l20c30/1","doc":"Defines the color rgb(29, 42, 88).","ref":"Fledex.Color.Names.RAL.html#h290l20c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l20c35/1","doc":"Defines the color rgb(25, 41, 97).","ref":"Fledex.Color.Names.RAL.html#h290l20c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l30c10/1","doc":"Defines the color rgb(67, 66, 82).","ref":"Fledex.Color.Names.RAL.html#h290l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l30c15/1","doc":"Defines the color rgb(65, 67, 91).","ref":"Fledex.Color.Names.RAL.html#h290l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l30c20/1","doc":"Defines the color rgb(61, 65, 97).","ref":"Fledex.Color.Names.RAL.html#h290l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l30c25/1","doc":"Defines the color rgb(60, 65, 106).","ref":"Fledex.Color.Names.RAL.html#h290l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l30c30/1","doc":"Defines the color rgb(56, 65, 114).","ref":"Fledex.Color.Names.RAL.html#h290l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l30c35/1","doc":"Defines the color rgb(53, 66, 123).","ref":"Fledex.Color.Names.RAL.html#h290l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l30c40/1","doc":"Defines the color rgb(46, 65, 130).","ref":"Fledex.Color.Names.RAL.html#h290l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l40c10/1","doc":"Defines the color rgb(91, 91, 108).","ref":"Fledex.Color.Names.RAL.html#h290l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l40c15/1","doc":"Defines the color rgb(90, 91, 116).","ref":"Fledex.Color.Names.RAL.html#h290l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l40c20/1","doc":"Defines the color rgb(86, 90, 125).","ref":"Fledex.Color.Names.RAL.html#h290l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l40c25/1","doc":"Defines the color rgb(84, 88, 131).","ref":"Fledex.Color.Names.RAL.html#h290l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l40c30/1","doc":"Defines the color rgb(80, 87, 139).","ref":"Fledex.Color.Names.RAL.html#h290l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l40c35/1","doc":"Defines the color rgb(76, 86, 146).","ref":"Fledex.Color.Names.RAL.html#h290l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l40c40/1","doc":"Defines the color rgb(73, 88, 156).","ref":"Fledex.Color.Names.RAL.html#h290l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l40c45/1","doc":"Defines the color rgb(65, 87, 162).","ref":"Fledex.Color.Names.RAL.html#h290l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l50c10/1","doc":"Defines the color rgb(115, 116, 134).","ref":"Fledex.Color.Names.RAL.html#h290l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l50c15/1","doc":"Defines the color rgb(113, 115, 140).","ref":"Fledex.Color.Names.RAL.html#h290l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l50c20/1","doc":"Defines the color rgb(110, 113, 150).","ref":"Fledex.Color.Names.RAL.html#h290l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l50c25/1","doc":"Defines the color rgb(111, 114, 159).","ref":"Fledex.Color.Names.RAL.html#h290l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l50c30/1","doc":"Defines the color rgb(108, 113, 166).","ref":"Fledex.Color.Names.RAL.html#h290l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l50c35/1","doc":"Defines the color rgb(103, 112, 174).","ref":"Fledex.Color.Names.RAL.html#h290l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l50c40/1","doc":"Defines the color rgb(99, 112, 182).","ref":"Fledex.Color.Names.RAL.html#h290l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l60c10/1","doc":"Defines the color rgb(140, 141, 161).","ref":"Fledex.Color.Names.RAL.html#h290l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l60c15/1","doc":"Defines the color rgb(140, 141, 168).","ref":"Fledex.Color.Names.RAL.html#h290l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l60c20/1","doc":"Defines the color rgb(135, 139, 177).","ref":"Fledex.Color.Names.RAL.html#h290l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l60c25/1","doc":"Defines the color rgb(136, 140, 186).","ref":"Fledex.Color.Names.RAL.html#h290l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l60c30/1","doc":"Defines the color rgb(133, 139, 194).","ref":"Fledex.Color.Names.RAL.html#h290l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l60c35/1","doc":"Defines the color rgb(126, 137, 200).","ref":"Fledex.Color.Names.RAL.html#h290l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l70c10/1","doc":"Defines the color rgb(169, 170, 189).","ref":"Fledex.Color.Names.RAL.html#h290l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l70c15/1","doc":"Defines the color rgb(166, 168, 197).","ref":"Fledex.Color.Names.RAL.html#h290l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l70c20/1","doc":"Defines the color rgb(163, 167, 204).","ref":"Fledex.Color.Names.RAL.html#h290l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l70c25/1","doc":"Defines the color rgb(161, 166, 214).","ref":"Fledex.Color.Names.RAL.html#h290l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l80c10/1","doc":"Defines the color rgb(195, 196, 214).","ref":"Fledex.Color.Names.RAL.html#h290l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l80c15/1","doc":"Defines the color rgb(195, 196, 221).","ref":"Fledex.Color.Names.RAL.html#h290l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l85c05/1","doc":"Defines the color rgb(214, 215, 219).","ref":"Fledex.Color.Names.RAL.html#h290l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l85c10/1","doc":"Defines the color rgb(209, 213, 234).","ref":"Fledex.Color.Names.RAL.html#h290l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l90c05/1","doc":"Defines the color rgb(226, 227, 233).","ref":"Fledex.Color.Names.RAL.html#h290l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h290l93c05/1","doc":"Defines the color rgb(234, 236, 241).","ref":"Fledex.Color.Names.RAL.html#h290l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l20c05/1","doc":"Defines the color rgb(49, 47, 54).","ref":"Fledex.Color.Names.RAL.html#h300l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l20c10/1","doc":"Defines the color rgb(47, 43, 58).","ref":"Fledex.Color.Names.RAL.html#h300l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l20c15/1","doc":"Defines the color rgb(47, 42, 65).","ref":"Fledex.Color.Names.RAL.html#h300l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l20c20/1","doc":"Defines the color rgb(46, 40, 72).","ref":"Fledex.Color.Names.RAL.html#h300l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l20c25/1","doc":"Defines the color rgb(44, 40, 76).","ref":"Fledex.Color.Names.RAL.html#h300l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l20c30/1","doc":"Defines the color rgb(42, 39, 86).","ref":"Fledex.Color.Names.RAL.html#h300l20c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l30c05/1","doc":"Defines the color rgb(70, 68, 76).","ref":"Fledex.Color.Names.RAL.html#h300l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l30c10/1","doc":"Defines the color rgb(71, 67, 84).","ref":"Fledex.Color.Names.RAL.html#h300l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l30c15/1","doc":"Defines the color rgb(70, 65, 89).","ref":"Fledex.Color.Names.RAL.html#h300l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l30c20/1","doc":"Defines the color rgb(70, 63, 96).","ref":"Fledex.Color.Names.RAL.html#h300l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l30c25/1","doc":"Defines the color rgb(70, 63, 103).","ref":"Fledex.Color.Names.RAL.html#h300l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l30c30/1","doc":"Defines the color rgb(69, 62, 110).","ref":"Fledex.Color.Names.RAL.html#h300l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l30c35/1","doc":"Defines the color rgb(68, 62, 117).","ref":"Fledex.Color.Names.RAL.html#h300l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l30c40/1","doc":"Defines the color rgb(65, 60, 123).","ref":"Fledex.Color.Names.RAL.html#h300l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c05/1","doc":"Defines the color rgb(95, 93, 100).","ref":"Fledex.Color.Names.RAL.html#h300l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c10/1","doc":"Defines the color rgb(94, 90, 106).","ref":"Fledex.Color.Names.RAL.html#h300l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c15/1","doc":"Defines the color rgb(94, 88, 113).","ref":"Fledex.Color.Names.RAL.html#h300l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c20/1","doc":"Defines the color rgb(95, 87, 121).","ref":"Fledex.Color.Names.RAL.html#h300l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c25/1","doc":"Defines the color rgb(95, 86, 128).","ref":"Fledex.Color.Names.RAL.html#h300l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c30/1","doc":"Defines the color rgb(94, 85, 135).","ref":"Fledex.Color.Names.RAL.html#h300l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c35/1","doc":"Defines the color rgb(94, 84, 141).","ref":"Fledex.Color.Names.RAL.html#h300l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c40/1","doc":"Defines the color rgb(90, 82, 147).","ref":"Fledex.Color.Names.RAL.html#h300l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l40c45/1","doc":"Defines the color rgb(89, 82, 156).","ref":"Fledex.Color.Names.RAL.html#h300l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l50c05/1","doc":"Defines the color rgb(119, 117, 125).","ref":"Fledex.Color.Names.RAL.html#h300l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l50c10/1","doc":"Defines the color rgb(120, 115, 132).","ref":"Fledex.Color.Names.RAL.html#h300l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l50c15/1","doc":"Defines the color rgb(120, 114, 140).","ref":"Fledex.Color.Names.RAL.html#h300l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l50c20/1","doc":"Defines the color rgb(120, 112, 147).","ref":"Fledex.Color.Names.RAL.html#h300l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l50c25/1","doc":"Defines the color rgb(119, 111, 154).","ref":"Fledex.Color.Names.RAL.html#h300l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l50c30/1","doc":"Defines the color rgb(119, 110, 162).","ref":"Fledex.Color.Names.RAL.html#h300l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l50c35/1","doc":"Defines the color rgb(120, 109, 170).","ref":"Fledex.Color.Names.RAL.html#h300l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l50c40/1","doc":"Defines the color rgb(118, 108, 176).","ref":"Fledex.Color.Names.RAL.html#h300l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l60c05/1","doc":"Defines the color rgb(145, 144, 152).","ref":"Fledex.Color.Names.RAL.html#h300l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l60c10/1","doc":"Defines the color rgb(146, 141, 159).","ref":"Fledex.Color.Names.RAL.html#h300l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l60c15/1","doc":"Defines the color rgb(146, 139, 166).","ref":"Fledex.Color.Names.RAL.html#h300l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l60c20/1","doc":"Defines the color rgb(146, 138, 174).","ref":"Fledex.Color.Names.RAL.html#h300l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l60c25/1","doc":"Defines the color rgb(145, 136, 181).","ref":"Fledex.Color.Names.RAL.html#h300l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l60c30/1","doc":"Defines the color rgb(145, 135, 189).","ref":"Fledex.Color.Names.RAL.html#h300l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l60c35/1","doc":"Defines the color rgb(144, 133, 196).","ref":"Fledex.Color.Names.RAL.html#h300l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l70c05/1","doc":"Defines the color rgb(172, 170, 179).","ref":"Fledex.Color.Names.RAL.html#h300l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l70c10/1","doc":"Defines the color rgb(173, 167, 185).","ref":"Fledex.Color.Names.RAL.html#h300l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l70c15/1","doc":"Defines the color rgb(173, 166, 194).","ref":"Fledex.Color.Names.RAL.html#h300l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l70c20/1","doc":"Defines the color rgb(174, 166, 201).","ref":"Fledex.Color.Names.RAL.html#h300l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l70c25/1","doc":"Defines the color rgb(173, 163, 209).","ref":"Fledex.Color.Names.RAL.html#h300l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l80c05/1","doc":"Defines the color rgb(200, 198, 206).","ref":"Fledex.Color.Names.RAL.html#h300l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l80c10/1","doc":"Defines the color rgb(198, 195, 214).","ref":"Fledex.Color.Names.RAL.html#h300l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l80c15/1","doc":"Defines the color rgb(201, 194, 221).","ref":"Fledex.Color.Names.RAL.html#h300l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l85c05/1","doc":"Defines the color rgb(215, 214, 220).","ref":"Fledex.Color.Names.RAL.html#h300l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l85c10/1","doc":"Defines the color rgb(217, 211, 229).","ref":"Fledex.Color.Names.RAL.html#h300l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h300l90c05/1","doc":"Defines the color rgb(228, 227, 233).","ref":"Fledex.Color.Names.RAL.html#h300l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l20c20/1","doc":"Defines the color rgb(56, 43, 70).","ref":"Fledex.Color.Names.RAL.html#h310l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l20c25/1","doc":"Defines the color rgb(58, 40, 76).","ref":"Fledex.Color.Names.RAL.html#h310l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l20c30/1","doc":"Defines the color rgb(55, 34, 82).","ref":"Fledex.Color.Names.RAL.html#h310l20c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l30c15/1","doc":"Defines the color rgb(78, 68, 89).","ref":"Fledex.Color.Names.RAL.html#h310l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l30c20/1","doc":"Defines the color rgb(76, 63, 93).","ref":"Fledex.Color.Names.RAL.html#h310l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l30c25/1","doc":"Defines the color rgb(81, 62, 100).","ref":"Fledex.Color.Names.RAL.html#h310l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l30c30/1","doc":"Defines the color rgb(83, 61, 107).","ref":"Fledex.Color.Names.RAL.html#h310l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l30c35/1","doc":"Defines the color rgb(81, 59, 110).","ref":"Fledex.Color.Names.RAL.html#h310l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l30c40/1","doc":"Defines the color rgb(85, 58, 118).","ref":"Fledex.Color.Names.RAL.html#h310l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l40c10/1","doc":"Defines the color rgb(100, 91, 107).","ref":"Fledex.Color.Names.RAL.html#h310l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l40c15/1","doc":"Defines the color rgb(103, 91, 114).","ref":"Fledex.Color.Names.RAL.html#h310l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l40c20/1","doc":"Defines the color rgb(105, 90, 120).","ref":"Fledex.Color.Names.RAL.html#h310l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l40c25/1","doc":"Defines the color rgb(106, 87, 127).","ref":"Fledex.Color.Names.RAL.html#h310l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l40c30/1","doc":"Defines the color rgb(106, 83, 131).","ref":"Fledex.Color.Names.RAL.html#h310l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l40c35/1","doc":"Defines the color rgb(108, 83, 137).","ref":"Fledex.Color.Names.RAL.html#h310l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l40c40/1","doc":"Defines the color rgb(111, 83, 144).","ref":"Fledex.Color.Names.RAL.html#h310l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l50c10/1","doc":"Defines the color rgb(125, 116, 133).","ref":"Fledex.Color.Names.RAL.html#h310l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l50c15/1","doc":"Defines the color rgb(126, 115, 139).","ref":"Fledex.Color.Names.RAL.html#h310l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l50c20/1","doc":"Defines the color rgb(130, 113, 145).","ref":"Fledex.Color.Names.RAL.html#h310l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l50c25/1","doc":"Defines the color rgb(132, 112, 152).","ref":"Fledex.Color.Names.RAL.html#h310l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l50c30/1","doc":"Defines the color rgb(133, 109, 158).","ref":"Fledex.Color.Names.RAL.html#h310l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l50c35/1","doc":"Defines the color rgb(132, 107, 163).","ref":"Fledex.Color.Names.RAL.html#h310l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l50c40/1","doc":"Defines the color rgb(134, 106, 170).","ref":"Fledex.Color.Names.RAL.html#h310l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l60c10/1","doc":"Defines the color rgb(149, 140, 158).","ref":"Fledex.Color.Names.RAL.html#h310l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l60c15/1","doc":"Defines the color rgb(153, 139, 165).","ref":"Fledex.Color.Names.RAL.html#h310l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l60c20/1","doc":"Defines the color rgb(156, 138, 171).","ref":"Fledex.Color.Names.RAL.html#h310l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l60c25/1","doc":"Defines the color rgb(158, 136, 177).","ref":"Fledex.Color.Names.RAL.html#h310l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l60c30/1","doc":"Defines the color rgb(159, 134, 183).","ref":"Fledex.Color.Names.RAL.html#h310l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l60c35/1","doc":"Defines the color rgb(161, 131, 192).","ref":"Fledex.Color.Names.RAL.html#h310l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l70c10/1","doc":"Defines the color rgb(177, 167, 183).","ref":"Fledex.Color.Names.RAL.html#h310l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l70c15/1","doc":"Defines the color rgb(180, 166, 191).","ref":"Fledex.Color.Names.RAL.html#h310l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l70c20/1","doc":"Defines the color rgb(181, 163, 197).","ref":"Fledex.Color.Names.RAL.html#h310l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l70c25/1","doc":"Defines the color rgb(183, 162, 204).","ref":"Fledex.Color.Names.RAL.html#h310l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l80c10/1","doc":"Defines the color rgb(203, 194, 211).","ref":"Fledex.Color.Names.RAL.html#h310l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l80c15/1","doc":"Defines the color rgb(207, 193, 218).","ref":"Fledex.Color.Names.RAL.html#h310l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l85c05/1","doc":"Defines the color rgb(215, 213, 219).","ref":"Fledex.Color.Names.RAL.html#h310l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l85c10/1","doc":"Defines the color rgb(220, 211, 227).","ref":"Fledex.Color.Names.RAL.html#h310l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h310l90c05/1","doc":"Defines the color rgb(231, 227, 231).","ref":"Fledex.Color.Names.RAL.html#h310l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l20c05/1","doc":"Defines the color rgb(53, 47, 54).","ref":"Fledex.Color.Names.RAL.html#h320l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l20c10/1","doc":"Defines the color rgb(55, 42, 56).","ref":"Fledex.Color.Names.RAL.html#h320l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l20c15/1","doc":"Defines the color rgb(56, 40, 61).","ref":"Fledex.Color.Names.RAL.html#h320l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l20c20/1","doc":"Defines the color rgb(59, 39, 65).","ref":"Fledex.Color.Names.RAL.html#h320l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l20c25/1","doc":"Defines the color rgb(60, 34, 70).","ref":"Fledex.Color.Names.RAL.html#h320l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l30c05/1","doc":"Defines the color rgb(73, 67, 74).","ref":"Fledex.Color.Names.RAL.html#h320l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l30c10/1","doc":"Defines the color rgb(77, 64, 79).","ref":"Fledex.Color.Names.RAL.html#h320l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l30c15/1","doc":"Defines the color rgb(79, 60, 82).","ref":"Fledex.Color.Names.RAL.html#h320l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l30c20/1","doc":"Defines the color rgb(83, 57, 88).","ref":"Fledex.Color.Names.RAL.html#h320l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l30c25/1","doc":"Defines the color rgb(87, 56, 94).","ref":"Fledex.Color.Names.RAL.html#h320l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l30c30/1","doc":"Defines the color rgb(88, 53, 99).","ref":"Fledex.Color.Names.RAL.html#h320l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l30c35/1","doc":"Defines the color rgb(90, 52, 104).","ref":"Fledex.Color.Names.RAL.html#h320l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l30c37/1","doc":"Defines the color rgb(94, 51, 109).","ref":"Fledex.Color.Names.RAL.html#h320l30c37/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l40c05/1","doc":"Defines the color rgb(98, 92, 99).","ref":"Fledex.Color.Names.RAL.html#h320l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l40c10/1","doc":"Defines the color rgb(101, 88, 103).","ref":"Fledex.Color.Names.RAL.html#h320l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l40c15/1","doc":"Defines the color rgb(105, 87, 109).","ref":"Fledex.Color.Names.RAL.html#h320l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l40c20/1","doc":"Defines the color rgb(108, 84, 114).","ref":"Fledex.Color.Names.RAL.html#h320l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l40c25/1","doc":"Defines the color rgb(110, 81, 120).","ref":"Fledex.Color.Names.RAL.html#h320l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l40c30/1","doc":"Defines the color rgb(114, 76, 123).","ref":"Fledex.Color.Names.RAL.html#h320l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l40c35/1","doc":"Defines the color rgb(117, 74, 128).","ref":"Fledex.Color.Names.RAL.html#h320l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l40c40/1","doc":"Defines the color rgb(120, 72, 136).","ref":"Fledex.Color.Names.RAL.html#h320l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l50c05/1","doc":"Defines the color rgb(120, 115, 122).","ref":"Fledex.Color.Names.RAL.html#h320l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l50c10/1","doc":"Defines the color rgb(125, 112, 129).","ref":"Fledex.Color.Names.RAL.html#h320l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l50c15/1","doc":"Defines the color rgb(128, 110, 133).","ref":"Fledex.Color.Names.RAL.html#h320l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l50c20/1","doc":"Defines the color rgb(135, 109, 140).","ref":"Fledex.Color.Names.RAL.html#h320l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l50c25/1","doc":"Defines the color rgb(136, 104, 145).","ref":"Fledex.Color.Names.RAL.html#h320l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l50c30/1","doc":"Defines the color rgb(140, 104, 151).","ref":"Fledex.Color.Names.RAL.html#h320l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l50c35/1","doc":"Defines the color rgb(143, 98, 154).","ref":"Fledex.Color.Names.RAL.html#h320l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l50c40/1","doc":"Defines the color rgb(146, 100, 162).","ref":"Fledex.Color.Names.RAL.html#h320l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l60c05/1","doc":"Defines the color rgb(148, 142, 150).","ref":"Fledex.Color.Names.RAL.html#h320l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l60c10/1","doc":"Defines the color rgb(152, 140, 155).","ref":"Fledex.Color.Names.RAL.html#h320l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l60c15/1","doc":"Defines the color rgb(156, 137, 161).","ref":"Fledex.Color.Names.RAL.html#h320l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l60c20/1","doc":"Defines the color rgb(160, 133, 166).","ref":"Fledex.Color.Names.RAL.html#h320l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l60c25/1","doc":"Defines the color rgb(163, 131, 172).","ref":"Fledex.Color.Names.RAL.html#h320l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l60c30/1","doc":"Defines the color rgb(167, 128, 178).","ref":"Fledex.Color.Names.RAL.html#h320l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l60c35/1","doc":"Defines the color rgb(169, 126, 182).","ref":"Fledex.Color.Names.RAL.html#h320l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l70c05/1","doc":"Defines the color rgb(174, 168, 176).","ref":"Fledex.Color.Names.RAL.html#h320l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l70c10/1","doc":"Defines the color rgb(178, 165, 183).","ref":"Fledex.Color.Names.RAL.html#h320l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l70c15/1","doc":"Defines the color rgb(181, 162, 188).","ref":"Fledex.Color.Names.RAL.html#h320l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l70c20/1","doc":"Defines the color rgb(189, 162, 196).","ref":"Fledex.Color.Names.RAL.html#h320l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l70c25/1","doc":"Defines the color rgb(192, 157, 200).","ref":"Fledex.Color.Names.RAL.html#h320l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l80c05/1","doc":"Defines the color rgb(203, 196, 203).","ref":"Fledex.Color.Names.RAL.html#h320l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l80c10/1","doc":"Defines the color rgb(207, 194, 209).","ref":"Fledex.Color.Names.RAL.html#h320l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l80c15/1","doc":"Defines the color rgb(211, 190, 213).","ref":"Fledex.Color.Names.RAL.html#h320l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l85c05/1","doc":"Defines the color rgb(217, 211, 218).","ref":"Fledex.Color.Names.RAL.html#h320l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l85c10/1","doc":"Defines the color rgb(222, 209, 224).","ref":"Fledex.Color.Names.RAL.html#h320l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h320l90c05/1","doc":"Defines the color rgb(232, 225, 230).","ref":"Fledex.Color.Names.RAL.html#h320l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l20c20/1","doc":"Defines the color rgb(64, 36, 61).","ref":"Fledex.Color.Names.RAL.html#h330l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l20c25/1","doc":"Defines the color rgb(70, 35, 67).","ref":"Fledex.Color.Names.RAL.html#h330l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l30c15/1","doc":"Defines the color rgb(85, 62, 81).","ref":"Fledex.Color.Names.RAL.html#h330l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l30c20/1","doc":"Defines the color rgb(90, 60, 85).","ref":"Fledex.Color.Names.RAL.html#h330l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l30c25/1","doc":"Defines the color rgb(94, 57, 88).","ref":"Fledex.Color.Names.RAL.html#h330l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l30c30/1","doc":"Defines the color rgb(99, 54, 93).","ref":"Fledex.Color.Names.RAL.html#h330l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l30c35/1","doc":"Defines the color rgb(103, 51, 98).","ref":"Fledex.Color.Names.RAL.html#h330l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l30c40/1","doc":"Defines the color rgb(104, 45, 99).","ref":"Fledex.Color.Names.RAL.html#h330l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l40c10/1","doc":"Defines the color rgb(105, 90, 103).","ref":"Fledex.Color.Names.RAL.html#h330l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l40c15/1","doc":"Defines the color rgb(110, 87, 107).","ref":"Fledex.Color.Names.RAL.html#h330l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l40c20/1","doc":"Defines the color rgb(114, 86, 112).","ref":"Fledex.Color.Names.RAL.html#h330l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l40c25/1","doc":"Defines the color rgb(119, 83, 115).","ref":"Fledex.Color.Names.RAL.html#h330l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l40c30/1","doc":"Defines the color rgb(127, 79, 120).","ref":"Fledex.Color.Names.RAL.html#h330l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l40c35/1","doc":"Defines the color rgb(131, 77, 124).","ref":"Fledex.Color.Names.RAL.html#h330l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l40c40/1","doc":"Defines the color rgb(131, 71, 125).","ref":"Fledex.Color.Names.RAL.html#h330l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l40c45/1","doc":"Defines the color rgb(134, 68, 128).","ref":"Fledex.Color.Names.RAL.html#h330l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l50c10/1","doc":"Defines the color rgb(129, 113, 126).","ref":"Fledex.Color.Names.RAL.html#h330l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l50c15/1","doc":"Defines the color rgb(136, 112, 132).","ref":"Fledex.Color.Names.RAL.html#h330l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l50c20/1","doc":"Defines the color rgb(141, 109, 137).","ref":"Fledex.Color.Names.RAL.html#h330l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l50c25/1","doc":"Defines the color rgb(145, 107, 140).","ref":"Fledex.Color.Names.RAL.html#h330l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l50c30/1","doc":"Defines the color rgb(150, 105, 147).","ref":"Fledex.Color.Names.RAL.html#h330l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l50c35/1","doc":"Defines the color rgb(154, 101, 150).","ref":"Fledex.Color.Names.RAL.html#h330l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l50c40/1","doc":"Defines the color rgb(159, 97, 152).","ref":"Fledex.Color.Names.RAL.html#h330l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l60c10/1","doc":"Defines the color rgb(156, 140, 154).","ref":"Fledex.Color.Names.RAL.html#h330l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l60c15/1","doc":"Defines the color rgb(162, 138, 159).","ref":"Fledex.Color.Names.RAL.html#h330l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l60c20/1","doc":"Defines the color rgb(168, 135, 164).","ref":"Fledex.Color.Names.RAL.html#h330l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l60c25/1","doc":"Defines the color rgb(170, 131, 164).","ref":"Fledex.Color.Names.RAL.html#h330l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l60c30/1","doc":"Defines the color rgb(176, 129, 170).","ref":"Fledex.Color.Names.RAL.html#h330l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l60c35/1","doc":"Defines the color rgb(182, 125, 175).","ref":"Fledex.Color.Names.RAL.html#h330l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l60c40/1","doc":"Defines the color rgb(186, 122, 179).","ref":"Fledex.Color.Names.RAL.html#h330l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l70c10/1","doc":"Defines the color rgb(184, 166, 181).","ref":"Fledex.Color.Names.RAL.html#h330l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l70c15/1","doc":"Defines the color rgb(188, 163, 184).","ref":"Fledex.Color.Names.RAL.html#h330l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l70c20/1","doc":"Defines the color rgb(193, 161, 189).","ref":"Fledex.Color.Names.RAL.html#h330l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l70c25/1","doc":"Defines the color rgb(202, 158, 194).","ref":"Fledex.Color.Names.RAL.html#h330l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l70c30/1","doc":"Defines the color rgb(205, 155, 196).","ref":"Fledex.Color.Names.RAL.html#h330l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l80c10/1","doc":"Defines the color rgb(211, 194, 207).","ref":"Fledex.Color.Names.RAL.html#h330l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l80c15/1","doc":"Defines the color rgb(216, 191, 212).","ref":"Fledex.Color.Names.RAL.html#h330l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l80c20/1","doc":"Defines the color rgb(225, 188, 216).","ref":"Fledex.Color.Names.RAL.html#h330l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l85c05/1","doc":"Defines the color rgb(219, 213, 218).","ref":"Fledex.Color.Names.RAL.html#h330l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l85c10/1","doc":"Defines the color rgb(228, 211, 224).","ref":"Fledex.Color.Names.RAL.html#h330l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l85c15/1","doc":"Defines the color rgb(234, 209, 228).","ref":"Fledex.Color.Names.RAL.html#h330l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h330l90c05/1","doc":"Defines the color rgb(235, 226, 229).","ref":"Fledex.Color.Names.RAL.html#h330l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l20c05/1","doc":"Defines the color rgb(53, 45, 50).","ref":"Fledex.Color.Names.RAL.html#h340l20c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l20c10/1","doc":"Defines the color rgb(58, 39, 50).","ref":"Fledex.Color.Names.RAL.html#h340l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l20c15/1","doc":"Defines the color rgb(60, 34, 51).","ref":"Fledex.Color.Names.RAL.html#h340l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l20c20/1","doc":"Defines the color rgb(68, 34, 56).","ref":"Fledex.Color.Names.RAL.html#h340l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l20c25/1","doc":"Defines the color rgb(76, 33, 61).","ref":"Fledex.Color.Names.RAL.html#h340l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l30c05/1","doc":"Defines the color rgb(75, 66, 71).","ref":"Fledex.Color.Names.RAL.html#h340l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l30c10/1","doc":"Defines the color rgb(81, 62, 73).","ref":"Fledex.Color.Names.RAL.html#h340l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l30c15/1","doc":"Defines the color rgb(87, 59, 76).","ref":"Fledex.Color.Names.RAL.html#h340l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l30c20/1","doc":"Defines the color rgb(92, 56, 78).","ref":"Fledex.Color.Names.RAL.html#h340l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l30c25/1","doc":"Defines the color rgb(99, 54, 84).","ref":"Fledex.Color.Names.RAL.html#h340l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l30c30/1","doc":"Defines the color rgb(101, 48, 84).","ref":"Fledex.Color.Names.RAL.html#h340l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l30c35/1","doc":"Defines the color rgb(105, 43, 87).","ref":"Fledex.Color.Names.RAL.html#h340l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l30c38/1","doc":"Defines the color rgb(110, 39, 89).","ref":"Fledex.Color.Names.RAL.html#h340l30c38/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c05/1","doc":"Defines the color rgb(98, 89, 95).","ref":"Fledex.Color.Names.RAL.html#h340l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c10/1","doc":"Defines the color rgb(106, 86, 98).","ref":"Fledex.Color.Names.RAL.html#h340l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c15/1","doc":"Defines the color rgb(112, 83, 100).","ref":"Fledex.Color.Names.RAL.html#h340l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c20/1","doc":"Defines the color rgb(118, 80, 103).","ref":"Fledex.Color.Names.RAL.html#h340l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c25/1","doc":"Defines the color rgb(123, 77, 107).","ref":"Fledex.Color.Names.RAL.html#h340l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c30/1","doc":"Defines the color rgb(128, 73, 110).","ref":"Fledex.Color.Names.RAL.html#h340l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c35/1","doc":"Defines the color rgb(131, 67, 112).","ref":"Fledex.Color.Names.RAL.html#h340l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c40/1","doc":"Defines the color rgb(136, 62, 114).","ref":"Fledex.Color.Names.RAL.html#h340l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l40c45/1","doc":"Defines the color rgb(145, 57, 119).","ref":"Fledex.Color.Names.RAL.html#h340l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c05/1","doc":"Defines the color rgb(124, 115, 121).","ref":"Fledex.Color.Names.RAL.html#h340l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c10/1","doc":"Defines the color rgb(133, 112, 124).","ref":"Fledex.Color.Names.RAL.html#h340l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c15/1","doc":"Defines the color rgb(139, 108, 126).","ref":"Fledex.Color.Names.RAL.html#h340l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c20/1","doc":"Defines the color rgb(145, 105, 129).","ref":"Fledex.Color.Names.RAL.html#h340l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c25/1","doc":"Defines the color rgb(150, 102, 132).","ref":"Fledex.Color.Names.RAL.html#h340l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c30/1","doc":"Defines the color rgb(155, 98, 135).","ref":"Fledex.Color.Names.RAL.html#h340l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c35/1","doc":"Defines the color rgb(160, 93, 139).","ref":"Fledex.Color.Names.RAL.html#h340l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c40/1","doc":"Defines the color rgb(167, 89, 141).","ref":"Fledex.Color.Names.RAL.html#h340l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l50c45/1","doc":"Defines the color rgb(173, 84, 143).","ref":"Fledex.Color.Names.RAL.html#h340l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l60c05/1","doc":"Defines the color rgb(152, 142, 148).","ref":"Fledex.Color.Names.RAL.html#h340l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l60c10/1","doc":"Defines the color rgb(158, 137, 150).","ref":"Fledex.Color.Names.RAL.html#h340l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l60c15/1","doc":"Defines the color rgb(167, 135, 154).","ref":"Fledex.Color.Names.RAL.html#h340l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l60c20/1","doc":"Defines the color rgb(172, 131, 156).","ref":"Fledex.Color.Names.RAL.html#h340l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l60c25/1","doc":"Defines the color rgb(176, 127, 158).","ref":"Fledex.Color.Names.RAL.html#h340l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l60c30/1","doc":"Defines the color rgb(182, 124, 162).","ref":"Fledex.Color.Names.RAL.html#h340l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l60c35/1","doc":"Defines the color rgb(189, 121, 165).","ref":"Fledex.Color.Names.RAL.html#h340l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l60c40/1","doc":"Defines the color rgb(196, 115, 169).","ref":"Fledex.Color.Names.RAL.html#h340l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l70c05/1","doc":"Defines the color rgb(177, 167, 173).","ref":"Fledex.Color.Names.RAL.html#h340l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l70c10/1","doc":"Defines the color rgb(185, 164, 176).","ref":"Fledex.Color.Names.RAL.html#h340l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l70c15/1","doc":"Defines the color rgb(194, 161, 181).","ref":"Fledex.Color.Names.RAL.html#h340l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l70c20/1","doc":"Defines the color rgb(200, 158, 183).","ref":"Fledex.Color.Names.RAL.html#h340l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l70c25/1","doc":"Defines the color rgb(202, 153, 183).","ref":"Fledex.Color.Names.RAL.html#h340l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l70c30/1","doc":"Defines the color rgb(212, 150, 189).","ref":"Fledex.Color.Names.RAL.html#h340l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l70c35/1","doc":"Defines the color rgb(218, 147, 193).","ref":"Fledex.Color.Names.RAL.html#h340l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l80c05/1","doc":"Defines the color rgb(207, 196, 199).","ref":"Fledex.Color.Names.RAL.html#h340l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l80c10/1","doc":"Defines the color rgb(215, 194, 206).","ref":"Fledex.Color.Names.RAL.html#h340l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l80c15/1","doc":"Defines the color rgb(223, 189, 208).","ref":"Fledex.Color.Names.RAL.html#h340l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l80c20/1","doc":"Defines the color rgb(230, 186, 210).","ref":"Fledex.Color.Names.RAL.html#h340l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l85c05/1","doc":"Defines the color rgb(223, 212, 217).","ref":"Fledex.Color.Names.RAL.html#h340l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l85c10/1","doc":"Defines the color rgb(231, 209, 221).","ref":"Fledex.Color.Names.RAL.html#h340l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l85c15/1","doc":"Defines the color rgb(240, 207, 225).","ref":"Fledex.Color.Names.RAL.html#h340l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l90c05/1","doc":"Defines the color rgb(235, 224, 228).","ref":"Fledex.Color.Names.RAL.html#h340l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h340l93c05/1","doc":"Defines the color rgb(244, 235, 239).","ref":"Fledex.Color.Names.RAL.html#h340l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l20c10/1","doc":"Defines the color rgb(59, 41, 50).","ref":"Fledex.Color.Names.RAL.html#h350l20c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l20c15/1","doc":"Defines the color rgb(65, 37, 51).","ref":"Fledex.Color.Names.RAL.html#h350l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l20c20/1","doc":"Defines the color rgb(72, 32, 52).","ref":"Fledex.Color.Names.RAL.html#h350l20c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l20c25/1","doc":"Defines the color rgb(75, 28, 53).","ref":"Fledex.Color.Names.RAL.html#h350l20c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l20c30/1","doc":"Defines the color rgb(83, 25, 56).","ref":"Fledex.Color.Names.RAL.html#h350l20c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l30c10/1","doc":"Defines the color rgb(82, 62, 71).","ref":"Fledex.Color.Names.RAL.html#h350l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l30c15/1","doc":"Defines the color rgb(90, 61, 74).","ref":"Fledex.Color.Names.RAL.html#h350l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l30c20/1","doc":"Defines the color rgb(97, 57, 75).","ref":"Fledex.Color.Names.RAL.html#h350l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l30c25/1","doc":"Defines the color rgb(103, 51, 76).","ref":"Fledex.Color.Names.RAL.html#h350l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l30c30/1","doc":"Defines the color rgb(110, 49, 79).","ref":"Fledex.Color.Names.RAL.html#h350l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l30c35/1","doc":"Defines the color rgb(111, 44, 79).","ref":"Fledex.Color.Names.RAL.html#h350l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l30c40/1","doc":"Defines the color rgb(117, 38, 83).","ref":"Fledex.Color.Names.RAL.html#h350l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c10/1","doc":"Defines the color rgb(110, 88, 97).","ref":"Fledex.Color.Names.RAL.html#h350l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c15/1","doc":"Defines the color rgb(115, 83, 98).","ref":"Fledex.Color.Names.RAL.html#h350l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c20/1","doc":"Defines the color rgb(122, 80, 99).","ref":"Fledex.Color.Names.RAL.html#h350l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c25/1","doc":"Defines the color rgb(127, 76, 100).","ref":"Fledex.Color.Names.RAL.html#h350l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c30/1","doc":"Defines the color rgb(135, 71, 102).","ref":"Fledex.Color.Names.RAL.html#h350l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c35/1","doc":"Defines the color rgb(140, 66, 104).","ref":"Fledex.Color.Names.RAL.html#h350l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c40/1","doc":"Defines the color rgb(145, 63, 106).","ref":"Fledex.Color.Names.RAL.html#h350l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c45/1","doc":"Defines the color rgb(149, 57, 106).","ref":"Fledex.Color.Names.RAL.html#h350l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l40c50/1","doc":"Defines the color rgb(156, 50, 107).","ref":"Fledex.Color.Names.RAL.html#h350l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c10/1","doc":"Defines the color rgb(133, 111, 121).","ref":"Fledex.Color.Names.RAL.html#h350l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c15/1","doc":"Defines the color rgb(141, 108, 122).","ref":"Fledex.Color.Names.RAL.html#h350l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c20/1","doc":"Defines the color rgb(149, 104, 125).","ref":"Fledex.Color.Names.RAL.html#h350l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c25/1","doc":"Defines the color rgb(156, 101, 126).","ref":"Fledex.Color.Names.RAL.html#h350l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c30/1","doc":"Defines the color rgb(161, 99, 129).","ref":"Fledex.Color.Names.RAL.html#h350l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c35/1","doc":"Defines the color rgb(170, 92, 129).","ref":"Fledex.Color.Names.RAL.html#h350l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c40/1","doc":"Defines the color rgb(177, 88, 130).","ref":"Fledex.Color.Names.RAL.html#h350l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c45/1","doc":"Defines the color rgb(177, 83, 132).","ref":"Fledex.Color.Names.RAL.html#h350l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l50c50/1","doc":"Defines the color rgb(189, 78, 132).","ref":"Fledex.Color.Names.RAL.html#h350l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l60c10/1","doc":"Defines the color rgb(160, 137, 148).","ref":"Fledex.Color.Names.RAL.html#h350l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l60c15/1","doc":"Defines the color rgb(167, 133, 148).","ref":"Fledex.Color.Names.RAL.html#h350l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l60c20/1","doc":"Defines the color rgb(177, 131, 152).","ref":"Fledex.Color.Names.RAL.html#h350l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l60c25/1","doc":"Defines the color rgb(184, 127, 151).","ref":"Fledex.Color.Names.RAL.html#h350l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l60c30/1","doc":"Defines the color rgb(192, 123, 154).","ref":"Fledex.Color.Names.RAL.html#h350l60c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l60c35/1","doc":"Defines the color rgb(197, 118, 155).","ref":"Fledex.Color.Names.RAL.html#h350l60c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l60c40/1","doc":"Defines the color rgb(205, 115, 157).","ref":"Fledex.Color.Names.RAL.html#h350l60c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l60c45/1","doc":"Defines the color rgb(208, 111, 160).","ref":"Fledex.Color.Names.RAL.html#h350l60c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l70c10/1","doc":"Defines the color rgb(188, 165, 173).","ref":"Fledex.Color.Names.RAL.html#h350l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l70c15/1","doc":"Defines the color rgb(196, 161, 175).","ref":"Fledex.Color.Names.RAL.html#h350l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l70c20/1","doc":"Defines the color rgb(201, 155, 176).","ref":"Fledex.Color.Names.RAL.html#h350l70c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l70c25/1","doc":"Defines the color rgb(212, 154, 179).","ref":"Fledex.Color.Names.RAL.html#h350l70c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l70c30/1","doc":"Defines the color rgb(221, 149, 180).","ref":"Fledex.Color.Names.RAL.html#h350l70c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l70c35/1","doc":"Defines the color rgb(226, 146, 182).","ref":"Fledex.Color.Names.RAL.html#h350l70c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l80c10/1","doc":"Defines the color rgb(216, 191, 200).","ref":"Fledex.Color.Names.RAL.html#h350l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l80c15/1","doc":"Defines the color rgb(223, 188, 201).","ref":"Fledex.Color.Names.RAL.html#h350l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l80c20/1","doc":"Defines the color rgb(232, 185, 205).","ref":"Fledex.Color.Names.RAL.html#h350l80c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l85c05/1","doc":"Defines the color rgb(222, 212, 216).","ref":"Fledex.Color.Names.RAL.html#h350l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l85c10/1","doc":"Defines the color rgb(233, 209, 218).","ref":"Fledex.Color.Names.RAL.html#h350l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l85c15/1","doc":"Defines the color rgb(239, 205, 219).","ref":"Fledex.Color.Names.RAL.html#h350l85c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l90c05/1","doc":"Defines the color rgb(237, 224, 225).","ref":"Fledex.Color.Names.RAL.html#h350l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l90c10/1","doc":"Defines the color rgb(245, 221, 230).","ref":"Fledex.Color.Names.RAL.html#h350l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h350l93c05/1","doc":"Defines the color rgb(246, 235, 238).","ref":"Fledex.Color.Names.RAL.html#h350l93c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l20c15/1","doc":"Defines the color rgb(67, 35, 44).","ref":"Fledex.Color.Names.RAL.html#h360l20c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l30c05/1","doc":"Defines the color rgb(77, 66, 68).","ref":"Fledex.Color.Names.RAL.html#h360l30c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l30c10/1","doc":"Defines the color rgb(83, 61, 68).","ref":"Fledex.Color.Names.RAL.html#h360l30c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l30c15/1","doc":"Defines the color rgb(90, 56, 68).","ref":"Fledex.Color.Names.RAL.html#h360l30c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l30c20/1","doc":"Defines the color rgb(98, 55, 69).","ref":"Fledex.Color.Names.RAL.html#h360l30c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l30c25/1","doc":"Defines the color rgb(102, 49, 69).","ref":"Fledex.Color.Names.RAL.html#h360l30c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l30c30/1","doc":"Defines the color rgb(108, 44, 69).","ref":"Fledex.Color.Names.RAL.html#h360l30c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l30c35/1","doc":"Defines the color rgb(117, 39, 69).","ref":"Fledex.Color.Names.RAL.html#h360l30c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l30c40/1","doc":"Defines the color rgb(121, 36, 69).","ref":"Fledex.Color.Names.RAL.html#h360l30c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c05/1","doc":"Defines the color rgb(101, 90, 92).","ref":"Fledex.Color.Names.RAL.html#h360l40c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c10/1","doc":"Defines the color rgb(107, 86, 94).","ref":"Fledex.Color.Names.RAL.html#h360l40c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c15/1","doc":"Defines the color rgb(115, 82, 92).","ref":"Fledex.Color.Names.RAL.html#h360l40c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c20/1","doc":"Defines the color rgb(123, 79, 93).","ref":"Fledex.Color.Names.RAL.html#h360l40c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c25/1","doc":"Defines the color rgb(129, 74, 92).","ref":"Fledex.Color.Names.RAL.html#h360l40c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c30/1","doc":"Defines the color rgb(136, 69, 94).","ref":"Fledex.Color.Names.RAL.html#h360l40c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c35/1","doc":"Defines the color rgb(143, 65, 95).","ref":"Fledex.Color.Names.RAL.html#h360l40c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c40/1","doc":"Defines the color rgb(150, 59, 96).","ref":"Fledex.Color.Names.RAL.html#h360l40c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c45/1","doc":"Defines the color rgb(155, 54, 94).","ref":"Fledex.Color.Names.RAL.html#h360l40c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l40c50/1","doc":"Defines the color rgb(161, 45, 93).","ref":"Fledex.Color.Names.RAL.html#h360l40c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c05/1","doc":"Defines the color rgb(128, 115, 117).","ref":"Fledex.Color.Names.RAL.html#h360l50c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c10/1","doc":"Defines the color rgb(133, 111, 118).","ref":"Fledex.Color.Names.RAL.html#h360l50c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c15/1","doc":"Defines the color rgb(142, 107, 118).","ref":"Fledex.Color.Names.RAL.html#h360l50c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c20/1","doc":"Defines the color rgb(148, 104, 119).","ref":"Fledex.Color.Names.RAL.html#h360l50c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c25/1","doc":"Defines the color rgb(157, 99, 117).","ref":"Fledex.Color.Names.RAL.html#h360l50c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c30/1","doc":"Defines the color rgb(165, 96, 120).","ref":"Fledex.Color.Names.RAL.html#h360l50c30/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c35/1","doc":"Defines the color rgb(173, 91, 120).","ref":"Fledex.Color.Names.RAL.html#h360l50c35/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c40/1","doc":"Defines the color rgb(180, 88, 119).","ref":"Fledex.Color.Names.RAL.html#h360l50c40/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c45/1","doc":"Defines the color rgb(188, 83, 120).","ref":"Fledex.Color.Names.RAL.html#h360l50c45/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l50c50/1","doc":"Defines the color rgb(192, 76, 119).","ref":"Fledex.Color.Names.RAL.html#h360l50c50/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l60c05/1","doc":"Defines the color rgb(153, 142, 145).","ref":"Fledex.Color.Names.RAL.html#h360l60c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l60c10/1","doc":"Defines the color rgb(160, 137, 144).","ref":"Fledex.Color.Names.RAL.html#h360l60c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l60c15/1","doc":"Defines the color rgb(169, 134, 145).","ref":"Fledex.Color.Names.RAL.html#h360l60c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l60c20/1","doc":"Defines the color rgb(178, 131, 146).","ref":"Fledex.Color.Names.RAL.html#h360l60c20/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l60c25/1","doc":"Defines the color rgb(184, 126, 145).","ref":"Fledex.Color.Names.RAL.html#h360l60c25/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l70c05/1","doc":"Defines the color rgb(181, 169, 172).","ref":"Fledex.Color.Names.RAL.html#h360l70c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l70c10/1","doc":"Defines the color rgb(188, 163, 170).","ref":"Fledex.Color.Names.RAL.html#h360l70c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l70c15/1","doc":"Defines the color rgb(198, 160, 171).","ref":"Fledex.Color.Names.RAL.html#h360l70c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l80c05/1","doc":"Defines the color rgb(209, 196, 198).","ref":"Fledex.Color.Names.RAL.html#h360l80c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l80c10/1","doc":"Defines the color rgb(217, 191, 197).","ref":"Fledex.Color.Names.RAL.html#h360l80c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l80c15/1","doc":"Defines the color rgb(229, 191, 202).","ref":"Fledex.Color.Names.RAL.html#h360l80c15/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l85c05/1","doc":"Defines the color rgb(226, 212, 212).","ref":"Fledex.Color.Names.RAL.html#h360l85c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l85c10/1","doc":"Defines the color rgb(234, 208, 214).","ref":"Fledex.Color.Names.RAL.html#h360l85c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l90c05/1","doc":"Defines the color rgb(241, 225, 224).","ref":"Fledex.Color.Names.RAL.html#h360l90c05/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l90c10/1","doc":"Defines the color rgb(249, 223, 229).","ref":"Fledex.Color.Names.RAL.html#h360l90c10/1"},{"type":"function","title":"Fledex.Color.Names.RAL.h360l93c05/1","doc":"Defines the color rgb(249, 234, 235).","ref":"Fledex.Color.Names.RAL.html#h360l93c05/1"},{"type":"macro","title":"Fledex.Color.Names.RAL.is_color_name/1","doc":"Check whether the atom is a valid color name","ref":"Fledex.Color.Names.RAL.html#is_color_name/1"},{"type":"function","title":"Fledex.Color.Names.RAL.names/0","doc":"Get a list of all the predefined color (atom) names.\n\nThe name can be used to either retrieve the info by calling `info/2` or by calling the function with that\nname (see also the description at the top and take a look at this [example livebook](3b_fledex_more_about_colors.livemd))","ref":"Fledex.Color.Names.RAL.html#names/0"},{"type":"module","title":"Fledex.Color.Names.SVG","doc":"Do not use this module directly, but use Fledex.Color.Names instead","ref":"Fledex.Color.Names.SVG.html"},{"type":"function","title":"Fledex.Color.Names.SVG.antiquewhite/1","doc":"Defines the color rgb(250, 235, 215).","ref":"Fledex.Color.Names.SVG.html#antiquewhite/1"},{"type":"function","title":"Fledex.Color.Names.SVG.aqua/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.SVG.html#aqua/1"},{"type":"function","title":"Fledex.Color.Names.SVG.aquamarine/1","doc":"Defines the color rgb(127, 255, 212).","ref":"Fledex.Color.Names.SVG.html#aquamarine/1"},{"type":"function","title":"Fledex.Color.Names.SVG.azure/1","doc":"Defines the color rgb(240, 255, 255).","ref":"Fledex.Color.Names.SVG.html#azure/1"},{"type":"function","title":"Fledex.Color.Names.SVG.beige/1","doc":"Defines the color rgb(245, 245, 220).","ref":"Fledex.Color.Names.SVG.html#beige/1"},{"type":"function","title":"Fledex.Color.Names.SVG.bisque/1","doc":"Defines the color rgb(255, 228, 196).","ref":"Fledex.Color.Names.SVG.html#bisque/1"},{"type":"function","title":"Fledex.Color.Names.SVG.black/1","doc":"Defines the color rgb(0, 0, 0).","ref":"Fledex.Color.Names.SVG.html#black/1"},{"type":"function","title":"Fledex.Color.Names.SVG.blanchedalmond/1","doc":"Defines the color rgb(255, 235, 205).","ref":"Fledex.Color.Names.SVG.html#blanchedalmond/1"},{"type":"function","title":"Fledex.Color.Names.SVG.blue/1","doc":"Defines the color rgb(0, 0, 255).","ref":"Fledex.Color.Names.SVG.html#blue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.blueviolet/1","doc":"Defines the color rgb(138, 43, 226).","ref":"Fledex.Color.Names.SVG.html#blueviolet/1"},{"type":"function","title":"Fledex.Color.Names.SVG.brown/1","doc":"Defines the color rgb(165, 42, 42).","ref":"Fledex.Color.Names.SVG.html#brown/1"},{"type":"function","title":"Fledex.Color.Names.SVG.burlywood/1","doc":"Defines the color rgb(222, 184, 135).","ref":"Fledex.Color.Names.SVG.html#burlywood/1"},{"type":"function","title":"Fledex.Color.Names.SVG.cadetblue/1","doc":"Defines the color rgb(95, 158, 160).","ref":"Fledex.Color.Names.SVG.html#cadetblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.chartreuse/1","doc":"Defines the color rgb(127, 255, 0).","ref":"Fledex.Color.Names.SVG.html#chartreuse/1"},{"type":"function","title":"Fledex.Color.Names.SVG.chocolate/1","doc":"Defines the color rgb(210, 105, 30).","ref":"Fledex.Color.Names.SVG.html#chocolate/1"},{"type":"type","title":"Fledex.Color.Names.SVG.color_names_t/0","doc":"The allowed color names","ref":"Fledex.Color.Names.SVG.html#t:color_names_t/0"},{"type":"function","title":"Fledex.Color.Names.SVG.colors/0","doc":"Get all the data about the predefined colors","ref":"Fledex.Color.Names.SVG.html#colors/0"},{"type":"function","title":"Fledex.Color.Names.SVG.coral/1","doc":"Defines the color rgb(255, 127, 80).","ref":"Fledex.Color.Names.SVG.html#coral/1"},{"type":"function","title":"Fledex.Color.Names.SVG.cornflowerblue/1","doc":"Defines the color rgb(100, 149, 237).","ref":"Fledex.Color.Names.SVG.html#cornflowerblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.cornsilk/1","doc":"Defines the color rgb(255, 248, 220).","ref":"Fledex.Color.Names.SVG.html#cornsilk/1"},{"type":"function","title":"Fledex.Color.Names.SVG.crimson/1","doc":"Defines the color rgb(220, 20, 60).","ref":"Fledex.Color.Names.SVG.html#crimson/1"},{"type":"function","title":"Fledex.Color.Names.SVG.cyan/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.SVG.html#cyan/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkblue/1","doc":"Defines the color rgb(0, 0, 139).","ref":"Fledex.Color.Names.SVG.html#darkblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkcyan/1","doc":"Defines the color rgb(0, 139, 139).","ref":"Fledex.Color.Names.SVG.html#darkcyan/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkgoldenrod/1","doc":"Defines the color rgb(184, 134, 11).","ref":"Fledex.Color.Names.SVG.html#darkgoldenrod/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkgray/1","doc":"Defines the color rgb(169, 169, 169).","ref":"Fledex.Color.Names.SVG.html#darkgray/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkgreen/1","doc":"Defines the color rgb(0, 100, 0).","ref":"Fledex.Color.Names.SVG.html#darkgreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkgrey/1","doc":"Defines the color rgb(169, 169, 169).","ref":"Fledex.Color.Names.SVG.html#darkgrey/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkkhaki/1","doc":"Defines the color rgb(189, 183, 107).","ref":"Fledex.Color.Names.SVG.html#darkkhaki/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkmagenta/1","doc":"Defines the color rgb(139, 0, 139).","ref":"Fledex.Color.Names.SVG.html#darkmagenta/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkolivegreen/1","doc":"Defines the color rgb(85, 107, 47).","ref":"Fledex.Color.Names.SVG.html#darkolivegreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkorange/1","doc":"Defines the color rgb(255, 140, 0).","ref":"Fledex.Color.Names.SVG.html#darkorange/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkorchid/1","doc":"Defines the color rgb(153, 50, 204).","ref":"Fledex.Color.Names.SVG.html#darkorchid/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkred/1","doc":"Defines the color rgb(139, 0, 0).","ref":"Fledex.Color.Names.SVG.html#darkred/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darksalmon/1","doc":"Defines the color rgb(233, 150, 122).","ref":"Fledex.Color.Names.SVG.html#darksalmon/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkseagreen/1","doc":"Defines the color rgb(143, 188, 143).","ref":"Fledex.Color.Names.SVG.html#darkseagreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkslateblue/1","doc":"Defines the color rgb(72, 61, 139).","ref":"Fledex.Color.Names.SVG.html#darkslateblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkslategray/1","doc":"Defines the color rgb(47, 79, 79).","ref":"Fledex.Color.Names.SVG.html#darkslategray/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkslategrey/1","doc":"Defines the color rgb(47, 79, 79).","ref":"Fledex.Color.Names.SVG.html#darkslategrey/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkturquoise/1","doc":"Defines the color rgb(0, 206, 209).","ref":"Fledex.Color.Names.SVG.html#darkturquoise/1"},{"type":"function","title":"Fledex.Color.Names.SVG.darkviolet/1","doc":"Defines the color rgb(148, 0, 211).","ref":"Fledex.Color.Names.SVG.html#darkviolet/1"},{"type":"function","title":"Fledex.Color.Names.SVG.deeppink/1","doc":"Defines the color rgb(255, 20, 147).","ref":"Fledex.Color.Names.SVG.html#deeppink/1"},{"type":"function","title":"Fledex.Color.Names.SVG.deepskyblue/1","doc":"Defines the color rgb(0, 191, 255).","ref":"Fledex.Color.Names.SVG.html#deepskyblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.dimgray/1","doc":"Defines the color rgb(105, 105, 105).","ref":"Fledex.Color.Names.SVG.html#dimgray/1"},{"type":"function","title":"Fledex.Color.Names.SVG.dimgrey/1","doc":"Defines the color rgb(105, 105, 105).","ref":"Fledex.Color.Names.SVG.html#dimgrey/1"},{"type":"function","title":"Fledex.Color.Names.SVG.dodgerblue/1","doc":"Defines the color rgb(30, 144, 255).","ref":"Fledex.Color.Names.SVG.html#dodgerblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.firebrick/1","doc":"Defines the color rgb(178, 34, 34).","ref":"Fledex.Color.Names.SVG.html#firebrick/1"},{"type":"function","title":"Fledex.Color.Names.SVG.floralwhite/1","doc":"Defines the color rgb(255, 250, 240).","ref":"Fledex.Color.Names.SVG.html#floralwhite/1"},{"type":"function","title":"Fledex.Color.Names.SVG.forestgreen/1","doc":"Defines the color rgb(34, 139, 34).","ref":"Fledex.Color.Names.SVG.html#forestgreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.fuchsia/1","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.SVG.html#fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.SVG.gainsboro/1","doc":"Defines the color rgb(220, 220, 220).","ref":"Fledex.Color.Names.SVG.html#gainsboro/1"},{"type":"function","title":"Fledex.Color.Names.SVG.ghostwhite/1","doc":"Defines the color rgb(248, 248, 255).","ref":"Fledex.Color.Names.SVG.html#ghostwhite/1"},{"type":"function","title":"Fledex.Color.Names.SVG.gold/1","doc":"Defines the color rgb(255, 215, 0).","ref":"Fledex.Color.Names.SVG.html#gold/1"},{"type":"function","title":"Fledex.Color.Names.SVG.goldenrod/1","doc":"Defines the color rgb(218, 165, 32).","ref":"Fledex.Color.Names.SVG.html#goldenrod/1"},{"type":"function","title":"Fledex.Color.Names.SVG.gray/1","doc":"Defines the color rgb(128, 128, 128).","ref":"Fledex.Color.Names.SVG.html#gray/1"},{"type":"function","title":"Fledex.Color.Names.SVG.green/1","doc":"Defines the color rgb(0, 128, 0).","ref":"Fledex.Color.Names.SVG.html#green/1"},{"type":"function","title":"Fledex.Color.Names.SVG.greenyellow/1","doc":"Defines the color rgb(173, 255, 47).","ref":"Fledex.Color.Names.SVG.html#greenyellow/1"},{"type":"function","title":"Fledex.Color.Names.SVG.grey/1","doc":"Defines the color rgb(128, 128, 128).","ref":"Fledex.Color.Names.SVG.html#grey/1"},{"type":"function","title":"Fledex.Color.Names.SVG.honeydew/1","doc":"Defines the color rgb(240, 255, 240).","ref":"Fledex.Color.Names.SVG.html#honeydew/1"},{"type":"function","title":"Fledex.Color.Names.SVG.hotpink/1","doc":"Defines the color rgb(255, 105, 180).","ref":"Fledex.Color.Names.SVG.html#hotpink/1"},{"type":"function","title":"Fledex.Color.Names.SVG.indianred/1","doc":"Defines the color rgb(205, 92, 92).","ref":"Fledex.Color.Names.SVG.html#indianred/1"},{"type":"function","title":"Fledex.Color.Names.SVG.indigo/1","doc":"Defines the color rgb(75, 0, 130).","ref":"Fledex.Color.Names.SVG.html#indigo/1"},{"type":"macro","title":"Fledex.Color.Names.SVG.is_color_name/1","doc":"Check whether the atom is a valid color name","ref":"Fledex.Color.Names.SVG.html#is_color_name/1"},{"type":"function","title":"Fledex.Color.Names.SVG.ivory/1","doc":"Defines the color rgb(255, 255, 240).","ref":"Fledex.Color.Names.SVG.html#ivory/1"},{"type":"function","title":"Fledex.Color.Names.SVG.khaki/1","doc":"Defines the color rgb(240, 230, 140).","ref":"Fledex.Color.Names.SVG.html#khaki/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lavender/1","doc":"Defines the color rgb(230, 230, 250).","ref":"Fledex.Color.Names.SVG.html#lavender/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lavenderblush/1","doc":"Defines the color rgb(255, 240, 245).","ref":"Fledex.Color.Names.SVG.html#lavenderblush/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lawngreen/1","doc":"Defines the color rgb(124, 252, 0).","ref":"Fledex.Color.Names.SVG.html#lawngreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lemonchiffon/1","doc":"Defines the color rgb(255, 250, 205).","ref":"Fledex.Color.Names.SVG.html#lemonchiffon/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightblue/1","doc":"Defines the color rgb(173, 216, 230).","ref":"Fledex.Color.Names.SVG.html#lightblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightcoral/1","doc":"Defines the color rgb(240, 128, 128).","ref":"Fledex.Color.Names.SVG.html#lightcoral/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightcyan/1","doc":"Defines the color rgb(224, 255, 255).","ref":"Fledex.Color.Names.SVG.html#lightcyan/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightgoldenrodyellow/1","doc":"Defines the color rgb(250, 250, 210).","ref":"Fledex.Color.Names.SVG.html#lightgoldenrodyellow/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightgray/1","doc":"Defines the color rgb(211, 211, 211).","ref":"Fledex.Color.Names.SVG.html#lightgray/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightgreen/1","doc":"Defines the color rgb(144, 238, 144).","ref":"Fledex.Color.Names.SVG.html#lightgreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightgrey/1","doc":"Defines the color rgb(211, 211, 211).","ref":"Fledex.Color.Names.SVG.html#lightgrey/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightpink/1","doc":"Defines the color rgb(255, 182, 193).","ref":"Fledex.Color.Names.SVG.html#lightpink/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightsalmon/1","doc":"Defines the color rgb(255, 160, 122).","ref":"Fledex.Color.Names.SVG.html#lightsalmon/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightseagreen/1","doc":"Defines the color rgb(32, 178, 170).","ref":"Fledex.Color.Names.SVG.html#lightseagreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightskyblue/1","doc":"Defines the color rgb(135, 206, 250).","ref":"Fledex.Color.Names.SVG.html#lightskyblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightslategray/1","doc":"Defines the color rgb(119, 136, 153).","ref":"Fledex.Color.Names.SVG.html#lightslategray/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightslategrey/1","doc":"Defines the color rgb(119, 136, 153).","ref":"Fledex.Color.Names.SVG.html#lightslategrey/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightsteelblue/1","doc":"Defines the color rgb(176, 196, 222).","ref":"Fledex.Color.Names.SVG.html#lightsteelblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lightyellow/1","doc":"Defines the color rgb(255, 255, 224).","ref":"Fledex.Color.Names.SVG.html#lightyellow/1"},{"type":"function","title":"Fledex.Color.Names.SVG.lime/1","doc":"Defines the color rgb(0, 255, 0).","ref":"Fledex.Color.Names.SVG.html#lime/1"},{"type":"function","title":"Fledex.Color.Names.SVG.limegreen/1","doc":"Defines the color rgb(50, 205, 50).","ref":"Fledex.Color.Names.SVG.html#limegreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.linen/1","doc":"Defines the color rgb(250, 240, 230).","ref":"Fledex.Color.Names.SVG.html#linen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.magenta/1","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.SVG.html#magenta/1"},{"type":"function","title":"Fledex.Color.Names.SVG.maroon/1","doc":"Defines the color rgb(128, 0, 0).","ref":"Fledex.Color.Names.SVG.html#maroon/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumaquamarine/1","doc":"Defines the color rgb(102, 205, 170).","ref":"Fledex.Color.Names.SVG.html#mediumaquamarine/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumblue/1","doc":"Defines the color rgb(0, 0, 205).","ref":"Fledex.Color.Names.SVG.html#mediumblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumorchid/1","doc":"Defines the color rgb(186, 85, 211).","ref":"Fledex.Color.Names.SVG.html#mediumorchid/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumpurple/1","doc":"Defines the color rgb(147, 112, 219).","ref":"Fledex.Color.Names.SVG.html#mediumpurple/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumseagreen/1","doc":"Defines the color rgb(60, 179, 113).","ref":"Fledex.Color.Names.SVG.html#mediumseagreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumslateblue/1","doc":"Defines the color rgb(123, 104, 238).","ref":"Fledex.Color.Names.SVG.html#mediumslateblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumspringgreen/1","doc":"Defines the color rgb(0, 250, 154).","ref":"Fledex.Color.Names.SVG.html#mediumspringgreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumturquoise/1","doc":"Defines the color rgb(72, 209, 204).","ref":"Fledex.Color.Names.SVG.html#mediumturquoise/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mediumvioletred/1","doc":"Defines the color rgb(199, 21, 133).","ref":"Fledex.Color.Names.SVG.html#mediumvioletred/1"},{"type":"function","title":"Fledex.Color.Names.SVG.midnightblue/1","doc":"Defines the color rgb(25, 25, 112).","ref":"Fledex.Color.Names.SVG.html#midnightblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mintcream/1","doc":"Defines the color rgb(245, 255, 250).","ref":"Fledex.Color.Names.SVG.html#mintcream/1"},{"type":"function","title":"Fledex.Color.Names.SVG.mistyrose/1","doc":"Defines the color rgb(255, 228, 225).","ref":"Fledex.Color.Names.SVG.html#mistyrose/1"},{"type":"function","title":"Fledex.Color.Names.SVG.moccasin/1","doc":"Defines the color rgb(255, 228, 181).","ref":"Fledex.Color.Names.SVG.html#moccasin/1"},{"type":"function","title":"Fledex.Color.Names.SVG.names/0","doc":"Get a list of all the predefined color (atom) names.\n\nThe name can be used to either retrieve the info by calling `info/2` or by calling the function with that\nname (see also the description at the top and take a look at this [example livebook](3b_fledex_more_about_colors.livemd))","ref":"Fledex.Color.Names.SVG.html#names/0"},{"type":"function","title":"Fledex.Color.Names.SVG.navajowhite/1","doc":"Defines the color rgb(255, 222, 173).","ref":"Fledex.Color.Names.SVG.html#navajowhite/1"},{"type":"function","title":"Fledex.Color.Names.SVG.navy/1","doc":"Defines the color rgb(0, 0, 128).","ref":"Fledex.Color.Names.SVG.html#navy/1"},{"type":"function","title":"Fledex.Color.Names.SVG.oldlace/1","doc":"Defines the color rgb(253, 245, 230).","ref":"Fledex.Color.Names.SVG.html#oldlace/1"},{"type":"function","title":"Fledex.Color.Names.SVG.olive/1","doc":"Defines the color rgb(128, 128, 0).","ref":"Fledex.Color.Names.SVG.html#olive/1"},{"type":"function","title":"Fledex.Color.Names.SVG.olivedrab/1","doc":"Defines the color rgb(107, 142, 35).","ref":"Fledex.Color.Names.SVG.html#olivedrab/1"},{"type":"function","title":"Fledex.Color.Names.SVG.orange/1","doc":"Defines the color rgb(255, 165, 0).","ref":"Fledex.Color.Names.SVG.html#orange/1"},{"type":"function","title":"Fledex.Color.Names.SVG.orangered/1","doc":"Defines the color rgb(255, 69, 0).","ref":"Fledex.Color.Names.SVG.html#orangered/1"},{"type":"function","title":"Fledex.Color.Names.SVG.orchid/1","doc":"Defines the color rgb(218, 112, 214).","ref":"Fledex.Color.Names.SVG.html#orchid/1"},{"type":"function","title":"Fledex.Color.Names.SVG.palegoldenrod/1","doc":"Defines the color rgb(238, 232, 170).","ref":"Fledex.Color.Names.SVG.html#palegoldenrod/1"},{"type":"function","title":"Fledex.Color.Names.SVG.palegreen/1","doc":"Defines the color rgb(152, 251, 152).","ref":"Fledex.Color.Names.SVG.html#palegreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.paleturquoise/1","doc":"Defines the color rgb(175, 238, 238).","ref":"Fledex.Color.Names.SVG.html#paleturquoise/1"},{"type":"function","title":"Fledex.Color.Names.SVG.palevioletred/1","doc":"Defines the color rgb(219, 112, 147).","ref":"Fledex.Color.Names.SVG.html#palevioletred/1"},{"type":"function","title":"Fledex.Color.Names.SVG.papayawhip/1","doc":"Defines the color rgb(255, 239, 213).","ref":"Fledex.Color.Names.SVG.html#papayawhip/1"},{"type":"function","title":"Fledex.Color.Names.SVG.peachpuff/1","doc":"Defines the color rgb(255, 218, 185).","ref":"Fledex.Color.Names.SVG.html#peachpuff/1"},{"type":"function","title":"Fledex.Color.Names.SVG.peru/1","doc":"Defines the color rgb(205, 133, 63).","ref":"Fledex.Color.Names.SVG.html#peru/1"},{"type":"function","title":"Fledex.Color.Names.SVG.pink/1","doc":"Defines the color rgb(255, 192, 203).","ref":"Fledex.Color.Names.SVG.html#pink/1"},{"type":"function","title":"Fledex.Color.Names.SVG.plum/1","doc":"Defines the color rgb(221, 160, 221).","ref":"Fledex.Color.Names.SVG.html#plum/1"},{"type":"function","title":"Fledex.Color.Names.SVG.powderblue/1","doc":"Defines the color rgb(176, 224, 230).","ref":"Fledex.Color.Names.SVG.html#powderblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.purple/1","doc":"Defines the color rgb(128, 0, 128).","ref":"Fledex.Color.Names.SVG.html#purple/1"},{"type":"function","title":"Fledex.Color.Names.SVG.red/1","doc":"Defines the color rgb(255, 0, 0).","ref":"Fledex.Color.Names.SVG.html#red/1"},{"type":"function","title":"Fledex.Color.Names.SVG.rosybrown/1","doc":"Defines the color rgb(188, 143, 143).","ref":"Fledex.Color.Names.SVG.html#rosybrown/1"},{"type":"function","title":"Fledex.Color.Names.SVG.royalblue/1","doc":"Defines the color rgb(65, 105, 225).","ref":"Fledex.Color.Names.SVG.html#royalblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.saddlebrown/1","doc":"Defines the color rgb(139, 69, 19).","ref":"Fledex.Color.Names.SVG.html#saddlebrown/1"},{"type":"function","title":"Fledex.Color.Names.SVG.salmon/1","doc":"Defines the color rgb(250, 128, 114).","ref":"Fledex.Color.Names.SVG.html#salmon/1"},{"type":"function","title":"Fledex.Color.Names.SVG.sandybrown/1","doc":"Defines the color rgb(244, 164, 96).","ref":"Fledex.Color.Names.SVG.html#sandybrown/1"},{"type":"function","title":"Fledex.Color.Names.SVG.seagreen/1","doc":"Defines the color rgb(46, 139, 87).","ref":"Fledex.Color.Names.SVG.html#seagreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.seashell/1","doc":"Defines the color rgb(255, 245, 238).","ref":"Fledex.Color.Names.SVG.html#seashell/1"},{"type":"function","title":"Fledex.Color.Names.SVG.sienna/1","doc":"Defines the color rgb(160, 82, 45).","ref":"Fledex.Color.Names.SVG.html#sienna/1"},{"type":"function","title":"Fledex.Color.Names.SVG.silver/1","doc":"Defines the color rgb(192, 192, 192).","ref":"Fledex.Color.Names.SVG.html#silver/1"},{"type":"function","title":"Fledex.Color.Names.SVG.skyblue/1","doc":"Defines the color rgb(135, 206, 235).","ref":"Fledex.Color.Names.SVG.html#skyblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.slateblue/1","doc":"Defines the color rgb(106, 90, 205).","ref":"Fledex.Color.Names.SVG.html#slateblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.slategray/1","doc":"Defines the color rgb(112, 128, 144).","ref":"Fledex.Color.Names.SVG.html#slategray/1"},{"type":"function","title":"Fledex.Color.Names.SVG.slategrey/1","doc":"Defines the color rgb(112, 128, 144).","ref":"Fledex.Color.Names.SVG.html#slategrey/1"},{"type":"function","title":"Fledex.Color.Names.SVG.snow/1","doc":"Defines the color rgb(255, 250, 250).","ref":"Fledex.Color.Names.SVG.html#snow/1"},{"type":"function","title":"Fledex.Color.Names.SVG.springgreen/1","doc":"Defines the color rgb(0, 255, 127).","ref":"Fledex.Color.Names.SVG.html#springgreen/1"},{"type":"function","title":"Fledex.Color.Names.SVG.steelblue/1","doc":"Defines the color rgb(70, 130, 180).","ref":"Fledex.Color.Names.SVG.html#steelblue/1"},{"type":"function","title":"Fledex.Color.Names.SVG.tan/1","doc":"Defines the color rgb(210, 180, 140).","ref":"Fledex.Color.Names.SVG.html#tan/1"},{"type":"function","title":"Fledex.Color.Names.SVG.teal/1","doc":"Defines the color rgb(0, 128, 128).","ref":"Fledex.Color.Names.SVG.html#teal/1"},{"type":"function","title":"Fledex.Color.Names.SVG.thistle/1","doc":"Defines the color rgb(216, 191, 216).","ref":"Fledex.Color.Names.SVG.html#thistle/1"},{"type":"function","title":"Fledex.Color.Names.SVG.tomato/1","doc":"Defines the color rgb(255, 99, 71).","ref":"Fledex.Color.Names.SVG.html#tomato/1"},{"type":"function","title":"Fledex.Color.Names.SVG.turquoise/1","doc":"Defines the color rgb(64, 224, 208).","ref":"Fledex.Color.Names.SVG.html#turquoise/1"},{"type":"function","title":"Fledex.Color.Names.SVG.violet/1","doc":"Defines the color rgb(238, 130, 238).","ref":"Fledex.Color.Names.SVG.html#violet/1"},{"type":"function","title":"Fledex.Color.Names.SVG.wheat/1","doc":"Defines the color rgb(245, 222, 179).","ref":"Fledex.Color.Names.SVG.html#wheat/1"},{"type":"function","title":"Fledex.Color.Names.SVG.white/1","doc":"Defines the color rgb(255, 255, 255).","ref":"Fledex.Color.Names.SVG.html#white/1"},{"type":"function","title":"Fledex.Color.Names.SVG.whitesmoke/1","doc":"Defines the color rgb(245, 245, 245).","ref":"Fledex.Color.Names.SVG.html#whitesmoke/1"},{"type":"function","title":"Fledex.Color.Names.SVG.yellow/1","doc":"Defines the color rgb(255, 255, 0).","ref":"Fledex.Color.Names.SVG.html#yellow/1"},{"type":"function","title":"Fledex.Color.Names.SVG.yellowgreen/1","doc":"Defines the color rgb(154, 205, 50).","ref":"Fledex.Color.Names.SVG.html#yellowgreen/1"},{"type":"module","title":"Fledex.Color.Names.Types","doc":"","ref":"Fledex.Color.Names.Types.html"},{"type":"type","title":"Fledex.Color.Names.Types.color_names_t/0","doc":"The allowed color names","ref":"Fledex.Color.Names.Types.html#t:color_names_t/0"},{"type":"type","title":"Fledex.Color.Names.Types.color_props_t/0","doc":"The different properties that can be interrogated from a named color","ref":"Fledex.Color.Names.Types.html#t:color_props_t/0"},{"type":"type","title":"Fledex.Color.Names.Types.color_struct_t/0","doc":"The structure of a named color with all it's attributes.","ref":"Fledex.Color.Names.Types.html#t:color_struct_t/0"},{"type":"type","title":"Fledex.Color.Names.Types.color_vals_t/0","doc":"The different values that can be returned when interrogating for some named color properties","ref":"Fledex.Color.Names.Types.html#t:color_vals_t/0"},{"type":"module","title":"Fledex.Color.Names.Wiki","doc":"Do not use this module directly, but use Fledex.Color.Names instead","ref":"Fledex.Color.Names.Wiki.html"},{"type":"function","title":"Fledex.Color.Names.Wiki.absolute_zero/1","doc":"Defines the color rgb(0, 71, 186).","ref":"Fledex.Color.Names.Wiki.html#absolute_zero/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.acid_green/1","doc":"Defines the color rgb(175, 191, 25).","ref":"Fledex.Color.Names.Wiki.html#acid_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.aero/1","doc":"Defines the color rgb(124, 186, 232).","ref":"Fledex.Color.Names.Wiki.html#aero/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.african_violet/1","doc":"Defines the color rgb(178, 132, 191).","ref":"Fledex.Color.Names.Wiki.html#african_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.air_superiority_blue/1","doc":"Defines the color rgb(114, 160, 193).","ref":"Fledex.Color.Names.Wiki.html#air_superiority_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.alice_blue/1","doc":"Defines the color rgb(239, 247, 255).","ref":"Fledex.Color.Names.Wiki.html#alice_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.alizarin/1","doc":"Defines the color rgb(219, 45, 66).","ref":"Fledex.Color.Names.Wiki.html#alizarin/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.alloy_orange/1","doc":"Defines the color rgb(196, 96, 15).","ref":"Fledex.Color.Names.Wiki.html#alloy_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.almond/1","doc":"Defines the color rgb(239, 221, 204).","ref":"Fledex.Color.Names.Wiki.html#almond/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.amaranth_deep_purple/1","doc":"Defines the color rgb(158, 43, 104).","ref":"Fledex.Color.Names.Wiki.html#amaranth_deep_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.amaranth_pink/1","doc":"Defines the color rgb(242, 155, 186).","ref":"Fledex.Color.Names.Wiki.html#amaranth_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.amaranth_purple/1","doc":"Defines the color rgb(170, 38, 79).","ref":"Fledex.Color.Names.Wiki.html#amaranth_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.amazon/1","doc":"Defines the color rgb(58, 122, 86).","ref":"Fledex.Color.Names.Wiki.html#amazon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.amber/1","doc":"Defines the color rgb(255, 191, 0).","ref":"Fledex.Color.Names.Wiki.html#amber/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.amethyst/1","doc":"Defines the color rgb(153, 102, 204).","ref":"Fledex.Color.Names.Wiki.html#amethyst/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.android_green/1","doc":"Defines the color rgb(61, 219, 135).","ref":"Fledex.Color.Names.Wiki.html#android_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.antique_brass/1","doc":"Defines the color rgb(204, 147, 117).","ref":"Fledex.Color.Names.Wiki.html#antique_brass/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.antique_bronze/1","doc":"Defines the color rgb(102, 91, 30).","ref":"Fledex.Color.Names.Wiki.html#antique_bronze/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.antique_fuchsia/1","doc":"Defines the color rgb(145, 91, 130).","ref":"Fledex.Color.Names.Wiki.html#antique_fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.antique_ruby/1","doc":"Defines the color rgb(132, 28, 45).","ref":"Fledex.Color.Names.Wiki.html#antique_ruby/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.antique_white/1","doc":"Defines the color rgb(249, 234, 214).","ref":"Fledex.Color.Names.Wiki.html#antique_white/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.apricot/1","doc":"Defines the color rgb(249, 206, 175).","ref":"Fledex.Color.Names.Wiki.html#apricot/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.aqua/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.Wiki.html#aqua/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.aquamarine/1","doc":"Defines the color rgb(127, 255, 211).","ref":"Fledex.Color.Names.Wiki.html#aquamarine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.arctic_lime/1","doc":"Defines the color rgb(209, 255, 20).","ref":"Fledex.Color.Names.Wiki.html#arctic_lime/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.artichoke_green/1","doc":"Defines the color rgb(73, 112, 68).","ref":"Fledex.Color.Names.Wiki.html#artichoke_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.arylide_yellow/1","doc":"Defines the color rgb(232, 214, 107).","ref":"Fledex.Color.Names.Wiki.html#arylide_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ash_gray/1","doc":"Defines the color rgb(178, 191, 181).","ref":"Fledex.Color.Names.Wiki.html#ash_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.atomic_tangerine/1","doc":"Defines the color rgb(255, 153, 102).","ref":"Fledex.Color.Names.Wiki.html#atomic_tangerine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.aureolin/1","doc":"Defines the color rgb(252, 237, 0).","ref":"Fledex.Color.Names.Wiki.html#aureolin/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.azure/1","doc":"Defines the color rgb(0, 127, 255).","ref":"Fledex.Color.Names.Wiki.html#azure/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.azure_x11_web_color/1","doc":"Defines the color rgb(239, 255, 255).","ref":"Fledex.Color.Names.Wiki.html#azure_x11_web_color/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.b_dazzled_blue/1","doc":"Defines the color rgb(45, 89, 147).","ref":"Fledex.Color.Names.Wiki.html#b_dazzled_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.baby_blue/1","doc":"Defines the color rgb(137, 206, 239).","ref":"Fledex.Color.Names.Wiki.html#baby_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.baby_blue_eyes/1","doc":"Defines the color rgb(160, 201, 242).","ref":"Fledex.Color.Names.Wiki.html#baby_blue_eyes/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.baby_pink/1","doc":"Defines the color rgb(244, 193, 193).","ref":"Fledex.Color.Names.Wiki.html#baby_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.baby_powder/1","doc":"Defines the color rgb(255, 255, 249).","ref":"Fledex.Color.Names.Wiki.html#baby_powder/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.baker_miller_pink/1","doc":"Defines the color rgb(255, 145, 175).","ref":"Fledex.Color.Names.Wiki.html#baker_miller_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.banana_mania/1","doc":"Defines the color rgb(249, 232, 181).","ref":"Fledex.Color.Names.Wiki.html#banana_mania/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.barn_red/1","doc":"Defines the color rgb(124, 10, 2).","ref":"Fledex.Color.Names.Wiki.html#barn_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.battleship_grey/1","doc":"Defines the color rgb(132, 132, 130).","ref":"Fledex.Color.Names.Wiki.html#battleship_grey/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.beau_blue/1","doc":"Defines the color rgb(188, 211, 229).","ref":"Fledex.Color.Names.Wiki.html#beau_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.beaver/1","doc":"Defines the color rgb(158, 130, 112).","ref":"Fledex.Color.Names.Wiki.html#beaver/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.beige/1","doc":"Defines the color rgb(244, 244, 219).","ref":"Fledex.Color.Names.Wiki.html#beige/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.big_dip_o_ruby/1","doc":"Defines the color rgb(155, 38, 66).","ref":"Fledex.Color.Names.Wiki.html#big_dip_o_ruby/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bisque/1","doc":"Defines the color rgb(255, 226, 196).","ref":"Fledex.Color.Names.Wiki.html#bisque/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bistre/1","doc":"Defines the color rgb(61, 43, 30).","ref":"Fledex.Color.Names.Wiki.html#bistre/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bistre_brown/1","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.Wiki.html#bistre_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bitter_lemon/1","doc":"Defines the color rgb(201, 224, 12).","ref":"Fledex.Color.Names.Wiki.html#bitter_lemon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.black/1","doc":"Defines the color rgb(0, 0, 0).","ref":"Fledex.Color.Names.Wiki.html#black/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.black_bean/1","doc":"Defines the color rgb(61, 12, 2).","ref":"Fledex.Color.Names.Wiki.html#black_bean/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.black_coral/1","doc":"Defines the color rgb(84, 96, 112).","ref":"Fledex.Color.Names.Wiki.html#black_coral/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.black_olive/1","doc":"Defines the color rgb(58, 61, 53).","ref":"Fledex.Color.Names.Wiki.html#black_olive/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.black_shadows/1","doc":"Defines the color rgb(191, 175, 178).","ref":"Fledex.Color.Names.Wiki.html#black_shadows/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blanched_almond/1","doc":"Defines the color rgb(255, 234, 204).","ref":"Fledex.Color.Names.Wiki.html#blanched_almond/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blast_off_bronze/1","doc":"Defines the color rgb(165, 112, 99).","ref":"Fledex.Color.Names.Wiki.html#blast_off_bronze/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bleu_de_france/1","doc":"Defines the color rgb(48, 140, 232).","ref":"Fledex.Color.Names.Wiki.html#bleu_de_france/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blizzard_blue/1","doc":"Defines the color rgb(170, 229, 237).","ref":"Fledex.Color.Names.Wiki.html#blizzard_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blood_red/1","doc":"Defines the color rgb(102, 0, 0).","ref":"Fledex.Color.Names.Wiki.html#blood_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue/1","doc":"Defines the color rgb(0, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_bell/1","doc":"Defines the color rgb(163, 163, 209).","ref":"Fledex.Color.Names.Wiki.html#blue_bell/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_crayola/1","doc":"Defines the color rgb(30, 117, 255).","ref":"Fledex.Color.Names.Wiki.html#blue_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_gray_crayola/1","doc":"Defines the color rgb(102, 153, 204).","ref":"Fledex.Color.Names.Wiki.html#blue_gray_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_jeans/1","doc":"Defines the color rgb(91, 173, 237).","ref":"Fledex.Color.Names.Wiki.html#blue_jeans/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_munsell/1","doc":"Defines the color rgb(0, 147, 175).","ref":"Fledex.Color.Names.Wiki.html#blue_munsell/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_ncs/1","doc":"Defines the color rgb(0, 135, 188).","ref":"Fledex.Color.Names.Wiki.html#blue_ncs/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_pantone/1","doc":"Defines the color rgb(0, 22, 168).","ref":"Fledex.Color.Names.Wiki.html#blue_pantone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_pigment/1","doc":"Defines the color rgb(51, 51, 153).","ref":"Fledex.Color.Names.Wiki.html#blue_pigment/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_sapphire/1","doc":"Defines the color rgb(17, 96, 127).","ref":"Fledex.Color.Names.Wiki.html#blue_sapphire/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_violet/1","doc":"Defines the color rgb(137, 43, 226).","ref":"Fledex.Color.Names.Wiki.html#blue_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blue_yonder/1","doc":"Defines the color rgb(79, 114, 165).","ref":"Fledex.Color.Names.Wiki.html#blue_yonder/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bluetiful/1","doc":"Defines the color rgb(61, 104, 232).","ref":"Fledex.Color.Names.Wiki.html#bluetiful/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.blush/1","doc":"Defines the color rgb(221, 91, 130).","ref":"Fledex.Color.Names.Wiki.html#blush/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bole/1","doc":"Defines the color rgb(119, 68, 58).","ref":"Fledex.Color.Names.Wiki.html#bole/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bone/1","doc":"Defines the color rgb(226, 216, 201).","ref":"Fledex.Color.Names.Wiki.html#bone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.brick_red/1","doc":"Defines the color rgb(204, 63, 84).","ref":"Fledex.Color.Names.Wiki.html#brick_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bright_lilac/1","doc":"Defines the color rgb(216, 145, 239).","ref":"Fledex.Color.Names.Wiki.html#bright_lilac/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bright_yellow_crayola/1","doc":"Defines the color rgb(255, 170, 28).","ref":"Fledex.Color.Names.Wiki.html#bright_yellow_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bronze/1","doc":"Defines the color rgb(204, 127, 51).","ref":"Fledex.Color.Names.Wiki.html#bronze/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.brown_sugar/1","doc":"Defines the color rgb(175, 109, 76).","ref":"Fledex.Color.Names.Wiki.html#brown_sugar/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.bud_green/1","doc":"Defines the color rgb(122, 181, 96).","ref":"Fledex.Color.Names.Wiki.html#bud_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.buff/1","doc":"Defines the color rgb(255, 198, 127).","ref":"Fledex.Color.Names.Wiki.html#buff/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.burgundy/1","doc":"Defines the color rgb(127, 0, 33).","ref":"Fledex.Color.Names.Wiki.html#burgundy/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.burlywood/1","doc":"Defines the color rgb(221, 183, 135).","ref":"Fledex.Color.Names.Wiki.html#burlywood/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.burnished_brown/1","doc":"Defines the color rgb(160, 122, 114).","ref":"Fledex.Color.Names.Wiki.html#burnished_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.burnt_orange/1","doc":"Defines the color rgb(204, 84, 0).","ref":"Fledex.Color.Names.Wiki.html#burnt_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.burnt_sienna/1","doc":"Defines the color rgb(232, 114, 81).","ref":"Fledex.Color.Names.Wiki.html#burnt_sienna/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.burnt_umber/1","doc":"Defines the color rgb(137, 51, 35).","ref":"Fledex.Color.Names.Wiki.html#burnt_umber/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.byzantine/1","doc":"Defines the color rgb(188, 51, 163).","ref":"Fledex.Color.Names.Wiki.html#byzantine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.byzantium/1","doc":"Defines the color rgb(112, 40, 99).","ref":"Fledex.Color.Names.Wiki.html#byzantium/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cadet_blue/1","doc":"Defines the color rgb(94, 158, 160).","ref":"Fledex.Color.Names.Wiki.html#cadet_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cadet_grey/1","doc":"Defines the color rgb(145, 163, 175).","ref":"Fledex.Color.Names.Wiki.html#cadet_grey/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cadmium_green/1","doc":"Defines the color rgb(0, 107, 61).","ref":"Fledex.Color.Names.Wiki.html#cadmium_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cadmium_orange/1","doc":"Defines the color rgb(237, 135, 45).","ref":"Fledex.Color.Names.Wiki.html#cadmium_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cafe_au_lait/1","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.Wiki.html#cafe_au_lait/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cafe_noir/1","doc":"Defines the color rgb(73, 53, 33).","ref":"Fledex.Color.Names.Wiki.html#cafe_noir/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cambridge_blue/1","doc":"Defines the color rgb(163, 193, 173).","ref":"Fledex.Color.Names.Wiki.html#cambridge_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.camel/1","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.Wiki.html#camel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cameo_pink/1","doc":"Defines the color rgb(239, 186, 204).","ref":"Fledex.Color.Names.Wiki.html#cameo_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.canary/1","doc":"Defines the color rgb(255, 255, 153).","ref":"Fledex.Color.Names.Wiki.html#canary/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.canary_yellow/1","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.Wiki.html#canary_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.candy_pink/1","doc":"Defines the color rgb(226, 112, 122).","ref":"Fledex.Color.Names.Wiki.html#candy_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cardinal/1","doc":"Defines the color rgb(196, 30, 58).","ref":"Fledex.Color.Names.Wiki.html#cardinal/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.caribbean_green/1","doc":"Defines the color rgb(0, 204, 153).","ref":"Fledex.Color.Names.Wiki.html#caribbean_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.carmine/1","doc":"Defines the color rgb(150, 0, 22).","ref":"Fledex.Color.Names.Wiki.html#carmine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.carmine_m_p/1","doc":"Defines the color rgb(214, 0, 63).","ref":"Fledex.Color.Names.Wiki.html#carmine_m_p/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.carnation_pink/1","doc":"Defines the color rgb(255, 165, 201).","ref":"Fledex.Color.Names.Wiki.html#carnation_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.carnelian/1","doc":"Defines the color rgb(178, 28, 28).","ref":"Fledex.Color.Names.Wiki.html#carnelian/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.carolina_blue/1","doc":"Defines the color rgb(86, 160, 211).","ref":"Fledex.Color.Names.Wiki.html#carolina_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.carrot_orange/1","doc":"Defines the color rgb(237, 145, 33).","ref":"Fledex.Color.Names.Wiki.html#carrot_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.catawba/1","doc":"Defines the color rgb(112, 53, 66).","ref":"Fledex.Color.Names.Wiki.html#catawba/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cedar_chest/1","doc":"Defines the color rgb(201, 89, 73).","ref":"Fledex.Color.Names.Wiki.html#cedar_chest/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.celadon/1","doc":"Defines the color rgb(170, 224, 175).","ref":"Fledex.Color.Names.Wiki.html#celadon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.celeste/1","doc":"Defines the color rgb(178, 255, 255).","ref":"Fledex.Color.Names.Wiki.html#celeste/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cerise/1","doc":"Defines the color rgb(221, 48, 99).","ref":"Fledex.Color.Names.Wiki.html#cerise/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cerulean/1","doc":"Defines the color rgb(0, 122, 165).","ref":"Fledex.Color.Names.Wiki.html#cerulean/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cerulean_blue/1","doc":"Defines the color rgb(40, 81, 191).","ref":"Fledex.Color.Names.Wiki.html#cerulean_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cerulean_crayola/1","doc":"Defines the color rgb(28, 170, 214).","ref":"Fledex.Color.Names.Wiki.html#cerulean_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cerulean_frost/1","doc":"Defines the color rgb(109, 155, 193).","ref":"Fledex.Color.Names.Wiki.html#cerulean_frost/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.champagne/1","doc":"Defines the color rgb(247, 232, 206).","ref":"Fledex.Color.Names.Wiki.html#champagne/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.champagne_pink/1","doc":"Defines the color rgb(242, 221, 206).","ref":"Fledex.Color.Names.Wiki.html#champagne_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.charcoal/1","doc":"Defines the color rgb(53, 68, 79).","ref":"Fledex.Color.Names.Wiki.html#charcoal/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.charm_pink/1","doc":"Defines the color rgb(229, 142, 170).","ref":"Fledex.Color.Names.Wiki.html#charm_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.chartreuse_web/1","doc":"Defines the color rgb(127, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#chartreuse_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cherry_blossom_pink/1","doc":"Defines the color rgb(255, 183, 196).","ref":"Fledex.Color.Names.Wiki.html#cherry_blossom_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.chestnut/1","doc":"Defines the color rgb(147, 68, 53).","ref":"Fledex.Color.Names.Wiki.html#chestnut/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.chili_red/1","doc":"Defines the color rgb(226, 61, 40).","ref":"Fledex.Color.Names.Wiki.html#chili_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.china_pink/1","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.Wiki.html#china_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.chinese_red/1","doc":"Defines the color rgb(170, 56, 30).","ref":"Fledex.Color.Names.Wiki.html#chinese_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.chinese_violet/1","doc":"Defines the color rgb(132, 96, 135).","ref":"Fledex.Color.Names.Wiki.html#chinese_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.chinese_yellow/1","doc":"Defines the color rgb(255, 178, 0).","ref":"Fledex.Color.Names.Wiki.html#chinese_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.chocolate_traditional/1","doc":"Defines the color rgb(122, 63, 0).","ref":"Fledex.Color.Names.Wiki.html#chocolate_traditional/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.chocolate_web/1","doc":"Defines the color rgb(209, 104, 30).","ref":"Fledex.Color.Names.Wiki.html#chocolate_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cinereous/1","doc":"Defines the color rgb(153, 130, 122).","ref":"Fledex.Color.Names.Wiki.html#cinereous/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cinnabar/1","doc":"Defines the color rgb(226, 66, 51).","ref":"Fledex.Color.Names.Wiki.html#cinnabar/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cinnamon_satin/1","doc":"Defines the color rgb(204, 96, 124).","ref":"Fledex.Color.Names.Wiki.html#cinnamon_satin/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.citrine/1","doc":"Defines the color rgb(226, 209, 10).","ref":"Fledex.Color.Names.Wiki.html#citrine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.citron/1","doc":"Defines the color rgb(158, 168, 30).","ref":"Fledex.Color.Names.Wiki.html#citron/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.claret/1","doc":"Defines the color rgb(127, 22, 51).","ref":"Fledex.Color.Names.Wiki.html#claret/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.coffee/1","doc":"Defines the color rgb(112, 79, 56).","ref":"Fledex.Color.Names.Wiki.html#coffee/1"},{"type":"type","title":"Fledex.Color.Names.Wiki.color_names_t/0","doc":"The allowed color names","ref":"Fledex.Color.Names.Wiki.html#t:color_names_t/0"},{"type":"function","title":"Fledex.Color.Names.Wiki.colors/0","doc":"Get all the data about the predefined colors","ref":"Fledex.Color.Names.Wiki.html#colors/0"},{"type":"function","title":"Fledex.Color.Names.Wiki.columbia_blue/1","doc":"Defines the color rgb(186, 216, 234).","ref":"Fledex.Color.Names.Wiki.html#columbia_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.congo_pink/1","doc":"Defines the color rgb(247, 130, 119).","ref":"Fledex.Color.Names.Wiki.html#congo_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cool_grey/1","doc":"Defines the color rgb(140, 145, 170).","ref":"Fledex.Color.Names.Wiki.html#cool_grey/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.copper/1","doc":"Defines the color rgb(183, 114, 51).","ref":"Fledex.Color.Names.Wiki.html#copper/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.copper_crayola/1","doc":"Defines the color rgb(216, 137, 102).","ref":"Fledex.Color.Names.Wiki.html#copper_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.copper_penny/1","doc":"Defines the color rgb(173, 112, 104).","ref":"Fledex.Color.Names.Wiki.html#copper_penny/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.copper_red/1","doc":"Defines the color rgb(204, 109, 81).","ref":"Fledex.Color.Names.Wiki.html#copper_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.copper_rose/1","doc":"Defines the color rgb(153, 102, 102).","ref":"Fledex.Color.Names.Wiki.html#copper_rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.coquelicot/1","doc":"Defines the color rgb(255, 56, 0).","ref":"Fledex.Color.Names.Wiki.html#coquelicot/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.coral/1","doc":"Defines the color rgb(255, 127, 79).","ref":"Fledex.Color.Names.Wiki.html#coral/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.coral_pink/1","doc":"Defines the color rgb(247, 130, 119).","ref":"Fledex.Color.Names.Wiki.html#coral_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cordovan/1","doc":"Defines the color rgb(137, 63, 68).","ref":"Fledex.Color.Names.Wiki.html#cordovan/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.corn/1","doc":"Defines the color rgb(249, 237, 91).","ref":"Fledex.Color.Names.Wiki.html#corn/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cornflower_blue/1","doc":"Defines the color rgb(99, 147, 237).","ref":"Fledex.Color.Names.Wiki.html#cornflower_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cornsilk/1","doc":"Defines the color rgb(255, 247, 219).","ref":"Fledex.Color.Names.Wiki.html#cornsilk/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cosmic_cobalt/1","doc":"Defines the color rgb(45, 45, 135).","ref":"Fledex.Color.Names.Wiki.html#cosmic_cobalt/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cosmic_latte/1","doc":"Defines the color rgb(255, 247, 232).","ref":"Fledex.Color.Names.Wiki.html#cosmic_latte/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cotton_candy/1","doc":"Defines the color rgb(255, 188, 216).","ref":"Fledex.Color.Names.Wiki.html#cotton_candy/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.coyote_brown/1","doc":"Defines the color rgb(130, 96, 61).","ref":"Fledex.Color.Names.Wiki.html#coyote_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cream/1","doc":"Defines the color rgb(255, 252, 209).","ref":"Fledex.Color.Names.Wiki.html#cream/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.crimson/1","doc":"Defines the color rgb(219, 20, 61).","ref":"Fledex.Color.Names.Wiki.html#crimson/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.crimson_ua/1","doc":"Defines the color rgb(158, 28, 51).","ref":"Fledex.Color.Names.Wiki.html#crimson_ua/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cultured_pearl/1","doc":"Defines the color rgb(244, 244, 244).","ref":"Fledex.Color.Names.Wiki.html#cultured_pearl/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cyan/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.Wiki.html#cyan/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cyan_process/1","doc":"Defines the color rgb(0, 183, 234).","ref":"Fledex.Color.Names.Wiki.html#cyan_process/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cyber_grape/1","doc":"Defines the color rgb(89, 66, 124).","ref":"Fledex.Color.Names.Wiki.html#cyber_grape/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cyber_yellow/1","doc":"Defines the color rgb(255, 211, 0).","ref":"Fledex.Color.Names.Wiki.html#cyber_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.cyclamen/1","doc":"Defines the color rgb(244, 112, 160).","ref":"Fledex.Color.Names.Wiki.html#cyclamen/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_brown/1","doc":"Defines the color rgb(102, 66, 33).","ref":"Fledex.Color.Names.Wiki.html#dark_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_byzantium/1","doc":"Defines the color rgb(91, 56, 84).","ref":"Fledex.Color.Names.Wiki.html#dark_byzantium/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_cyan/1","doc":"Defines the color rgb(0, 140, 140).","ref":"Fledex.Color.Names.Wiki.html#dark_cyan/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_electric_blue/1","doc":"Defines the color rgb(84, 104, 119).","ref":"Fledex.Color.Names.Wiki.html#dark_electric_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_goldenrod/1","doc":"Defines the color rgb(183, 135, 10).","ref":"Fledex.Color.Names.Wiki.html#dark_goldenrod/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_green_x11/1","doc":"Defines the color rgb(0, 99, 0).","ref":"Fledex.Color.Names.Wiki.html#dark_green_x11/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_jungle_green/1","doc":"Defines the color rgb(25, 35, 33).","ref":"Fledex.Color.Names.Wiki.html#dark_jungle_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_khaki/1","doc":"Defines the color rgb(188, 183, 107).","ref":"Fledex.Color.Names.Wiki.html#dark_khaki/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_lava/1","doc":"Defines the color rgb(71, 61, 51).","ref":"Fledex.Color.Names.Wiki.html#dark_lava/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_liver_horses/1","doc":"Defines the color rgb(84, 61, 56).","ref":"Fledex.Color.Names.Wiki.html#dark_liver_horses/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_magenta/1","doc":"Defines the color rgb(140, 0, 140).","ref":"Fledex.Color.Names.Wiki.html#dark_magenta/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_olive_green/1","doc":"Defines the color rgb(84, 107, 45).","ref":"Fledex.Color.Names.Wiki.html#dark_olive_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_orange/1","doc":"Defines the color rgb(255, 140, 0).","ref":"Fledex.Color.Names.Wiki.html#dark_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_orchid/1","doc":"Defines the color rgb(153, 51, 204).","ref":"Fledex.Color.Names.Wiki.html#dark_orchid/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_purple/1","doc":"Defines the color rgb(48, 25, 51).","ref":"Fledex.Color.Names.Wiki.html#dark_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_red/1","doc":"Defines the color rgb(140, 0, 0).","ref":"Fledex.Color.Names.Wiki.html#dark_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_salmon/1","doc":"Defines the color rgb(232, 150, 122).","ref":"Fledex.Color.Names.Wiki.html#dark_salmon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_sea_green/1","doc":"Defines the color rgb(142, 188, 142).","ref":"Fledex.Color.Names.Wiki.html#dark_sea_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_sienna/1","doc":"Defines the color rgb(61, 20, 20).","ref":"Fledex.Color.Names.Wiki.html#dark_sienna/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_sky_blue/1","doc":"Defines the color rgb(140, 191, 214).","ref":"Fledex.Color.Names.Wiki.html#dark_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_slate_blue/1","doc":"Defines the color rgb(71, 61, 140).","ref":"Fledex.Color.Names.Wiki.html#dark_slate_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_slate_gray/1","doc":"Defines the color rgb(45, 79, 79).","ref":"Fledex.Color.Names.Wiki.html#dark_slate_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_spring_green/1","doc":"Defines the color rgb(22, 114, 68).","ref":"Fledex.Color.Names.Wiki.html#dark_spring_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_turquoise/1","doc":"Defines the color rgb(0, 206, 209).","ref":"Fledex.Color.Names.Wiki.html#dark_turquoise/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dark_violet/1","doc":"Defines the color rgb(147, 0, 211).","ref":"Fledex.Color.Names.Wiki.html#dark_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.davy_s_grey/1","doc":"Defines the color rgb(84, 84, 84).","ref":"Fledex.Color.Names.Wiki.html#davy_s_grey/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_cerise/1","doc":"Defines the color rgb(216, 51, 135).","ref":"Fledex.Color.Names.Wiki.html#deep_cerise/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_champagne/1","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.Wiki.html#deep_champagne/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_chestnut/1","doc":"Defines the color rgb(186, 79, 71).","ref":"Fledex.Color.Names.Wiki.html#deep_chestnut/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_jungle_green/1","doc":"Defines the color rgb(0, 73, 73).","ref":"Fledex.Color.Names.Wiki.html#deep_jungle_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_pink/1","doc":"Defines the color rgb(255, 20, 147).","ref":"Fledex.Color.Names.Wiki.html#deep_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_saffron/1","doc":"Defines the color rgb(255, 153, 51).","ref":"Fledex.Color.Names.Wiki.html#deep_saffron/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_sky_blue/1","doc":"Defines the color rgb(0, 191, 255).","ref":"Fledex.Color.Names.Wiki.html#deep_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_space_sparkle/1","doc":"Defines the color rgb(73, 99, 107).","ref":"Fledex.Color.Names.Wiki.html#deep_space_sparkle/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.deep_taupe/1","doc":"Defines the color rgb(124, 94, 96).","ref":"Fledex.Color.Names.Wiki.html#deep_taupe/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.denim/1","doc":"Defines the color rgb(20, 96, 188).","ref":"Fledex.Color.Names.Wiki.html#denim/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.denim_blue/1","doc":"Defines the color rgb(33, 66, 181).","ref":"Fledex.Color.Names.Wiki.html#denim_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.desert/1","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.Wiki.html#desert/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.desert_sand/1","doc":"Defines the color rgb(237, 201, 175).","ref":"Fledex.Color.Names.Wiki.html#desert_sand/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dim_gray/1","doc":"Defines the color rgb(104, 104, 104).","ref":"Fledex.Color.Names.Wiki.html#dim_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dodger_blue/1","doc":"Defines the color rgb(30, 142, 255).","ref":"Fledex.Color.Names.Wiki.html#dodger_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.drab_dark_brown/1","doc":"Defines the color rgb(73, 63, 40).","ref":"Fledex.Color.Names.Wiki.html#drab_dark_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.duke_blue/1","doc":"Defines the color rgb(0, 0, 155).","ref":"Fledex.Color.Names.Wiki.html#duke_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.dutch_white/1","doc":"Defines the color rgb(239, 221, 186).","ref":"Fledex.Color.Names.Wiki.html#dutch_white/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ebony/1","doc":"Defines the color rgb(84, 91, 79).","ref":"Fledex.Color.Names.Wiki.html#ebony/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ecru/1","doc":"Defines the color rgb(193, 178, 127).","ref":"Fledex.Color.Names.Wiki.html#ecru/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.eerie_black/1","doc":"Defines the color rgb(28, 28, 28).","ref":"Fledex.Color.Names.Wiki.html#eerie_black/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.eggplant/1","doc":"Defines the color rgb(96, 63, 81).","ref":"Fledex.Color.Names.Wiki.html#eggplant/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.eggshell/1","doc":"Defines the color rgb(239, 234, 214).","ref":"Fledex.Color.Names.Wiki.html#eggshell/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.electric_lime/1","doc":"Defines the color rgb(204, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#electric_lime/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.electric_purple/1","doc":"Defines the color rgb(191, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#electric_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.electric_violet/1","doc":"Defines the color rgb(142, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#electric_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.emerald/1","doc":"Defines the color rgb(79, 198, 119).","ref":"Fledex.Color.Names.Wiki.html#emerald/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.eminence/1","doc":"Defines the color rgb(107, 48, 130).","ref":"Fledex.Color.Names.Wiki.html#eminence/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.english_lavender/1","doc":"Defines the color rgb(181, 130, 147).","ref":"Fledex.Color.Names.Wiki.html#english_lavender/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.english_red/1","doc":"Defines the color rgb(170, 73, 81).","ref":"Fledex.Color.Names.Wiki.html#english_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.english_vermillion/1","doc":"Defines the color rgb(204, 71, 73).","ref":"Fledex.Color.Names.Wiki.html#english_vermillion/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.english_violet/1","doc":"Defines the color rgb(86, 61, 91).","ref":"Fledex.Color.Names.Wiki.html#english_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.erin/1","doc":"Defines the color rgb(0, 255, 63).","ref":"Fledex.Color.Names.Wiki.html#erin/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.eton_blue/1","doc":"Defines the color rgb(150, 198, 163).","ref":"Fledex.Color.Names.Wiki.html#eton_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fallow/1","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.Wiki.html#fallow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.falu_red/1","doc":"Defines the color rgb(127, 22, 22).","ref":"Fledex.Color.Names.Wiki.html#falu_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fandango/1","doc":"Defines the color rgb(181, 51, 137).","ref":"Fledex.Color.Names.Wiki.html#fandango/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fandango_pink/1","doc":"Defines the color rgb(221, 81, 132).","ref":"Fledex.Color.Names.Wiki.html#fandango_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fawn/1","doc":"Defines the color rgb(229, 170, 112).","ref":"Fledex.Color.Names.Wiki.html#fawn/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fern_green/1","doc":"Defines the color rgb(79, 119, 66).","ref":"Fledex.Color.Names.Wiki.html#fern_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.field_drab/1","doc":"Defines the color rgb(107, 84, 30).","ref":"Fledex.Color.Names.Wiki.html#field_drab/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fiery_rose/1","doc":"Defines the color rgb(255, 84, 112).","ref":"Fledex.Color.Names.Wiki.html#fiery_rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.file/0","doc":"","ref":"Fledex.Color.Names.Wiki.html#file/0"},{"type":"function","title":"Fledex.Color.Names.Wiki.finn/1","doc":"Defines the color rgb(104, 48, 104).","ref":"Fledex.Color.Names.Wiki.html#finn/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fire_engine_red/1","doc":"Defines the color rgb(206, 33, 40).","ref":"Fledex.Color.Names.Wiki.html#fire_engine_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.firebrick/1","doc":"Defines the color rgb(178, 33, 33).","ref":"Fledex.Color.Names.Wiki.html#firebrick/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.flame/1","doc":"Defines the color rgb(226, 89, 33).","ref":"Fledex.Color.Names.Wiki.html#flame/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.flax/1","doc":"Defines the color rgb(237, 219, 130).","ref":"Fledex.Color.Names.Wiki.html#flax/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.flirt/1","doc":"Defines the color rgb(163, 0, 109).","ref":"Fledex.Color.Names.Wiki.html#flirt/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.floral_white/1","doc":"Defines the color rgb(255, 249, 239).","ref":"Fledex.Color.Names.Wiki.html#floral_white/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.forest_green_web/1","doc":"Defines the color rgb(33, 140, 33).","ref":"Fledex.Color.Names.Wiki.html#forest_green_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_beige/1","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.Wiki.html#french_beige/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_bistre/1","doc":"Defines the color rgb(132, 109, 76).","ref":"Fledex.Color.Names.Wiki.html#french_bistre/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_blue/1","doc":"Defines the color rgb(0, 114, 186).","ref":"Fledex.Color.Names.Wiki.html#french_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_fuchsia/1","doc":"Defines the color rgb(252, 63, 145).","ref":"Fledex.Color.Names.Wiki.html#french_fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_lilac/1","doc":"Defines the color rgb(135, 96, 142).","ref":"Fledex.Color.Names.Wiki.html#french_lilac/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_lime/1","doc":"Defines the color rgb(158, 252, 56).","ref":"Fledex.Color.Names.Wiki.html#french_lime/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_mauve/1","doc":"Defines the color rgb(211, 114, 211).","ref":"Fledex.Color.Names.Wiki.html#french_mauve/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_pink/1","doc":"Defines the color rgb(252, 107, 158).","ref":"Fledex.Color.Names.Wiki.html#french_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_raspberry/1","doc":"Defines the color rgb(198, 43, 71).","ref":"Fledex.Color.Names.Wiki.html#french_raspberry/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_sky_blue/1","doc":"Defines the color rgb(119, 181, 255).","ref":"Fledex.Color.Names.Wiki.html#french_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.french_violet/1","doc":"Defines the color rgb(135, 5, 206).","ref":"Fledex.Color.Names.Wiki.html#french_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.frostbite/1","doc":"Defines the color rgb(232, 53, 165).","ref":"Fledex.Color.Names.Wiki.html#frostbite/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fuchsia/1","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fuchsia_crayola/1","doc":"Defines the color rgb(193, 84, 193).","ref":"Fledex.Color.Names.Wiki.html#fuchsia_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fulvous/1","doc":"Defines the color rgb(226, 132, 0).","ref":"Fledex.Color.Names.Wiki.html#fulvous/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.fuzzy_wuzzy/1","doc":"Defines the color rgb(135, 66, 30).","ref":"Fledex.Color.Names.Wiki.html#fuzzy_wuzzy/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gainsboro/1","doc":"Defines the color rgb(219, 219, 219).","ref":"Fledex.Color.Names.Wiki.html#gainsboro/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gamboge/1","doc":"Defines the color rgb(226, 155, 15).","ref":"Fledex.Color.Names.Wiki.html#gamboge/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.generic_viridian/1","doc":"Defines the color rgb(0, 127, 102).","ref":"Fledex.Color.Names.Wiki.html#generic_viridian/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ghost_white/1","doc":"Defines the color rgb(247, 247, 255).","ref":"Fledex.Color.Names.Wiki.html#ghost_white/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.glaucous/1","doc":"Defines the color rgb(96, 130, 181).","ref":"Fledex.Color.Names.Wiki.html#glaucous/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.glossy_grape/1","doc":"Defines the color rgb(170, 145, 178).","ref":"Fledex.Color.Names.Wiki.html#glossy_grape/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.go_green/1","doc":"Defines the color rgb(0, 170, 102).","ref":"Fledex.Color.Names.Wiki.html#go_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gold_crayola/1","doc":"Defines the color rgb(229, 191, 137).","ref":"Fledex.Color.Names.Wiki.html#gold_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gold_fusion/1","doc":"Defines the color rgb(132, 117, 79).","ref":"Fledex.Color.Names.Wiki.html#gold_fusion/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gold_metallic/1","doc":"Defines the color rgb(211, 175, 56).","ref":"Fledex.Color.Names.Wiki.html#gold_metallic/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gold_web_golden/1","doc":"Defines the color rgb(255, 214, 0).","ref":"Fledex.Color.Names.Wiki.html#gold_web_golden/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.golden_brown/1","doc":"Defines the color rgb(153, 102, 20).","ref":"Fledex.Color.Names.Wiki.html#golden_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.golden_poppy/1","doc":"Defines the color rgb(252, 193, 0).","ref":"Fledex.Color.Names.Wiki.html#golden_poppy/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.golden_yellow/1","doc":"Defines the color rgb(255, 221, 0).","ref":"Fledex.Color.Names.Wiki.html#golden_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.goldenrod/1","doc":"Defines the color rgb(216, 165, 33).","ref":"Fledex.Color.Names.Wiki.html#goldenrod/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gotham_green/1","doc":"Defines the color rgb(0, 86, 63).","ref":"Fledex.Color.Names.Wiki.html#gotham_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.granite_gray/1","doc":"Defines the color rgb(102, 102, 102).","ref":"Fledex.Color.Names.Wiki.html#granite_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.granny_smith_apple/1","doc":"Defines the color rgb(168, 226, 160).","ref":"Fledex.Color.Names.Wiki.html#granny_smith_apple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gray_web/1","doc":"Defines the color rgb(127, 127, 127).","ref":"Fledex.Color.Names.Wiki.html#gray_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gray_x11_gray/1","doc":"Defines the color rgb(191, 191, 191).","ref":"Fledex.Color.Names.Wiki.html#gray_x11_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green/1","doc":"Defines the color rgb(0, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_blue/1","doc":"Defines the color rgb(17, 99, 181).","ref":"Fledex.Color.Names.Wiki.html#green_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_crayola/1","doc":"Defines the color rgb(28, 170, 119).","ref":"Fledex.Color.Names.Wiki.html#green_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_lizard/1","doc":"Defines the color rgb(165, 244, 51).","ref":"Fledex.Color.Names.Wiki.html#green_lizard/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_munsell/1","doc":"Defines the color rgb(0, 168, 119).","ref":"Fledex.Color.Names.Wiki.html#green_munsell/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_ncs/1","doc":"Defines the color rgb(0, 158, 107).","ref":"Fledex.Color.Names.Wiki.html#green_ncs/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_pantone/1","doc":"Defines the color rgb(0, 173, 66).","ref":"Fledex.Color.Names.Wiki.html#green_pantone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_pigment/1","doc":"Defines the color rgb(0, 165, 79).","ref":"Fledex.Color.Names.Wiki.html#green_pigment/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_sheen/1","doc":"Defines the color rgb(109, 173, 160).","ref":"Fledex.Color.Names.Wiki.html#green_sheen/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.green_web/1","doc":"Defines the color rgb(0, 127, 0).","ref":"Fledex.Color.Names.Wiki.html#green_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.gunmetal/1","doc":"Defines the color rgb(40, 51, 56).","ref":"Fledex.Color.Names.Wiki.html#gunmetal/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.hansa_yellow/1","doc":"Defines the color rgb(232, 214, 107).","ref":"Fledex.Color.Names.Wiki.html#hansa_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.harlequin/1","doc":"Defines the color rgb(63, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#harlequin/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.harvest_gold/1","doc":"Defines the color rgb(216, 145, 0).","ref":"Fledex.Color.Names.Wiki.html#harvest_gold/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.heat_wave/1","doc":"Defines the color rgb(255, 122, 0).","ref":"Fledex.Color.Names.Wiki.html#heat_wave/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.heliotrope/1","doc":"Defines the color rgb(221, 114, 255).","ref":"Fledex.Color.Names.Wiki.html#heliotrope/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.heliotrope_gray/1","doc":"Defines the color rgb(170, 153, 168).","ref":"Fledex.Color.Names.Wiki.html#heliotrope_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.hollywood_cerise/1","doc":"Defines the color rgb(244, 0, 160).","ref":"Fledex.Color.Names.Wiki.html#hollywood_cerise/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.honolulu_blue/1","doc":"Defines the color rgb(0, 109, 175).","ref":"Fledex.Color.Names.Wiki.html#honolulu_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.hooker_s_green/1","doc":"Defines the color rgb(73, 119, 107).","ref":"Fledex.Color.Names.Wiki.html#hooker_s_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.hot_magenta/1","doc":"Defines the color rgb(255, 28, 206).","ref":"Fledex.Color.Names.Wiki.html#hot_magenta/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.hot_pink/1","doc":"Defines the color rgb(255, 104, 181).","ref":"Fledex.Color.Names.Wiki.html#hot_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.hunter_green/1","doc":"Defines the color rgb(53, 94, 58).","ref":"Fledex.Color.Names.Wiki.html#hunter_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.iceberg/1","doc":"Defines the color rgb(112, 165, 209).","ref":"Fledex.Color.Names.Wiki.html#iceberg/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.illuminating_emerald/1","doc":"Defines the color rgb(48, 145, 119).","ref":"Fledex.Color.Names.Wiki.html#illuminating_emerald/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.imperial_red/1","doc":"Defines the color rgb(237, 40, 56).","ref":"Fledex.Color.Names.Wiki.html#imperial_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.inchworm/1","doc":"Defines the color rgb(178, 237, 91).","ref":"Fledex.Color.Names.Wiki.html#inchworm/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.independence/1","doc":"Defines the color rgb(76, 81, 109).","ref":"Fledex.Color.Names.Wiki.html#independence/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.india_green/1","doc":"Defines the color rgb(17, 135, 7).","ref":"Fledex.Color.Names.Wiki.html#india_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.indian_red/1","doc":"Defines the color rgb(204, 91, 91).","ref":"Fledex.Color.Names.Wiki.html#indian_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.indian_yellow/1","doc":"Defines the color rgb(226, 168, 86).","ref":"Fledex.Color.Names.Wiki.html#indian_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.indigo/1","doc":"Defines the color rgb(73, 0, 130).","ref":"Fledex.Color.Names.Wiki.html#indigo/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.indigo_dye/1","doc":"Defines the color rgb(0, 63, 107).","ref":"Fledex.Color.Names.Wiki.html#indigo_dye/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.international_klein_blue/1","doc":"Defines the color rgb(17, 10, 142).","ref":"Fledex.Color.Names.Wiki.html#international_klein_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.international_orange_engineering/1","doc":"Defines the color rgb(186, 22, 12).","ref":"Fledex.Color.Names.Wiki.html#international_orange_engineering/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.international_orange_golden_gate_bridge/1","doc":"Defines the color rgb(191, 53, 43).","ref":"Fledex.Color.Names.Wiki.html#international_orange_golden_gate_bridge/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.irresistible/1","doc":"Defines the color rgb(178, 68, 107).","ref":"Fledex.Color.Names.Wiki.html#irresistible/1"},{"type":"macro","title":"Fledex.Color.Names.Wiki.is_color_name/1","doc":"Check whether the atom is a valid color name","ref":"Fledex.Color.Names.Wiki.html#is_color_name/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.isabelline/1","doc":"Defines the color rgb(244, 239, 237).","ref":"Fledex.Color.Names.Wiki.html#isabelline/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.italian_sky_blue/1","doc":"Defines the color rgb(178, 255, 255).","ref":"Fledex.Color.Names.Wiki.html#italian_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ivory/1","doc":"Defines the color rgb(255, 255, 239).","ref":"Fledex.Color.Names.Wiki.html#ivory/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.japanese_carmine/1","doc":"Defines the color rgb(158, 40, 51).","ref":"Fledex.Color.Names.Wiki.html#japanese_carmine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.japanese_violet/1","doc":"Defines the color rgb(91, 51, 86).","ref":"Fledex.Color.Names.Wiki.html#japanese_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.jasmine/1","doc":"Defines the color rgb(247, 221, 124).","ref":"Fledex.Color.Names.Wiki.html#jasmine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.jazzberry_jam/1","doc":"Defines the color rgb(165, 10, 94).","ref":"Fledex.Color.Names.Wiki.html#jazzberry_jam/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.jet/1","doc":"Defines the color rgb(51, 51, 51).","ref":"Fledex.Color.Names.Wiki.html#jet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.jonquil/1","doc":"Defines the color rgb(244, 201, 22).","ref":"Fledex.Color.Names.Wiki.html#jonquil/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.june_bud/1","doc":"Defines the color rgb(188, 216, 86).","ref":"Fledex.Color.Names.Wiki.html#june_bud/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.jungle_green/1","doc":"Defines the color rgb(40, 170, 135).","ref":"Fledex.Color.Names.Wiki.html#jungle_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.kelly_green/1","doc":"Defines the color rgb(76, 186, 22).","ref":"Fledex.Color.Names.Wiki.html#kelly_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.keppel/1","doc":"Defines the color rgb(58, 175, 158).","ref":"Fledex.Color.Names.Wiki.html#keppel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.key_lime/1","doc":"Defines the color rgb(232, 244, 140).","ref":"Fledex.Color.Names.Wiki.html#key_lime/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.khaki_web/1","doc":"Defines the color rgb(193, 175, 145).","ref":"Fledex.Color.Names.Wiki.html#khaki_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.khaki_x11_light_khaki/1","doc":"Defines the color rgb(239, 229, 140).","ref":"Fledex.Color.Names.Wiki.html#khaki_x11_light_khaki/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.kobe/1","doc":"Defines the color rgb(135, 45, 22).","ref":"Fledex.Color.Names.Wiki.html#kobe/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.kobi/1","doc":"Defines the color rgb(232, 158, 196).","ref":"Fledex.Color.Names.Wiki.html#kobi/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.kobicha/1","doc":"Defines the color rgb(107, 68, 35).","ref":"Fledex.Color.Names.Wiki.html#kobicha/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ksu_purple/1","doc":"Defines the color rgb(79, 38, 130).","ref":"Fledex.Color.Names.Wiki.html#ksu_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.languid_lavender/1","doc":"Defines the color rgb(214, 201, 221).","ref":"Fledex.Color.Names.Wiki.html#languid_lavender/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lapis_lazuli/1","doc":"Defines the color rgb(38, 96, 155).","ref":"Fledex.Color.Names.Wiki.html#lapis_lazuli/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.laser_lemon/1","doc":"Defines the color rgb(255, 255, 102).","ref":"Fledex.Color.Names.Wiki.html#laser_lemon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.laurel_green/1","doc":"Defines the color rgb(168, 186, 158).","ref":"Fledex.Color.Names.Wiki.html#laurel_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lava/1","doc":"Defines the color rgb(206, 15, 33).","ref":"Fledex.Color.Names.Wiki.html#lava/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lavender_blue/1","doc":"Defines the color rgb(204, 204, 255).","ref":"Fledex.Color.Names.Wiki.html#lavender_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lavender_blush/1","doc":"Defines the color rgb(255, 239, 244).","ref":"Fledex.Color.Names.Wiki.html#lavender_blush/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lavender_floral/1","doc":"Defines the color rgb(181, 124, 219).","ref":"Fledex.Color.Names.Wiki.html#lavender_floral/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lavender_gray/1","doc":"Defines the color rgb(196, 193, 209).","ref":"Fledex.Color.Names.Wiki.html#lavender_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lavender_web/1","doc":"Defines the color rgb(229, 229, 249).","ref":"Fledex.Color.Names.Wiki.html#lavender_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lawn_green/1","doc":"Defines the color rgb(124, 252, 0).","ref":"Fledex.Color.Names.Wiki.html#lawn_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lemon/1","doc":"Defines the color rgb(255, 247, 0).","ref":"Fledex.Color.Names.Wiki.html#lemon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lemon_chiffon/1","doc":"Defines the color rgb(255, 249, 204).","ref":"Fledex.Color.Names.Wiki.html#lemon_chiffon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lemon_curry/1","doc":"Defines the color rgb(204, 160, 28).","ref":"Fledex.Color.Names.Wiki.html#lemon_curry/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lemon_glacier/1","doc":"Defines the color rgb(252, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#lemon_glacier/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lemon_meringue/1","doc":"Defines the color rgb(244, 234, 191).","ref":"Fledex.Color.Names.Wiki.html#lemon_meringue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lemon_yellow/1","doc":"Defines the color rgb(255, 244, 79).","ref":"Fledex.Color.Names.Wiki.html#lemon_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lemon_yellow_crayola/1","doc":"Defines the color rgb(255, 255, 158).","ref":"Fledex.Color.Names.Wiki.html#lemon_yellow_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.liberty/1","doc":"Defines the color rgb(84, 89, 165).","ref":"Fledex.Color.Names.Wiki.html#liberty/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_blue/1","doc":"Defines the color rgb(173, 216, 229).","ref":"Fledex.Color.Names.Wiki.html#light_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_coral/1","doc":"Defines the color rgb(239, 127, 127).","ref":"Fledex.Color.Names.Wiki.html#light_coral/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_cornflower_blue/1","doc":"Defines the color rgb(147, 204, 234).","ref":"Fledex.Color.Names.Wiki.html#light_cornflower_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_cyan/1","doc":"Defines the color rgb(224, 255, 255).","ref":"Fledex.Color.Names.Wiki.html#light_cyan/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_french_beige/1","doc":"Defines the color rgb(198, 173, 127).","ref":"Fledex.Color.Names.Wiki.html#light_french_beige/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_goldenrod_yellow/1","doc":"Defines the color rgb(249, 249, 209).","ref":"Fledex.Color.Names.Wiki.html#light_goldenrod_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_gray/1","doc":"Defines the color rgb(211, 211, 211).","ref":"Fledex.Color.Names.Wiki.html#light_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_green/1","doc":"Defines the color rgb(142, 237, 142).","ref":"Fledex.Color.Names.Wiki.html#light_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_orange/1","doc":"Defines the color rgb(255, 216, 175).","ref":"Fledex.Color.Names.Wiki.html#light_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_periwinkle/1","doc":"Defines the color rgb(196, 204, 224).","ref":"Fledex.Color.Names.Wiki.html#light_periwinkle/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_pink/1","doc":"Defines the color rgb(255, 181, 193).","ref":"Fledex.Color.Names.Wiki.html#light_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_salmon/1","doc":"Defines the color rgb(255, 160, 122).","ref":"Fledex.Color.Names.Wiki.html#light_salmon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_sea_green/1","doc":"Defines the color rgb(33, 178, 170).","ref":"Fledex.Color.Names.Wiki.html#light_sea_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_sky_blue/1","doc":"Defines the color rgb(135, 206, 249).","ref":"Fledex.Color.Names.Wiki.html#light_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_slate_gray/1","doc":"Defines the color rgb(119, 135, 153).","ref":"Fledex.Color.Names.Wiki.html#light_slate_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_steel_blue/1","doc":"Defines the color rgb(175, 196, 221).","ref":"Fledex.Color.Names.Wiki.html#light_steel_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.light_yellow/1","doc":"Defines the color rgb(255, 255, 224).","ref":"Fledex.Color.Names.Wiki.html#light_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lilac/1","doc":"Defines the color rgb(198, 163, 198).","ref":"Fledex.Color.Names.Wiki.html#lilac/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lilac_luster/1","doc":"Defines the color rgb(173, 153, 170).","ref":"Fledex.Color.Names.Wiki.html#lilac_luster/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lime_color_wheel/1","doc":"Defines the color rgb(191, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#lime_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lime_green/1","doc":"Defines the color rgb(51, 204, 51).","ref":"Fledex.Color.Names.Wiki.html#lime_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lime_web_x11_green/1","doc":"Defines the color rgb(0, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#lime_web_x11_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lincoln_green/1","doc":"Defines the color rgb(25, 89, 5).","ref":"Fledex.Color.Names.Wiki.html#lincoln_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.linen/1","doc":"Defines the color rgb(249, 239, 229).","ref":"Fledex.Color.Names.Wiki.html#linen/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.lion/1","doc":"Defines the color rgb(221, 204, 155).","ref":"Fledex.Color.Names.Wiki.html#lion/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.liseran_purple/1","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.Wiki.html#liseran_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.little_boy_blue/1","doc":"Defines the color rgb(107, 160, 219).","ref":"Fledex.Color.Names.Wiki.html#little_boy_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.liver/1","doc":"Defines the color rgb(102, 76, 71).","ref":"Fledex.Color.Names.Wiki.html#liver/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.liver_chestnut/1","doc":"Defines the color rgb(153, 114, 86).","ref":"Fledex.Color.Names.Wiki.html#liver_chestnut/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.liver_dogs/1","doc":"Defines the color rgb(183, 109, 40).","ref":"Fledex.Color.Names.Wiki.html#liver_dogs/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.liver_organ/1","doc":"Defines the color rgb(107, 45, 30).","ref":"Fledex.Color.Names.Wiki.html#liver_organ/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.livid/1","doc":"Defines the color rgb(102, 153, 204).","ref":"Fledex.Color.Names.Wiki.html#livid/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.macaroni_and_cheese/1","doc":"Defines the color rgb(255, 188, 135).","ref":"Fledex.Color.Names.Wiki.html#macaroni_and_cheese/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.madder_lake/1","doc":"Defines the color rgb(204, 51, 53).","ref":"Fledex.Color.Names.Wiki.html#madder_lake/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.magenta/1","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#magenta/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.magenta_crayola/1","doc":"Defines the color rgb(244, 84, 165).","ref":"Fledex.Color.Names.Wiki.html#magenta_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.magenta_dye/1","doc":"Defines the color rgb(201, 30, 122).","ref":"Fledex.Color.Names.Wiki.html#magenta_dye/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.magenta_haze/1","doc":"Defines the color rgb(158, 68, 117).","ref":"Fledex.Color.Names.Wiki.html#magenta_haze/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.magenta_pantone/1","doc":"Defines the color rgb(209, 63, 124).","ref":"Fledex.Color.Names.Wiki.html#magenta_pantone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.magenta_process/1","doc":"Defines the color rgb(255, 0, 142).","ref":"Fledex.Color.Names.Wiki.html#magenta_process/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.magic_mint/1","doc":"Defines the color rgb(170, 239, 209).","ref":"Fledex.Color.Names.Wiki.html#magic_mint/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.magnolia/1","doc":"Defines the color rgb(242, 232, 214).","ref":"Fledex.Color.Names.Wiki.html#magnolia/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mahogany/1","doc":"Defines the color rgb(191, 63, 0).","ref":"Fledex.Color.Names.Wiki.html#mahogany/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maize/1","doc":"Defines the color rgb(249, 237, 91).","ref":"Fledex.Color.Names.Wiki.html#maize/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maize_crayola/1","doc":"Defines the color rgb(242, 198, 73).","ref":"Fledex.Color.Names.Wiki.html#maize_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.majorelle_blue/1","doc":"Defines the color rgb(96, 79, 219).","ref":"Fledex.Color.Names.Wiki.html#majorelle_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.malachite/1","doc":"Defines the color rgb(10, 216, 81).","ref":"Fledex.Color.Names.Wiki.html#malachite/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.manatee/1","doc":"Defines the color rgb(150, 153, 170).","ref":"Fledex.Color.Names.Wiki.html#manatee/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mandarin/1","doc":"Defines the color rgb(242, 122, 71).","ref":"Fledex.Color.Names.Wiki.html#mandarin/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mango/1","doc":"Defines the color rgb(252, 191, 2).","ref":"Fledex.Color.Names.Wiki.html#mango/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mango_tango/1","doc":"Defines the color rgb(255, 130, 66).","ref":"Fledex.Color.Names.Wiki.html#mango_tango/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mantis/1","doc":"Defines the color rgb(114, 193, 102).","ref":"Fledex.Color.Names.Wiki.html#mantis/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mardi_gras/1","doc":"Defines the color rgb(135, 0, 132).","ref":"Fledex.Color.Names.Wiki.html#mardi_gras/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.marigold/1","doc":"Defines the color rgb(234, 163, 33).","ref":"Fledex.Color.Names.Wiki.html#marigold/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maroon_crayola/1","doc":"Defines the color rgb(193, 33, 71).","ref":"Fledex.Color.Names.Wiki.html#maroon_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maroon_web/1","doc":"Defines the color rgb(127, 0, 0).","ref":"Fledex.Color.Names.Wiki.html#maroon_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maroon_x11/1","doc":"Defines the color rgb(175, 48, 96).","ref":"Fledex.Color.Names.Wiki.html#maroon_x11/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mauve/1","doc":"Defines the color rgb(224, 175, 255).","ref":"Fledex.Color.Names.Wiki.html#mauve/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mauve_taupe/1","doc":"Defines the color rgb(145, 94, 109).","ref":"Fledex.Color.Names.Wiki.html#mauve_taupe/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mauvelous/1","doc":"Defines the color rgb(239, 153, 170).","ref":"Fledex.Color.Names.Wiki.html#mauvelous/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_blue/1","doc":"Defines the color rgb(71, 170, 204).","ref":"Fledex.Color.Names.Wiki.html#maximum_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_blue_green/1","doc":"Defines the color rgb(48, 191, 191).","ref":"Fledex.Color.Names.Wiki.html#maximum_blue_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_blue_purple/1","doc":"Defines the color rgb(170, 170, 229).","ref":"Fledex.Color.Names.Wiki.html#maximum_blue_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_green/1","doc":"Defines the color rgb(94, 140, 48).","ref":"Fledex.Color.Names.Wiki.html#maximum_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_green_yellow/1","doc":"Defines the color rgb(216, 229, 79).","ref":"Fledex.Color.Names.Wiki.html#maximum_green_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_purple/1","doc":"Defines the color rgb(114, 51, 127).","ref":"Fledex.Color.Names.Wiki.html#maximum_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_red/1","doc":"Defines the color rgb(216, 33, 33).","ref":"Fledex.Color.Names.Wiki.html#maximum_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_red_purple/1","doc":"Defines the color rgb(165, 58, 119).","ref":"Fledex.Color.Names.Wiki.html#maximum_red_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_yellow/1","doc":"Defines the color rgb(249, 249, 56).","ref":"Fledex.Color.Names.Wiki.html#maximum_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maximum_yellow_red/1","doc":"Defines the color rgb(242, 186, 73).","ref":"Fledex.Color.Names.Wiki.html#maximum_yellow_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.may_green/1","doc":"Defines the color rgb(76, 145, 63).","ref":"Fledex.Color.Names.Wiki.html#may_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.maya_blue/1","doc":"Defines the color rgb(114, 193, 249).","ref":"Fledex.Color.Names.Wiki.html#maya_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_aquamarine/1","doc":"Defines the color rgb(102, 221, 170).","ref":"Fledex.Color.Names.Wiki.html#medium_aquamarine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_blue/1","doc":"Defines the color rgb(0, 0, 204).","ref":"Fledex.Color.Names.Wiki.html#medium_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_candy_apple_red/1","doc":"Defines the color rgb(226, 5, 43).","ref":"Fledex.Color.Names.Wiki.html#medium_candy_apple_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_carmine/1","doc":"Defines the color rgb(175, 63, 53).","ref":"Fledex.Color.Names.Wiki.html#medium_carmine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_champagne/1","doc":"Defines the color rgb(242, 229, 170).","ref":"Fledex.Color.Names.Wiki.html#medium_champagne/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_orchid/1","doc":"Defines the color rgb(186, 84, 211).","ref":"Fledex.Color.Names.Wiki.html#medium_orchid/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_purple/1","doc":"Defines the color rgb(147, 112, 219).","ref":"Fledex.Color.Names.Wiki.html#medium_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_sea_green/1","doc":"Defines the color rgb(61, 178, 112).","ref":"Fledex.Color.Names.Wiki.html#medium_sea_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_slate_blue/1","doc":"Defines the color rgb(122, 104, 237).","ref":"Fledex.Color.Names.Wiki.html#medium_slate_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_spring_green/1","doc":"Defines the color rgb(0, 249, 153).","ref":"Fledex.Color.Names.Wiki.html#medium_spring_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_turquoise/1","doc":"Defines the color rgb(71, 209, 204).","ref":"Fledex.Color.Names.Wiki.html#medium_turquoise/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.medium_violet_red/1","doc":"Defines the color rgb(198, 20, 132).","ref":"Fledex.Color.Names.Wiki.html#medium_violet_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mellow_apricot/1","doc":"Defines the color rgb(247, 183, 119).","ref":"Fledex.Color.Names.Wiki.html#mellow_apricot/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mellow_yellow/1","doc":"Defines the color rgb(247, 221, 124).","ref":"Fledex.Color.Names.Wiki.html#mellow_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.melon/1","doc":"Defines the color rgb(255, 186, 173).","ref":"Fledex.Color.Names.Wiki.html#melon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.metallic_gold/1","doc":"Defines the color rgb(211, 175, 56).","ref":"Fledex.Color.Names.Wiki.html#metallic_gold/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.metallic_seaweed/1","doc":"Defines the color rgb(10, 124, 140).","ref":"Fledex.Color.Names.Wiki.html#metallic_seaweed/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.metallic_sunburst/1","doc":"Defines the color rgb(155, 124, 56).","ref":"Fledex.Color.Names.Wiki.html#metallic_sunburst/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mexican_pink/1","doc":"Defines the color rgb(226, 0, 124).","ref":"Fledex.Color.Names.Wiki.html#mexican_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_blue/1","doc":"Defines the color rgb(124, 211, 229).","ref":"Fledex.Color.Names.Wiki.html#middle_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_blue_green/1","doc":"Defines the color rgb(140, 216, 204).","ref":"Fledex.Color.Names.Wiki.html#middle_blue_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_blue_purple/1","doc":"Defines the color rgb(140, 114, 191).","ref":"Fledex.Color.Names.Wiki.html#middle_blue_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_green/1","doc":"Defines the color rgb(76, 140, 86).","ref":"Fledex.Color.Names.Wiki.html#middle_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_green_yellow/1","doc":"Defines the color rgb(170, 191, 96).","ref":"Fledex.Color.Names.Wiki.html#middle_green_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_grey/1","doc":"Defines the color rgb(140, 135, 127).","ref":"Fledex.Color.Names.Wiki.html#middle_grey/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_purple/1","doc":"Defines the color rgb(216, 130, 181).","ref":"Fledex.Color.Names.Wiki.html#middle_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_red/1","doc":"Defines the color rgb(229, 142, 114).","ref":"Fledex.Color.Names.Wiki.html#middle_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_red_purple/1","doc":"Defines the color rgb(165, 84, 84).","ref":"Fledex.Color.Names.Wiki.html#middle_red_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_yellow/1","doc":"Defines the color rgb(255, 234, 0).","ref":"Fledex.Color.Names.Wiki.html#middle_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.middle_yellow_red/1","doc":"Defines the color rgb(237, 175, 117).","ref":"Fledex.Color.Names.Wiki.html#middle_yellow_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.midnight/1","doc":"Defines the color rgb(112, 38, 112).","ref":"Fledex.Color.Names.Wiki.html#midnight/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.midnight_blue/1","doc":"Defines the color rgb(25, 25, 112).","ref":"Fledex.Color.Names.Wiki.html#midnight_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.midnight_green_eagle_green/1","doc":"Defines the color rgb(0, 73, 84).","ref":"Fledex.Color.Names.Wiki.html#midnight_green_eagle_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mikado_yellow/1","doc":"Defines the color rgb(255, 196, 12).","ref":"Fledex.Color.Names.Wiki.html#mikado_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mimi_pink/1","doc":"Defines the color rgb(255, 216, 232).","ref":"Fledex.Color.Names.Wiki.html#mimi_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mindaro/1","doc":"Defines the color rgb(226, 249, 135).","ref":"Fledex.Color.Names.Wiki.html#mindaro/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ming/1","doc":"Defines the color rgb(53, 114, 124).","ref":"Fledex.Color.Names.Wiki.html#ming/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.minion_yellow/1","doc":"Defines the color rgb(244, 219, 79).","ref":"Fledex.Color.Names.Wiki.html#minion_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mint/1","doc":"Defines the color rgb(61, 181, 137).","ref":"Fledex.Color.Names.Wiki.html#mint/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mint_cream/1","doc":"Defines the color rgb(244, 255, 249).","ref":"Fledex.Color.Names.Wiki.html#mint_cream/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mint_green/1","doc":"Defines the color rgb(153, 255, 153).","ref":"Fledex.Color.Names.Wiki.html#mint_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.misty_moss/1","doc":"Defines the color rgb(186, 181, 119).","ref":"Fledex.Color.Names.Wiki.html#misty_moss/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.misty_rose/1","doc":"Defines the color rgb(255, 226, 224).","ref":"Fledex.Color.Names.Wiki.html#misty_rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mode_beige/1","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.Wiki.html#mode_beige/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mona_lisa/1","doc":"Defines the color rgb(255, 147, 142).","ref":"Fledex.Color.Names.Wiki.html#mona_lisa/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.morning_blue/1","doc":"Defines the color rgb(140, 163, 153).","ref":"Fledex.Color.Names.Wiki.html#morning_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.moss_green/1","doc":"Defines the color rgb(137, 153, 91).","ref":"Fledex.Color.Names.Wiki.html#moss_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mountain_meadow/1","doc":"Defines the color rgb(48, 186, 142).","ref":"Fledex.Color.Names.Wiki.html#mountain_meadow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mountbatten_pink/1","doc":"Defines the color rgb(153, 122, 140).","ref":"Fledex.Color.Names.Wiki.html#mountbatten_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.msu_green/1","doc":"Defines the color rgb(22, 68, 58).","ref":"Fledex.Color.Names.Wiki.html#msu_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mulberry/1","doc":"Defines the color rgb(196, 73, 140).","ref":"Fledex.Color.Names.Wiki.html#mulberry/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mulberry_crayola/1","doc":"Defines the color rgb(198, 79, 155).","ref":"Fledex.Color.Names.Wiki.html#mulberry_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mustard/1","doc":"Defines the color rgb(255, 219, 89).","ref":"Fledex.Color.Names.Wiki.html#mustard/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.myrtle_green/1","doc":"Defines the color rgb(48, 119, 114).","ref":"Fledex.Color.Names.Wiki.html#myrtle_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mystic/1","doc":"Defines the color rgb(214, 81, 130).","ref":"Fledex.Color.Names.Wiki.html#mystic/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.mystic_maroon/1","doc":"Defines the color rgb(173, 66, 119).","ref":"Fledex.Color.Names.Wiki.html#mystic_maroon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.nadeshiko_pink/1","doc":"Defines the color rgb(244, 173, 198).","ref":"Fledex.Color.Names.Wiki.html#nadeshiko_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.names/0","doc":"Get a list of all the predefined color (atom) names.\n\nThe name can be used to either retrieve the info by calling `info/2` or by calling the function with that\nname (see also the description at the top and take a look at this [example livebook](3b_fledex_more_about_colors.livemd))","ref":"Fledex.Color.Names.Wiki.html#names/0"},{"type":"function","title":"Fledex.Color.Names.Wiki.naples_yellow/1","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.Wiki.html#naples_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.navajo_white/1","doc":"Defines the color rgb(255, 221, 173).","ref":"Fledex.Color.Names.Wiki.html#navajo_white/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.navy_blue/1","doc":"Defines the color rgb(0, 0, 127).","ref":"Fledex.Color.Names.Wiki.html#navy_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.navy_blue_crayola/1","doc":"Defines the color rgb(25, 114, 209).","ref":"Fledex.Color.Names.Wiki.html#navy_blue_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.neon_blue/1","doc":"Defines the color rgb(68, 102, 255).","ref":"Fledex.Color.Names.Wiki.html#neon_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.neon_fuchsia/1","doc":"Defines the color rgb(255, 63, 99).","ref":"Fledex.Color.Names.Wiki.html#neon_fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.neon_green/1","doc":"Defines the color rgb(56, 255, 20).","ref":"Fledex.Color.Names.Wiki.html#neon_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.new_york_pink/1","doc":"Defines the color rgb(214, 130, 127).","ref":"Fledex.Color.Names.Wiki.html#new_york_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.nickel/1","doc":"Defines the color rgb(114, 114, 114).","ref":"Fledex.Color.Names.Wiki.html#nickel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.non_photo_blue/1","doc":"Defines the color rgb(163, 221, 237).","ref":"Fledex.Color.Names.Wiki.html#non_photo_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.nyanza/1","doc":"Defines the color rgb(232, 255, 219).","ref":"Fledex.Color.Names.Wiki.html#nyanza/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ochre/1","doc":"Defines the color rgb(204, 119, 33).","ref":"Fledex.Color.Names.Wiki.html#ochre/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.old_burgundy/1","doc":"Defines the color rgb(66, 48, 45).","ref":"Fledex.Color.Names.Wiki.html#old_burgundy/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.old_gold/1","doc":"Defines the color rgb(206, 181, 58).","ref":"Fledex.Color.Names.Wiki.html#old_gold/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.old_lace/1","doc":"Defines the color rgb(252, 244, 229).","ref":"Fledex.Color.Names.Wiki.html#old_lace/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.old_lavender/1","doc":"Defines the color rgb(119, 104, 119).","ref":"Fledex.Color.Names.Wiki.html#old_lavender/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.old_mauve/1","doc":"Defines the color rgb(102, 48, 71).","ref":"Fledex.Color.Names.Wiki.html#old_mauve/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.old_rose/1","doc":"Defines the color rgb(191, 127, 130).","ref":"Fledex.Color.Names.Wiki.html#old_rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.old_silver/1","doc":"Defines the color rgb(132, 132, 130).","ref":"Fledex.Color.Names.Wiki.html#old_silver/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.olive/1","doc":"Defines the color rgb(127, 127, 0).","ref":"Fledex.Color.Names.Wiki.html#olive/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.olive_drab_3/1","doc":"Defines the color rgb(107, 142, 35).","ref":"Fledex.Color.Names.Wiki.html#olive_drab_3/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.olive_drab_7/1","doc":"Defines the color rgb(61, 51, 30).","ref":"Fledex.Color.Names.Wiki.html#olive_drab_7/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.olive_green/1","doc":"Defines the color rgb(181, 178, 91).","ref":"Fledex.Color.Names.Wiki.html#olive_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.olivine/1","doc":"Defines the color rgb(153, 186, 114).","ref":"Fledex.Color.Names.Wiki.html#olivine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.onyx/1","doc":"Defines the color rgb(53, 56, 56).","ref":"Fledex.Color.Names.Wiki.html#onyx/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.opal/1","doc":"Defines the color rgb(168, 193, 188).","ref":"Fledex.Color.Names.Wiki.html#opal/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.opera_mauve/1","doc":"Defines the color rgb(183, 132, 165).","ref":"Fledex.Color.Names.Wiki.html#opera_mauve/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange/1","doc":"Defines the color rgb(255, 127, 0).","ref":"Fledex.Color.Names.Wiki.html#orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_crayola/1","doc":"Defines the color rgb(255, 117, 56).","ref":"Fledex.Color.Names.Wiki.html#orange_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_pantone/1","doc":"Defines the color rgb(255, 89, 0).","ref":"Fledex.Color.Names.Wiki.html#orange_pantone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_peel/1","doc":"Defines the color rgb(255, 158, 0).","ref":"Fledex.Color.Names.Wiki.html#orange_peel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_red/1","doc":"Defines the color rgb(255, 104, 30).","ref":"Fledex.Color.Names.Wiki.html#orange_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_red_crayola/1","doc":"Defines the color rgb(255, 84, 73).","ref":"Fledex.Color.Names.Wiki.html#orange_red_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_soda/1","doc":"Defines the color rgb(249, 91, 61).","ref":"Fledex.Color.Names.Wiki.html#orange_soda/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_web/1","doc":"Defines the color rgb(255, 165, 0).","ref":"Fledex.Color.Names.Wiki.html#orange_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_yellow/1","doc":"Defines the color rgb(244, 188, 30).","ref":"Fledex.Color.Names.Wiki.html#orange_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orange_yellow_crayola/1","doc":"Defines the color rgb(247, 214, 104).","ref":"Fledex.Color.Names.Wiki.html#orange_yellow_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orchid/1","doc":"Defines the color rgb(216, 112, 214).","ref":"Fledex.Color.Names.Wiki.html#orchid/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orchid_crayola/1","doc":"Defines the color rgb(226, 155, 209).","ref":"Fledex.Color.Names.Wiki.html#orchid_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.orchid_pink/1","doc":"Defines the color rgb(242, 188, 204).","ref":"Fledex.Color.Names.Wiki.html#orchid_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ou_crimson_red/1","doc":"Defines the color rgb(132, 22, 22).","ref":"Fledex.Color.Names.Wiki.html#ou_crimson_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.outer_space_crayola/1","doc":"Defines the color rgb(45, 56, 58).","ref":"Fledex.Color.Names.Wiki.html#outer_space_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.outrageous_orange/1","doc":"Defines the color rgb(255, 109, 73).","ref":"Fledex.Color.Names.Wiki.html#outrageous_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.oxblood/1","doc":"Defines the color rgb(73, 0, 0).","ref":"Fledex.Color.Names.Wiki.html#oxblood/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.oxford_blue/1","doc":"Defines the color rgb(0, 33, 71).","ref":"Fledex.Color.Names.Wiki.html#oxford_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pacific_blue/1","doc":"Defines the color rgb(28, 168, 201).","ref":"Fledex.Color.Names.Wiki.html#pacific_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pakistan_green/1","doc":"Defines the color rgb(0, 102, 0).","ref":"Fledex.Color.Names.Wiki.html#pakistan_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.palatinate_purple/1","doc":"Defines the color rgb(104, 40, 96).","ref":"Fledex.Color.Names.Wiki.html#palatinate_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pale_aqua/1","doc":"Defines the color rgb(191, 211, 229).","ref":"Fledex.Color.Names.Wiki.html#pale_aqua/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pale_cerulean/1","doc":"Defines the color rgb(155, 196, 226).","ref":"Fledex.Color.Names.Wiki.html#pale_cerulean/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pale_dogwood/1","doc":"Defines the color rgb(237, 122, 155).","ref":"Fledex.Color.Names.Wiki.html#pale_dogwood/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pale_pink/1","doc":"Defines the color rgb(249, 216, 221).","ref":"Fledex.Color.Names.Wiki.html#pale_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pale_purple_pantone/1","doc":"Defines the color rgb(249, 229, 249).","ref":"Fledex.Color.Names.Wiki.html#pale_purple_pantone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pale_spring_bud/1","doc":"Defines the color rgb(237, 234, 188).","ref":"Fledex.Color.Names.Wiki.html#pale_spring_bud/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pansy_purple/1","doc":"Defines the color rgb(119, 22, 73).","ref":"Fledex.Color.Names.Wiki.html#pansy_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.paolo_veronese_green/1","doc":"Defines the color rgb(0, 155, 124).","ref":"Fledex.Color.Names.Wiki.html#paolo_veronese_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.papaya_whip/1","doc":"Defines the color rgb(255, 239, 214).","ref":"Fledex.Color.Names.Wiki.html#papaya_whip/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.paradise_pink/1","doc":"Defines the color rgb(229, 61, 96).","ref":"Fledex.Color.Names.Wiki.html#paradise_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.parchment/1","doc":"Defines the color rgb(242, 232, 209).","ref":"Fledex.Color.Names.Wiki.html#parchment/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.paris_green/1","doc":"Defines the color rgb(79, 198, 119).","ref":"Fledex.Color.Names.Wiki.html#paris_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pastel_pink/1","doc":"Defines the color rgb(221, 165, 163).","ref":"Fledex.Color.Names.Wiki.html#pastel_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.patriarch/1","doc":"Defines the color rgb(127, 0, 127).","ref":"Fledex.Color.Names.Wiki.html#patriarch/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.paua/1","doc":"Defines the color rgb(30, 0, 94).","ref":"Fledex.Color.Names.Wiki.html#paua/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.payne_s_grey/1","doc":"Defines the color rgb(84, 104, 119).","ref":"Fledex.Color.Names.Wiki.html#payne_s_grey/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.peach/1","doc":"Defines the color rgb(255, 229, 181).","ref":"Fledex.Color.Names.Wiki.html#peach/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.peach_crayola/1","doc":"Defines the color rgb(255, 204, 163).","ref":"Fledex.Color.Names.Wiki.html#peach_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.peach_puff/1","doc":"Defines the color rgb(255, 216, 186).","ref":"Fledex.Color.Names.Wiki.html#peach_puff/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pear/1","doc":"Defines the color rgb(209, 226, 48).","ref":"Fledex.Color.Names.Wiki.html#pear/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pearly_purple/1","doc":"Defines the color rgb(183, 104, 163).","ref":"Fledex.Color.Names.Wiki.html#pearly_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.periwinkle/1","doc":"Defines the color rgb(204, 204, 255).","ref":"Fledex.Color.Names.Wiki.html#periwinkle/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.periwinkle_crayola/1","doc":"Defines the color rgb(193, 204, 229).","ref":"Fledex.Color.Names.Wiki.html#periwinkle_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.permanent_geranium_lake/1","doc":"Defines the color rgb(224, 43, 43).","ref":"Fledex.Color.Names.Wiki.html#permanent_geranium_lake/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persian_blue/1","doc":"Defines the color rgb(28, 56, 186).","ref":"Fledex.Color.Names.Wiki.html#persian_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persian_green/1","doc":"Defines the color rgb(0, 165, 147).","ref":"Fledex.Color.Names.Wiki.html#persian_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persian_indigo/1","doc":"Defines the color rgb(51, 17, 122).","ref":"Fledex.Color.Names.Wiki.html#persian_indigo/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persian_orange/1","doc":"Defines the color rgb(216, 142, 89).","ref":"Fledex.Color.Names.Wiki.html#persian_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persian_pink/1","doc":"Defines the color rgb(247, 127, 191).","ref":"Fledex.Color.Names.Wiki.html#persian_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persian_plum/1","doc":"Defines the color rgb(112, 28, 28).","ref":"Fledex.Color.Names.Wiki.html#persian_plum/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persian_red/1","doc":"Defines the color rgb(204, 51, 51).","ref":"Fledex.Color.Names.Wiki.html#persian_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persian_rose/1","doc":"Defines the color rgb(255, 40, 163).","ref":"Fledex.Color.Names.Wiki.html#persian_rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.persimmon/1","doc":"Defines the color rgb(237, 89, 0).","ref":"Fledex.Color.Names.Wiki.html#persimmon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pewter_blue/1","doc":"Defines the color rgb(140, 168, 183).","ref":"Fledex.Color.Names.Wiki.html#pewter_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.phlox/1","doc":"Defines the color rgb(221, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#phlox/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.phthalo_blue/1","doc":"Defines the color rgb(0, 15, 137).","ref":"Fledex.Color.Names.Wiki.html#phthalo_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.phthalo_green/1","doc":"Defines the color rgb(17, 53, 35).","ref":"Fledex.Color.Names.Wiki.html#phthalo_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.picotee_blue/1","doc":"Defines the color rgb(45, 38, 135).","ref":"Fledex.Color.Names.Wiki.html#picotee_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pictorial_carmine/1","doc":"Defines the color rgb(193, 10, 79).","ref":"Fledex.Color.Names.Wiki.html#pictorial_carmine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.piggy_pink/1","doc":"Defines the color rgb(252, 221, 229).","ref":"Fledex.Color.Names.Wiki.html#piggy_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pine_green/1","doc":"Defines the color rgb(0, 119, 112).","ref":"Fledex.Color.Names.Wiki.html#pine_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pine_tree/1","doc":"Defines the color rgb(40, 45, 35).","ref":"Fledex.Color.Names.Wiki.html#pine_tree/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pink/1","doc":"Defines the color rgb(255, 191, 204).","ref":"Fledex.Color.Names.Wiki.html#pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pink_lace/1","doc":"Defines the color rgb(255, 221, 244).","ref":"Fledex.Color.Names.Wiki.html#pink_lace/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pink_lavender/1","doc":"Defines the color rgb(216, 178, 209).","ref":"Fledex.Color.Names.Wiki.html#pink_lavender/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pink_pantone/1","doc":"Defines the color rgb(214, 71, 147).","ref":"Fledex.Color.Names.Wiki.html#pink_pantone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pink_sherbet/1","doc":"Defines the color rgb(247, 142, 165).","ref":"Fledex.Color.Names.Wiki.html#pink_sherbet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pistachio/1","doc":"Defines the color rgb(147, 196, 114).","ref":"Fledex.Color.Names.Wiki.html#pistachio/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.platinum/1","doc":"Defines the color rgb(229, 226, 226).","ref":"Fledex.Color.Names.Wiki.html#platinum/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.plum/1","doc":"Defines the color rgb(142, 68, 132).","ref":"Fledex.Color.Names.Wiki.html#plum/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.plum_web/1","doc":"Defines the color rgb(221, 160, 221).","ref":"Fledex.Color.Names.Wiki.html#plum_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.plump_purple/1","doc":"Defines the color rgb(89, 68, 178).","ref":"Fledex.Color.Names.Wiki.html#plump_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.polished_pine/1","doc":"Defines the color rgb(91, 163, 147).","ref":"Fledex.Color.Names.Wiki.html#polished_pine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pomp_and_power/1","doc":"Defines the color rgb(135, 96, 142).","ref":"Fledex.Color.Names.Wiki.html#pomp_and_power/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.popstar/1","doc":"Defines the color rgb(191, 79, 96).","ref":"Fledex.Color.Names.Wiki.html#popstar/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.portland_orange/1","doc":"Defines the color rgb(255, 89, 53).","ref":"Fledex.Color.Names.Wiki.html#portland_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.powder_blue/1","doc":"Defines the color rgb(175, 224, 229).","ref":"Fledex.Color.Names.Wiki.html#powder_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.princeton_orange/1","doc":"Defines the color rgb(244, 127, 38).","ref":"Fledex.Color.Names.Wiki.html#princeton_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.process_yellow/1","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.Wiki.html#process_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.prune/1","doc":"Defines the color rgb(112, 28, 28).","ref":"Fledex.Color.Names.Wiki.html#prune/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.prussian_blue/1","doc":"Defines the color rgb(0, 48, 84).","ref":"Fledex.Color.Names.Wiki.html#prussian_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.psychedelic_purple/1","doc":"Defines the color rgb(221, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#psychedelic_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.puce/1","doc":"Defines the color rgb(204, 135, 153).","ref":"Fledex.Color.Names.Wiki.html#puce/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pullman_brown_ups_brown/1","doc":"Defines the color rgb(99, 63, 22).","ref":"Fledex.Color.Names.Wiki.html#pullman_brown_ups_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.pumpkin/1","doc":"Defines the color rgb(255, 117, 22).","ref":"Fledex.Color.Names.Wiki.html#pumpkin/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purple/1","doc":"Defines the color rgb(96, 0, 127).","ref":"Fledex.Color.Names.Wiki.html#purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purple_mountain_majesty/1","doc":"Defines the color rgb(150, 119, 181).","ref":"Fledex.Color.Names.Wiki.html#purple_mountain_majesty/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purple_munsell/1","doc":"Defines the color rgb(158, 0, 196).","ref":"Fledex.Color.Names.Wiki.html#purple_munsell/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purple_navy/1","doc":"Defines the color rgb(79, 81, 127).","ref":"Fledex.Color.Names.Wiki.html#purple_navy/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purple_pizzazz/1","doc":"Defines the color rgb(255, 79, 216).","ref":"Fledex.Color.Names.Wiki.html#purple_pizzazz/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purple_plum/1","doc":"Defines the color rgb(155, 81, 181).","ref":"Fledex.Color.Names.Wiki.html#purple_plum/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purple_web/1","doc":"Defines the color rgb(127, 0, 127).","ref":"Fledex.Color.Names.Wiki.html#purple_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purple_x11/1","doc":"Defines the color rgb(160, 33, 239).","ref":"Fledex.Color.Names.Wiki.html#purple_x11/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.purpureus/1","doc":"Defines the color rgb(153, 79, 173).","ref":"Fledex.Color.Names.Wiki.html#purpureus/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.queen_blue/1","doc":"Defines the color rgb(66, 107, 147).","ref":"Fledex.Color.Names.Wiki.html#queen_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.queen_pink/1","doc":"Defines the color rgb(232, 204, 214).","ref":"Fledex.Color.Names.Wiki.html#queen_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.quick_silver/1","doc":"Defines the color rgb(165, 165, 165).","ref":"Fledex.Color.Names.Wiki.html#quick_silver/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.quinacridone_magenta/1","doc":"Defines the color rgb(142, 58, 89).","ref":"Fledex.Color.Names.Wiki.html#quinacridone_magenta/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.radical_red/1","doc":"Defines the color rgb(255, 53, 94).","ref":"Fledex.Color.Names.Wiki.html#radical_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.raisin_black/1","doc":"Defines the color rgb(35, 33, 35).","ref":"Fledex.Color.Names.Wiki.html#raisin_black/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rajah/1","doc":"Defines the color rgb(249, 170, 96).","ref":"Fledex.Color.Names.Wiki.html#rajah/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.raspberry/1","doc":"Defines the color rgb(226, 10, 91).","ref":"Fledex.Color.Names.Wiki.html#raspberry/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.raspberry_glace/1","doc":"Defines the color rgb(145, 94, 109).","ref":"Fledex.Color.Names.Wiki.html#raspberry_glace/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.raspberry_rose/1","doc":"Defines the color rgb(178, 68, 107).","ref":"Fledex.Color.Names.Wiki.html#raspberry_rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.raw_sienna/1","doc":"Defines the color rgb(214, 137, 89).","ref":"Fledex.Color.Names.Wiki.html#raw_sienna/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.raw_umber/1","doc":"Defines the color rgb(130, 102, 68).","ref":"Fledex.Color.Names.Wiki.html#raw_umber/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.razzle_dazzle_rose/1","doc":"Defines the color rgb(255, 51, 204).","ref":"Fledex.Color.Names.Wiki.html#razzle_dazzle_rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.razzmatazz/1","doc":"Defines the color rgb(226, 38, 107).","ref":"Fledex.Color.Names.Wiki.html#razzmatazz/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.razzmic_berry/1","doc":"Defines the color rgb(140, 79, 132).","ref":"Fledex.Color.Names.Wiki.html#razzmic_berry/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rebecca_purple/1","doc":"Defines the color rgb(102, 51, 153).","ref":"Fledex.Color.Names.Wiki.html#rebecca_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red/1","doc":"Defines the color rgb(255, 0, 0).","ref":"Fledex.Color.Names.Wiki.html#red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_crayola/1","doc":"Defines the color rgb(237, 33, 76).","ref":"Fledex.Color.Names.Wiki.html#red_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_munsell/1","doc":"Defines the color rgb(242, 0, 61).","ref":"Fledex.Color.Names.Wiki.html#red_munsell/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_ncs/1","doc":"Defines the color rgb(196, 2, 51).","ref":"Fledex.Color.Names.Wiki.html#red_ncs/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_orange/1","doc":"Defines the color rgb(255, 84, 73).","ref":"Fledex.Color.Names.Wiki.html#red_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_orange_color_wheel/1","doc":"Defines the color rgb(255, 68, 0).","ref":"Fledex.Color.Names.Wiki.html#red_orange_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_orange_crayola/1","doc":"Defines the color rgb(255, 104, 30).","ref":"Fledex.Color.Names.Wiki.html#red_orange_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_pantone/1","doc":"Defines the color rgb(237, 40, 56).","ref":"Fledex.Color.Names.Wiki.html#red_pantone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_pigment/1","doc":"Defines the color rgb(237, 28, 35).","ref":"Fledex.Color.Names.Wiki.html#red_pigment/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_purple/1","doc":"Defines the color rgb(226, 0, 119).","ref":"Fledex.Color.Names.Wiki.html#red_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_ryb/1","doc":"Defines the color rgb(255, 38, 17).","ref":"Fledex.Color.Names.Wiki.html#red_ryb/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_salsa/1","doc":"Defines the color rgb(252, 58, 73).","ref":"Fledex.Color.Names.Wiki.html#red_salsa/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_violet/1","doc":"Defines the color rgb(198, 20, 132).","ref":"Fledex.Color.Names.Wiki.html#red_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_violet_color_wheel/1","doc":"Defines the color rgb(145, 43, 61).","ref":"Fledex.Color.Names.Wiki.html#red_violet_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.red_violet_crayola/1","doc":"Defines the color rgb(191, 68, 142).","ref":"Fledex.Color.Names.Wiki.html#red_violet_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.redwood/1","doc":"Defines the color rgb(163, 89, 81).","ref":"Fledex.Color.Names.Wiki.html#redwood/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.resolution_blue/1","doc":"Defines the color rgb(0, 35, 135).","ref":"Fledex.Color.Names.Wiki.html#resolution_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rhythm/1","doc":"Defines the color rgb(119, 117, 150).","ref":"Fledex.Color.Names.Wiki.html#rhythm/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rich_black/1","doc":"Defines the color rgb(0, 63, 63).","ref":"Fledex.Color.Names.Wiki.html#rich_black/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rich_black_fogra29/1","doc":"Defines the color rgb(0, 10, 17).","ref":"Fledex.Color.Names.Wiki.html#rich_black_fogra29/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rich_black_fogra39/1","doc":"Defines the color rgb(0, 2, 2).","ref":"Fledex.Color.Names.Wiki.html#rich_black_fogra39/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rifle_green/1","doc":"Defines the color rgb(68, 76, 56).","ref":"Fledex.Color.Names.Wiki.html#rifle_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.robin_egg_blue/1","doc":"Defines the color rgb(0, 204, 204).","ref":"Fledex.Color.Names.Wiki.html#robin_egg_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rocket_metallic/1","doc":"Defines the color rgb(137, 127, 127).","ref":"Fledex.Color.Names.Wiki.html#rocket_metallic/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rojo_spanish_red/1","doc":"Defines the color rgb(168, 17, 0).","ref":"Fledex.Color.Names.Wiki.html#rojo_spanish_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.roman_silver/1","doc":"Defines the color rgb(130, 137, 150).","ref":"Fledex.Color.Names.Wiki.html#roman_silver/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose/1","doc":"Defines the color rgb(255, 0, 127).","ref":"Fledex.Color.Names.Wiki.html#rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_bonbon/1","doc":"Defines the color rgb(249, 66, 158).","ref":"Fledex.Color.Names.Wiki.html#rose_bonbon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_dust/1","doc":"Defines the color rgb(158, 94, 112).","ref":"Fledex.Color.Names.Wiki.html#rose_dust/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_ebony/1","doc":"Defines the color rgb(102, 71, 68).","ref":"Fledex.Color.Names.Wiki.html#rose_ebony/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_madder/1","doc":"Defines the color rgb(226, 38, 53).","ref":"Fledex.Color.Names.Wiki.html#rose_madder/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_pink/1","doc":"Defines the color rgb(255, 102, 204).","ref":"Fledex.Color.Names.Wiki.html#rose_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_pompadour/1","doc":"Defines the color rgb(237, 122, 155).","ref":"Fledex.Color.Names.Wiki.html#rose_pompadour/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_red/1","doc":"Defines the color rgb(193, 30, 86).","ref":"Fledex.Color.Names.Wiki.html#rose_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_taupe/1","doc":"Defines the color rgb(142, 91, 91).","ref":"Fledex.Color.Names.Wiki.html#rose_taupe/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rose_vale/1","doc":"Defines the color rgb(170, 79, 81).","ref":"Fledex.Color.Names.Wiki.html#rose_vale/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rosewood/1","doc":"Defines the color rgb(102, 0, 10).","ref":"Fledex.Color.Names.Wiki.html#rosewood/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rosso_corsa/1","doc":"Defines the color rgb(211, 0, 0).","ref":"Fledex.Color.Names.Wiki.html#rosso_corsa/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rosy_brown/1","doc":"Defines the color rgb(188, 142, 142).","ref":"Fledex.Color.Names.Wiki.html#rosy_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.royal_blue_dark/1","doc":"Defines the color rgb(0, 35, 102).","ref":"Fledex.Color.Names.Wiki.html#royal_blue_dark/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.royal_blue_light/1","doc":"Defines the color rgb(63, 104, 224).","ref":"Fledex.Color.Names.Wiki.html#royal_blue_light/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.royal_purple/1","doc":"Defines the color rgb(119, 81, 168).","ref":"Fledex.Color.Names.Wiki.html#royal_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.royal_yellow/1","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.Wiki.html#royal_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ruber/1","doc":"Defines the color rgb(206, 68, 117).","ref":"Fledex.Color.Names.Wiki.html#ruber/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rubine_red/1","doc":"Defines the color rgb(209, 0, 86).","ref":"Fledex.Color.Names.Wiki.html#rubine_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ruby/1","doc":"Defines the color rgb(224, 17, 94).","ref":"Fledex.Color.Names.Wiki.html#ruby/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ruby_red/1","doc":"Defines the color rgb(155, 17, 30).","ref":"Fledex.Color.Names.Wiki.html#ruby_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rufous/1","doc":"Defines the color rgb(168, 28, 7).","ref":"Fledex.Color.Names.Wiki.html#rufous/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.russet/1","doc":"Defines the color rgb(127, 68, 28).","ref":"Fledex.Color.Names.Wiki.html#russet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.russian_green/1","doc":"Defines the color rgb(102, 145, 102).","ref":"Fledex.Color.Names.Wiki.html#russian_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.russian_violet/1","doc":"Defines the color rgb(51, 22, 76).","ref":"Fledex.Color.Names.Wiki.html#russian_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rust/1","doc":"Defines the color rgb(183, 63, 12).","ref":"Fledex.Color.Names.Wiki.html#rust/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.rusty_red/1","doc":"Defines the color rgb(216, 43, 66).","ref":"Fledex.Color.Names.Wiki.html#rusty_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sacramento_state_green/1","doc":"Defines the color rgb(5, 56, 38).","ref":"Fledex.Color.Names.Wiki.html#sacramento_state_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.saddle_brown/1","doc":"Defines the color rgb(140, 68, 17).","ref":"Fledex.Color.Names.Wiki.html#saddle_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.safety_orange/1","doc":"Defines the color rgb(255, 119, 0).","ref":"Fledex.Color.Names.Wiki.html#safety_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.safety_orange_blaze_orange/1","doc":"Defines the color rgb(255, 102, 0).","ref":"Fledex.Color.Names.Wiki.html#safety_orange_blaze_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.safety_yellow/1","doc":"Defines the color rgb(237, 209, 2).","ref":"Fledex.Color.Names.Wiki.html#safety_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.saffron/1","doc":"Defines the color rgb(244, 196, 48).","ref":"Fledex.Color.Names.Wiki.html#saffron/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sage/1","doc":"Defines the color rgb(188, 183, 137).","ref":"Fledex.Color.Names.Wiki.html#sage/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.salmon/1","doc":"Defines the color rgb(249, 127, 114).","ref":"Fledex.Color.Names.Wiki.html#salmon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.salmon_pink/1","doc":"Defines the color rgb(255, 145, 163).","ref":"Fledex.Color.Names.Wiki.html#salmon_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sand/1","doc":"Defines the color rgb(193, 178, 127).","ref":"Fledex.Color.Names.Wiki.html#sand/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sand_dune/1","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.Wiki.html#sand_dune/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sandy_brown/1","doc":"Defines the color rgb(244, 163, 96).","ref":"Fledex.Color.Names.Wiki.html#sandy_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sap_green/1","doc":"Defines the color rgb(79, 124, 40).","ref":"Fledex.Color.Names.Wiki.html#sap_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sapphire/1","doc":"Defines the color rgb(15, 81, 186).","ref":"Fledex.Color.Names.Wiki.html#sapphire/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sapphire_blue/1","doc":"Defines the color rgb(0, 102, 165).","ref":"Fledex.Color.Names.Wiki.html#sapphire_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sapphire_crayola/1","doc":"Defines the color rgb(45, 91, 160).","ref":"Fledex.Color.Names.Wiki.html#sapphire_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.satin_sheen_gold/1","doc":"Defines the color rgb(204, 160, 53).","ref":"Fledex.Color.Names.Wiki.html#satin_sheen_gold/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.scarlet/1","doc":"Defines the color rgb(255, 35, 0).","ref":"Fledex.Color.Names.Wiki.html#scarlet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.schauss_pink/1","doc":"Defines the color rgb(255, 145, 175).","ref":"Fledex.Color.Names.Wiki.html#schauss_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.school_bus_yellow/1","doc":"Defines the color rgb(255, 216, 0).","ref":"Fledex.Color.Names.Wiki.html#school_bus_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.screamin_green/1","doc":"Defines the color rgb(102, 255, 102).","ref":"Fledex.Color.Names.Wiki.html#screamin_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sea_green/1","doc":"Defines the color rgb(45, 140, 86).","ref":"Fledex.Color.Names.Wiki.html#sea_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sea_green_crayola/1","doc":"Defines the color rgb(0, 255, 204).","ref":"Fledex.Color.Names.Wiki.html#sea_green_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.seal_brown/1","doc":"Defines the color rgb(51, 20, 20).","ref":"Fledex.Color.Names.Wiki.html#seal_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.seance/1","doc":"Defines the color rgb(96, 33, 135).","ref":"Fledex.Color.Names.Wiki.html#seance/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.seashell/1","doc":"Defines the color rgb(255, 244, 237).","ref":"Fledex.Color.Names.Wiki.html#seashell/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.secret/1","doc":"Defines the color rgb(117, 66, 114).","ref":"Fledex.Color.Names.Wiki.html#secret/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.selective_yellow/1","doc":"Defines the color rgb(255, 186, 0).","ref":"Fledex.Color.Names.Wiki.html#selective_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sepia/1","doc":"Defines the color rgb(112, 66, 20).","ref":"Fledex.Color.Names.Wiki.html#sepia/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.shadow/1","doc":"Defines the color rgb(137, 119, 91).","ref":"Fledex.Color.Names.Wiki.html#shadow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.shadow_blue/1","doc":"Defines the color rgb(119, 140, 165).","ref":"Fledex.Color.Names.Wiki.html#shadow_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.shamrock_green/1","doc":"Defines the color rgb(0, 158, 96).","ref":"Fledex.Color.Names.Wiki.html#shamrock_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sheen_green/1","doc":"Defines the color rgb(142, 211, 0).","ref":"Fledex.Color.Names.Wiki.html#sheen_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.shimmering_blush/1","doc":"Defines the color rgb(216, 135, 147).","ref":"Fledex.Color.Names.Wiki.html#shimmering_blush/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.shiny_shamrock/1","doc":"Defines the color rgb(94, 165, 119).","ref":"Fledex.Color.Names.Wiki.html#shiny_shamrock/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.shocking_pink/1","doc":"Defines the color rgb(252, 15, 191).","ref":"Fledex.Color.Names.Wiki.html#shocking_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.shocking_pink_crayola/1","doc":"Defines the color rgb(255, 112, 255).","ref":"Fledex.Color.Names.Wiki.html#shocking_pink_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sienna/1","doc":"Defines the color rgb(135, 45, 22).","ref":"Fledex.Color.Names.Wiki.html#sienna/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.silver/1","doc":"Defines the color rgb(191, 191, 191).","ref":"Fledex.Color.Names.Wiki.html#silver/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.silver_chalice/1","doc":"Defines the color rgb(170, 170, 170).","ref":"Fledex.Color.Names.Wiki.html#silver_chalice/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.silver_crayola/1","doc":"Defines the color rgb(201, 191, 186).","ref":"Fledex.Color.Names.Wiki.html#silver_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.silver_metallic/1","doc":"Defines the color rgb(170, 168, 173).","ref":"Fledex.Color.Names.Wiki.html#silver_metallic/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.silver_pink/1","doc":"Defines the color rgb(196, 173, 173).","ref":"Fledex.Color.Names.Wiki.html#silver_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.silver_sand/1","doc":"Defines the color rgb(191, 193, 193).","ref":"Fledex.Color.Names.Wiki.html#silver_sand/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sinopia/1","doc":"Defines the color rgb(204, 63, 10).","ref":"Fledex.Color.Names.Wiki.html#sinopia/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sizzling_red/1","doc":"Defines the color rgb(255, 56, 84).","ref":"Fledex.Color.Names.Wiki.html#sizzling_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sizzling_sunrise/1","doc":"Defines the color rgb(255, 219, 0).","ref":"Fledex.Color.Names.Wiki.html#sizzling_sunrise/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.skobeloff/1","doc":"Defines the color rgb(0, 114, 114).","ref":"Fledex.Color.Names.Wiki.html#skobeloff/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sky_blue/1","doc":"Defines the color rgb(135, 206, 234).","ref":"Fledex.Color.Names.Wiki.html#sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sky_blue_crayola/1","doc":"Defines the color rgb(117, 214, 234).","ref":"Fledex.Color.Names.Wiki.html#sky_blue_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sky_magenta/1","doc":"Defines the color rgb(206, 112, 175).","ref":"Fledex.Color.Names.Wiki.html#sky_magenta/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.slate_blue/1","doc":"Defines the color rgb(107, 89, 204).","ref":"Fledex.Color.Names.Wiki.html#slate_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.slate_gray/1","doc":"Defines the color rgb(112, 127, 142).","ref":"Fledex.Color.Names.Wiki.html#slate_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.slimy_green/1","doc":"Defines the color rgb(40, 150, 22).","ref":"Fledex.Color.Names.Wiki.html#slimy_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.smitten/1","doc":"Defines the color rgb(198, 63, 135).","ref":"Fledex.Color.Names.Wiki.html#smitten/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.smoky_black/1","doc":"Defines the color rgb(15, 12, 7).","ref":"Fledex.Color.Names.Wiki.html#smoky_black/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.snow/1","doc":"Defines the color rgb(255, 249, 249).","ref":"Fledex.Color.Names.Wiki.html#snow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.solid_pink/1","doc":"Defines the color rgb(137, 56, 66).","ref":"Fledex.Color.Names.Wiki.html#solid_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sonic_silver/1","doc":"Defines the color rgb(117, 117, 117).","ref":"Fledex.Color.Names.Wiki.html#sonic_silver/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.space_cadet/1","doc":"Defines the color rgb(28, 40, 81).","ref":"Fledex.Color.Names.Wiki.html#space_cadet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_bistre/1","doc":"Defines the color rgb(127, 117, 51).","ref":"Fledex.Color.Names.Wiki.html#spanish_bistre/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_blue/1","doc":"Defines the color rgb(0, 112, 183).","ref":"Fledex.Color.Names.Wiki.html#spanish_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_carmine/1","doc":"Defines the color rgb(209, 0, 71).","ref":"Fledex.Color.Names.Wiki.html#spanish_carmine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_gray/1","doc":"Defines the color rgb(153, 153, 153).","ref":"Fledex.Color.Names.Wiki.html#spanish_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_green/1","doc":"Defines the color rgb(0, 145, 79).","ref":"Fledex.Color.Names.Wiki.html#spanish_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_orange/1","doc":"Defines the color rgb(232, 96, 0).","ref":"Fledex.Color.Names.Wiki.html#spanish_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_pink/1","doc":"Defines the color rgb(247, 191, 191).","ref":"Fledex.Color.Names.Wiki.html#spanish_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_red/1","doc":"Defines the color rgb(229, 0, 38).","ref":"Fledex.Color.Names.Wiki.html#spanish_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_sky_blue/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.Wiki.html#spanish_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_violet/1","doc":"Defines the color rgb(76, 40, 130).","ref":"Fledex.Color.Names.Wiki.html#spanish_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spanish_viridian/1","doc":"Defines the color rgb(0, 127, 91).","ref":"Fledex.Color.Names.Wiki.html#spanish_viridian/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spring_bud/1","doc":"Defines the color rgb(165, 252, 0).","ref":"Fledex.Color.Names.Wiki.html#spring_bud/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spring_frost/1","doc":"Defines the color rgb(135, 255, 40).","ref":"Fledex.Color.Names.Wiki.html#spring_frost/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spring_green/1","doc":"Defines the color rgb(0, 255, 127).","ref":"Fledex.Color.Names.Wiki.html#spring_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.spring_green_crayola/1","doc":"Defines the color rgb(237, 234, 188).","ref":"Fledex.Color.Names.Wiki.html#spring_green_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.st_patrick_s_blue/1","doc":"Defines the color rgb(35, 40, 122).","ref":"Fledex.Color.Names.Wiki.html#st_patrick_s_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.star_command_blue/1","doc":"Defines the color rgb(0, 122, 183).","ref":"Fledex.Color.Names.Wiki.html#star_command_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.steel_blue/1","doc":"Defines the color rgb(68, 130, 181).","ref":"Fledex.Color.Names.Wiki.html#steel_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.steel_pink/1","doc":"Defines the color rgb(204, 51, 204).","ref":"Fledex.Color.Names.Wiki.html#steel_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.stil_de_grain_yellow/1","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.Wiki.html#stil_de_grain_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.straw/1","doc":"Defines the color rgb(226, 216, 112).","ref":"Fledex.Color.Names.Wiki.html#straw/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.strawberry/1","doc":"Defines the color rgb(249, 79, 84).","ref":"Fledex.Color.Names.Wiki.html#strawberry/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.strawberry_blonde/1","doc":"Defines the color rgb(255, 147, 96).","ref":"Fledex.Color.Names.Wiki.html#strawberry_blonde/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.strong_lime_green/1","doc":"Defines the color rgb(51, 204, 51).","ref":"Fledex.Color.Names.Wiki.html#strong_lime_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sugar_plum/1","doc":"Defines the color rgb(145, 79, 117).","ref":"Fledex.Color.Names.Wiki.html#sugar_plum/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sunglow/1","doc":"Defines the color rgb(255, 204, 51).","ref":"Fledex.Color.Names.Wiki.html#sunglow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sunray/1","doc":"Defines the color rgb(226, 170, 86).","ref":"Fledex.Color.Names.Wiki.html#sunray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sunset/1","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.Wiki.html#sunset/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.super_pink/1","doc":"Defines the color rgb(206, 107, 168).","ref":"Fledex.Color.Names.Wiki.html#super_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.sweet_brown/1","doc":"Defines the color rgb(168, 56, 48).","ref":"Fledex.Color.Names.Wiki.html#sweet_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.syracuse_orange/1","doc":"Defines the color rgb(211, 68, 0).","ref":"Fledex.Color.Names.Wiki.html#syracuse_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tan/1","doc":"Defines the color rgb(209, 181, 140).","ref":"Fledex.Color.Names.Wiki.html#tan/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tan_crayola/1","doc":"Defines the color rgb(216, 153, 107).","ref":"Fledex.Color.Names.Wiki.html#tan_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tangerine/1","doc":"Defines the color rgb(242, 132, 0).","ref":"Fledex.Color.Names.Wiki.html#tangerine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tango_pink/1","doc":"Defines the color rgb(226, 112, 122).","ref":"Fledex.Color.Names.Wiki.html#tango_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tart_orange/1","doc":"Defines the color rgb(249, 76, 68).","ref":"Fledex.Color.Names.Wiki.html#tart_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.taupe/1","doc":"Defines the color rgb(71, 61, 51).","ref":"Fledex.Color.Names.Wiki.html#taupe/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.taupe_gray/1","doc":"Defines the color rgb(140, 132, 137).","ref":"Fledex.Color.Names.Wiki.html#taupe_gray/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tea_green/1","doc":"Defines the color rgb(209, 239, 191).","ref":"Fledex.Color.Names.Wiki.html#tea_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tea_rose/1","doc":"Defines the color rgb(244, 193, 193).","ref":"Fledex.Color.Names.Wiki.html#tea_rose/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.teal/1","doc":"Defines the color rgb(0, 127, 127).","ref":"Fledex.Color.Names.Wiki.html#teal/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.teal_blue/1","doc":"Defines the color rgb(53, 117, 135).","ref":"Fledex.Color.Names.Wiki.html#teal_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.telemagenta/1","doc":"Defines the color rgb(206, 51, 117).","ref":"Fledex.Color.Names.Wiki.html#telemagenta/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tenne_tawny/1","doc":"Defines the color rgb(204, 86, 0).","ref":"Fledex.Color.Names.Wiki.html#tenne_tawny/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.terra_cotta/1","doc":"Defines the color rgb(226, 114, 91).","ref":"Fledex.Color.Names.Wiki.html#terra_cotta/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.thistle/1","doc":"Defines the color rgb(216, 191, 216).","ref":"Fledex.Color.Names.Wiki.html#thistle/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.thulian_pink/1","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.Wiki.html#thulian_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tickle_me_pink/1","doc":"Defines the color rgb(252, 137, 170).","ref":"Fledex.Color.Names.Wiki.html#tickle_me_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tiffany_blue/1","doc":"Defines the color rgb(10, 186, 181).","ref":"Fledex.Color.Names.Wiki.html#tiffany_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.timberwolf/1","doc":"Defines the color rgb(219, 214, 209).","ref":"Fledex.Color.Names.Wiki.html#timberwolf/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.titanium_yellow/1","doc":"Defines the color rgb(237, 229, 0).","ref":"Fledex.Color.Names.Wiki.html#titanium_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tomato/1","doc":"Defines the color rgb(255, 99, 71).","ref":"Fledex.Color.Names.Wiki.html#tomato/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tourmaline/1","doc":"Defines the color rgb(135, 160, 168).","ref":"Fledex.Color.Names.Wiki.html#tourmaline/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tropical_rainforest/1","doc":"Defines the color rgb(0, 117, 94).","ref":"Fledex.Color.Names.Wiki.html#tropical_rainforest/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.true_blue/1","doc":"Defines the color rgb(0, 114, 206).","ref":"Fledex.Color.Names.Wiki.html#true_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.trypan_blue/1","doc":"Defines the color rgb(28, 5, 178).","ref":"Fledex.Color.Names.Wiki.html#trypan_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tufts_blue/1","doc":"Defines the color rgb(61, 142, 221).","ref":"Fledex.Color.Names.Wiki.html#tufts_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tumbleweed/1","doc":"Defines the color rgb(221, 170, 135).","ref":"Fledex.Color.Names.Wiki.html#tumbleweed/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.turquoise/1","doc":"Defines the color rgb(63, 224, 209).","ref":"Fledex.Color.Names.Wiki.html#turquoise/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.turquoise_blue/1","doc":"Defines the color rgb(0, 255, 239).","ref":"Fledex.Color.Names.Wiki.html#turquoise_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.turquoise_green/1","doc":"Defines the color rgb(160, 214, 181).","ref":"Fledex.Color.Names.Wiki.html#turquoise_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.turtle_green/1","doc":"Defines the color rgb(137, 153, 91).","ref":"Fledex.Color.Names.Wiki.html#turtle_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tuscan/1","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.Wiki.html#tuscan/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tuscan_brown/1","doc":"Defines the color rgb(112, 79, 56).","ref":"Fledex.Color.Names.Wiki.html#tuscan_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tuscan_red/1","doc":"Defines the color rgb(124, 71, 71).","ref":"Fledex.Color.Names.Wiki.html#tuscan_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tuscan_tan/1","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.Wiki.html#tuscan_tan/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tuscany/1","doc":"Defines the color rgb(191, 153, 153).","ref":"Fledex.Color.Names.Wiki.html#tuscany/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.twilight_lavender/1","doc":"Defines the color rgb(137, 73, 107).","ref":"Fledex.Color.Names.Wiki.html#twilight_lavender/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.tyrian_purple/1","doc":"Defines the color rgb(102, 2, 61).","ref":"Fledex.Color.Names.Wiki.html#tyrian_purple/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ua_blue/1","doc":"Defines the color rgb(0, 51, 170).","ref":"Fledex.Color.Names.Wiki.html#ua_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ua_red/1","doc":"Defines the color rgb(216, 0, 76).","ref":"Fledex.Color.Names.Wiki.html#ua_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ultra_pink/1","doc":"Defines the color rgb(255, 112, 255).","ref":"Fledex.Color.Names.Wiki.html#ultra_pink/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ultra_red/1","doc":"Defines the color rgb(252, 107, 132).","ref":"Fledex.Color.Names.Wiki.html#ultra_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ultramarine/1","doc":"Defines the color rgb(17, 10, 142).","ref":"Fledex.Color.Names.Wiki.html#ultramarine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.ultramarine_blue/1","doc":"Defines the color rgb(63, 102, 244).","ref":"Fledex.Color.Names.Wiki.html#ultramarine_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.umber/1","doc":"Defines the color rgb(99, 81, 71).","ref":"Fledex.Color.Names.Wiki.html#umber/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.unbleached_silk/1","doc":"Defines the color rgb(255, 221, 201).","ref":"Fledex.Color.Names.Wiki.html#unbleached_silk/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.united_nations_blue/1","doc":"Defines the color rgb(91, 145, 229).","ref":"Fledex.Color.Names.Wiki.html#united_nations_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.university_of_pennsylvania_red/1","doc":"Defines the color rgb(165, 0, 33).","ref":"Fledex.Color.Names.Wiki.html#university_of_pennsylvania_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.unmellow_yellow/1","doc":"Defines the color rgb(255, 255, 102).","ref":"Fledex.Color.Names.Wiki.html#unmellow_yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.up_forest_green/1","doc":"Defines the color rgb(0, 68, 33).","ref":"Fledex.Color.Names.Wiki.html#up_forest_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.up_maroon/1","doc":"Defines the color rgb(122, 17, 17).","ref":"Fledex.Color.Names.Wiki.html#up_maroon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.upsdell_red/1","doc":"Defines the color rgb(173, 33, 40).","ref":"Fledex.Color.Names.Wiki.html#upsdell_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.uranian_blue/1","doc":"Defines the color rgb(175, 219, 244).","ref":"Fledex.Color.Names.Wiki.html#uranian_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.usafa_blue/1","doc":"Defines the color rgb(0, 79, 153).","ref":"Fledex.Color.Names.Wiki.html#usafa_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.van_dyke_brown/1","doc":"Defines the color rgb(102, 66, 40).","ref":"Fledex.Color.Names.Wiki.html#van_dyke_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vanilla/1","doc":"Defines the color rgb(242, 229, 170).","ref":"Fledex.Color.Names.Wiki.html#vanilla/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vanilla_ice/1","doc":"Defines the color rgb(242, 142, 168).","ref":"Fledex.Color.Names.Wiki.html#vanilla_ice/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vegas_gold/1","doc":"Defines the color rgb(196, 178, 89).","ref":"Fledex.Color.Names.Wiki.html#vegas_gold/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.venetian_red/1","doc":"Defines the color rgb(198, 7, 20).","ref":"Fledex.Color.Names.Wiki.html#venetian_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.verdigris/1","doc":"Defines the color rgb(66, 178, 173).","ref":"Fledex.Color.Names.Wiki.html#verdigris/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vermilion2/1","doc":"Defines the color rgb(216, 56, 30).","ref":"Fledex.Color.Names.Wiki.html#vermilion2/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vermilion/1","doc":"Defines the color rgb(226, 66, 51).","ref":"Fledex.Color.Names.Wiki.html#vermilion/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.veronica/1","doc":"Defines the color rgb(160, 33, 239).","ref":"Fledex.Color.Names.Wiki.html#veronica/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet/1","doc":"Defines the color rgb(142, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet_blue/1","doc":"Defines the color rgb(51, 73, 178).","ref":"Fledex.Color.Names.Wiki.html#violet_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet_blue_crayola/1","doc":"Defines the color rgb(117, 109, 198).","ref":"Fledex.Color.Names.Wiki.html#violet_blue_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet_color_wheel/1","doc":"Defines the color rgb(127, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#violet_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet_crayola/1","doc":"Defines the color rgb(150, 61, 127).","ref":"Fledex.Color.Names.Wiki.html#violet_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet_red/1","doc":"Defines the color rgb(247, 84, 147).","ref":"Fledex.Color.Names.Wiki.html#violet_red/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet_red_perbang/1","doc":"Defines the color rgb(239, 89, 155).","ref":"Fledex.Color.Names.Wiki.html#violet_red_perbang/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet_ryb/1","doc":"Defines the color rgb(135, 0, 175).","ref":"Fledex.Color.Names.Wiki.html#violet_ryb/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.violet_web/1","doc":"Defines the color rgb(237, 130, 237).","ref":"Fledex.Color.Names.Wiki.html#violet_web/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.viridian/1","doc":"Defines the color rgb(63, 130, 109).","ref":"Fledex.Color.Names.Wiki.html#viridian/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.viridian_green/1","doc":"Defines the color rgb(0, 150, 153).","ref":"Fledex.Color.Names.Wiki.html#viridian_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vivid_burgundy/1","doc":"Defines the color rgb(158, 28, 53).","ref":"Fledex.Color.Names.Wiki.html#vivid_burgundy/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vivid_sky_blue/1","doc":"Defines the color rgb(0, 204, 255).","ref":"Fledex.Color.Names.Wiki.html#vivid_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vivid_tangerine/1","doc":"Defines the color rgb(255, 160, 137).","ref":"Fledex.Color.Names.Wiki.html#vivid_tangerine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.vivid_violet/1","doc":"Defines the color rgb(158, 0, 255).","ref":"Fledex.Color.Names.Wiki.html#vivid_violet/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.volt/1","doc":"Defines the color rgb(204, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#volt/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.warm_black/1","doc":"Defines the color rgb(0, 66, 66).","ref":"Fledex.Color.Names.Wiki.html#warm_black/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.weezy_blue/1","doc":"Defines the color rgb(22, 155, 204).","ref":"Fledex.Color.Names.Wiki.html#weezy_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wheat/1","doc":"Defines the color rgb(244, 221, 178).","ref":"Fledex.Color.Names.Wiki.html#wheat/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.white/1","doc":"Defines the color rgb(255, 255, 255).","ref":"Fledex.Color.Names.Wiki.html#white/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wild_blue_yonder/1","doc":"Defines the color rgb(163, 173, 209).","ref":"Fledex.Color.Names.Wiki.html#wild_blue_yonder/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wild_orchid/1","doc":"Defines the color rgb(211, 112, 163).","ref":"Fledex.Color.Names.Wiki.html#wild_orchid/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wild_strawberry/1","doc":"Defines the color rgb(255, 66, 163).","ref":"Fledex.Color.Names.Wiki.html#wild_strawberry/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wild_watermelon/1","doc":"Defines the color rgb(252, 107, 132).","ref":"Fledex.Color.Names.Wiki.html#wild_watermelon/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.windsor_tan/1","doc":"Defines the color rgb(165, 84, 2).","ref":"Fledex.Color.Names.Wiki.html#windsor_tan/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wine/1","doc":"Defines the color rgb(114, 45, 56).","ref":"Fledex.Color.Names.Wiki.html#wine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wine_dregs/1","doc":"Defines the color rgb(102, 48, 71).","ref":"Fledex.Color.Names.Wiki.html#wine_dregs/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.winter_sky/1","doc":"Defines the color rgb(255, 0, 124).","ref":"Fledex.Color.Names.Wiki.html#winter_sky/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wintergreen_dream/1","doc":"Defines the color rgb(86, 135, 124).","ref":"Fledex.Color.Names.Wiki.html#wintergreen_dream/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wisteria/1","doc":"Defines the color rgb(201, 160, 219).","ref":"Fledex.Color.Names.Wiki.html#wisteria/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.wood_brown/1","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.Wiki.html#wood_brown/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.xanadu/1","doc":"Defines the color rgb(114, 135, 119).","ref":"Fledex.Color.Names.Wiki.html#xanadu/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.xanthic/1","doc":"Defines the color rgb(237, 237, 10).","ref":"Fledex.Color.Names.Wiki.html#xanthic/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.xanthous/1","doc":"Defines the color rgb(242, 181, 45).","ref":"Fledex.Color.Names.Wiki.html#xanthous/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yale_blue/1","doc":"Defines the color rgb(0, 53, 107).","ref":"Fledex.Color.Names.Wiki.html#yale_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow/1","doc":"Defines the color rgb(255, 255, 0).","ref":"Fledex.Color.Names.Wiki.html#yellow/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_crayola/1","doc":"Defines the color rgb(252, 232, 130).","ref":"Fledex.Color.Names.Wiki.html#yellow_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_green/1","doc":"Defines the color rgb(153, 204, 51).","ref":"Fledex.Color.Names.Wiki.html#yellow_green/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_green_color_wheel/1","doc":"Defines the color rgb(48, 178, 25).","ref":"Fledex.Color.Names.Wiki.html#yellow_green_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_green_crayola/1","doc":"Defines the color rgb(196, 226, 132).","ref":"Fledex.Color.Names.Wiki.html#yellow_green_crayola/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_munsell/1","doc":"Defines the color rgb(239, 204, 0).","ref":"Fledex.Color.Names.Wiki.html#yellow_munsell/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_ncs/1","doc":"Defines the color rgb(255, 211, 0).","ref":"Fledex.Color.Names.Wiki.html#yellow_ncs/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_orange/1","doc":"Defines the color rgb(255, 173, 66).","ref":"Fledex.Color.Names.Wiki.html#yellow_orange/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_orange_color_wheel/1","doc":"Defines the color rgb(255, 147, 5).","ref":"Fledex.Color.Names.Wiki.html#yellow_orange_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_pantone/1","doc":"Defines the color rgb(255, 221, 0).","ref":"Fledex.Color.Names.Wiki.html#yellow_pantone/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_process/1","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.Wiki.html#yellow_process/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_ryb/1","doc":"Defines the color rgb(255, 255, 51).","ref":"Fledex.Color.Names.Wiki.html#yellow_ryb/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yellow_sunshine/1","doc":"Defines the color rgb(255, 247, 0).","ref":"Fledex.Color.Names.Wiki.html#yellow_sunshine/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.yinmn_blue/1","doc":"Defines the color rgb(45, 79, 142).","ref":"Fledex.Color.Names.Wiki.html#yinmn_blue/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.zaffre/1","doc":"Defines the color rgb(0, 20, 168).","ref":"Fledex.Color.Names.Wiki.html#zaffre/1"},{"type":"function","title":"Fledex.Color.Names.Wiki.zomp/1","doc":"Defines the color rgb(56, 165, 142).","ref":"Fledex.Color.Names.Wiki.html#zomp/1"},{"type":"module","title":"Fledex.Color.Names.WikiUtils","doc":"","ref":"Fledex.Color.Names.WikiUtils.html"},{"type":"function","title":"Fledex.Color.Names.WikiUtils.converter/1","doc":"","ref":"Fledex.Color.Names.WikiUtils.html#converter/1"},{"type":"module","title":"Fledex.Color.Types","doc":"","ref":"Fledex.Color.Types.html"},{"type":"type","title":"Fledex.Color.Types.color/0","doc":"","ref":"Fledex.Color.Types.html#t:color/0"},{"type":"type","title":"Fledex.Color.Types.color_any/0","doc":"","ref":"Fledex.Color.Types.html#t:color_any/0"},{"type":"type","title":"Fledex.Color.Types.colorint/0","doc":"","ref":"Fledex.Color.Types.html#t:colorint/0"},{"type":"type","title":"Fledex.Color.Types.hsl/0","doc":"","ref":"Fledex.Color.Types.html#t:hsl/0"},{"type":"type","title":"Fledex.Color.Types.hsv/0","doc":"","ref":"Fledex.Color.Types.html#t:hsv/0"},{"type":"type","title":"Fledex.Color.Types.rgb/0","doc":"","ref":"Fledex.Color.Types.html#t:rgb/0"},{"type":"extras","title":"Fledex","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# Fledex\n[![Hex.pm](https://img.shields.io/hexpm/l/fledex \"License\")](https://github.com/a-maze-d/fledex/blob/main/LICENSES/Apache-2.0.txt)\n[![Hex version](https://img.shields.io/hexpm/v/fledex.svg?color=0000ff \"Hex version\")](https://hex.pm/packages/fledex)\n[![API docs](https://img.shields.io/hexpm/v/fledex.svg?label=hexdocs&color=0000ff \"API docs\")](https://hexdocs.pm/fledex)\n[![ElixirCI](https://github.com/a-maze-d/fledex/actions/workflows/elixir.yml/badge.svg \"ElixirCI\")](https://github.com/a-maze-d/fledex/actions/workflows/elixir.yml)\n[![REUSE status](https://api.reuse.software/badge/github.com/a-maze-d/fledex)](https://api.reuse.software/info/github.com/a-maze-d/fledex)\n[![Coverage Status](https://coveralls.io/repos/github/a-maze-d/fledex/badge.svg?branch=main)](https://coveralls.io/github/a-maze-d/fledex?branch=main)\n[![Downloads](https://img.shields.io/hexpm/dt/fledex.svg)](https://hex.pm/packages/fledex)\n\n \n\nFledex is a small [Elixir](https://elixir-lang.org/) library It really is intended for educational purposes.\nIt is written for a RaspberryPi Zero W running [Nerves](https://nerves-project.org/) especially with a [Nerves-Livebook](https://hexdocs.pm/nerves/getting-started.html#nerves-livebook), but you could use it without Nerves or Livebook.\n\nThe intent of the library is to simplify the programming of a programmable LED strip (currently based on a [WS2801 chip](https://cdn-shop.adafruit.com/datasheets/WS2801.pdf)) and thereby to make it accessible even for kids.\n\nThe idea is to introduce similarly easy concepts for the programming of LEDs as [SonicPi](https://sonic-pi.net/) did for music. The library was developed in collaboration with my son and hopefully we can push it to become better over time. For my son the goal will be to connect the LEDs to some music and to animate the LEDs depending on the beat.\n\nQuite a lot of inspiration came from the [FastLED project](http://fastled.io/) and quite a few of their functions got reimplemented in Elixir. If you look at the implementation of some of those functions you might want to look at their comments.","ref":"readme-1.html"},{"type":"extras","title":"Installation - Fledex","doc":"The library is [available in Hex](https://hex.pm/packages/fledex), the package can be installed\nby adding `:fledex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fledex, \"~> 0.5\"}\n  ]\nend\n```","ref":"readme-1.html#installation"},{"type":"extras","title":"Usage - Fledex","doc":"The smoothest way is to use the Fledex DSL which defines some functions and macros. To enable them you need to `use Fledex`. This will (by default) start the animation manager (`Fledex.Animation.Manager`) through which all led definitions are routed. But don't worry, you won't really see it.\n\n**Note:** by enabling the DSL through the `use Fledex` call, the most important modules \nare aliased: `Fledex.Leds`, `Fledex.LedStrip`, `Fledex.Utils.PubSub`, `Fledex.Color.Names`, and the different drivers (all part of the `FledexDriver.Impl` namespace). We will see a \nbit later what functionality those modules provide.\n\nAs a next step you define an LED strip through the `led_strip` macro. While defining the led strip you need to decide on how you want to talk to your strip; you need an appropriate driver.  There are several ways on how you can address your LED strip. The most common ways are through an SPI bus (`Fledex.Driver.Impl.Spi`) or through Kino (`Fledex.Driver.Impl.Kino`) as a simulated LED strip in [Livebook](https://livebook.dev/). It is possible to adjust the settings of the drivers, or even define several drivers at the same time.\n\nThis will look like the following:\n```elixir\nled_strip Spi do\n  # ... here comes the definition of your leds ...\nend\n```\n\nOnce we have defined our led strip we can start to define sequences of leds. This can be achieved in 4 different ways:\n\n* **static:** a static set of leds that do not change over time\n* **animation:** an animated, i.e. changing set of leds\n* **component** can encapsulate (and make the usage) of already predefined static and animated set of leds easier.\n\nAll of them define a function that defines a sequence of leds (`Fledex.Leds`). which might (or might not) change over time to give the desired effects.\n\nCombined this might look like the following (a bit of an artificial example to demonstrate all 3 types at the same time):\n```elixir\nalias Fledex.Component.Dot\n\nled_strip :nested_components, Kino do\n  animation :second,\n    send_config: fn _triggers ->\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now()\n      %{offset: second, rotate_left: false}\n    end do\n    _triggers ->\n      leds(60) |> light(:red)\n  end\n\n  component(:minute, Dot, color: :red, count: 60, trigger_name: :minute)\n  component(:hour, Dot, color: :blue, count: 24, trigger_name: :hour)\n\n  static :helper do\n    leds(5) |> light(:davy_s_grey, offset: 5) |> repeat(12)\n  end\nend\n```\n\nYou mainly use the functionality from `Fledex.Leds` which has plenty of functions. It allows to set individual leds, provides the possibility to nest led sequences, to repeat and to define leds through some functions, like gradients and rainbow distributions.\n`Fledex.Color.Names` provides a very rich set of predefined [color names](https://www.ditig.com/256-colors-cheat-sheet), but you can define it also by specifying a hex value. \nHere an example of an led squence of 10 leds with the first 3 being `red`, `green`, and  `0x0000ff` (blue). The rest will be black (off).\n```elixir\n  leds(10) |> red() |> light(:green) |> light(0x0000ff)\n```\n\nThere is also a rich set of support functionality to make the definition of LED strips (and especially animations) easier, like:\n\n* `Fledex.Effect.*` to define some effects (like Dimming, Wanish, ...) on a sequence of leds\n* `Fledex.job` to define repetitive tasks, like fetching some weather information\n\nTake a look at the [Livebook examples](README.md#livebook) on how to use the DSL. Note: the livebooks do present also the internals how the library works. As a first step you can skip those.","ref":"readme-1.html#usage"},{"type":"extras","title":"Livebook - Fledex","doc":"As mentioned above, the library works well in conjunction with Livebook so you probably want to take your first steps with it. You can find some [livebooks](livebooks/README.md) files that show you how to use the library in a notebook (with and without hardware). You should be able to do most of your development on a computer (emulating the LED strip with a `Fledex.Driver.Impl.Kino`) before adjusting it to the real hardware (with the `Fledex.Driver.Impl.Spi`). On real hardware you can even run it with serveral drivers at the same time.\n\n# Nerves-Livebook\nTODO: Add more info...","ref":"readme-1.html#livebook"},{"type":"extras","title":"Further Docs - Fledex","doc":"you can find some further documentation in the `docs` folder about:\n\n* An Overview over the [Architecture](docs/architecture.md)\n* How to setup and connect real [Hardware](docs/hardware.md)\n* You might find in the folder also some temporary documenation with some thoughts, but I delete them again, once they have fulfilled their purpose, except for: \n* A bit of history with the [Project Plan](docs/project_plan.md) as created with my son, since it's a nostalgic document","ref":"readme-1.html#further-docs"},{"type":"extras","title":"Known Limitations - Fledex","doc":"If you want to run this library in nerves-livebook, you currently have to compile your own livebook with the library included in your `mix.exs` file, since you can't add any libraries that are not already bundled.","ref":"readme-1.html#known-limitations"},{"type":"extras","title":"Contributing - Fledex","doc":"Contributions of any kind are very much welcome\n\n* raising issues, \n* raising PR (see also [this](CLA.md) doc), \n* reporting security vulnerabilities (see also [this](SECURITY.md) doc), \n* suggesting improvements to documentation incl. reporting typos, \n* raising feature requests,\n* ... \n\nBefore doing so please make sure to also read through the [CONTRIBUTING](CONTRIBUTING.md) document and ensure to follow the [Code of Conduct](CODE_OF_CONDUCT.md).\n\nIf you need any assistance, feel free to send an email to fledex at reik.org","ref":"readme-1.html#contributing"},{"type":"extras","title":"Architecture","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# Architecture\nThis document gives a rough overview over the architecture of Fledex. We first will \nlook at the low level aspects (the different drivers) and then work our way up the \nstack.\n\n![Architecture Diagram](./architecture.drawio.svg)\n\n# The drivers\nThe main interface to talk to the \"hardware\" is the `Fledex.LedStrip`. It takes the\n`Fledex.Leds` definitions merges them and then passes the result to the actual \nhardware drivers. It plays about the same role as a window server in operating system.\n\nThe `Fledex.LedStrip` allows to define serveral namespaces that can have their own \nled definitions and that are only merged together at \"display\" time. This is similar \nin defining several windows in a window server. They all end up on the same display.\n\nThe `Fledex.LedStrip` does not really know how to talk to the actual hardware, but \nleaves this to the hardware spectific `Fledex.Driver.Driver`s. It's possible to \nregister several drivers at the same time.\n\nCurrently there are 4 drivers available:\n* `Spi` is the main driver for talking to a real \n  [led strip with a ws2801 chip](https://www.amazon.com/s?k=ws2801) over the spi bus\n* `Kino` is a driver that is very convenient when working with a \n  [Livebook](https://livebook.dev/) to emulate an led strip.\n* `Logger` is a driver that dumps the data to a logger.\n* `Null` is a driver that acts similar to `/dev/null`, i.e. doesn't do anyting with the\n  data. This can be very convenient for running some tests.\n\nNote: In addition an additional a special `:config` driver can be used, which simply returns the current definition. This can be very useful when defining components as well as in tests.\n\n# The Leds\nThe `Leds` is an easy way to define a set of Leds. This module provides the \npossibility to specify individual leds by integer/name/rgb-values, by a generator \nfunction (like `rainbow/2`, or `gradient/2`), or by combining various `Leds` \ndefinitions into a single definition.\n\nThe `Leds` are not bound to a specific led strip (and namespace), but can be send \nto one by calling the `send()` function with the appropriate parameters. For \nconvenience it's possible to bind it already during creation time to a specific \nled strip and namespace.\n\n# The Animations\nTo define individual `Leds` is nice, but it would be even nicer, if it would be \npossible to animate the `Leds`. This is where the `Animator` comes in. It allows \nto define `Leds` and vary them through some triggers (like a timer/counter). \n\nIt's possible to define this simply through a sequence of `Leds` definitions \nfollowed by a `send()` and some `Process.sleep()`, but that approach would have \nseveral limitations.\n\nThe `Animator` is a `GenServer` that loops through the animation function and allows\nto modify the animation between loops.\n\nThe various `Fledex.Animation.Animator`s can be managed through a \n`Fledex.Animation.Manager`. It allows to create, redefine, and destroy animations \n(i.e.`Fledex.Animation.Animator`s) through a single configuration.\n\n# The Fledex DSL\nThe ultimate goal is to define a `Fledex` DSL that can configure the \n`Fledex.Animation.Manager` and update annimations on the fly.\n\nIn the above diagram an example is shown on how such a DSL might look like (and how it maps to the different components), but for clarity does not show all features. \n\n# The Triggers\nThe `Fledex.LedStrip` is publishing via `Fledex.Utils.PubSub` an event (a trigger) \nthat gets picked up by the `Fledex.Animation.Animator`s to change their animation. \nThe trigger can not only be created by the driver, but also by external events. The\ndifference is that only the triggers from the driver is used by the `Fledex.Animation.\nAnimator`s to redefine the animation. All other triggers are collected over time and\ncan be used when updating the animation.\n\nFor example: we want to be able to check the current temperature in regular interval \nand trigger a re-animation to adjust the \"display\" depending on the temperature. Your temperature checking code would use the `Fledex.Utils.PubSub.broadcast_trigger/1` function to publish the temperature.\n\n# The Job\nIt is quite common to execute certain functions in regular intervals (like in the example mentioned above to check the temperature). For this purpose a cron job facility is provided.\n\n# The Coordinator and the states\nAnimations and Effects can publish an event to communicate about the animation/effect state.\nThis state can then be picked up by a coordinator to control different animations and effects.\nThe Coordinator will simply execute a function which can pattern match on the context and the state to make some decisions.\n\n# Final Notes","ref":"architecture.html"},{"type":"extras","title":"Naming - Architecture","doc":"The led naming, the namespace naming, and the `Fledex.LedStrip` server naming should \nall be driven by the `Fledex`  DSL. Even though it would be possible to have different\nnames it helps to align them. The `led_strip` name becomes the `Fledex.LedStrip` server\nname. The `animation` name becomes the namespace name and combined with the `led_strip`\nname the `Fledex.Animation.Animator` server name.","ref":"architecture.html#naming"},{"type":"extras","title":"Hardware (examples)","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# Hardware (examples)","ref":"hardware.html"},{"type":"extras","title":"Introduction - Hardware (examples)","doc":"This is a short description what you need to do on hardware side and how\nto connect the Raspberry Pi (RPI) with the LED strip.\nThe description consists of 2 parts, the first one without a level-shifter\nthe second one with a level shifter\n\n\n> [!CAUTION]\n> YOU MUST BE A QUALIFIED ELECTRICIAN TO CONNECT TO HIGH/DANGEROUS VOLTAGES (> 30V)\n> \n> NO RESPONSIBILITY CAN BE TAKEN FOR ANY DAMAGE CAUSED BY FOLLOWING THIS GUIDE","ref":"hardware.html#introduction"},{"type":"extras","title":"Hardware components - Hardware (examples)","doc":"* Raspberry Pi Zero W (with pin header)\n* LED strip with a [WS2801 chip](https://cdn-shop.adafruit.com/datasheets/WS2801.pdf) ([e.g. this one on Amazon](https://amzn.eu/d/cPdgigY))\n* 5V Power supply, powerful enough to power the LED strip (e.g. [Mean Well LPV-35-5](https://www.meanwell.com/webapp/product/search.aspx?prod=LPV-35) for a 3m strip)\n* (optional) [Level shifter](https://www.ti.com/product/TXB0104?qgpn=txb0104) in a easy to use format (e.g. [the one from Adafruit](https://www.adafruit.com/product/1875))\n* cables, soldering iron, plugs, ...\n\nNote: Fledex currenlty only supports the LED strips with WS2801 chips via the SPI bus, but it would be easy to extend the library with other drivers for other chip types or buses.","ref":"hardware.html#hardware-components"},{"type":"extras","title":"SPI and WS2801 - Hardware (examples)","doc":"We are connecting the LED strip with the Raspberry Pi through the [SPI (Serial Peripheral Interface)](https://en.wikipedia.org/wiki/Serial_Peripheral_Interface). The SPI has 4 logical signals, but we are only interested in 2 of them.\n\n* Clock (SCLK)\n* Master Out, Slave In (MOSI)\n\nThe WS2801 uses a very simple protocol via SPI. It uses as a bus where one LED will pass on the message to the next LED, removing the first information from the message. \n\nWe don't require the other signals:\n\n* Chip Select (CS)\n* Master In, Slave Out (MISO)  \n\nThis is because we neither address every chip individually nor do the chips provide any response. The LED strip doesn't even expose those signals.\n\nIf you look carefully, you can find on the LED strip a DI (Data In) and DO (Data Out) pins. They indicate in which direction the signals are flowing. The same also applies to the CI (Clock In) and CO (Clock Out) pins. \n\nWhen you connect your Raspberry Pi you will have to connect the MOSI (of the RPI) to the DI (of the LED strip) and the SCLK (of the RPI) to the CI (of the LED strip).\n\nIn the following we will look at two ways to connect the LED strip to the RPI, one directly (which probably works, but is not recommended) and one with a so called level shifter.\n\nThe reason for the level shifter is that the RPI (even though it's powered with 5V) uses 3.3V for its SPI port. The LED strip is powered with 5V and expects a 5V signal. We should adjust between the two voltage levels.","ref":"hardware.html#spi-and-ws2801"},{"type":"extras","title":"Finding the pins on the RPI - Hardware (examples)","doc":"It can be quite tricky to find the correct pin on the RPI. Therefore several resources are linked below. The difficult part is to figure out where pin 1 is located, everything else is then quite easy.\nThe below drawings try to make it clear on how you have to look at your RPI. You look from the the top down onto the processor (black) and then you can easily find pin 1.","ref":"hardware.html#finding-the-pins-on-the-rpi"},{"type":"extras","title":"Direct Connection - Hardware (examples)","doc":"The direct connection (especially with short conncetions) will probably work, because the allowed tolerance for a HIGH signal and will still be above the required 2V. Any signal above 2V is considered as HIGH (= binary a 1) and any signal below 0.8V is considered as LOW (= binary a 0). \n\n![direct connection](hardware.drawio.svg \"Direct connection\")","ref":"hardware.html#direct-connection"},{"type":"extras","title":"Connection via a Level Shifter - Hardware (examples)","doc":"It is better to use a level shifter to properly translate between the 3.3V signals and the required 5V signals.\n\nThere are [different ways](https://electronics.stackexchange.com/questions/82104/single-transistor-level-up-shifter/82112#82112) on how to level shift. We will us the Adafruit TXB0104 Bi-Directional Level shifter. It is a bit of an overkill, because we neither need to translate in both direction, nor do we require 4 signal lines, but it's easy to work with.\n\nYou have to do the following steps:\n\n1. Connect the higher voltage and lower voltages to LV and HV respectively. This tells the level shifter to which levels we want to translate. It's important to make sure that the lower voltage is on the LV side and the higher voltage on the HV side.\n2. Connect each signal line to one of the signal pins. The 3.3V to the LV side (A1-A4) and the 5V to the corresponding pins on the HV side (B1-B2).\n3. Enable the output by connecting the OE pin to the LV pin\n4. Connect all the Ground lines to the GND pin.\n\n![Connection with Level shifter](hardware-Page-2.drawio.svg)","ref":"hardware.html#connection-via-a-level-shifter"},{"type":"extras","title":"Additional Information - Hardware (examples)","doc":"","ref":"hardware.html#additional-information"},{"type":"extras","title":"Pin information: - Hardware (examples)","doc":"* https://pinout.xyz/pinout/spi# \n* https://www.raspberrypi.com/documentation/computers/raspberry-pi.html\n* https://pi4j.com/1.2/pins/model-zerow-rev1.html","ref":"hardware.html#pin-information"},{"type":"extras","title":"Logic Levels - Hardware (examples)","doc":"* https://learn.sparkfun.com/tutorials/logic-levels/all","ref":"hardware.html#logic-levels"},{"type":"extras","title":"Project Plan","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# Project Plan","ref":"project_plan.html"},{"type":"extras","title":"Introduction - Project Plan","doc":"This is the initial project plan developed with my son. Since I speak German\nwith him, it's written in German.","ref":"project_plan.html#introduction"},{"type":"extras","title":"The Plan - Project Plan","doc":"1. Was moechtest do machen: Blau blinken\n2. Was bedeutet das genau:\n    1. alle Lampen sind blau\n    2. warte einen Augenblick\n    3. alle Lampen sind aus\n    4. warte einen Augenblick\n    5. fange wieder bei 1 an\n```elixir\n    loop :infinite do\n        lamp blue, repeat: 96\n        sleep 1_000\n        lamp off, repeat: 96\n        sleep 1_000\n    end\n```\n\n3. Welche Funktionsbloecke haben wir?\n    1. Schleife (loop)\n    2. Farbe definieren (blau, aus (=schwarz))\n    3. Pause (sleep)\n4. Wie definieren wir eine Farbe?\n    1. Mit Namen (blau, kek, blue)\n    2. Mit Hex-Zahlen (0x0000FF)\n    3. Mit RGB Werten (0, 0, 255) (Werte im Interval zwischen [0, 255])\n        1. 255 ist maximaler Wert ==> 300 gibt einen Fehler\n5. Wie definiert man mehrere Lampen? (Anzahl Lampen muss bekannt sein)\n    1. Definiere 1 Farbe & wiederhole sie (fuer eine Anzahl an Lampen / auf alle Lampen)\n    2. Definiere mehrer Lampen und wiederhole sie auf alle\n    3. Definiere Anfangs- und Endfarbe und interpoliere dazwischen\n    4. Definiere Farbverlaeufe\n        1. Regenbogenfarben\n    5. Kombination die oberen Moeglichkeiten\n6.\n```elixir\n    loop :infinite do\n        lamp red, offset: 58\n        lamp green, offset: 12\n        sleep 1_000\n        lamp off, offset: 58\n        lamp off, offset: 12\n        sleep 1_000        \n    end\n```","ref":"project_plan.html#the-plan"},{"type":"extras","title":"Project Plan Review - Project Plan","doc":"We made a walkthrough with my son to check whether the library contains all the\nelement that he was looking for, i.e. we have fulfilled the project plan\n(Note: in the code examples we don't include the installation of the library or\nthe `use Fledex`)\n\n1. Blue blinking. The solution looks a little bit different, we don't use the\n   the sleep function, but we do this by a) a divisor and b) a case statement\n   switching on the two \"states\" when checking the remaineder of the counter by\n   two.\n    ```elixir\n    led_count = 1\n    divisor = 10\n    led_strip :one, Kino do\n      animation :blink_blue do\n        triggers ->\n        counter = triggers[:one] || 0 \n        counter = trunc(counter/divisor) \n        case rem(counter, 2) do\n          0 -> leds(1) |> black |> repeat(led_count)\n          1 -> leds(1) |> blue |> repeat(led_count)\n        end\n      end\n    end\n    ```\n2. see above. We have all the elements (even though in a slightly different form)\n3. see above. We have all the elements (even though in a slightly different form)\n4. To define a color we can do the following:\n   ```elixir\n   leds(10) |> light(:blue) |> red |> light(0x00ff00) |> light({0, 0, 255}) |> light({500, 0, 0})\n   ```\n   This gives us 10 leds with the first 5 being colored: blue, red, green, blue, red\n   Note1: The last value is outside the range, but will automatically be capped to\n   stay within the allowed range. Hence the last led will be simply red. We won't throw\n   an error.\n   Note2: at this point we do not have translations of the colors (that would be too much work :-)\n   and the customer has started to learn Enlish and therefore it's not a problem anymore\n5. Here the solutions for the different parts:\n   1. Use of the repeat function within the light function (note the offset does need to be specified)\n   ```elixir\n   leds(10) |> light(:red, offset: 1, repeat: 5)\n   ```\n   Use of the repeat function for an led sequence (the resulting sequence is shorter compared to the above example):\n   ```elixir\n   leds(1) |> light(:red) |> repeat(5)\n   ```\n   2. But the latter allows us to solve the next one too\n   ```elixir\n   leds(3) |> red() |> green() |> blue() |> repeat(3)\n   ```\n   3. This is easily done with the gradient function\n   ```elixir\n   leds(10) |> gradient(:blue, :red)\n   ```\n   4. This is solved as the above one, but we use the rainbow function\n   ```elixir\n   leds(10) |> rainbow()\n   ```\n   5. The above can be combined in a wild way:\n   ```elixir\n   l1 = leds(7) |> rainbow() |> repeat(3)\n   leds(50) |> light(l1, 5) |> light(l1, 30)\n   ```\n6. The offset can be defined by using the offset function as shown in 5.5","ref":"project_plan.html#project-plan-review"},{"type":"extras","title":"Result - Project Plan","doc":"The customer has accepted the implementation and we can close down this project\nplan thereby :-)","ref":"project_plan.html#result"},{"type":"extras","title":"Cheatsheet","doc":"<!--\nCopyright 2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n# Cheatsheet\n\nThis is a very brief overview over the most important commands in the Fledex language\n\n## `use Fledex` library\n{: .col-2}\n\nBefore you use any of the structures below, you first need to install the library and then `use` it.","ref":"cheatsheet.html"},{"type":"extras","title":"Installation - Cheatsheet","doc":"Before you can use Fledex, you need to install the library. Either as a dependency in your `mix.exs` file, or as part of your setup in your livebook by calling\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.4\"}\n])\n```","ref":"cheatsheet.html#installation"},{"type":"extras","title":"Example - Cheatsheet","doc":"```elexir\nuse Fledex\n```","ref":"cheatsheet.html#example"},{"type":"extras","title":"Description - Cheatsheet","doc":"By `use`-ing the library, it is possible to use the structures specified below. It is safe to use this even in a functional context, i.e. it does not need to be part of a module.\n\nIn addition, the following modules will be imported:\n\n* `Crontab.CronExpression`: used to define job intervals\n* `Fledex.Leds`: used to define LEDs\n* `Fledex.Color.Names`: used to specify colors\n* `Fledex.Utils.PubSub`: used to publish events/data towards animations\n\nIn addition a `Fledex.Animation.Manager` will be started in the background (if there is none running) which will manage all animations.","ref":"cheatsheet.html#description"},{"type":"extras","title":"The `led_strip` - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#the-led_strip"},{"type":"extras","title":"Example - Cheatsheet","doc":"```elixir\nled_strip :name, Kino do\n  animation :seconds do\n    %{seconds: seconds} -> leds(60) |> light(:red, offset: seconds)\n    _ -> leds()\n  end\n  static :indicators do\n    leds(5) |> light(:white) |> repeat(12)\n    end\n  end\n  job :clock, ~e[* * * * * * *]e do\n    date_time = DateTime.utc_now()\n    broadcast_trigger(%{seconds: date_time.seconds})\n  end\nend\n```","ref":"cheatsheet.html#example"},{"type":"extras","title":"Parameters - Cheatsheet","doc":"The `led_strip` takes the following parameters:\n\n| Parameter   | Description                              |\n| ---         | ---                                  |\n| `name`      | (mandatory) Every strip needs a unique name. This needs to be an atom |\n| `driver`    | (mandatory) The driver that should be used to display the LEDs. The most common options are: `Kino` (for livebook), and `Spi` (for real hardware). The special driver `:config` returns the defined config, instead of configuring a driver. |","ref":"cheatsheet.html#parameters"},{"type":"extras","title":"The `do ... end` block - Cheatsheet","doc":"The following structures inside the `do ... end` block are allowed:\n\n| Structure   | Description       |\n| ---         | ---               |\n| `animation` | Defines an animation that can change over time        |\n| `static`    | Defines a certain pattern, it cannot change over time |\n| `effect`    | Defines an effect that gets applied to an animation   |\n| `job`       | Does not define any LEDs, but some job that should be executed in regular intervals |\n| `component` | Defines a component. It's equivalent to a set of `static`, `animation`, `job`, including `effect`s. It allows to reuse certain aspects |\n\nSee below for more details about them","ref":"cheatsheet.html#the-do-end-block"},{"type":"extras","title":"The `animation` - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#the-animation"},{"type":"extras","title":"Example - Cheatsheet","doc":"```elexir\nanimation name, options do\n  leds(10)\nend\n```","ref":"cheatsheet.html#example"},{"type":"extras","title":"Parameters - Cheatsheet","doc":"The `animation` takes the following paramerters\n\n| Parameter | Description |\n|---        |---          |\n| `name`    | (mandatory) Every animation needs a unique name. This must be an atom |\n| `options` | (optional) A set of options, that is rarely used |","ref":"cheatsheet.html#parameters"},{"type":"extras","title":"The `do ... end` block - Cheatsheet","doc":"The structure inside the `do ... end` block can be any Elixir code, but it needs to return (at least) an `Fledex.Leds` structure (see below). \n\n**Caution:** This function gets executed quite frequently and you need to ensure to keep it lightweight.\n\nThe code block is actually a function and it is possible to pattern match on a parameter (which is a map) and to extract information from the paramerter:\n\n```elexir\nanimation :name do\n  %{trigger_name: value} -> leds(value)\n  _ -> leds()\nend\n```\n\n**Note:** it's important to notice that the map might not contain the information you expect especially during initialization phase. Make sure you have a \"catch all\" clause.","ref":"cheatsheet.html#the-do-end-block"},{"type":"extras","title":"The `static` - Cheatsheet","doc":"{: .col-2}\n\nThe static structure is very similar to the `animation` structure, except that won't be updated and changed over time. Therefore it's also not possible to use the optional parameter in the `do ... end` block.","ref":"cheatsheet.html#the-static"},{"type":"extras","title":"Example - Cheatsheet","doc":"```elexir\nstatic name, options do\n  leds(10) |> light(:red)\nend\n```","ref":"cheatsheet.html#example"},{"type":"extras","title":"Parameters - Cheatsheet","doc":"The `static` structure takes the following parameters:\n\n| Parameter | Description |\n|---        |---          |\n| `name`    | (mandatory) Every animation needs a unique name. This must be an atom |\n| `options` | (optional) A set of options, that is rarely used |","ref":"cheatsheet.html#parameters"},{"type":"extras","title":"The `do ... end` block - Cheatsheet","doc":"The structure inside the `do ... end` block can be any Elixir code, but it needs to return (at least) an Leds structure (see below).\n\nContrary to the `animation` the `static` structure only get called once and does not get called repeatedly.","ref":"cheatsheet.html#the-do-end-block"},{"type":"extras","title":"The `effect` - Cheatsheet","doc":"{: .col-2}\n\nAny `animation` can be wrapped into an effect that impacts how the `animation` is perceived.","ref":"cheatsheet.html#the-effect"},{"type":"extras","title":"Example - Cheatsheet","doc":"```elexir\neffect Fledex.Effect.Rotation, trigger_name: :john do\n  animation :seconds do:\n    ...\n  end\n  animation :minutes do:\n    ...\n  end\nend\n```\n\nAs can be seen in the example, the effect encapsulates one (or more) animations that it will impact.","ref":"cheatsheet.html#example"},{"type":"extras","title":"Parameters - Cheatsheet","doc":"| Parameter | Description |\n|---        |---          |\n| `effect`  | (mandatory) A module that implements the `Fledex.Effect.Interface`. You cand find some examples in the `Fledex.Effect` namespace, like: `Dimming`, `Rotation`, `Offset`, `Wanish`. |\n| `options` | (optional) A list of key value pairs that configure the effect. The settings are very specific to each effect. |","ref":"cheatsheet.html#parameters"},{"type":"extras","title":"The `do ... end` block - Cheatsheet","doc":"The `do ... end` block can contain, similar to the `led_strip` any of the fledex macros, but it only has a real effect on `animations`. Effects can even be nested, i.e. to have a `Dimming` around a `Rotation` effect which contains an animation.","ref":"cheatsheet.html#the-do-end-block"},{"type":"extras","title":"The `job` - Cheatsheet","doc":"{: .col-2}\n\nAs mentioned above, very little work should be done as part of an animation. Any heavy lifting should be done in a separate process, and you probably don't want to do it very frequently anyway.\n\nA `job` is there to shedule a task in regular intervals and to publish it to the animations. The animation can extract that information from the parameter that gets passed to the `do ... end` block (see above).","ref":"cheatsheet.html#the-job"},{"type":"extras","title":"Example - Cheatsheet","doc":"```elixir\njob :name, ~e[* * * * * * *]e do\n  date_time = DateTime.utc_now()\n  broadcast_trigger(%{seconds: date_time.seconds})\nend\n```","ref":"cheatsheet.html#example"},{"type":"extras","title":"Parameters - Cheatsheet","doc":"The `job` takes a couple of parameters:\n\n| Parameter | Description |\n|---        |---          |\n| `name`    | (mandatory) Every job needs to get a unique name. This must be an atom |\n| `pattern` | (mandatory) You need to specify a pattern when the job should run. The pattern can eithe rbe a normal crontab pattern (e.g. `~e[*/15]`) with minute precision or an extended one (e.g. `~e[*/15]e`) with second precision. More details can be found in [this cheatsheet](https://hexdocs.pm/crontab/cron_notation.html#expressions). |\n| `options` | (optional) one or more options can be specified (see below for details) |","ref":"cheatsheet.html#parameters"},{"type":"extras","title":"Options - Cheatsheet","doc":"The following options are recognized:\n\n| Option | Description |\n|---     |---          |\n| `:run_once` | to run the directly after configuration, independent from the actual schedule |\n| `:timezone` | specify a different timezone than the usual `UTC` |\n| `:overlap`  | Whether different runs should overlap. Usually this is not desired |","ref":"cheatsheet.html#options"},{"type":"extras","title":"The `do ... end` block - Cheatsheet","doc":"The `do ... end` block can consist of any valid Elixir code. The code will be called without any arguments. Usually you want to use at the end a `broadcast_trigger/1` call \nto publish data towards the animations that react to data and change their look.","ref":"cheatsheet.html#the-do-end-block"},{"type":"extras","title":"The `component` - Cheatsheet","doc":"{: .col-2}\n\nThe `component` allows to encapsulate several animations and to reuse them into a single component. Examples are: `Fledex.Component.Clock`, `Fledex.Component.Dot`, and `Fledex.Component.Thermometer`.","ref":"cheatsheet.html#the-component"},{"type":"extras","title":"Example - Cheatsheet","doc":"```elexir\n  component(:thermo, Thermometer,\n    range: -20..40,\n    trigger: :temperature,\n    negative: :blue,\n    null: :may_green,\n    positive: :red,\n    marker: :davy_s_grey\n  )\n```","ref":"cheatsheet.html#example"},{"type":"extras","title":"Parameters - Cheatsheet","doc":"The `component` takes the following parameters:\n\n| Parameters | Description |\n| `name`     | (mandatory) Every component needs a name, but since a component consists of potentially several animations, the component could also take a tuple of names that are then assigned to the different animations (otherwise they are generated from the base name passed in) |\n| `component` | (mandatory) The name of the module that defines the component (that implements the `Fledex.Component.Interface` behaviour) |\n| `options` | (mandatory) A lit of options. The exact options are dependent on the component |","ref":"cheatsheet.html#parameters"},{"type":"extras","title":"The `Fledex.Leds` struct - Cheatsheet","doc":"{: .col-2}\n\nThe `Fledex.Leds` module allows to define a sequence of leds","ref":"cheatsheet.html#the-fledex-leds-struct"},{"type":"extras","title":"Example - Cheatsheet","doc":"```elexir\nleds(3)\n  |> light(:red)\n  |> light(:green)\n  |> light(:blue)\n  |> repeat(5)\n```","ref":"cheatsheet.html#example"},{"type":"extras","title":"Creation - Cheatsheet","doc":"| Function  | Description |\n|---        |---          |\n| `leds/0`  | Creates an led sequence with zero length. This sounds maybe stupid but is useful if you don't want to define an animation (maybe because you are maybe still not fully initialized) |\n| `leds/1`  | Creates an led sequence with a specified length |\n| `leds/2`  | (rarely used) Creates an led sequence with a specific length and some options (important for the `send` function). |\n| `leds/3`  | Creates an led sequence with a list of colors that will be assigned to the leds. Pass an empty map (`%{}`) as the last argument |\n| `leds/4`   | (rarely used) Creates an led sequence with all the bells and whisles: `count`, list of `colors`, `options`, and some `meta` information |","ref":"cheatsheet.html#creation"},{"type":"extras","title":"Lights - Cheatsheet","doc":"| Function  | Description |\n|---        |---          |\n| `light/2`  | This sets the color of the next led. Whenever you call this function an internal counter will be updated to the next led. Therefore you can nicely sequence it. **Note:**. The \"color\" can also be another led sequence that will be added at the corresponding position. |\n| `light/3`  | This sets a color with some options, like to offset and whether it repeats. **Note:** the offset is 1 indexed and must be greater than zero. |","ref":"cheatsheet.html#lights"},{"type":"extras","title":"Other Functions - Cheatsheet","doc":"The above functions would be enough, but some special functions make life easier:\n\n| Function  | Description |\n|---        |---          |\n| `repeat/2`  | This function does what it says. It will repeat the current sequence n-times and make the whole sequence n-times longer. |\n| `rainbow/2` | This function creates a rainbow over the leds. It takes a couple of parameters to control the rainbow effect. |\n| `gradient/4` | This function creates a gradient between the two colors specified, with a couple of options to control the exact behaviour. |","ref":"cheatsheet.html#other-functions"},{"type":"extras","title":"The colors - Cheatsheet","doc":"{: .col-2}\n\nFledex has a very extensive color list as can be found on [Wikipedia](https://en.wikipedia.org/wiki/List_of_colors:_A%E2%80%93F). Take a look at `Fledex.Color.Names` for the full list of colors, but here the most important colors:","ref":"cheatsheet.html#the-colors"},{"type":"extras","title":"Examples - Cheatsheet","doc":"red  \n    \n          orange  \n    \n          yellow  \n    \n          green  \n    \n          cyan  \n    \n          blue  \n    \n          violet","ref":"cheatsheet.html#examples"},{"type":"extras","title":"Usage - Cheatsheet","doc":"There are several ways on how a color can be applied to an `Fledex.Leds` struct:\n\n#### Atom\n\n```elexir\nleds(1) |> light(:red)\n```\n\n#### Function\n\n```elexir\nleds(1) |> red()\n```","ref":"cheatsheet.html#usage"},{"type":"extras","title":"Intro","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# Intro\nThis is a description of the livebooks in this folder. The examples are structured in such a way that we slowly walk up the abstraction stack. From very low level to a high level language. If are not interested in the technical details, the motivations, and the decisions then you probably want to only look at livebook \"[#1 First steps with an led strip](livebooks/README.md#1-first-steps-with-an-led-strip)\" (which has nothing to do with Fledex as such but how to set up your LED strip correctly) and the dsl specific chapters starting with livebook [#6 Fledex DSL](livebooks/README.md#6-fledex-dsl) (to define your animations). Only the whole set will give you, however, a good overview.\n\nIt is recommended that when you look at the different livebooks you look at the [Architecture Overview](../docs/architecture.md) in parallel. Take also a look at the [Hardware](../docs/hardware.md) description, because you need to have your hardware setup ready to run anything on a real led strip. Most examples can be run in the livebook and don't require any additional hardware.\n\nThe different livebooks have been categorized:\n\n* **intro:** You probably want to start with this one\n* **background:** You can skip this livebook, except if you want to understand the evolution of the library\n* **details:** You should probably look at those livebooks, because it explains some details and generic concepts. You can do so either right from the beginning, or at a later point in time (when you feel that it's time to learn more about it)\n* **usage:** Those livebooks you really should look at to learn how to use the library\n\n# 1. First steps with an LED strip (intro)\nThe first livebook has nothing to do with the Fledex library, but describes on how to set up the [RaspberryPi](https://www.raspberrypi.org/), how to connect the LED strip to it and how we can communicate with it via the SPI bus. It also shows how easy it is to communicate to an LED strip. At the same time it is cumbersome, due the sheer number of LEDs that can be addressed. This example is good to\n\n- ensure that everything is set up correctly (before we bring the complexity of a library in)\n- get an understanding on why Fledex was created in the first place to make the definition of the strip easier\n\nWe don't really want to work on this level\n\n# 2. Fledex: First steps (background)\nThe first steps with the Fledex library. The example shows how the LED strip can be emulated with\nthe Kino driver, but it does contain commented out code for the SPI driver too to send it to a\nreal LED strip.\nIn the driver configs we define an error correction, since the 5050 chips have too intensive green\nand blue LEDs that need to be compensated to have a more natural look. The Kino driver does not\nrequire such a compensation, even though it is possible to define one too.\nBy changing the definition of our LEDs we can also create some simple animations\n\nThis example works still on a very low level, one that we do not want use. \n\n# 2b. Fledex: How to define LEDs (details)\nIn this livebook we take a closer look how we can define sequences of leds. We start with a brief look at how we can define colors, but we'll take a more detailed look at colors\nin __3b. Fledex: More about colors__. Then we'll look at sub-sequences and how to\ngenerate sequences with functions.\n\n# 3. Fledex: Animations (background)\nIn this livebook we look how animations can be defined, this is the next step(s) above the `Fledex.LedStrip`. The `Fledex.Animation.Manager` is the level that we want to operate on and the following examples will use what we have explored here and will create some concrete examples:\n\n* a clock (using local information) and \n* a weather indicator (collecting data via the internet)\n\n# 3b. Fledex: More about colors (details)\nHere we talk a bit more about colors and even color corrections\n\n# 4. Fledex: Clock example (background)\nThis is the first \"meaningful\" example that displays the current time on the LED strip. We define 4 \"animations\" for:\n\n* the indicators (otherwise it becomes hard to read the time), \n* the seconds (red), \n* the minutes (green), and \n* the hours (blue).\n\nThis example demonstrates how easy we do things when we can pull the information whenever needed. The current time is something that is readily available on the device and can be called as often as we want. Hence we can call this function every time we paint the strip.\n\n**CAUTION:** we repaint the LED strip very frequent and therefore it's nothing you want to do with data that is expensive to retrieve.\n\n# 5. Fledex: Weather example (background)\nThis is an example where we **CANNOT** fetch the information every time we want to paint the strip (which could be serveral times per second), since we are calling a public API. The API would surely block us if we would try to attempt to call it that often.\n\nTherefore we fetch the information at regular intervals, outside of our animation loop. For that we define a small GenServer which makes the API call, and publishes the data via pubsub to then be picked up by the animation loop.\n\n# 6. Fledex: DSL (usage)\nIn this example we will look at the Fledex DSL that removes a lot of the boilerplate and therefore makes the definition of an LED strip even easier. Under the hood it uses the same principles as the ones we have encountered in the examples 3-5.\n\nIn this example we will reimplement the Clock, but this time with our DSL.\n\n# 7. Fledex: Effects (usage)\nIn this chapter we take a look at the effect functionality. An animation can be \"spiced\" with one or more effects. This id also part of the Fledex DSL.\n\nWe won't look at all possible effects, but at some examples. It is quite easy to create your own effect and we'll take a look on how to do that too.\n\n# 8. Fledex: Component (usage)\nIn this chapter we will take a look on how to create reusable components. This way you don't have to redefine certain animations\n\n# 9. Fledex: Job (usage)\nAnimations often require some time activity. In this chapter we will take a look at the `job` feature that makes the scheduling of repetitive tasks much easier by providing a cron-job like feature. This is mainly intended to trigger some events for the animation(s), but could really be used for anything.","ref":"readme-2.html"},{"type":"extras","title":"1. First steps with an LED strip","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 1. First steps with an LED strip\n\n```elixir\nMix.install([\n  {:circuits_spi, \"~> 2.0\"}\n])\n```","ref":"1_first_steps_with_an_led_strip.html"},{"type":"extras","title":"Search and open the SPI bus - 1. First steps with an LED strip","doc":"First of all we try to figure out what kind of SPI buses exist on the device\n\n```elixir\n_ = Circuits.SPI.bus_names()\n```\n\nAs a next step we open the first SPI bus and close it again. Let's make sure this works without any error\n\n```elixir\n{:ok, ref} =\n  Circuits.SPI.open(\"spidev0.0\",\n    mode: 0,\n    bits_per_word: 8,\n    speed_hz: 1_000_000,\n    delay_us: 10,\n    lsb_first: false\n  )\n\n:ok = Circuits.SPI.close(ref)\n```","ref":"1_first_steps_with_an_led_strip.html#search-and-open-the-spi-bus"},{"type":"extras","title":"Define a data structure - 1. First steps with an LED strip","doc":"Mext we define a data structure as required by the LED strip. The documentation states that we simply\nhave to send the bytes for the different LEDs in a row. If it's too short only a couple of LEDs will be \naddressed and the rest will not get any info. If the data structure is longer all LEDs will receive their\nupdate and the rest of the data will be ignored.\n\nTo start with we define 3 LEDs with the color red\n\n```elixir\nrange = Enum.to_list(1..3)\n\ndata =\n  Enum.reduce(range, <<>>, fn _index, leds ->\n    leds <> <<0xFF, 0x00, 0x00>>\n  end)\n```","ref":"1_first_steps_with_an_led_strip.html#define-a-data-structure"},{"type":"extras","title":"Send the data to the LED strip - 1. First steps with an LED strip","doc":"For this we need to combine the above steps, i.e.\n\n1. We open the SPI bus\n2. We define a datastructure with only zeros (to delete the strip, make it completely black)\n3. We send the binary to the SPI bus\n4. We define our data structure with some colors (see above)\n5. We send the binary to the SPI bus\n6. We close the SPI bus\n\nLet's see what the result will be\n\n```elixir\n# 1\n{:ok, ref} =\n  Circuits.SPI.open(\"spidev0.0\",\n    mode: 0,\n    bits_per_word: 8,\n    speed_hz: 1_000_000,\n    delay_us: 10,\n    lsb_first: false\n  )\n\n# 2 (we got a 3m strup with 96 LEDs, 3x 32 LEDs)\ndata_black =\n  Enum.reduce(Enum.to_list(1..96), <<>>, fn lindex, leds ->\n    leds <> <<0, 0, 0>>\n  end)\n\n# 3\n{:ok, _} = Circuits.SPI.transfer(ref, data_black)\n\n# 4\ndata_3red =\n  Enum.reduce(Enum.to_list(1..3), <<>>, fn _index, leds ->\n    leds <> <<0xFF, 0x00, 0x00>>\n  end)\n\n# 5\n{:ok, _} = Circuits.SPI.transfer(ref, data_3red)\n\n# 6\n:ok = Circuits.SPI.close(ref)\n```","ref":"1_first_steps_with_an_led_strip.html#send-the-data-to-the-led-strip"},{"type":"extras","title":"2. Fledex: Some simple tests","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 2. Fledex: Some simple tests\n\n```elixir\n# We start to define some libraries we need. If you are running on a laptop\n# the libraries will be loaded, but on a nerves_livebook you can only use\n# what has been compiled in.\nMix.install([\n  {:fledex, \"~>0.5\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Leds\nalias Fledex.LedStrip\nalias Fledex.Driver.Impl.Kino\nalias Fledex.Driver.Impl.Spi\nalias Fledex.Color.Correction\n\n:ok\n```","ref":"2_fledex_first_steps.html"},{"type":"extras","title":"Defining a strip - 2. Fledex: Some simple tests","doc":"Fledex has several drivers which can also be used in parallel. It's probably best to only use a single driver to start with. The `Kino` driver does not have any hardware dependency and therefore is probably a good start to ensure that the library is loaded correctly.\n\nAt this point, we won't go into the details what all the settings really mean, so just accept them for what they are. What is important to understand is the first parameter (`LedStrip`) which is the name of our strip through which we will refer to it. For simplicity we use the same name as the name of the module, but it can be any [`atom`](https://hexdocs.pm/elixir/1.12/Atom.html).\n\nThis allows us to have several strips at the same time. Whenever we interact with the LedStrip we need to use that name to specify which strip we mean.\n\n```elixir\n# frame = Kino.Frame.new() |> Kino.render()\n\n{:ok, pid} =\n  LedStrip.start_link(\n    LedStrip,\n    [\n      {Kino, update_freq: 1, color_correction: Correction.no_color_correction()}\n      # {Spi, color_correction: Correction.define_correction(\n      #   Correction.Color.typical_smd5050(),\n      #   Correction.Temperature.uncorrected_temperature()\n      # )}\n    ],\n    timer_only_dirty_update: false,\n    merge_strategy: :cap\n  )\n```","ref":"2_fledex_first_steps.html#defining-a-strip"},{"type":"extras","title":"Setting individual LEDs - 2. Fledex: Some simple tests","doc":"Now we are ready to send some data to the led_strip. Before we send some color information, we first define a namspace (`:default`) to which we will do the drawing. Each led strip can have several namespaces that can operate independently and that get merged at the end to the same led strip (similar to a window in a window server). We'll see later why this is useful.\n\n```elixir\nLedStrip.define_namespace(LedStrip, :default)\nLedStrip.set_leds(LedStrip, :default, [0xFF0000, 0x00FF00, 0x0000FF])\n```","ref":"2_fledex_first_steps.html#setting-individual-leds"},{"type":"extras","title":"Helper functions - 2. Fledex: Some simple tests","doc":"We now define a couple of helper functions. The first 2 functions (`red/1` and `blue/1`) are talking directly with the LED driver, the latter two (`rainbow/1` and `gradient/1`) are making use of the Leds client module that helps to create nice effects like a rainbow.\n\nAll functions are trying to create a simple animation by configuring the leds, sleeping for a while, and then reconfiguring the leds.\n\n```elixir\ndefmodule Helpers do\n  def red(namespace) do\n    Enum.each(1..10, fn _index ->\n      LedStrip.set_leds(LedStrip, namespace, [0xFF0000, 0x000000, 0x000000, 0x000000, 0x000000])\n      Process.sleep(600)\n      LedStrip.set_leds(LedStrip, namespace, [0x000000, 0xFF0000, 0x000000, 0x000000, 0x000000])\n      Process.sleep(600)\n      LedStrip.set_leds(LedStrip, namespace, [0x000000, 0x000000, 0xFF0000, 0x000000, 0x000000])\n      Process.sleep(600)\n      LedStrip.set_leds(LedStrip, namespace, [0x000000, 0x000000, 0x000000, 0xFF0000, 0x000000])\n      Process.sleep(600)\n      LedStrip.set_leds(LedStrip, namespace, [0x000000, 0x000000, 0x000000, 0x000000, 0xFF0000])\n      Process.sleep(600)\n    end)\n  end\n\n  def blue(namespace) do\n    Enum.each(1..10, fn _index ->\n      LedStrip.set_leds(LedStrip, namespace, [\n        0x000000,\n        0x000000,\n        0x000000,\n        0x000000,\n        0x0000FF,\n        0x00FF00\n      ])\n\n      Process.sleep(600)\n\n      LedStrip.set_leds(LedStrip, namespace, [\n        0x000000,\n        0x000000,\n        0x000000,\n        0x0000FF,\n        0x000000,\n        0x000000\n      ])\n\n      Process.sleep(600)\n\n      LedStrip.set_leds(LedStrip, namespace, [\n        0x000000,\n        0x000000,\n        0x0000FF,\n        0x000000,\n        0x000000,\n        0x00FF00\n      ])\n\n      Process.sleep(600)\n\n      LedStrip.set_leds(LedStrip, namespace, [\n        0x000000,\n        0x0000FF,\n        0x000000,\n        0x000000,\n        0x000000,\n        0x000000\n      ])\n\n      Process.sleep(600)\n\n      LedStrip.set_leds(LedStrip, namespace, [\n        0x0000FF,\n        0x000000,\n        0x000000,\n        0x000000,\n        0x000000,\n        0x00FF00\n      ])\n\n      Process.sleep(600)\n    end)\n  end\n\n  def rainbow(namespace) do\n    Enum.each(0..10000, fn index ->\n      config = [\n        num_leds: 50,\n        reversed: true\n      ]\n\n      Leds.leds(50)\n      |> Leds.set_led_strip_info(namespace, LedStrip)\n      |> Leds.rainbow(config)\n      |> Leds.send(offset: index)\n\n      # before sending the next update we sleep a bit\n      Process.sleep(100)\n    end)\n  end\n\n  def gradient(namespace) do\n    Enum.each(0..10000, fn index ->\n      Leds.leds(50)\n      |> Leds.set_led_strip_info(namespace, LedStrip)\n      |> Leds.gradient(0xFF0000, 0x0000FF, %{num_leds: 50})\n      |> Leds.send(\n        offset: index,\n        rotate_left: true\n      )\n\n      # before sending the next update we sleep a bit\n      Process.sleep(100)\n    end)\n  end\nend\n```\n\nTake note, that our functions create sequences of different length.\n\n<!-- livebook:{\"branch_parent_index\":2} -->","ref":"2_fledex_first_steps.html#helper-functions"},{"type":"extras","title":"Red and blue - 2. Fledex: Some simple tests","doc":"Now we can try it out with one of the first functions.  Let's call our `red/1` function. We spawn it in  a separate process. The reason for that you'll see in a second.\n\n**Note:** you might have to scroll up to see the animation\n\n```elixir\nLedStrip.define_namespace(LedStrip, :red)\n\nspawn(fn ->\n  Helpers.red(:red)\nend)\n```\n\nSimilarly you can do the same thing with the `blue/1` function. Where it gets interesting is, when you start first the red function and then start the blue function while the red function is still running.\n\n**Note:** Don't forget to use a differnt namespace name compared to the above function, otherwise one function would constantly overwrite what the other function has defined. We want them to live in parallel and get merged.\n\n```elixir\nLedStrip.define_namespace(LedStrip, :blue)\n\nspawn(fn ->\n  Helpers.blue(:blue)\nend)\n```\n\nWhile both functions are running, they will\n\n<!-- livebook:{\"branch_parent_index\":2} -->","ref":"2_fledex_first_steps.html#red-and-blue"},{"type":"extras","title":"Rainbow - 2. Fledex: Some simple tests","doc":"Now we can use the above functions with our Strip. We can run the functions by spawning a new thread. This allows to also see what happens if another thread works in parallel. Here we create a rainbow effect that will be send with a changing offset so that the rainbow rotates through the LEDs\n\n```elixir\nLedStrip.define_namespace(LedStrip, :rainbow)\nspawn(fn -> Helpers.rainbow(:rainbow) end)\n```\n\n<!-- livebook:{\"branch_parent_index\":2} -->","ref":"2_fledex_first_steps.html#rainbow"},{"type":"extras","title":"Gradient - 2. Fledex: Some simple tests","doc":"Here we create a gradient between red and blue. Also this one we let rotate through. Note, depending on whether you started the rainbow above or not, you might see different results. Try this section with and without running the Rainbow section.\n\n```elixir\nLedStrip.define_namespace(LedStrip, :gradient)\nspawn(fn -> Helpers.gradient(:gradient) end)\n```\n\nWe can drop the namespaces to see what happens\n\n```elixir\nLedStrip.drop_namespace(LedStrip, :gradient)\n```\n\nAs we can see our animation stops to be visible and our calls to `set_leds` will fail (but we swallow those errors).\n\n<!-- livebook:{\"branch_parent_index\":2} -->","ref":"2_fledex_first_steps.html#gradient"},{"type":"extras","title":"Several animations - 2. Fledex: Some simple tests","doc":"This test is running a couple of different ligth definitions in parallel.\n\n```elixir\nLedStrip.define_namespace(LedStrip, :john)\nLedStrip.define_namespace(LedStrip, :jane)\nLedStrip.define_namespace(LedStrip, :default)\n\nspawn(fn -> Helpers.blue(:jane) end)\nspawn(fn -> Helpers.red(:john) end)\nspawn(fn -> Helpers.rainbow(:default) end)\n```\n\nAs you can see the animations overlap each other. We will work with this principle going forward.\n\nOnce we are done we should stop our GenServer (even though I rarely run this one ;-) but it's good to know how to do it).\n\nNote: you might see some warnings, that are caused by our above functions that will automatically start the server if hasn't been started yet. You can safely ignore those for now.\n\n```elixir\nLedStrip.stop(LedStrip)\n```","ref":"2_fledex_first_steps.html#several-animations"},{"type":"extras","title":"2b Fledex: How to define LEDs","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 2b Fledex: How to define LEDs\n\n```elixir\nMix.install(\n  [\n    {:fledex, \"~>0.5\"}\n  ],\n  # necessary to enable the nicer rendering\n  consolidate_protocols: false\n)\n```","ref":"2b_fledex_how_to_define_leds.html"},{"type":"extras","title":"Intro - 2b Fledex: How to define LEDs","doc":"The `Fledex.Leds` module allows you to easily define a sequence of LEDs. In this livebook we will look at the following aspects:\n\n* the different color concepts\n* defining individual LEDs (in sequence and out of sequence)\n* merging LED sequences\n* repeating an LED sequence\n* defining LEDs through a function (gradient & rainbow)\n* sending leds to a `Fledex.LedStrip`","ref":"2b_fledex_how_to_define_leds.html#intro"},{"type":"extras","title":"Color concepts - 2b Fledex: How to define LEDs","doc":"Fledex allows to define colors in many different ways.\n\nOne very common one is to work with an integer (as defined in `Types.colorint`) with a representation of the color similar to the [html notation](https://www.w3schools.com/colors/default.asp) It's best to write the color as hexadecimal, since each color has a range from 0 to 255 (i.e gets 2 digits), i.e 0xrrggbb (rr=red, gg=green, bb=blue).\n\n**Example:**  `0x2cafe4`  where red has a value of  `0x2c`  (44), green of  `0xaf`  (175), and blue  of  `0xe4`  (228)\n.This is equivalent to the decimal `2 928 612`.\n\n```elixir\n# we define our own color\nmy_color1 = 0x2CAFE4\nmy_color2 = 2_928_612\n\nFledex.Color.KinoRender.new([my_color1, my_color2])\n```\n\nFledex does also allow to specify an `{r, g, b}` triple (as defined in `Types.rgb`). Each color is again in the 0 to 255 range and you can either write it as decimal or as hexadecimal number.\n\n```elixir\nmy_color3 = {0x2C, 0xAF, 0xE4}\nmy_color4 = {44, 175, 228}\n\nFledex.Color.KinoRender.new([my_color3, my_color4])\n```\n\nThe next most convenient way is to defined a color through its name (see `Fledex.Color.Names`). \nWe will look at this in more detail in a [later chapter](./3b_fledex_more_about_colors.livemd)\n\n```elixir\nalias Fledex.Color.Names\n# note, this is a slightly different color compared to the above one, since the exact color \n# does not exist. \"Cerulean (Crayola): {28, 170, 214} is roughly the same color\nmy_color5 = :cerulean_crayola\nmy_color6 = Names.info(my_color5)\nmy_color7 = Names.cerulean_crayola()\n\nFledex.Color.KinoRender.new([my_color5, my_color6, my_color7])\n```\n\nFrom the color names you can also get more information, but as mentioned above we'll look at this in a later chapter.\n\nIn addition, you might encounter, in some cases, other color encodings like `Type.hsv` or `Typee.hsl`. But they are in general not so important.","ref":"2b_fledex_how_to_define_leds.html#color-concepts"},{"type":"extras","title":"Defining individual Leds - 2b Fledex: How to define LEDs","doc":"In Fledex you define a sequence of LEDs (and their colors) through the `Leds` module.\nYou first define the size of the sequence. Let us define a sequence of 30 LEDs (by calling `Leds.leds`):\n\n```elixir\nalias Fledex.Leds\n\nleds = Leds.leds(30)\n```\n\nEach LED in that sequence does not have any color assigned to it and therefore is (by definition) switched off (black).\n\nIt is now possble to define individual LEDs in that sequence by simply specifying the color through the `Leds.light()` functions and chaining them together:\n\n```elixir\nleds =\n  leds\n  |> Leds.light(0xFF0000)\n  |> Leds.light(:green)\n  |> Leds.light(255)\n```\n\nAs can be seen, every time we call the `light` function we move an `index` to know which one we defined as last and we can thereby simply define the light one after the next. It should be noted that the leds are one-indexed.\n\nIt is possible to define specific LEDs by specifying an offset. Let's extend our leds:\n\n```elixir\nalias Fledex.Color.Names\n\nleds =\n  leds\n  |> Leds.light(:red, offset: 10)\n  |> Leds.light(Names.green())\n  |> Leds.light({0, 0, 0xFF})\n```\n\nAs seen, if we specify the `offset: 10` and we continue to define colors without offset the next LED in the sequence will be defined (i.e with offset `11`)\n\nIf you are curious, take a look at the `Raw` tab which shows how this is encoded:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\n%Fledex.Leds{\n  ...\n  leds: %{1 => 16711680, 2 => 65280, 3 => 255, 10 => 16711680, 11 => 65280, 12 => 255},\n  ...\n}\n```\n\nWe have a `map` (`%{}`) with the `offset` as key and the color as value. We also remember the position where we should insert the next light:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\n%Fledex.Leds{\n  ...\n  meta: %{index: 13}\n  ...\n}\n```\n\nIt is possble to define a color with an invalid offset. i.e. which is outside the allowed range. This is not a problem. The information will be carried around, but will be ignored . Take a look at the `Raw` data of the next example where we define a light at `offset: 40` even tough we only have 30 leds:\n\n```elixir\nleds =\n  leds\n  |> Leds.light(:green, offset: 40)\n```\n\nIt's important to remember that the information is retained, since in some circumstances, it  is possible that it might become visible again (like changing the led count through `Fledex.Leds.set_count`)","ref":"2b_fledex_how_to_define_leds.html#defining-individual-leds"},{"type":"extras","title":"Merging LED sequences - 2b Fledex: How to define LEDs","doc":"It is quite commonly that you want to define an LED sequence as a combination of serveral other sequences. This can easily be done by passing `Leds` as if it were a single light:\n\n```elixir\nleds_sub =\n  Leds.leds(2)\n  |> Leds.light(0xFF0000)\n  |> Leds.light(0x00FF00)\n\nleds =\n  Leds.leds(30)\n  # define the red-green once\n  |> Leds.light(leds_sub)\n  # define the red-green a second time with an offset\n  |> Leds.light(leds_sub, offset: 5)\n```","ref":"2b_fledex_how_to_define_leds.html#merging-led-sequences"},{"type":"extras","title":"Repeating an LED sequence - 2b Fledex: How to define LEDs","doc":"It is possble to define a sequence of LEDs by repeating it. If you want to have 5 red LEDs you define a single LED and instruct it to be repeated 5 times. This would look like this:\n\n```elixir\nleds =\n  Leds.leds(30)\n  |> Leds.light(:red, offset: 5, repeat: 5)\n```\n\nYou can also use this to repeat a sub-sequence. This will repeat the whole subsequence as many times in a row as specified.\n\n```elixir\nleds_sub =\n  Leds.leds(2)\n  |> Leds.light(0xFF0000)\n  |> Leds.light(0x00FF00)\n\nleds =\n  Leds.leds(30)\n  |> Leds.light(leds_sub, offset: 5, repeat: 3)\n```","ref":"2b_fledex_how_to_define_leds.html#repeating-an-led-sequence"},{"type":"extras","title":"Definining LEDs through a function - 2b Fledex: How to define LEDs","doc":"When you want to create a color sequence that is more complex, then this can also be achieved through some functions.\n\nIf, for example, you want to create a rainbow pattern over 10 LEDs, you can do so by using the `rainbow/2` function.\n\nNote: If you don't specify the nubmer of leds, all leds in the sequence will be used (here it woudl be all 30 leds)\n\n```elixir\nleds =\n  Leds.leds(30)\n  |> Leds.rainbow(num_leds: 10)\n```\n\nAnother function is the `gradient/3` function that allows a transition from one color to another.\n\n```elixir\nleds =\n  Leds.leds(30)\n  |> Leds.gradient(:red, :blue)\n```\n\n`repeat/2` is another function that will take the already defined sequence (size `x`) and repeats it `y` times. Hence, the newly returned led sequence size will be: `size = x * y`.\n\n```elixir\nLeds.leds(10)\n|> Leds.gradient(:red, :blue)\n|> Leds.repeat(3)\n```","ref":"2b_fledex_how_to_define_leds.html#definining-leds-through-a-function"},{"type":"extras","title":"Sending LEDs to an led-strip - 2b Fledex: How to define LEDs","doc":"Once we have defined our Leds, we can send them to our `Fledex.LedStrip`. This is not\ndifficult, but it's such a common task that the Leds module provides the convenience\nfunction `send/2`. and some supporting functions (`set_led_strip_info/3`, `rotate/2`,\n`to_list/1`).\n\nWe won't discuss the send function in detail, since we'll look at this in more details in other chapters.","ref":"2b_fledex_how_to_define_leds.html#sending-leds-to-an-led-strip"},{"type":"extras","title":"3. Fledex: Animations","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 3. Fledex: Animations\n\n```elixir\n# In this example we'll use the simple setup (experiments are inteded to not run on real\n# hardware but on a normal livebook, This makes it easier to stay up-to-date and experiment\n# We start to define our fledex library, directly linking to the latest version on github\nMix.install([\n  {:fledex, \"~>0.5\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Animation.Manager\nalias Fledex.Leds\nalias Fledex.LedStrip\nalias Fledex.Driver.Impl.Kino\nalias Fledex.Color.Correction\n\n{:ok, pid} = Manager.start_link()\n\n:ok\n```","ref":"3_fledex_animations.html"},{"type":"extras","title":"Preparation - 3. Fledex: Animations","doc":"To start with, we define a couple of aliases to make our life easier and more importantly, we start our `Fledex.Animation.Manager`. We will use it to create animations. The animations are actually maintained by the `Fledex.Animation.Animator`, but we will interact with it only through the `Fledex.Animation.Manager`.","ref":"3_fledex_animations.html#preparation"},{"type":"extras","title":"Helper functions - 3. Fledex: Animations","doc":"We define a bit of helper functions that we will use when we define our animations. Those helper functions are the actual definitions of how the ledstrip will look.\n\nNote that the functions get in a map (here called triggers) that can contain serveral\ntriggers. It will definitely contain one trigger (caused by the `Fledex.LedStrip`) with\nthe name of the led strip. The structure does not need to be used, but can be used in\norder to change the animation based on the trigger. Here we use the trigger in the send\nconfiguration to specify an offset to the leds and thereby create a movement.\n\n```elixir\ndefmodule HelperFunctions do\n  @rainbow Leds.leds(50)\n           |> Leds.rainbow(\n             num_leds: 50,\n             reversed: true\n           )\n  def rainbow(_triggers) do\n    @rainbow\n  end\n\n  def send_config(triggers) do\n    [offset: triggers[:john]]\n  end\nend\n```","ref":"3_fledex_animations.html#helper-functions"},{"type":"extras","title":"Creating a first animation - 3. Fledex: Animations","doc":"Now it's time to define our first animation by using the `Fledex.Animation.Manager`. Before we can define our animations we first have to define (and configure) our led strip. The `Fledex.Animation.Manager` can manage serveral strips at the same time.\n\nWe call our led strip `:john` (it has to be an atom). In this example we will only use the simple kino driver (and configure it with defaults) and thereby display the result within our livebook.\n\nWe then define an animation configuration that consists of a map with the key being the name of the animation and the value being the configuration of that animation. Each animation configuration needs to specify the `:type` as `:animation`, because (as we will see later) other types exist, and a `:def_func` that defines our animation (potentially with an additional `:send_config_func` as shown here. We'll look at this in more detail in a later section).\n\n```elixir\nManager.register_strip(:john, [{Kino, []}], [])\n\nManager.register_config(:john, %{\n  caine: %{\n    type: :animation,\n    def_func: &HelperFunctions.rainbow/1,\n    send_config_func: &HelperFunctions.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#creating-a-first-animation"},{"type":"extras","title":"Replacing our animation - 3. Fledex: Animations","doc":"We can now redefine our animation by registering different functions. Here we define a 3 led wide red dot that moves slowly from right to left.\n\nNote: we are starting to use color names instead of defining it through an integer. If you want to learn more, then take a small detour to the [Color livebook](./3b_fledex_more_about_colors.livemd)\n\nThe strip has been defined above, and is shown above, so when you redefine it you will have to look above too :-)\n\n```elixir\nimport Bitwise\n\ndefmodule HelperFunctions2 do\n  @red_leds Leds.leds(50) |> Leds.light(:red) |> Leds.light(:red) |> Leds.light(:red)\n  def red_leds(_triggers) do\n    @red_leds\n  end\n\n  def send_config(triggers) do\n    slow_offset = rem(triggers[:john] || 0 >>> 5, 50)\n    [offset: slow_offset]\n  end\nend\n\nManager.register_config(:john, %{\n  caine: %{\n    type: :animation,\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#replacing-our-animation"},{"type":"extras","title":"Defining serveral animations - 3. Fledex: Animations","doc":"It's also possible to define serveral animations. Here we continue with our previous animation (we do have to explicitly specify it again, otherwise it would be removed) and add a new animation with 3 leds that move faster from right to left.\n\n```elixir\nimport Bitwise\n\ndefmodule HelperFunctions3 do\n  @rgb_leds Leds.leds(50) |> Leds.light(:red) |> Leds.light(:green) |> Leds.light(:blue)\n  def rgb_leds(_triggers) do\n    @rgb_leds\n  end\n\n  def send_config(triggers) do\n    faster_offset = 50 - rem(triggers[:john] || 0 >>> 2, 50)\n    [offset: faster_offset]\n  end\nend\n\nManager.register_config(:john, %{\n  caine: %{\n    type: :animation,\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  },\n  doe: %{\n    type: :animation,\n    def_func: &HelperFunctions3.rgb_leds/1,\n    send_config_func: &HelperFunctions3.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#defining-serveral-animations"},{"type":"extras","title":"Use of anonymous functions - 3. Fledex: Animations","doc":"It is also possible to use an anonymous function during the definition which avoids to create a separate module. Here we redefine our above definition, but this time we define `:doe` with an anonymous function. To really see that we have changed the definition we define the leds as all blue. In addition we change the `send_config_func` to animate the dots even faster.\n\nThe advantage of using the anonymous functions is that you don't get any compilation error, that occures if you recompile the module. Try it out by reevaluating the below definition several times and then doing the same thing with the previous definition.\n\nThis allows for a smooth replacement of definitions.\n\n```elixir\nManager.register_config(:john, %{\n  caine: %{\n    type: :animation,\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  },\n  doe: %{\n    type: :animation,\n    def_func: fn _triggers ->\n      Leds.leds(50) |> Leds.light(:blue) |> Leds.light(:blue) |> Leds.light(:blue)\n    end,\n    send_config_func: fn triggers ->\n      faster_offset = 50 - rem(triggers[:john] || 0 >>> 1, 50)\n      [offset: faster_offset]\n    end\n  }\n})\n```\n\nFrom now on we will _only_ define our definitions through the use of anonymous functions.","ref":"3_fledex_animations.html#use-of-anonymous-functions"},{"type":"extras","title":"3b Fledex: Everything about Colors","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 3b Fledex: Everything about Colors\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.5\"}\n])\n```","ref":"3b_fledex_more_about_colors.html"},{"type":"extras","title":"Colors and different drivers - 3b Fledex: Everything about Colors","doc":"Different drivers have different color characteristics. Therefore you might have to adjust the colors when migrating from one output to another. Some drivers allow some color correction to try to adjust for those issues (see also the 'Color Correction' section.","ref":"3b_fledex_more_about_colors.html#colors-and-different-drivers"},{"type":"extras","title":"Color Information - 3b Fledex: Everything about Colors","doc":"Fledex has an extensive set of predefined colors from [Wikipedia](https://en.wikipedia.org/wiki/List_of_colors:_A%E2%80%93F), [CSS](https://drafts.csswg.org/css-color/#named-colors), [SVG](https://www.w3.org/TR/SVG11/types.html#ColorKeywords), and [RAL](https://en.wikipedia.org/wiki/List_of_RAL_colours).Apart from the last list (which is not so commonly used), they are all combined together to a single Names module. You can retrieve those names by calling:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\nFledex.Color.Names.names()\n```\n\nYou can also retrieve the complete data set by calling:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\nFledex.Color.Names.colors()\n```\n\nHere a list of all the colors (except the RAL colors, those can be found in `Fledex.Color.Names.RAL`):\n\n```elixir\nKino.DataTable.new(Fledex.Color.Names.colors(),\n  keys: [:descriptive_name, :name, :rgb, :hex, :hsv, :hsl, :source],\n  sorting_enabled: true\n)\n```\n\nYou can also retrieve the information from a specific color, like `:almond` in the following way\n\n* `almond/0`: Every color has it's own function and the :hex value (represented as integer) will be returned\n* `almond/1`: This allows the retrieve a specific representation. It should be noted, that the color functions (that are often just approximations), do not provide the same results. The values returned here are the ones as defined in their sources:\n  * `:all`: This retrieves the full data set\n  * `:hex`: This is the same as `almond/0`\n  * `:rgb`: This retrieves an RGB struct, i.e. `{r, g, b}`\n  * `:hsv`: This retrieves an HSV struct, i.e. `{h, s, v}`\n  * `:hsl`: This retrieves an HSL struct, i.e. `{h, s, l}`\n  * `:index`: The index of this color in the list of all colors\n  * `:desriptive_name`: a string with name (we derive the `Atom` from it)\n  * `:source`: Information where the color comes from. Even the colors on Wikipedia are often coming from other sources.\n* `info/1` and `info/2`: They are convenience functions when you only have an atom as the color name. They map to the functions, thus `info(:almond)` is equal to `almond()` and `info(:almond, what)` is equal to `almond(what)`.\n\nIn addition each color can also be used directly in an `Leds` sequence since it provides two convenience functions:\n\n* `almond(leds)` which takes an `Leds` sequence and adds the `:almond` color to it (at the next position). This is equivalent to:\n  ```elixir\n  leds |> Leds.light(almond(:hex))\n  ```\n* `almond(leds, opts)` which takes an `Leds` sequence and an some other options, like the offset to specify where the led should be positioned. This is equivalent to:\n  ```elixir\n  leds |> Leds.light(almond(:hex), offset: offset)\n  ```\n\nThis allows for a very natural way to define an led sequence. especially if we import the `Fledex.Leds` and `Fledex.Color.Names` modules.\n\n```elixir\nimport Fledex.Leds\nimport Fledex.Color.Names\n\nleds(5) |> almond |> red |> green |> blue(offset: 5)\n```","ref":"3b_fledex_more_about_colors.html#color-information"},{"type":"extras","title":"Color Correction - 3b Fledex: Everything about Colors","doc":"More info to follow","ref":"3b_fledex_more_about_colors.html#color-correction"},{"type":"extras","title":"4. Fledex: Clock Example","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 4. Fledex: Clock Example\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.5\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Animation.Manager\nalias Fledex.Driver.Impl.Kino\nalias Fledex.Leds\nalias Fledex.LedStrip\n\n{:ok, pid} = Manager.start_link()\n\n:ok\n```","ref":"4_fledex_clock_example.html"},{"type":"extras","title":"Intro - 4. Fledex: Clock Example","doc":"The goal of this project is to create a clock that displays its hour, minute and second on the strip. We use the `Kino` driver as output and we limit the amount of leds to a reasonable number.\nTherefore we can't really display every second and every minute. We can get a bit creative in how we display it.\n\nBut before we get there, we first initiate our led strip.","ref":"4_fledex_clock_example.html#intro"},{"type":"extras","title":"Preparational steps - 4. Fledex: Clock Example","doc":"First we register a strip (we name it `:clock`) with our `Fledex.Animation.Manager` and we use the default settings for the `Kino` driver.\n\nThen we modify the led strip to update with a very low frequency. Our clock only updates every second and therefore it's unnecessary that we update it more often than that. To avoid any issues due to some runtime delays, we update it twice every second. Thereby the second indicator will never jump an led.\n\n```elixir\n# we start with the default configuration but change the timer update frequency to 500ms\n:ok = Manager.register_strip(:clock, [{Kino, []}], timer_update_timeout: 500)\n\n:ok\n```","ref":"4_fledex_clock_example.html#preparational-steps"},{"type":"extras","title":"Defining our clock - 4. Fledex: Clock Example","doc":"We now register our animations for the `:clock` led strip. We define 4 animations. One as visual help to make it easier to read the clock by having an indicator every 5 intervals and one each for the seconds, minutes, and hours.\n\nEach animation consists of two elements:\n\n* `def_func` this defines a function that will be called to define a sequence of LEDs (how many LEDs and which colors). The function receives a `trigger` (a `map`) that can contain various information, but at least contains a counter with the name of the led strip (i.e. in our case with the name `:counter`). We will use this to define a sequence of the correct length and color the fist led. In this function we don't use the `trigger`\n* `send_config_func` this defines a function that will be called after the LED strip has been defined (see `Fledex.Leds.send/2` for more details and options). We will use this to rotatae the led sequence (dependent on the `trigger` that we also get here as input) in such a way that the colored dot will come to the correct position in the sequence. We also explicitly specify the direction of our rotation. We can rotate to the left or the right.\n\nNote: we get the time by simply making a call to `Time.utc_now/0` and adjusting it to our timezone (UTC+1) (`Time.add/2`). We then extract (through pattern matching) the information we are intersted in (second, minute, hour)\n\nOur `:help` \"animation\" defines an led sequence of 5 leds (the first one being colored) and repeats that pattern 12 times. This is not a real animation, since we output a static pattern every time.\n\n```elixir\nconfig = %{\n  seconds: %{\n    type: :animation,\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:red)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      [offset: second, rotate_left: false]\n    end\n  },\n  minutes: %{\n    type: :animation,\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:green)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: _hour, minute: minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      [offset: minute, rotate_left: false]\n    end\n  },\n  hours: %{\n    type: :animation,\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:blue)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: hour, minute: _minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      [offset: hour, rotate_left: false]\n    end\n  },\n  help: %{\n    type: :animation,\n    def_func: fn _triggers ->\n      Leds.leds(5)\n      |> Leds.light(:ash_gray)\n      |> Leds.repeat(12)\n    end\n  }\n}\n```","ref":"4_fledex_clock_example.html#defining-our-clock"},{"type":"extras","title":"Starting our animation - 4. Fledex: Clock Example","doc":"Now that we have defined our configuration we can start our animation, by registering our animations-configuration to our `Fledex.Animation.Manager` by calling `register_config/2`. That's it!\n\n```elixir\nManager.register_config(:clock, config)\n```\n\nIf you are searching for your led strip then scoll up. It's displayed where you have registered your led strip with the `Fledex.Animation.Manager`.\n\nThat's it, this wasn't too difficult, but continue reading, it will get even easier :-)","ref":"4_fledex_clock_example.html#starting-our-animation"},{"type":"extras","title":"5. Fledex: Weather example","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 5. Fledex: Weather example\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.5\"},\n  {:jason, \"~>1.2\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Animation.Manager\nalias Fledex.Leds\nalias Fledex.LedStrip\nalias Fledex.Driver.Impl.Kino\nalias Fledex.Color.Correction\nalias Fledex.Utils.PubSub\n\n{:ok, pid} = Manager.start_link()\n\n:ok\n```","ref":"5_fledex_weather_example.html"},{"type":"extras","title":"Intro - 5. Fledex: Weather example","doc":"In the last project we created a clock. We could make a call to get the current time in every redraw loop. This approach is not possible for data that we are fetching from an external source. In this example we will create a weather display. We will get the information from an API.\n\nIf we took the same approach as in the clock example, we would make an API call every 500ms which probably would result in us getting blocked. It is completely unnecessary to make that many call; the wheather doesn't change that frequently.\n\nWhat we will do is to check every 15 min what the latest weather status is.\n\nThere are plenty of Weather APIs on the internet, but most of them require to register which is not ideal for a public example. Therefore I decided to use [Open-Meteo](https://open-meteo.com/) which provides all we need.\n\nWe need to decide for which location we want to get the weather. Since I'm living in Budapest I use it's coordinates (lat: `47.4729344`, lon: `19.0468802`). To figure out your own coordinates, you can use [Open Street Map](https://www.openstreetmap.org). Search for your location, right click on the exact position, right-click and select Query feature. Now the [URL](https://www.openstreetmap.org/query?lat=47.4729344&lon=19.0468802) will privide you with the `lat`-itude and `lon`-gitude coordinates.\n\nThen we can make the call to [`https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m`](https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m) to get the weather data that will look like the following:\n\n```json\n{\n  \"latitude\": 47.5,\n  \"longitude\": 19.0625,\n  \"generationtime_ms\": 0.04100799560546875,\n  \"utc_offset_seconds\": 0,\n  \"timezone\": \"GMT\",\n  \"timezone_abbreviation\": \"GMT\",\n  \"elevation\": 113,\n  \"current_units\": {\n    \"time\": \"iso8601\",\n    \"interval\": \"seconds\",\n    \"temperature_2m\": \"°C\"\n  },\n  \"current\": {\n    \"time\": \"2023-10-30T13:30\",\n    \"interval\": 900,\n    \"temperature_2m\": 22.1\n  }\n}\n```\n\nAs can be seen we get the information we are interested in, the current temperature (in °C)","ref":"5_fledex_weather_example.html#intro"},{"type":"extras","title":"Configuring the led strip - 5. Fledex: Weather example","doc":"Now it's time to prepare our led strip. First we define our strip and we set a very low refresh rate. An update every 10 sec is enough.\n\n```elixir\n# we start with the default configuration, but change the timer update frequency to 10 sec\n:ok = Manager.register_strip(:weather, [{Kino, []}], timer_update_timeout: 10_000)\n\n:ok\n```\n\nNow we define two animations, the first one creates blue (below zero), green (zero), or red (above zero) indicators. The indicators have the length of the temperature and start from zero to either go to the left (negative) or the right (positive). The second animation is a helper that creates some lines every 5°C to make it easier to read the temperature.\n\nThe temperature will be delivered to us as part of the trigger. We'll look at how we will get  this information in the section below.\n\nAs and additional bonus, the thermometer is showing the full scale, if no proper measurement is received (arbitrarily high value of 100), which can happen during the initialization phase.\n\n```elixir\nManager.register_config(:weather, %{\n  temperature: %{\n    type: :animation,\n    def_func: fn triggers ->\n      temp = triggers[:temperature] || 100\n      temp = round(temp)\n\n      temp =\n        if temp == 100 do\n          100\n        else\n          temp = min(temp, 40)\n          max(temp, -20)\n        end\n\n      {leds, offset} =\n        case temp do\n          temp when temp == 100 ->\n            {Leds.leds(61)\n             |> Leds.light(:blue, offset: 1, repeat: 20)\n             |> Leds.light(:green)\n             |> Leds.light(:red, offset: 22, repeat: 40), 1}\n\n          temp when temp < 0 ->\n            {Leds.leds(1) |> Leds.light(:blue) |> Leds.repeat(-temp), 21 + temp}\n\n          temp when temp == 0 ->\n            {Leds.leds(1) |> Leds.light(:may_green), 21}\n\n          temp when temp > 0 ->\n            {Leds.leds(1) |> Leds.light(:red) |> Leds.repeat(temp), 22}\n        end\n\n      Leds.leds(61) |> Leds.light(leds, offset: offset)\n    end\n  },\n  help: %{\n    type: :animation,\n    # we allow temperatures down to -20C and up to +40C\n    def_func: fn _triggers ->\n      negative_scale =\n        Leds.leds(5)\n        |> Leds.light(:ash_gray)\n        |> Leds.repeat(4)\n\n      positive_scale =\n        Leds.leds(5)\n        |> Leds.light(:ash_gray, offset: 5)\n        |> Leds.repeat(8)\n\n      Leds.leds(61)\n      |> Leds.light(negative_scale)\n      |> Leds.light(:ash_gray)\n      |> Leds.light(positive_scale)\n    end\n  }\n})\n```\n\nFor testing we can send an arbitrary temperature value to our strip. This allows us to also see whether the strip has the correct behavior when the temperature is at zero (or even below) degree. For testing it would be really unpractical if we need to wait until the outside temperature reaches those levels.\n\nHere we send a temperature value of -15.2 degree (which the strip should round to -15 degree). Remember, we set the strip to update slowly and therefore it might (depending on when the next refresh will happen) take a little while before you see the change.\n\n```elixir\nPubSub.broadcast_trigger(%{temperature: -15.2})\n```","ref":"5_fledex_weather_example.html#configuring-the-led-strip"},{"type":"extras","title":"Getting the weather data - 5. Fledex: Weather example","doc":"Before we can start with the weather data, we need to make sure that we can make http client calls (also over https) and therefore we start the two services.\n\n```elixir\n:inets.start()\n:ssl.start()\n```\n\nNow we can make the actual call. We do want to make this call in regular intervals (every 15 min), parse the response and publish the temperature through pubsub. To do this we create a small server. In a [later chapter](./9_fledex_jobs.livemd) we will see how we can use one of the `Fledex` services to do the scheduling.\n\nWe start it with our URL (note, the parsing in the server is URL specific, so you can't simply change it to another site) and with our 15min refresh interval (specified in ms).\n\nThe server will extract the temperature and send it via pubsub to our update functions.\n\n```elixir\ndefmodule CallUrlPeriodic do\n  use GenServer\n\n  def start_link(url, interval_ms) do\n    pid = Process.whereis(__MODULE__)\n\n    if pid == nil do\n      GenServer.start_link(__MODULE__, %{url: url, interval_ms: interval_ms}, name: __MODULE__)\n    else\n      # server is already running. We could reconfigure it, but we don't do this here.\n      {:ok, pid}\n    end\n  end\n\n  @impl true\n  def init(state) do\n    :timer.send_interval(state.interval_ms, :work)\n    # we send ourselve immediately a request\n    send(self(), :work)\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_info(:work, state) do\n    {:ok, resp} =\n      :httpc.request(:get, {String.to_charlist(state.url), []}, [], body_format: :binary)\n\n    {{_, 200, ~c\"OK\"}, _headers, body} = resp\n    json = Jason.decode!(body)\n    temperature = json[\"current\"][\"temperature_2m\"]\n    PubSub.broadcast_trigger(%{temperature: temperature})\n\n    {:noreply, state}\n  end\nend\n\n{:ok, pid} =\n  CallUrlPeriodic.start_link(\n    \"https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m\",\n    900_000\n  )\n```","ref":"5_fledex_weather_example.html#getting-the-weather-data"},{"type":"extras","title":"Annotations - 5. Fledex: Weather example","doc":"If you want to be more fancy in your display, you could also add [other features](https://open-meteo.com/en/docs), like the general weather condition (called `weather_code`). For this the [wmo codes](https://www.nodc.noaa.gov/archive/arc0021/0002199/1.1/data/0-data/HTML/WMO-CODE/WMO4677.HTM) and their meaning might come in handy.\n\nCurrently I see:\n\n```json\n...\n\"current\":{\n  ...\n  \"weather_code\":3\n  }\n...\n```\n\nmeaning that \"Clouds generally forming or developing\"\n\nNow it's up to you to become creative. Happy experimenting :-)","ref":"5_fledex_weather_example.html#annotations"},{"type":"extras","title":"6. Fledex: DSL","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 6. Fledex: DSL\n\n```elixir\n# In this example we'll use the simple setup (experiments are inteded to not run on real\n# hardware but on a normal livebook, This makes it easier to stay up-to-date and experiment\n# We start to define our fledex library, directly linking to the latest version on github\nMix.install([\n  {:fledex, \"~>0.5\"}\n])\n```","ref":"6_fledex_dsl.html"},{"type":"extras","title":"Intro - 6. Fledex: DSL","doc":"We now define our animations with our DSL with the following steps:\n\n* First we have to `use Fledex` in order to \n  * load our `Fledex` DSL (like `led_strip`,`animation` and the like) and\n  * to import commonly used functions, like `Fledex.Leds`, `Fledex.Color.Names`. This means we won't write `Leds` in fron of functions anymore.\n  * to start (by default) the `Fledex.Animation.Manager` if it's not already running, who will take care of all the animation coordinations.\n\n```elixir\nuse Fledex\n```","ref":"6_fledex_dsl.html#intro"},{"type":"extras","title":"The clock - 6. Fledex: DSL","doc":"We now go back to our [clock example](./4_fledex_clock_example.livemd) and rewrite it with our  DSL:\n\n* We define a new strip with a name (`:clock`), and configure it (we use the `Kino`\n  default driver for display). This will internally create a new `Fledex.LedStrip` \n  server (if it's not already running) that will control the strip. Its server name will\n  be identical to the `led_strip` name.\n* Then within this strip we define several `animation`s (which will internally use the `Fledex.Animation.Animator`). Each animation is identified\n  by its own name (`:help`, `:hour`, `:minute`, `:second`).\n* Within each animation we define a function that will be executed repeatedly.\n* Inside that function we can define one or several `Leds`, either directly or through \n  an led sequence (like a rainbow function) and animate those leds depending on some\n  trigger data (data that comes into the animation function). An explanation of what \n  we are doing in our example here will be given after the code.\n\nIt is also possble to define some other configurations (like the `send_config_func` that we used in the \"[Fledex Clock Example](./4_fledex_clock_example.livemd)\") but we don't need it right now.\n\n```elixir\nled_strip :clock, Kino do\n  # 1.\n  static :help do\n    leds(5) |> light(davy_s_grey()) |> repeat(12)\n  end\n\n  # 2.\n  animation :hour do\n    _triggers ->\n      %{hour: hour, minute: _minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      # 3.\n      leds(24) |> light(blue(), offset: hour + 1)\n  end\n\n  # 2.\n  animation :minute do\n    _triggers ->\n      %{hour: _hour, minute: minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      # 3.\n      leds(60) |> light(:may_green, offset: minute + 1)\n  end\n\n  # 2.\n  animation :second do\n    _triggers ->\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now() |> Time.add(1, :hour)\n      # 3.\n      leds(60) |> light(:red, offset: second + 1)\n  end\nend\n```\n\nThe above code should result in an animation displaying the clock.Now it's time to look at the different animation parts and how they work.\n\n1. We first define a `static` animation (one that doesn't animate). This animation does not get any triggers and will only be called once during the initalization (since it's static). Notice that this function gets no argument (we don't have the trailing `_triggers ->` part that you find in the other parts). It is used to make it easier to read the time by having a dash every 5 steps and those do not change over time. The markers are repeating in a regular pattern, so we only define the first one and then repeat it with the `repeat/2` function 12 times.\n2. For all other animations we make a call to the system time (`Time.utc_now()`) and therefore don't require the `_trigger` information. We shift the result to the right timezone (we add 1 hour, for UTC+1). We pattern match the result, depending on the animation into `hour`, `minute`, or `second`.\n3. We then define a sequence of `Leds` of the right length (`24` for `hour`, and `60` for `minute` and `second`). We switch-on only a single light in some color at the correct position (with the offset corresponding to `hour`, `minute` or `second`)\n\n**Notes:**\n\n1. in classical Erlang/Elixir style the underscore (`_`) in `_triggers` indicates that the variable is not used.\n2. The DSL allows you to remove the `_trigger ->` part in an animation if you don't need it.\n3. The code could have been more compact by also just matching the part that we are interested in. Also considering the previous point the `:second` indicator could have been defined like this:\n   ```elixir\n   animation :second do\n      %{second: second} = Time.utc_now() |> Time.add(1, :hour)\n      leds(60) |> light(:red, offset: second + 1)\n   end\n   ```\n4. In the clock example we defined a static sequence of `Leds` and offsetted it. This required the definition of a `send_config_func`. We will look on how to do it with the DSL as a next step.","ref":"6_fledex_dsl.html#the-clock"},{"type":"extras","title":"Clock (with send function) - 6. Fledex: DSL","doc":"We are now implementing the above example, but demonstrating on how the `:second`, `:minute`, and `:hour` indicators can be implemented in exactly the same way as we did in [chapter 4](./4_fledex_clock_example.livemd), i.e. with a send function that shifts the red marker depending on the time.\n\nWe also take the occasion to demonstrate on how you can define a second strip, by giving it a new name (`:clock2`). To demonstrate that it's really a new stip this clock here displays the time in UTC (we don't add the extra hour of offset). Look carefully at the blue hour indicator.\n\nAlso, the above strip should continue to run and a new strip will appear below the code. Had we called the strip the same as above (i.e. `:clock`), then the above output would have stopped updating and a new one would appear here.\n\nTry it out and modify any of the two animations. They should be fully independent.\n\n```elixir\nled_strip :clock2, Kino do\n  static :help do\n    leds(5) |> light(davy_s_grey()) |> repeat(12)\n  end\n\n  animation :hour,\n    send_config: fn _triggers ->\n      %{hour: hour, minute: _minute, second: _second} = Time.utc_now()\n      [offset: hour, rotate_left: false]\n    end do\n    _triggers ->\n      leds(24) |> light(blue())\n  end\n\n  animation :minute,\n    send_config: fn _triggers ->\n      %{hour: _hour, minute: minute, second: _second} = Time.utc_now()\n      [offset: minute, rotate_left: false]\n    end do\n    _triggers ->\n      leds(60) |> light(:may_green)\n  end\n\n  animation :second,\n    send_config: fn _triggers ->\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now()\n      [offset: second, rotate_left: false]\n    end do\n    _triggers ->\n      leds(60) |> light(:red)\n  end\nend\n```","ref":"6_fledex_dsl.html#clock-with-send-function"},{"type":"extras","title":"The weather app - 6. Fledex: DSL","doc":"We now implement the [weather app](./5_fledex_weather_example.livemd) (indicating the temperature) we implemented in chapter 5 by using our DSL.\n\n```elixir\nled_strip :weather, Kino do\n  animation :temperature do\n    triggers ->\n      temp = triggers[:temperature] || 100\n      temp = round(temp)\n\n      temp =\n        if temp == 100 do\n          100\n        else\n          temp = min(temp, 40)\n          max(temp, -20)\n        end\n\n      {leds, offset} =\n        case temp do\n          temp when temp == 100 ->\n            {leds(61)\n             |> light(:blue, offset: 1, repeat: 20)\n             |> light(:may_green)\n             |> light(:red, offset: 22, repeat: 40), 1}\n\n          temp when temp < 0 ->\n            {leds(1) |> light(:blue) |> repeat(temp), 21 + temp}\n\n          temp when temp == 0 ->\n            {leds(1) |> light(:may_green), 21}\n\n          temp when temp > 0 ->\n            {leds(1) |> light(:red) |> repeat(temp), 22}\n        end\n\n      leds(61) |> light(leds, offset: offset)\n  end\n\n  static :help do\n    # we allow temperatures down to -20C and up to +40C\n    negative_scale =\n      leds(5)\n      |> light(davy_s_grey())\n      |> repeat(4)\n\n    positive_scale =\n      leds(5)\n      |> light(davy_s_grey(), offset: 5)\n      |> repeat(8)\n\n    leds(61)\n    |> light(negative_scale)\n    |> light(davy_s_grey())\n    |> light(positive_scale)\n  end\nend\n```\n\nThis time we don't implement the connection to the weather API, but we only fake it.\nFledex imports `Fledex.Utils.PubSub` and therefore we can use the `broadcast_trigger/1` function directly.\n\n```elixir\nbroadcast_trigger(%{temperature: 17.2})\n```","ref":"6_fledex_dsl.html#the-weather-app"},{"type":"extras","title":"7. Fledex: Effects","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 7. Fledex: Effects\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.5\"}\n])\n\n:ok\n```","ref":"7_fledex_effects.html"},{"type":"extras","title":"Introduction - 7. Fledex: Effects","doc":"> [!Warning]\n> \n> This version contains a big change in how effects should behave and interact.\n> This is still work in progress and you might run into issues. The next version\n> should fix those issues and update the documentation accordingly. Still you \n> can get an understanding by walking through this livebook.\n> \n> TODO: remove this once fixed!\n\nIn this chapter we will look at some effects that we can apply to an animation. Effects are simply applied by wrapping the `animation` marco into an `effect` macro. But before we do so we first need to load our framework (and we define some aliases that will come in handy a bit later).\n\n```elixir\nalias Fledex.Effect.Rotation\nalias Fledex.Effect.Wanish\n\nuse Fledex\n```\n\nThere is already a standard set of effects available all under the `Fledex.Effect` (like the ones we aliased above), but you can create your own effects. by simply implementing the behaviour `Fledex.Effect.Interface`. We'll take a look on how to do this below.\n\nIn the following we'll take a closer look at two of the standard effects:\n\n* The Wanish effect\n* The Rotation effect\n\nThe latter one we have already encountered under the hood, without realizing it. It provided the functionality of the `send_config_func` to rotate the pixels\n\n<!-- livebook:{\"branch_parent_index\":0} -->","ref":"7_fledex_effects.html#introduction"},{"type":"extras","title":"The Wanish effect - 7. Fledex: Effects","doc":"The wanish effect makes some leds vanish starting from one end and extending to infity. The effect can be controled through a couple of conig parameters:\n\n* `:trigger_name`: this is the name that will be used as the steering factor for the effect. If nothing is specified the animation will use the `led_strip`name as trigger name (in this case `:john` will be used, so we don't need to specify it).\n* `:divisor`: the trigger might come with a too high frequency and you want to slow down the wanishing effect. The Divisor will slow it down with that factor. (default: 1, i.e. no slow down)\n* `:direction`: the direction specifies whether the wanishing should happen from the start (`:left`) or from the end (`:right`) of the led_strip\n* `:circulate`: indicates whether we want to warp around and redo the wanishing once the first round has finished. In that case the full led sequence will be visible and will wanish again. Note: if you use `:reappear` this will automatically be set.\n* `:reappear`: this will enable the `:circulate` and instead of all leds appearing at the same time, they will first slowly reappear (one by one) and only once they are all visible again will they disappear again. This setting comes with an extra `:reappear_key`, but in most cases you don't need to worry about it, because the default will be just fine.\n* `:switch_on_off_func`: There is also a possibility to control when you want the effect to be switched on or off, but this is outside the scope of this description.\n\nHere is an example on such an effect on a simple led sequence\n\n```elixir\nled_strip :john, Kino do\n  effect Wanish, divisor: 2, direction: :right, reappear: true do\n    animation :test do\n      _triggers ->\n        leds(50) |> rainbow()\n    end\n  end\nend\n```\n\n<!-- livebook:{\"branch_parent_index\":0} -->","ref":"7_fledex_effects.html#the-wanish-effect"},{"type":"extras","title":"The Rotation effect - 7. Fledex: Effects","doc":"As mentioned above, we have used the functionality of the rotation effect already. It is only a very simple version and it can't be combined with other effects. Therefore let's look at the rotation once more, this time as an effect.\n\nThe available configuration parameters are:\n\n* `:trigger_name`: This is again the trigger that will drive the animation. If nothing is specified, the `Fledex.Animation.Animator` will set the `led_strip` name as the default. Therefore you rarely have to set it manually.\n* `:direction`: The rotation can be applied into two directions: `:left` (default) and `:right`\n* `:divisor`: As before this allows to slow down the animation, by not updating it on every trigger event.\n\nLet's see how this looks if we rely on the default values:\n\n```elixir\nled_strip :rotation, Kino do\n  effect Rotation do\n    animation :rainbow do\n      _triggers -> leds(50) |> rainbow()\n    end\n  end\nend\n```\n\n<!-- livebook:{\"branch_parent_index\":0} -->","ref":"7_fledex_effects.html#the-rotation-effect"},{"type":"extras","title":"Combining effects - 7. Fledex: Effects","doc":"It is possble to combine several effects. The order of the effects can be imporant, so make sure you apply them in the correct order.\n\nLet's try it out by combining our rotation and wanishing effect on a rainbow color spectrum.\n\n```elixir\nled_strip :rotation_and_wanish, Kino do\n  effect Rotation do\n    effect Wanish, divisor: 1, direction: :right, reappear: true do\n      animation :rainbow do\n        _triggers -> leds(50) |> rainbow()\n      end\n    end\n  end\nend\n```\n\n<!-- livebook:{\"branch_parent_index\":0} -->","ref":"7_fledex_effects.html#combining-effects"},{"type":"extras","title":"BYOE: Bring Your Own Effect - 7. Fledex: Effects","doc":"It is maybe nice to use pre-exisiting effects, but it's much more exciting to create your own effect. In this example we are looking on how to do that.\n\nYou might be wondering what an effect is. It's simply a module with a `@behaviour Fledex.Effect.Interface`. If you `use Fledex.Effect.Interface` you only need to implement the simple `apply/5` function. The function takes 5 parameters\n\n* a `list` of `colorint`s, e.g. `[0xff0000, 0x00ff00, 0x0000ff]`\n* a length of the list passed in as first argument. This is to avoid to walk through the list to figure this out.\n* a keyword list with `config`uration parameters. They are the ones you specified in the `effect` macro. As an effect implementer, you can decide what kind of parameters are permitted. There is one parameter that will be populated by the `Fledex.Animation.Animator` if it's not specified, which is the `:trigger_name`. It is the trigger that drives your effect.\n* a `triggers` map containing the various triggers (like the strip counter, or some other triggers as we have seen in our weather example)\n* a `context` map containing information what the effect will manipulate. It contains information about the, `led_strip` name, the `animation` name, and the `effect` index. To start with you can ignore it.\n\nThe function returns\n\n* a list of LEDs (color integers),\n* the new count of the list (which can be smaller than the initial count),\n* and a map of (potentially modified) `triggers`. This also allows to retain some state between each call of the filter.\n\nThe most simplest filter is the one that simply returns the passed in parameters:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\n  def apply(leds, count, _config, trigggers, _context) do\n    {leds, count, triggers}\n  end\n```\n\nHere the full code:\n\n```elixir\ndefmodule LivebookEffect1 do\n  use Fledex.Effect.Interface\n\n  @impl true\n  @spec apply(\n          leds :: [Types.colorint()],\n          count :: non_neg_integer,\n          config :: keyword,\n          triggers :: map,\n          context :: map\n        ) :: {list(Types.colorint()), non_neg_integer, map}\n  def apply(leds, count, _config, triggers, _context) do\n    {leds, count, triggers}\n  end\nend\n```\n\nThis is of course not very exciting, since\n\n* defining an effect that does nothing is useless and\n* defining an effect has no effect if you don't usee it. \n  But it's a good starting point.\n\nNow let's create a new effect that does something. What about going crazy and to randomize the leds?\n\nThis is very easy to accomplish, we only need to call the `Enum.shuffle/1` function.\n\n```elixir\ndefmodule LivebookEffect2 do\n  use Fledex.Effect.Interface\n\n  @impl true\n  @spec apply(\n          leds :: [Types.colorint()],\n          count :: non_neg_integer,\n          config :: keyword,\n          triggers :: map,\n          context :: map\n        ) :: {list(Types.colorint()), non_neg_integer, map}\n  def apply(leds, count, _config, triggers, _context) do\n    {Enum.shuffle(leds), count, triggers}\n  end\nend\n```\n\nThat's it already, now we can already use our own effect as we have used an effect above. Let's see how crazy this looks.\n\n```elixir\nled_strip :xmas, Kino do\n  effect LivebookEffect2 do\n    animation :xmas do\n      _triggers -> leds(50) |> rainbow()\n    end\n  end\nend\n```","ref":"7_fledex_effects.html#byoe-bring-your-own-effect"},{"type":"extras","title":"8. Fledex: Component","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 8. Fledex: Component\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.5\"}\n])\n```","ref":"8_fledex_component.html"},{"type":"extras","title":"Introduction - 8. Fledex: Component","doc":"In this chapter we will look at components and how they can simplify the creation of applications. A component is a self-contained entity with a specific behavior that can be reused.\n\nIf this description doesn't make too much sense (yet), it hopefully will make sense once you take a look at one of the examples. Then we'll take a closer look at what a component is.","ref":"8_fledex_component.html#introduction"},{"type":"extras","title":"Setup - 8. Fledex: Component","doc":"We start again by activating our DSL\n\n```elixir\nuse Fledex\n```\n\n<!-- livebook:{\"branch_parent_index\":1} -->","ref":"8_fledex_component.html#setup"},{"type":"extras","title":"The Weather animation (with a component) - 8. Fledex: Component","doc":"Instead of defining the complicated logic of the termometer indicator, we use this time a component that has all this logic build in. The component defines our configuration and all we have to do is to specify the mandatory (and if desired optional) parameters.\n\n```elixir\nalias Fledex.Component.Thermometer\n\nled_strip :john, Kino do\n  component(:thermo, Thermometer,\n    range: -20..40,\n    trigger: :temperature,\n    negative: :blue,\n    null: :may_green,\n    positive: :red,\n    marker: :davy_s_grey\n  )\nend\n```\n\nTo test our animation we fake again the temperature by simply publishing the desired temperature.\n\n```elixir\nFledex.Utils.PubSub.broadcast(:fledex, \"trigger\", {:trigger, %{temperature: 17.2}})\n```","ref":"8_fledex_component.html#the-weather-animation-with-a-component"},{"type":"extras","title":"What is a component - 8. Fledex: Component","doc":"The question now is just \"what is a component\"?\n\nThe component is simply a module that implements the `@behaviour Fledex.Component.Interface`. Only a single `configure/2` function is required that returns a `Fledex.Animation.Manager.configs_t` structure and thus can define anything you normaly would define within the led_strip macro, e.g. through the `animation`, `static`, ... macros.\n\nTo get the correct behaviour the component gets 2 parameters:\n\n1. The **name** of the component: Each animation gets it's own name, so does the component. It should be noted that an component can create several animations and the component should make sure to name each of those individually. The termometer has two \"animations\" the scale and the markers on the scale. The former gets the name of the component and the latter gets the name with `.helper` attached.\n2. a **keyword list of options**: The list of parameters allows us to configure our component. Each component can define their own set of settings. Probably a reoccuring parameter is `:trigger_name` wich allows us to configure runtime parameters, but this is by convention only.\n\nAs you have seen a component is nothing special but it allows to redefine a reusable structure. A component can be defined and distributed through an external library.\n\n<!-- livebook:{\"branch_parent_index\":1} -->","ref":"8_fledex_component.html#what-is-a-component"},{"type":"extras","title":"Netsted components - 8. Fledex: Component","doc":"We now take a slightly different approach for creating our component. As we have seen above a component is simply a configuration and the dsl is simply an easier way to write a config. Thus, we can reuse one within the other.\n\n```elixir\nalias Fledex.Component.Dot\n\nled_strip :nested_components, Kino do\n  component(:minute, Dot, color: :red, count: 60, trigger_name: :minute)\n  component(:hour, Dot, color: :blue, count: 24, trigger_name: :hour)\n\n  static :helper do\n    leds(5) |> light(:davy_s_grey, offset: 5) |> repeat(12)\n  end\nend\n```\n\n```elixir\nbroadcast_trigger(%{hour: 17, minute: 34})\n```\n\nThe interesting thing in the `Fledex.Component.Dot` component is that it actually defines the component by using the `Fledex.animation/3` macro. The code looks like the following\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\n  def configure(name, options) when is_atom(name) and is_list(options) do\n    use Fledex\n    # ... here comes some option extraction stuff\n    animation name do\n      triggers when is_map(triggers) and is_map_key(triggers, trigger_name) ->\n        leds(count) |> light(color, offset: triggers[trigger_name])\n      _ -> leds()\n    end\n  end\n\n```\n\n<!-- livebook:{\"branch_parent_index\":1} -->","ref":"8_fledex_component.html#netsted-components"},{"type":"extras","title":"The clock component - 8. Fledex: Component","doc":"The `Fledex.Component.Clock` component is an interesting one, because it defines several animations and even a static pattern. For that it uses the special `led_strip` driver `:config` that simply returns the config instead of delegating to the `Fledex.Animation.Manager`.\n\nEach animation requires its own unique name and this is accomplished with a small utility function that combines the strip name (the one we get in) and an additional fraction.\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\n  def configure(name, options) do\n    # ... here comes some option extraction stuff \n    use Fledex\n    led_strip name, :config do\n      component :minute, Dot, color: minute_color, count: 60, trigger_name: create_name(trigger_name, :minute)\n      component :hour, Dot, color: hour_color, count: 24, trigger_name: create_name(trigger_name, :hour)\n      static create_name(trigger_name, :helper) do\n        leds(5) |> light(helper_color, offset: 5) |> repeat(12)\n      end\n    end\n  end\n\n```\n\nAs you can see it defines, more or less, the same animations as our example above. Thus, instead of us defining the different animations, the component is doing this for us.\nTo use the component, we now simply have to use the clock and pass in the necessary options, and that's it!\n\n```elixir\nalias Fledex.Component.Clock\nimport Crontab.CronExpression\n\nled_strip :nested_components2, Kino do\n  component(:myclock, Clock, trigger_name: :clock)\nend\n```\n\nAnd to see the correct time, we only need to publish the appropriate time. When we do so we shouldn't forget that the animations are reacting to two triggers that we passed in. We need to publish the triggers `:clock_hour` and `:clock_minute` as triggers (or if we like add even the `:clock_second` too).\n\n```elixir\nbroadcast_trigger(%{clock_hour: 17, clock_minute: 34, clock_second: 12})\n```\n\n<!-- livebook:{\"branch_parent_index\":1} -->","ref":"8_fledex_component.html#the-clock-component"},{"type":"extras","title":"A job to drive the clock - 8. Fledex: Component","doc":"Regular updates is something so common that we'll look at the `job` macro that will allow us to schedule udpates in regular intervals. We will take a closer look at this in [another livebook](./9_fledex_jobs.livemd) but here is already a sneak preview.\n\n```elixir\nalias Fledex.Component.Clock\n\nled_strip :nested_components3, Kino do\n  component(:myclock2, Clock, trigger_name: :clock2)\n\n  job :clock, ~e[* * * * * * *]e do\n    %DateTime{hour: hour, minute: minute, second: second} = DateTime.utc_now()\n\n    broadcast_trigger(%{\n      clock2_hour: hour,\n      clock2_minute: minute,\n      clock2_second: second\n    })\n  end\nend\n```\n\n<!-- livebook:{\"branch_parent_index\":1} -->","ref":"8_fledex_component.html#a-job-to-drive-the-clock"},{"type":"extras","title":"Debugging tricks - 8. Fledex: Component","doc":"When you develop components it can sometimes be difficult to debug them especially if you nest other components into your own. You easily will run into the question \"Why does my component not show what I expect it to show?\". The issue is usually that the triggers are not properly configured. But figuring out where it goes wrong is not so easy.\n\nThere is a quite simply trick to debug a component by adding the following animation\nto your component:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\n  animation :logger do\n    %{logger: logger} = trigger ->\n      if rem(logger, 10) == 0 do\n        IO.puts \"logger: #{inspect trigger}\"\n      end\n      {leds(), %{trigger | logger: logger+1}}\n    trigger -> {leds(), Map.put_new(trigger, :logger, 0)}\n  end\n```\n\nIt will log the triggers in regular intervals so you see what the component receives and you can then compare it with what you would expect.\nAs you can see this animation has no effect on your animation, because it always returns empty `leds()`. We only use the side effect (writing to `IO.puts`) of this animation.","ref":"8_fledex_component.html#debugging-tricks"},{"type":"extras","title":"9. Fledex: Job","doc":"<!--\nCopyright 2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# 9. Fledex: Job\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.5\"},\n  {:jason, \"~>1.2\"}\n])\n```","ref":"9_fledex_jobs.html"},{"type":"extras","title":"Setup - 9. Fledex: Job","doc":"Let's start with the usual setup\n\n```elixir\nuse Fledex\n```\n\n<!-- livebook:{\"branch_parent_index\":0} -->","ref":"9_fledex_jobs.html#setup"},{"type":"extras","title":"Clock with job - 9. Fledex: Job","doc":"In the last couple of examples it was always a bit cumbersome to get those updates in regular intervals. at every screen refresh we needed to do calculate something or we needed a decently complicated `GenServer` to do tasks in regular intervals.\n\nLet me introduce you to `job`. It allows us to take care of repetitive work by easily specifying a cron-job. All you need are:\n\n* a name for the job that identifies it uniquely\n* a schedule when the job should run (see [this cheatsheet](https://hexdocs.pm/crontab/cron_notation.html#expressions) for the possibilities)\n* and a function that should be executed, probably one that will at the end publish an event with `Fledex.Utils.PubSub.broadcast_trigger/1`\n\nThe example here implements our clock example with the `Fledex.Component.Clock` component (see the previous chapter) and uses the `job` macro to schedule the updates.\n\n```elixir\nalias Fledex.Component.Clock\n\nled_strip :nested_components2, Kino do\n  component(\n    :clock,\n    Clock,\n    trigger_name: {:clock_hour, :clock_minute, :clock_second}\n  )\n\n  job :clock, ~e[@secondly]e do\n    date_time = DateTime.utc_now()\n\n    broadcast_trigger(%{\n      clock_hour: date_time.hour,\n      clock_minute: date_time.minute,\n      clock_second: date_time.second\n    })\n  end\nend\n```\n\n<!-- livebook:{\"branch_parent_index\":0} -->","ref":"9_fledex_jobs.html#clock-with-job"},{"type":"extras","title":"Weather station with job - 9. Fledex: Job","doc":"Our weather station example becomes now much easier, because we don't have to implement the timer functinality ourselves. We can simply implement a job for that.\n\nAs before we need to make sure we can make http calls by starting the appropriate services\n\n```elixir\n:inets.start()\n:ssl.start()\n```\n\nNow we are ready to define our new simplified weather station using:\n\n* defining an `Fledex.led_strip`\n* using the `Fledex.Component.Thermometer` component as `Fledex.component`\n* and defining a `Fledex.job` that runs every 15min (making sure we call it as soon as we define it even though it might not be time for it yet, by specifying `run_once: true`)\n\n**Note:** we are using the normal crontab job pattern, whereas above we used the extended version (with second precision) above.\n\n```elixir\nalias Fledex.Component.Thermometer\n\nled_strip :john, Kin do\n  component(:thermo, Thermometer,\n    range: -20..40,\n    trigger: :temperature,\n    negative: :blue,\n    null: :may_green,\n    positive: :red,\n    marker: :davy_s_grey\n  )\n\n  job :fetcher, ~e[*/15 * * * * *], run_once: true do\n    url =\n      ~c\"https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m\"\n\n    {:ok, resp} =\n      :httpc.request(:get, {url, []}, [], body_format: :binary)\n\n    {{_, 200, ~c\"OK\"}, _headers, body} = resp\n    json = Jason.decode!(body)\n    temperature = json[\"current\"][\"temperature_2m\"]\n    broadcast_trigger(%{temperature: temperature})\n  end\nend\n```","ref":"9_fledex_jobs.html#weather-station-with-job"},{"type":"extras","title":"Security Policy","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# Security Policy","ref":"security.html"},{"type":"extras","title":"Supported Versions - Security Policy","doc":"Even though security issues are quite unlikely in this library, if issues\nare discovered, I'm happy to fix those (as far as reasonablly possible). \nCurrently only the latest version is supported","ref":"security.html#supported-versions"},{"type":"extras","title":"Reporting a Vulnerability - Security Policy","doc":"If you think you found a vulnerability and want to report it, then send an\nemail to fledex at reik.org","ref":"security.html#reporting-a-vulnerability"},{"type":"extras","title":"CLA","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->","ref":"cla.html"},{"type":"extras","title":"Fiduciary License Agreement 2.0 - CLA","doc":"based on the","ref":"cla.html#fiduciary-license-agreement-2-0"},{"type":"extras","title":"Individual Contributor Exclusive License Agreement - CLA","doc":"## (including the Traditional Patent License OPTION)\n\nThank you for your interest in contributing to a-maze-d's Fledex (\"We\" or \"Us\").\n\nThe purpose of this contributor agreement (\"Agreement\") is to clarify and document the rights granted by contributors to Us. To make this document effective, please follow the instructions at https://github.com/a-maze-d/fledex/blob/main/CONTRIBUTING.md.","ref":"cla.html#individual-contributor-exclusive-license-agreement"},{"type":"extras","title":"0\\. Preamble - CLA","doc":"Software is deeply embedded in all aspects of our lives and it is important that it empower, rather than restrict us. Free Software gives everybody the rights to use, understand, adapt and share software. These rights help support other fundamental freedoms like freedom of speech, press and privacy.\n\nDevelopment of Free Software can follow many patterns. In some cases whole development is handled by a sole programmer or a small group of people. But usually, the creation and maintenance of software is a complex process that requires the contribution of many individuals. This also affects who owns the rights to the software. In the latter case, rights in software are owned jointly by a great number of individuals.\n\nTo tackle this issue some projects require a full copyright assignment to be signed by all contributors. The problem with such assignments is that they often lack checks and balances that would protect the contributors from potential abuse of power from the new copyright holder.\n\nFSFE’s Fiduciary License Agreement (FLA) was created by the Free Software Foundation Europe e.V. with just that in mind – to concentrate all deciding power within one entity and prevent fragmentation of rights on one hand, while on the other preventing that single entity from abusing its power. The main aim is to ensure that the software covered under the FLA will forever remain Free Software.\n\nThis process only serves for the transfer of economic rights. So-called moral rights (e.g. authors right to be identified as author) remain with the original author(s) and are inalienable.","ref":"cla.html#0-preamble"},{"type":"extras","title":"How to use this FLA - CLA","doc":"If You are an employee and have created the Contribution as part of your employment, You need to have Your employer approve this Agreement or sign the Entity version of this document. If You do not own the Copyright in the entire work of authorship, any other author of the Contribution should also sign this – in any event, please contact Us at fledex@reik.org","ref":"cla.html#how-to-use-this-fla"},{"type":"extras","title":"1\\. Definitions - CLA","doc":"**\"You\"** means the individual Copyright owner who Submits a Contribution to Us.\n\n**\"Legal Entity\"** means an entity that is not a natural person.\n\n**\"Affiliate\"** means any other Legal Entity that controls, is controlled by, or under common control with that Legal Entity. For the purposes of this definition, \"control\" means (i) the power, direct or indirect, to cause the direction or management of such Legal Entity, whether by contract or otherwise, (ii) ownership of fifty percent (50%) or more of the outstanding shares or securities that vote to elect the management or other persons who direct such Legal Entity or (iii) beneficial ownership of such entity.\n\n**\"Contribution\"** means any original work of authorship, including any original modifications or additions to an existing work of authorship, Submitted by You to Us, in which You own the Copyright.\n\n**\"Copyright\"** means all rights protecting works of authorship, including copyright, moral and neighboring rights, as appropriate, for the full term of their existence.\n\n**\"Material\"** means the software or documentation made available by Us to third parties. When this Agreement covers more than one software project, the Material means the software or documentation to which the Contribution was Submitted. After You Submit the Contribution, it may be included in the Material.\n\n**\"Submit\"** means any act by which a Contribution is transferred to Us by You by means of tangible or intangible media, including but not limited to electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, Us, but excluding any transfer that is conspicuously marked or otherwise designated in writing by You as \"Not a Contribution.\"\n\n**\"Documentation\"** means any non-software portion of a Contribution.","ref":"cla.html#1-definitions"},{"type":"extras","title":"2\\. License grant - CLA","doc":"#### 2.1 Copyright license to Us\n\nSubject to the terms and conditions of this Agreement, You hereby grant to Us a worldwide, royalty-free, exclusive, perpetual and irrevocable (except as stated in Section 8.2) license, with the right to transfer an unlimited number of non-exclusive licenses or to grant sublicenses to third parties, under the Copyright covering the Contribution to use the Contribution by all means, including, but not limited to:\n\n* publish the Contribution,\n* modify the Contribution,\n* prepare derivative works based upon or containing the Contribution and/or to combine the Contribution with other Materials,\n* reproduce the Contribution in original or modified form,\n* distribute, to make the Contribution available to the public, display and publicly perform the Contribution in original or modified form.\n\n#### 2.2 Moral rights\n\nMoral Rights remain unaffected to the extent they are recognized and not waivable by applicable law. Notwithstanding, You may add your name to the attribution mechanism customary used in the Materials you Contribute to, such as the header of the source code files of Your Contribution, and We will respect this attribution when using Your Contribution.\n\n#### 2.3 Copyright license back to You\n\nUpon such grant of rights to Us, We immediately grant to You a worldwide, royalty-free, non-exclusive, perpetual and irrevocable license, with the right to transfer an unlimited number of non-exclusive licenses or to grant sublicenses to third parties, under the Copyright covering the Contribution to use the Contribution by all means, including, but not limited to:\n\n* publish the Contribution,\n* modify the Contribution,\n* prepare derivative works based upon or containing the Contribution and/or to combine the Contribution with other Materials,\n* reproduce the Contribution in original or modified form,\n* distribute, to make the Contribution available to the public, display and publicly perform the Contribution in original or modified form.\n\nThis license back is limited to the Contribution and does not provide any rights to the Material.","ref":"cla.html#2-license-grant"},{"type":"extras","title":"3\\. Patents - CLA","doc":"#### 3.1 Patent license\n\nSubject to the terms and conditions of this Agreement You hereby grant to Us and to recipients of Materials distributed by Us a worldwide, royalty-free, non-exclusive, perpetual and irrevocable (except as stated in Section 3.2) patent license, with the right to transfer an unlimited number of non-exclusive licenses or to grant sublicenses to third parties, to make, have made, use, sell, offer for sale, import and otherwise transfer the Contribution and the Contribution in combination with any Material (and portions of such combination). This license applies to all patents owned or controlled by You, whether already acquired or hereafter acquired, that would be infringed by making, having made, using, selling, offering for sale, importing or otherwise transferring of Your Contribution(s) alone or by combination of Your Contribution(s) with any Material.\n\n#### 3.2 Revocation of patent license\n\nYou reserve the right to revoke the patent license stated in section 3.1 if We make any infringement claim that is targeted at your Contribution and not asserted for a Defensive Purpose. An assertion of claims of the Patents shall be considered for a \"Defensive Purpose\" if the claims are asserted against an entity that has filed, maintained, threatened, or voluntarily participated in a patent infringement lawsuit against Us or any of Our licensees.","ref":"cla.html#3-patents"},{"type":"extras","title":"4\\. License obligations by Us - CLA","doc":"We agree to (sub)license the Contribution or any Materials containing, based on or derived from your Contribution under the terms of any licenses the Free Software Foundation classifies as Free Software License and which are approved by the Open Source Initiative as Open Source licenses.\n\nWe agree to license patents owned or controlled by You only to the extent necessary to (sub)license Your Contribution(s) and the combination of Your Contribution(s) with the Material under the terms of any licenses the Free Software Foundation classifies as Free Software licenses and which are approved by the Open Source Initiative as Open Source licenses..","ref":"cla.html#4-license-obligations-by-us"},{"type":"extras","title":"5. Disclaimer - CLA","doc":"THE CONTRIBUTION IS PROVIDED \"AS IS\". MORE PARTICULARLY, ALL EXPRESS OR IMPLIED WARRANTIES INCLUDING, WITHOUT LIMITATION, ANY IMPLIED WARRANTY OF SATISFACTORY QUALITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE EXPRESSLY DISCLAIMED BY YOU TO US AND BY US TO YOU. TO THE EXTENT THAT ANY SUCH WARRANTIES CANNOT BE DISCLAIMED, SUCH WARRANTY IS LIMITED IN DURATION AND EXTENT TO THE MINIMUM PERIOD AND EXTENT PERMITTED BY LAW.","ref":"cla.html#5-disclaimer"},{"type":"extras","title":"6. Consequential damage waiver - CLA","doc":"TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, IN NO EVENT WILL YOU OR WE BE LIABLE FOR ANY LOSS OF PROFITS, LOSS OF ANTICIPATED SAVINGS, LOSS OF DATA, INDIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL AND EXEMPLARY DAMAGES ARISING OUT OF THIS AGREEMENT REGARDLESS OF THE LEGAL OR EQUITABLE THEORY (CONTRACT, TORT OR OTHERWISE) UPON WHICH THE CLAIM IS BASED.","ref":"cla.html#6-consequential-damage-waiver"},{"type":"extras","title":"7. Approximation of disclaimer and damage waiver - CLA","doc":"IF THE DISCLAIMER AND DAMAGE WAIVER MENTIONED IN SECTION 5. AND SECTION 6. CANNOT BE GIVEN LEGAL EFFECT UNDER APPLICABLE LOCAL LAW, REVIEWING COURTS SHALL APPLY LOCAL LAW THAT MOST CLOSELY APPROXIMATES AN ABSOLUTE WAIVER OF ALL CIVIL OR CONTRACTUAL LIABILITY IN CONNECTION WITH THE CONTRIBUTION.","ref":"cla.html#7-approximation-of-disclaimer-and-damage-waiver"},{"type":"extras","title":"8. Term - CLA","doc":"8.1 This Agreement shall come into effect upon Your acceptance of the terms and conditions.\n\n8.2 This Agreement shall apply for the term of the copyright and patents licensed here. However, You shall have the right to terminate the Agreement if We do not fulfill the obligations as set forth in Section 4. Such termination must be made in writing.\n\n8.3 In the event of a termination of this Agreement Sections 5., 6., 7., 8., and 9. shall survive such termination and shall remain in full force thereafter. For the avoidance of doubt, Free and Open Source Software (sub)licenses that have already been granted for Contributions at the date of the termination shall remain in full force after the termination of this Agreement.","ref":"cla.html#8-term"},{"type":"extras","title":"9. Miscellaneous - CLA","doc":"9.1 This Agreement and all disputes, claims, actions, suits or other proceedings arising out of this agreement or relating in any way to it shall be governed by the laws of Hungary excluding its private international law provisions.\n\n9.2 This Agreement sets out the entire agreement between You and Us for Your Contributions to Us and overrides all other agreements or understandings.\n\n9.3 In case of Your death, this agreement shall continue with Your heirs. In case of more than one heir, all heirs must exercise their rights through a commonly authorized person.\n\n9.4 If any provision of this Agreement is found void and unenforceable, such provision will be replaced to the extent possible with a provision that comes closest to the meaning of the original provision and that is enforceable. The terms and conditions set forth in this Agreement shall apply notwithstanding any failure of essential purpose of this Agreement or any limited remedy to the maximum extent possible under law.\n\n9.5 You agree to notify Us of any facts or circumstances of which you become aware that would make this Agreement inaccurate in any respect.","ref":"cla.html#9-miscellaneous"},{"type":"extras","title":"You - CLA","doc":"Date:\n\nName:\n\nTitle:\n\nAddress:","ref":"cla.html#you"},{"type":"extras","title":"Us - CLA","doc":"Date:\n\nName:\n\nTitle:\n\nAddress:\n\n#### Recreate this Contributor License Agreement\n\n[https://contributoragreements.org/ca-cla-chooser/?beneficiary-name=a-maze-d&project-name=Fledex&project-website=https%3A%2F%2Fgithub.com%2Fa-maze-d%2Ffledex&project-email=fledex%40reik.org&process-url=https%3A%2F%2Fgithub.com%2Fa-maze-d%2Ffledex%2Fblob%2Fmain%2FCONTRIBUTING.md&project-jurisdiction=Hungary&agreement-exclusivity=exclusive&fsfe-compliance=&fsfe-fla=&outbound-option=fsfe&outboundlist=&outboundlist-custom=&medialist=\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_\\_&patent-option=Traditional&your-date=&your-name=&your-title=&your-address=&your-patents=&pos=apply&action=](https://contributoragreements.org/ca-cla-chooser/?beneficiary-name=a-maze-d&project-name=Fledex&project-website=https%3A%2F%2Fgithub.com%2Fa-maze-d%2Ffledex&project-email=fledex%40reik.org&process-url=https%3A%2F%2Fgithub.com%2Fa-maze-d%2Ffledex%2Fblob%2Fmain%2FCONTRIBUTING.md&project-jurisdiction=Hungary&agreement-exclusivity=exclusive&fsfe-compliance=&fsfe-fla=&outbound-option=fsfe&outboundlist=&outboundlist-custom=&medialist=____________________&patent-option=Traditional&your-date=&your-name=&your-title=&your-address=&your-patents=&pos=apply&action=)\n\n[](https://contributoragreements.org/ca-cla-chooser/?beneficiary-name=a-maze-d&project-name=Fledex&project-website=https%3A%2F%2Fgithub.com%2Fa-maze-d%2Ffledex&project-email=fledex%40reik.org&process-url=https%3A%2F%2Fgithub.com%2Fa-maze-d%2Ffledex%2Fblob%2Fmain%2FCONTRIBUTING.md&project-jurisdiction=Hungary&agreement-exclusivity=exclusive&fsfe-compliance=&fsfe-fla=&outbound-option=fsfe&outboundlist=&outboundlist-custom=&medialist=____________________&patent-option=Traditional&your-date=&your-name=&your-title=&your-address=&your-patents=&pos=apply&action=)\n\n[](https://contributoragreements.org/ca-cla-chooser/?beneficiary-name=a-maze-d&project-name=Fledex&project-website=https%3A%2F%2Fgithub.com%2Fa-maze-d%2Ffledex&project-email=fledex%40reik.org&process-url=https%3A%2F%2Fgithub.com%2Fa-maze-d%2Ffledex%2Fblob%2Fmain%2FCONTRIBUTING.md&project-jurisdiction=Hungary&agreement-exclusivity=exclusive&fsfe-compliance=&fsfe-fla=&outbound-option=fsfe&outboundlist=&outboundlist-custom=&medialist=____________________&patent-option=Traditional&your-date=&your-name=&your-title=&your-address=&your-patents=&pos=apply&action=)","ref":"cla.html#us"},{"type":"extras","title":"Contributing","doc":"<!--\nCopyright 2023-2024, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n# Contributing","ref":"contributing.html"},{"type":"extras","title":"Introduction - Contributing","doc":"Contributions to this library are very welcome. I do reserve the right to decide on what will (and will not) be added to the library. Thus, before doing any bigger changes you might want to ask for feedback.","ref":"contributing.html#introduction"},{"type":"extras","title":"Pull Requests - Contributing","doc":"By making a pull request you agree to the [CLA (= Contributor License Agreement)](CLA.md) and during your pull request you will have to sign-off on them.","ref":"contributing.html#pull-requests"},{"type":"extras","title":"CLA outside from pull requests - Contributing","doc":"You can also agree to the agreement outside a pull request (even though that's more complicated, but might make sense for companies). Please contact me in that case","ref":"contributing.html#cla-outside-from-pull-requests"},{"type":"extras","title":"Right - Contributing","doc":"As a contributor you have the right to add yourself to the [Contributors file](CONTRIBUTORS.md).","ref":"contributing.html#right"},{"type":"extras","title":"Contributors","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n# Contributors\nI would like to say thank you to all those people that have directly or indirectly contributed. If you think you should be on this list, do not hesitate to ping me.\n\n* christhekeele (on Elixirforum for helping with my macro issues)\n* sodapopcan and hauleth (on Elixirforum for helping with my guard issues)","ref":"contributors.html"},{"type":"extras","title":"Contributor Covenant Code of Conduct","doc":"<!--\nCopyright 2023, Matthias Reik  \n\nSPDX-License-Identifier: Apache-2.0\n-->\n\n# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Contributor Covenant Code of Conduct","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, caste, color, religion, or sexual\nidentity and orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Contributor Covenant Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n* Demonstrating empathy and kindness toward other people\n* Being respectful of differing opinions, viewpoints, and experiences\n* Giving and gracefully accepting constructive feedback\n* Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n* Focusing on what is best not just for us as individuals, but for the overall\n  community\n\nExamples of unacceptable behavior include:\n\n* The use of sexualized language or imagery, and sexual attention or advances of\n  any kind\n* Trolling, insulting or derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or email address,\n  without their explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Contributor Covenant Code of Conduct","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Contributor Covenant Code of Conduct","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official email address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Contributor Covenant Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement at\n[INSERT CONTACT METHOD].\nAll complaints will be reviewed and investigated promptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Enforcement Guidelines - Contributor Covenant Code of Conduct","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:","ref":"code_of_conduct.html#enforcement-guidelines"},{"type":"extras","title":"1. Correction - Contributor Covenant Code of Conduct","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.","ref":"code_of_conduct.html#1-correction"},{"type":"extras","title":"2. Warning - Contributor Covenant Code of Conduct","doc":"**Community Impact**: A violation through a single incident or series of\nactions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or permanent\nban.","ref":"code_of_conduct.html#2-warning"},{"type":"extras","title":"3. Temporary Ban - Contributor Covenant Code of Conduct","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.","ref":"code_of_conduct.html#3-temporary-ban"},{"type":"extras","title":"4. Permanent Ban - Contributor Covenant Code of Conduct","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior, harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within the\ncommunity.","ref":"code_of_conduct.html#4-permanent-ban"},{"type":"extras","title":"Attribution - Contributor Covenant Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.1, available at\n[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1].\n\nCommunity Impact Guidelines were inspired by\n[Mozilla's code of conduct enforcement ladder][Mozilla CoC].\n\nFor answers to common questions about this code of conduct, see the FAQ at\n[https://www.contributor-covenant.org/faq][FAQ]. Translations are available at\n[https://www.contributor-covenant.org/translations][translations].\n\n[homepage]: https://www.contributor-covenant.org\n[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html\n[Mozilla CoC]: https://github.com/mozilla/diversity\n[FAQ]: https://www.contributor-covenant.org/faq\n[translations]: https://www.contributor-covenant.org/translations","ref":"code_of_conduct.html#attribution"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}